import{u as V,e as A,f as E,h as I,_ as $}from"./index.e4ceb7bd.js";import{u as z,N as H,M as g,T as W,F as j}from"./responsive.3bd8a197.js";/* empty css               */import{d as x,c as n,aP as G,C as a,aE as s,aH as o,aI as t,b2 as K,b3 as C,b4 as U,j as w,w as q,p as J,o as O,D as Q,aF as r,b5 as X,G as k,E as Y,b6 as Z,u as S,F as ee,b7 as ae,b8 as te,b9 as oe,ba as se}from"./arco.2329baeb.js";import{u as ne,e as le}from"./vue.46369188.js";import"./chart.db8aed57.js";/* empty css               *//* empty css              *//* empty css               */const ue=x({__name:"page-layout",setup(L){const c=V(),e=n(()=>c.getCacheList);return(v,f)=>{const _=G("router-view");return a(),s(_,null,{default:o(({Component:i,route:l})=>[t(K,{name:"fade",mode:"out-in",appear:""},{default:o(()=>[l.meta.ignoreCache?(a(),s(C(i),{key:l.fullPath})):(a(),s(U,{key:1,include:e.value},[(a(),s(C(i),{key:l.fullPath}))],1032,["include"]))]),_:2},1024)]),_:1})}}}),re={key:0,class:"layout-navbar"},ce={class:"menu-wrapper"},ie="60px",pe=x({__name:"default-layout",setup(L){const c=w(!1),e=A(),v=E(),f=ne(),_=le(),i=I();z(!0);const l=n(()=>e.navbar),y=n(()=>e.menu&&!e.topMenu),m=n(()=>e.hideMenu),M=n(()=>e.footer),b=n(()=>e.menuCollapse?48:e.menuWidth),B=n(()=>e.menuCollapse),T=n(()=>{const u=y.value&&!m.value?{paddingLeft:`${b.value}px`}:{},h=l.value?{paddingTop:ie}:{};return{...u,...h}}),D=u=>{!c.value||e.updateSettings({menuCollapse:u})};q(()=>v.role,u=>{u&&!i.accessRouter(_)&&f.push({name:"notFound"})});const p=w(!1),F=()=>{p.value=!1};return J("toggleDrawerMenu",()=>{p.value=!p.value}),O(()=>{c.value=!0}),(u,h)=>{const N=ae,P=te,R=oe,d=se;return a(),s(d,{class:ee(["layout",{mobile:S(e).hideMenu}])},{default:o(()=>[l.value?(a(),Q("div",re,[t(H)])):r("",!0),t(d,null,{default:o(()=>[t(d,null,{default:o(()=>[y.value?X((a(),s(N,{key:0,class:"layout-sider",breakpoint:"xl",collapsed:B.value,collapsible:!0,width:b.value,style:k({paddingTop:l.value?"60px":""}),"hide-trigger":!0,onCollapse:D},{default:o(()=>[Y("div",ce,[t(g)])]),_:1},8,["collapsed","width","style"])),[[Z,!m.value]]):r("",!0),m.value?(a(),s(P,{key:1,visible:p.value,placement:"left",footer:!1,"mask-closable":"",closable:!1,onCancel:F},{default:o(()=>[t(g)]),_:1},8,["visible"])):r("",!0),t(d,{class:"layout-content",style:k(T.value)},{default:o(()=>[S(e).tabBar?(a(),s(W,{key:0})):r("",!0),t(R,null,{default:o(()=>[t(ue)]),_:1}),M.value?(a(),s(j,{key:1})):r("",!0)]),_:1},8,["style"])]),_:1})]),_:1})]),_:1},8,["class"])}}});const Ce=$(pe,[["__scopeId","data-v-428bc3c1"]]);export{Ce as default};
