.layout[data-v-428bc3c1]{width:100%;height:100%}.layout-navbar[data-v-428bc3c1]{position:fixed;top:0;left:0;z-index:100;width:100%;height:60px}.layout-sider[data-v-428bc3c1]{position:fixed;top:0;left:0;z-index:99;height:100%;transition:all .2s cubic-bezier(.34,.69,.1,1)}.layout-sider[data-v-428bc3c1]:after{position:absolute;top:0;right:-1px;display:block;width:1px;height:100%;background-color:var(--color-border);content:""}.layout-sider[data-v-428bc3c1]>.arco-layout-sider-children{overflow-y:hidden}.menu-wrapper[data-v-428bc3c1]{height:100%;overflow:auto;overflow-x:hidden}.menu-wrapper[data-v-428bc3c1] .arco-menu ::-webkit-scrollbar{width:12px;height:4px}.menu-wrapper[data-v-428bc3c1] .arco-menu ::-webkit-scrollbar-thumb{border:4px solid transparent;background-clip:padding-box;border-radius:7px;background-color:var(--color-text-4)}.menu-wrapper[data-v-428bc3c1] .arco-menu ::-webkit-scrollbar-thumb:hover{background-color:var(--color-text-3)}.layout-content[data-v-428bc3c1]{min-height:100vh;overflow-y:hidden;background-color:var(--color-fill-2);transition:padding .2s cubic-bezier(.34,.69,.1,1)}
