.login-wrapper[data-v-1667e839]{min-height:100vh;display:flex;justify-content:center;align-items:center;background:#f8f9fa}.login-container[data-v-1667e839]{width:420px;border-radius:12px;box-shadow:0 4px 24px #0000000a;border:1px solid var(--color-border);margin:20px}.login-container[data-v-1667e839]{width:420px;border-radius:12px;box-shadow:0 4px 24px #0000000a;border:1px solid var(--color-border)}.login-header[data-v-1667e839]{text-align:center;margin-bottom:40px}.login-header h1[data-v-1667e839]{font-size:32px;font-weight:500;color:var(--color-text-1);margin-bottom:8px}.login-header p[data-v-1667e839]{color:var(--color-text-3);font-size:15px}.custom-input[data-v-1667e839]{height:48px;border-radius:6px;padding-left:40px}[data-v-1667e839] .arco-input-prefix{margin-right:12px}.login-btn[data-v-1667e839]{width:100%;height:48px;border-radius:6px;margin-top:15px;font-size:16px}.divider[data-v-1667e839]{margin:30px 0;border-bottom:1px solid var(--color-border);position:relative;text-align:center}.divider span[data-v-1667e839]{position:relative;top:-10px;background:var(--color-bg-2);padding:0 15px;color:var(--color-text-3);font-size:13px}.social-login[data-v-1667e839]{display:flex;justify-content:center;gap:15px;margin-top:25px}.social-icon[data-v-1667e839]{width:40px;height:40px;border:1px solid var(--color-border);background-color:var(--color-bg-2)}.social-icon[data-v-1667e839]:hover{background-color:var(--color-bg-3)}
