.arco-result{box-sizing:border-box;width:100%;padding:32px 32px 24px}.arco-result-icon{margin-bottom:16px;font-size:20px;text-align:center}.arco-result-icon-tip{display:flex;width:45px;height:45px;align-items:center;justify-content:center;border-radius:50%;margin:0 auto}.arco-result-icon-custom .arco-result-icon-tip{font-size:45px;color:inherit;width:unset;height:unset}.arco-result-icon-success .arco-result-icon-tip{color:rgb(var(--success-6));background-color:var(--color-success-light-1)}.arco-result-icon-error .arco-result-icon-tip{color:rgb(var(--danger-6));background-color:var(--color-danger-light-1)}.arco-result-icon-info .arco-result-icon-tip{color:rgb(var(--primary-6));background-color:var(--color-primary-light-1)}.arco-result-icon-warning .arco-result-icon-tip{color:rgb(var(--warning-6));background-color:var(--color-warning-light-1)}.arco-result-icon-404,.arco-result-icon-403,.arco-result-icon-500{padding-top:24px}.arco-result-icon-404 .arco-result-icon-tip,.arco-result-icon-403 .arco-result-icon-tip,.arco-result-icon-500 .arco-result-icon-tip{width:92px;height:92px;line-height:92px}.arco-result-title{color:var(--color-text-1);font-weight:500;font-size:14px;line-height:1.5715;text-align:center}.arco-result-subtitle{color:var(--color-text-2);font-size:14px;line-height:1.5715;text-align:center}.arco-result-extra{margin-top:20px;text-align:center}.arco-result-content{margin-top:20px}.container[data-v-380457ca]{padding:0 20px 20px;height:calc(100% - 40px)}.container[data-v-380457ca] .content{position:relative;display:flex;flex-direction:column;align-items:center;justify-content:center;height:100%;text-align:center;background-color:var(--color-bg-1);border-radius:4px}
