import{_ as c}from"./index.e4ceb7bd.js";/* empty css               */import{d as _,bp as r,C as i,D as d,aI as e,E as o,aH as p,aJ as u,aP as m,aU as l}from"./arco.2329baeb.js";import{u as x}from"./vue.46369188.js";import"./chart.db8aed57.js";const f={class:"container"},v={class:"content"},B={class:"operation-row"},b={name:"404"},k=_({...b,setup(y){return x(),(h,t)=>{const s=m("Breadcrumb"),a=r,n=l;return i(),d("div",f,[e(s,{items:"exception / 404"}),o("div",v,[e(a,{class:"result",status:"404",subtitle:"The resource does not exist"}),o("div",B,[e(n,{key:"back",type:"primary"},{default:p(()=>t[0]||(t[0]=[u(" Back ")])),_:1})])])])}}});const I=c(k,[["__scopeId","data-v-380457ca"]]);export{I as default};
