.arco-space{display:inline-flex}.arco-space-horizontal .arco-space-item{display:flex;align-items:center}.arco-space-vertical{flex-direction:column}.arco-space-align-baseline{align-items:baseline}.arco-space-align-start{align-items:flex-start}.arco-space-align-end{align-items:flex-end}.arco-space-align-center{align-items:center}.arco-space-wrap{flex-wrap:wrap}.arco-space-fill{display:flex}
