.arco-modal-container{position:fixed;top:0;right:0;bottom:0;left:0}.arco-modal-mask{position:absolute;top:0;right:0;bottom:0;left:0;background-color:var(--color-mask-bg)}.arco-modal-wrapper{position:absolute;top:0;right:0;bottom:0;left:0;overflow:auto;text-align:center}.arco-modal-wrapper.arco-modal-wrapper-align-center{white-space:nowrap}.arco-modal-wrapper.arco-modal-wrapper-align-center:after{display:inline-block;width:0;height:100%;vertical-align:middle;content:""}.arco-modal-wrapper.arco-modal-wrapper-align-center .arco-modal{top:0;vertical-align:middle}.arco-modal-wrapper.arco-modal-wrapper-moved{text-align:left}.arco-modal-wrapper.arco-modal-wrapper-moved .arco-modal{top:0;vertical-align:top}.arco-modal{position:relative;top:100px;display:inline-block;width:520px;margin:0 auto;line-height:1.5715;white-space:initial;text-align:left;background-color:var(--color-bg-3);border-radius:var(--border-radius-medium)}.arco-modal-draggable .arco-modal-header{cursor:move}.arco-modal-header{display:flex;flex-shrink:0;align-items:center;box-sizing:border-box;width:100%;height:48px;padding:0 20px;border-bottom:1px solid var(--color-neutral-3)}.arco-modal-header .arco-modal-title{display:flex;flex:1;align-items:center;justify-content:center}.arco-modal-header .arco-modal-title-align-start{justify-content:flex-start}.arco-modal-header .arco-modal-title-align-center{justify-content:center}.arco-modal-body{position:relative;padding:24px 20px;overflow:auto;color:var(--color-text-1);font-size:14px}.arco-modal-footer{flex-shrink:0;box-sizing:border-box;width:100%;padding:16px 20px;text-align:right;border-top:1px solid var(--color-neutral-3)}.arco-modal-footer>.arco-btn:not(:nth-child(1)){margin-left:12px}.arco-modal-close-btn{margin-left:-12px;color:var(--color-text-1);font-size:12px;cursor:pointer}.arco-modal-title{color:var(--color-text-1);font-weight:500;font-size:16px}.arco-modal-title-icon{margin-right:10px;font-size:18px;vertical-align:-.15em}.arco-modal-title-icon .arco-icon-info-circle-fill{color:rgb(var(--primary-6))}.arco-modal-title-icon .arco-icon-check-circle-fill{color:rgb(var(--success-6))}.arco-modal-title-icon .arco-icon-exclamation-circle-fill{color:rgb(var(--warning-6))}.arco-modal-title-icon .arco-icon-close-circle-fill{color:rgb(var(--danger-6))}.arco-modal-simple{width:400px;padding:24px 32px 32px}.arco-modal-simple .arco-modal-header,.arco-modal-simple .arco-modal-footer{height:unset;padding:0;border:none}.arco-modal-simple .arco-modal-header{margin-bottom:24px}.arco-modal-simple .arco-modal-title{justify-content:center}.arco-modal-simple .arco-modal-title-align-start{justify-content:flex-start}.arco-modal-simple .arco-modal-title-align-center{justify-content:center}.arco-modal-simple .arco-modal-footer{margin-top:32px;text-align:center}.arco-modal-simple .arco-modal-body{padding:0}.arco-modal-fullscreen{top:0;display:inline-flex;flex-direction:column;box-sizing:border-box;width:100%;height:100%}.arco-modal-fullscreen .arco-modal-footer{margin-top:auto}.zoom-modal-enter-from,.zoom-modal-appear-from{transform:scale(.5);opacity:0}.zoom-modal-enter-to,.zoom-modal-appear-to{transform:scale(1);opacity:1}.zoom-modal-enter-active,.zoom-modal-appear-active{transition:opacity .4s cubic-bezier(.3,1.3,.3,1),transform .4s cubic-bezier(.3,1.3,.3,1)}.zoom-modal-leave-from{transform:scale(1);opacity:1}.zoom-modal-leave-to{transform:scale(.5);opacity:0}.zoom-modal-leave-active{transition:opacity .4s cubic-bezier(.3,1.3,.3,1),transform .4s cubic-bezier(.3,1.3,.3,1)}.fade-modal-enter-from,.fade-modal-appear-from{opacity:0}.fade-modal-enter-to,.fade-modal-appear-to{opacity:1}.fade-modal-enter-active,.fade-modal-appear-active{transition:opacity .4s cubic-bezier(.3,1.3,.3,1)}.fade-modal-leave-from{opacity:1}.fade-modal-leave-to{opacity:0}.fade-modal-leave-active{transition:opacity .4s cubic-bezier(.3,1.3,.3,1)}
