import{e as D,f as R,h as V,_ as E}from"./index.e4ceb7bd.js";import{u as H,N as I,M as f,T as z,F as W}from"./responsive.3bd8a197.js";/* empty css               */import{d as j,j as y,c as t,w as A,p as G,o as P,C as n,aE as l,aH as o,D as U,aI as a,aF as r,b5 as $,G as h,E as q,b6 as J,u as b,F as K,b7 as O,b8 as Q,b9 as X,ba as Y}from"./arco.2329baeb.js";import{u as Z,e as ee}from"./vue.46369188.js";import ae from"./index.bc1be572.js";import"./chart.db8aed57.js";/* empty css               *//* empty css              *//* empty css               *//* empty css              *//* empty css               */const te={key:0,class:"layout-navbar"},oe={class:"menu-wrapper"},se="60px",ne=j({__name:"home-layout",setup(le){const d=y(!1),e=D(),g=R(),w=Z(),C=ee(),k=V();H(!0);const i=t(()=>e.navbar),m=t(()=>e.menu&&!e.topMenu),p=t(()=>e.hideMenu),x=t(()=>e.footer),_=t(()=>e.menuCollapse?48:e.menuWidth),M=t(()=>e.menuCollapse),S=t(()=>{const s=m.value&&!p.value?{paddingLeft:`${_.value}px`}:{},v=i.value?{paddingTop:se}:{};return{...s,...v}}),L=s=>{!d.value||e.updateSettings({menuCollapse:s})};A(()=>g.role,s=>{s&&!k.accessRouter(C)&&w.push({name:"notFound"})});const u=y(!1),B=()=>{u.value=!1};return G("toggleDrawerMenu",()=>{u.value=!u.value}),P(()=>{d.value=!0}),(s,v)=>{const F=O,N=Q,T=X,c=Y;return n(),l(c,{class:K(["layout",{mobile:b(e).hideMenu}])},{default:o(()=>[i.value?(n(),U("div",te,[a(I)])):r("",!0),a(c,null,{default:o(()=>[a(c,null,{default:o(()=>[m.value?$((n(),l(F,{key:0,class:"layout-sider",breakpoint:"xl",collapsed:M.value,collapsible:!0,width:_.value,style:h({paddingTop:i.value?"60px":""}),"hide-trigger":!0,onCollapse:L},{default:o(()=>[q("div",oe,[a(f)])]),_:1},8,["collapsed","width","style"])),[[J,!p.value]]):r("",!0),p.value?(n(),l(N,{key:1,visible:u.value,placement:"left",footer:!1,"mask-closable":"",closable:!1,onCancel:B},{default:o(()=>[a(f)]),_:1},8,["visible"])):r("",!0),a(c,{class:"layout-content",style:h(S.value)},{default:o(()=>[b(e).tabBar?(n(),l(z,{key:0})):r("",!0),a(T,null,{default:o(()=>[a(ae)]),_:1}),x.value?(n(),l(W,{key:1})):r("",!0)]),_:1},8,["style"])]),_:1})]),_:1})]),_:1},8,["class"])}}});const be=E(ne,[["__scopeId","data-v-320f4106"]]);export{be as default};
