import{d as J,t as T,_ as U}from"./index.e4ceb7bd.js";/* empty css              *//* empty css               *//* empty css               *//* empty css              *//* empty css               *//* empty css               *//* empty css              *//* empty css               *//* empty css               */import{d as j,r as h,j as f,aP as O,bu as $,C as l,D as A,aI as e,aH as t,aJ as r,b5 as v,aE as m,E as w,aK as H,aF as K,bq as X,br as Y,b0 as G,a$ as L,bt as Q,aV as W,ac as Z,aU as ee,aX as te,bh as ae,bv as oe,bw as ne,aY as se}from"./arco.2329baeb.js";import"./chart.db8aed57.js";import"./vue.46369188.js";const ie={class:"container"},le={name:"SystemNodeManagement"},re=j({...le,setup(de){const o=h({ipaddr:"",page:1,page_size:10,total:0}),g=h({...o}),D=[{title:"ipaddr",dataIndex:"ipaddr"},{title:"name",dataIndex:"platform.name"},{title:"release",dataIndex:"platform.release"},{title:"version",dataIndex:"platform.version"},{title:"machine",dataIndex:"platform.machine"},{title:"processor",dataIndex:"platform.processor"},{title:"operations",dataIndex:"operations",slotName:"operations",width:200}],x=f([]),d=()=>{const n="/api/node/list";J.get(n,{params:o}).then(a=>{x.value=a.data,g.total=a.total})},b=()=>{o.page=1,o.page_size=10,o.total=0,o.ipaddr="",d()},V=n=>{o.page=n,d()},p=f(!1),y=f(),k=n=>{y.value=JSON.stringify(n,null,2),p.value=!0};return d(),(n,a)=>{const N=O("Breadcrumb"),S=X,F=Y,s=G,c=L,B=Q,C=W,z=Z,_=ee,I=T,P=te,R=ae,M=oe,q=ne,E=se,u=$("permission");return l(),A("div",ie,[e(N,{items:"System / NodeManagement"}),e(E,{title:"NodeManagement",class:"general-card"},{default:t(()=>[e(c,null,{default:t(()=>[e(s,{flex:1},{default:t(()=>[e(B,{"label-col-props":{span:6},model:o,"wrapper-col-props":{span:18},"label-align":"left"},{default:t(()=>[e(c,{gutter:16},{default:t(()=>[e(s,{span:8},{default:t(()=>[e(F,{field:"ipaddr","hide-label":""},{default:t(()=>[e(S,{modelValue:o.ipaddr,"onUpdate:modelValue":a[0]||(a[0]=i=>o.ipaddr=i),placeholder:"Please enter the query parameters"},{prefix:t(()=>a[2]||(a[2]=[r("IP Addr")])),_:1},8,["modelValue"])]),_:1})]),_:1})]),_:1})]),_:1},8,["model"])]),_:1}),e(C,{direction:"vertical",style:{height:"84px"}}),e(s,{flex:"100px",style:{"text-align":"right"}},{default:t(()=>[e(P,{size:18,direction:"vertical"},{default:t(()=>[v((l(),m(_,{type:"primary",onClick:d},{icon:t(()=>[e(z)]),default:t(()=>[a[3]||(a[3]=r(" Search "))]),_:1})),[[u,["admin"]]]),v((l(),m(_,{onClick:b},{icon:t(()=>[e(I)]),default:t(()=>[a[4]||(a[4]=r(" SearchReset "))]),_:1})),[[u,["admin"]]])]),_:1})]),_:1})]),_:1}),e(C,{style:{"margin-top":"0"}}),e(c,{style:{"margin-bottom":"16px"}},{default:t(()=>[e(s,{span:12}),e(s,{span:12,style:{display:"flex","align-items":"center","justify-content":"end"}},{default:t(()=>[e(R,{content:"Refresh"},{default:t(()=>[w("div",{class:"action-icon",onClick:b},[e(I,{size:"18"})])]),_:1})]),_:1})]),_:1}),e(M,{"row-key":"id",pagination:g,columns:D,data:x.value,bordered:!1,size:"small",onPageChange:V},{operations:t(({record:i})=>[e(c,null,{default:t(()=>[e(s,{span:8},{default:t(()=>[v((l(),m(_,{type:"outline",size:"mini",status:"success",onClick:pe=>k(i)},{default:t(()=>a[5]||(a[5]=[r(" ViewDetails ")])),_:2},1032,["onClick"])),[[u,["admin"]]])]),_:2},1024)]),_:2},1024)]),_:1},8,["pagination","data"]),p.value?(l(),m(q,{key:0,visible:p.value,"onUpdate:visible":a[1]||(a[1]=i=>p.value=i),width:"85%",footer:!1},{title:t(()=>a[6]||(a[6]=[r("NodeDetails")])),default:t(()=>[w("pre",null,H(y.value),1)]),_:1},8,["visible"])):K("",!0)]),_:1})])}}});const we=U(re,[["__scopeId","data-v-10fdd62f"]]);export{we as default};
