.arco-textarea-wrapper{display:inline-flex;box-sizing:border-box;color:var(--color-text-1);font-size:14px;background-color:var(--color-fill-2);border:1px solid transparent;border-radius:var(--border-radius-small);cursor:text;transition:color .1s cubic-bezier(0,0,1,1),border-color .1s cubic-bezier(0,0,1,1),background-color .1s cubic-bezier(0,0,1,1);position:relative;display:inline-block;width:100%;padding-right:0;padding-left:0;overflow:hidden}.arco-textarea-wrapper:hover{background-color:var(--color-fill-3);border-color:transparent}.arco-textarea-wrapper:focus-within,.arco-textarea-wrapper.arco-textarea-focus{z-index:1;background-color:var(--color-bg-2);border-color:rgb(var(--primary-6));box-shadow:0 0 0 0 var(--color-primary-light-2)}.arco-textarea-wrapper.arco-textarea-disabled{color:var(--color-text-4);background-color:var(--color-fill-2);border-color:transparent;cursor:not-allowed}.arco-textarea-wrapper.arco-textarea-disabled:hover{color:var(--color-text-4);background-color:var(--color-fill-2);border-color:transparent}.arco-textarea-wrapper.arco-textarea-disabled .arco-textarea-prefix,.arco-textarea-wrapper.arco-textarea-disabled .arco-textarea-suffix{color:inherit}.arco-textarea-wrapper.arco-textarea-error{background-color:var(--color-danger-light-1);border-color:transparent}.arco-textarea-wrapper.arco-textarea-error:hover{background-color:var(--color-danger-light-2);border-color:transparent}.arco-textarea-wrapper.arco-textarea-error:focus-within,.arco-textarea-wrapper.arco-textarea-error.arco-textarea-wrapper-focus{z-index:1;background-color:var(--color-bg-2);border-color:rgb(var(--danger-6));box-shadow:0 0 0 0 var(--color-danger-light-2)}.arco-textarea-wrapper .arco-textarea-prefix,.arco-textarea-wrapper .arco-textarea-suffix{display:inline-flex;flex-shrink:0;align-items:center;white-space:nowrap;user-select:none}.arco-textarea-wrapper .arco-textarea-prefix>svg,.arco-textarea-wrapper .arco-textarea-suffix>svg{font-size:14px}.arco-textarea-wrapper .arco-textarea-prefix{padding-right:12px;color:var(--color-text-2)}.arco-textarea-wrapper .arco-textarea-suffix{padding-left:12px;color:var(--color-text-2)}.arco-textarea-wrapper .arco-textarea-suffix .arco-feedback-icon{display:inline-flex}.arco-textarea-wrapper .arco-textarea-suffix .arco-feedback-icon-status-validating{color:rgb(var(--primary-6))}.arco-textarea-wrapper .arco-textarea-suffix .arco-feedback-icon-status-success{color:rgb(var(--success-6))}.arco-textarea-wrapper .arco-textarea-suffix .arco-feedback-icon-status-warning{color:rgb(var(--warning-6))}.arco-textarea-wrapper .arco-textarea-suffix .arco-feedback-icon-status-error{color:rgb(var(--danger-6))}.arco-textarea-wrapper .arco-textarea-clear-btn{align-self:center;color:var(--color-text-2);font-size:12px;visibility:hidden;cursor:pointer}.arco-textarea-wrapper .arco-textarea-clear-btn>svg{position:relative;transition:color .1s cubic-bezier(0,0,1,1)}.arco-textarea-wrapper:hover .arco-textarea-clear-btn{visibility:visible}.arco-textarea-wrapper:not(.arco-textarea-focus) .arco-textarea-icon-hover:hover:before{background-color:var(--color-fill-4)}.arco-textarea-wrapper .arco-textarea-word-limit{position:absolute;right:10px;bottom:6px;color:var(--color-text-3);font-size:12px;user-select:none}.arco-textarea-wrapper.arco-textarea-scroll .arco-textarea-word-limit{right:25px}.arco-textarea-wrapper .arco-textarea-clear-btn{position:absolute;top:50%;right:10px;transform:translateY(-50%)}.arco-textarea-wrapper.arco-textarea-scroll .arco-textarea-clear-btn{right:25px}.arco-textarea-wrapper:hover .arco-textarea-clear-btn{display:block}.arco-textarea-wrapper .arco-textarea-mirror{position:absolute;visibility:hidden}.arco-textarea{width:100%;color:inherit;background:none;border:none;border-radius:0;outline:none;cursor:inherit;-webkit-appearance:none;-webkit-tap-highlight-color:rgba(0,0,0,0);display:block;box-sizing:border-box;height:100%;min-height:32px;padding:4px 12px;font-size:14px;line-height:1.5715;vertical-align:top;resize:vertical}.arco-textarea::placeholder{color:var(--color-text-3)}.arco-textarea[disabled]::placeholder{color:var(--color-text-4)}.arco-textarea[disabled]{-webkit-text-fill-color:var(--color-text-4)}pre code.hljs{display:block;overflow-x:auto;padding:1em}code.hljs{padding:3px 5px}/*!
  Theme: GitHub
  Description: Light theme as seen on github.com
  Author: github.com
  Maintainer: @Hirse
  Updated: 2021-05-15

  Outdated base version: https://github.com/primer/github-syntax-light
  Current colors taken from GitHub's CSS
*/.hljs{color:#24292e;background:#ffffff}.hljs-doctag,.hljs-keyword,.hljs-meta .hljs-keyword,.hljs-template-tag,.hljs-template-variable,.hljs-type,.hljs-variable.language_{color:#d73a49}.hljs-title,.hljs-title.class_,.hljs-title.class_.inherited__,.hljs-title.function_{color:#6f42c1}.hljs-attr,.hljs-attribute,.hljs-literal,.hljs-meta,.hljs-number,.hljs-operator,.hljs-variable,.hljs-selector-attr,.hljs-selector-class,.hljs-selector-id{color:#005cc5}.hljs-regexp,.hljs-string,.hljs-meta .hljs-string{color:#032f62}.hljs-built_in,.hljs-symbol{color:#e36209}.hljs-comment,.hljs-code,.hljs-formula{color:#6a737d}.hljs-name,.hljs-quote,.hljs-selector-tag,.hljs-selector-pseudo{color:#22863a}.hljs-subst{color:#24292e}.hljs-section{color:#005cc5;font-weight:700}.hljs-bullet{color:#735c0f}.hljs-emphasis{color:#24292e;font-style:italic}.hljs-strong{color:#24292e;font-weight:700}.hljs-addition{color:#22863a;background-color:#f0fff4}.hljs-deletion{color:#b31d28;background-color:#ffeef0}.container[data-v-a5fa6086]{padding:20px;height:800px}.history-panel[data-v-a5fa6086]{padding:16px;border-right:1px solid var(--color-border)}.new-chat-btn[data-v-a5fa6086]{width:100%;margin-bottom:16px}.history-title[data-v-a5fa6086]{color:var(--color-text-2);font-weight:500;margin-bottom:12px}.history-item[data-v-a5fa6086]{padding:12px 16px;margin:4px 0;border-radius:8px;cursor:pointer;transition:all .2s ease}.history-item[data-v-a5fa6086]:hover{background-color:var(--color-bg-3)}.history-item.active[data-v-a5fa6086]{background-color:var(--color-primary-light-2);font-weight:500;border-left:4px solid var(--color-primary-light-2)}.delete-btn[data-v-a5fa6086]{color:red;padding:0;margin-left:auto}.chat-panel[data-v-a5fa6086]{display:flex;flex-direction:column;height:100%}.chat-container[data-v-a5fa6086]{flex:1;display:flex;flex-direction:column;height:100%}.message-area[data-v-a5fa6086]{height:630px;padding:20px;overflow-y:auto;background:var(--color-bg-2)}.message-group[data-v-a5fa6086]{margin-bottom:24px}.message-bubble[data-v-a5fa6086]{max-width:75%;padding:16px 20px;border-radius:16px;margin:8px 0;position:relative}.user-message[data-v-a5fa6086]{margin-left:auto;background:var(--color-primary-light-1);border:1px solid var(--color-primary-light-3)}.bot-message[data-v-a5fa6086]{margin-right:auto;background:var(--color-bg-3);border:1px solid var(--color-border)}.message-header[data-v-a5fa6086]{display:flex;align-items:center;gap:8px;margin-bottom:8px;font-size:12px;color:var(--color-text-3)}.avatar[data-v-a5fa6086]{font-size:16px}.message-content[data-v-a5fa6086]{line-height:1.6;word-break:break-word}.user-content[data-v-a5fa6086]{color:#000;white-space:pre-wrap;word-break:break-word}.bot-content[data-v-a5fa6086]{color:var(--color-text-1)}.message-content[data-v-a5fa6086] pre{background:var(--color-bg-4);padding:16px;border-radius:12px;overflow-x:auto;margin:12px 0}.message-content[data-v-a5fa6086] code{font-family:Fira Code,monospace;font-size:14px}.message-content[data-v-a5fa6086] ul{padding-left:24px}.time[data-v-a5fa6086]{margin-left:auto;color:var(--color-text-3)}
