.arco-trigger-wrapper{display:inline-block}.arco-trigger-popup{position:absolute;z-index:1000}.arco-trigger-arrow{position:absolute;z-index:-1;display:block;box-sizing:border-box;width:8px;height:8px;background-color:var(--color-bg-5);content:""}.arco-trigger-popup[trigger-placement=top] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=tl] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=tr] .arco-trigger-arrow{border-top:none;border-left:none;border-bottom-right-radius:var(--border-radius-small)}.arco-trigger-popup[trigger-placement=bottom] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=bl] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=br] .arco-trigger-arrow{border-right:none;border-bottom:none;border-top-left-radius:var(--border-radius-small)}.arco-trigger-popup[trigger-placement=left] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=lt] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=lb] .arco-trigger-arrow{border-bottom:none;border-left:none;border-top-right-radius:var(--border-radius-small)}.arco-trigger-popup[trigger-placement=right] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=rt] .arco-trigger-arrow,.arco-trigger-popup[trigger-placement=rb] .arco-trigger-arrow{border-top:none;border-right:none;border-bottom-left-radius:var(--border-radius-small)}.arco-scrollbar{position:relative}.arco-scrollbar-container{position:relative;scrollbar-width:none}.arco-scrollbar-container::-webkit-scrollbar{display:none}.arco-scrollbar-track{position:absolute;z-index:100}.arco-scrollbar-track-direction-horizontal{bottom:0;left:0;box-sizing:border-box;width:100%;height:15px}.arco-scrollbar-track-direction-vertical{top:0;right:0;box-sizing:border-box;width:15px;height:100%}.arco-scrollbar-thumb{position:absolute;display:block;box-sizing:border-box}.arco-scrollbar-thumb-bar{width:100%;height:100%;background-color:var(--color-neutral-4);border-radius:6px}.arco-scrollbar-thumb:hover .arco-scrollbar-thumb-bar,.arco-scrollbar-thumb-dragging .arco-scrollbar-thumb-bar{background-color:var(--color-neutral-6)}.arco-scrollbar-thumb-direction-horizontal .arco-scrollbar-thumb-bar{height:9px;margin:3px 0}.arco-scrollbar-thumb-direction-vertical .arco-scrollbar-thumb-bar{width:9px;margin:0 3px}.arco-scrollbar.arco-scrollbar-type-embed .arco-scrollbar-thumb{opacity:0;transition:opacity ease .2s}.arco-scrollbar.arco-scrollbar-type-embed .arco-scrollbar-thumb-dragging,.arco-scrollbar.arco-scrollbar-type-embed:hover .arco-scrollbar-thumb{opacity:.8}.arco-scrollbar.arco-scrollbar-type-track .arco-scrollbar-track{background-color:var(--color-neutral-1)}.arco-scrollbar.arco-scrollbar-type-track .arco-scrollbar-track-direction-horizontal{border-top:1px solid var(--color-neutral-3);border-bottom:1px solid var(--color-neutral-3)}.arco-scrollbar.arco-scrollbar-type-track .arco-scrollbar-track-direction-vertical{border-right:1px solid var(--color-neutral-3);border-left:1px solid var(--color-neutral-3)}.arco-scrollbar.arco-scrollbar-type-track .arco-scrollbar-thumb-direction-horizontal{margin:-1px 0}.arco-scrollbar.arco-scrollbar-type-track .arco-scrollbar-thumb-direction-vertical{margin:0 -1px}.arco-scrollbar.arco-scrollbar-type-track.arco-scrollbar-both .arco-scrollbar-track-direction-vertical:after{position:absolute;right:-1px;bottom:0;display:block;box-sizing:border-box;width:15px;height:15px;background-color:var(--color-neutral-1);border-right:1px solid var(--color-neutral-3);border-bottom:1px solid var(--color-neutral-3);content:""}.arco-tooltip-content{max-width:350px;padding:8px 12px;color:#fff;font-size:14px;line-height:1.5715;text-align:left;word-wrap:break-word;background-color:var(--color-tooltip-bg);border-radius:var(--border-radius-small)}.arco-tooltip-mini{padding:4px 12px;font-size:14px}.arco-tooltip-popup-arrow{background-color:var(--color-tooltip-bg)}
