import{d as G_,s as Ra,i as Ea,t as W_,c as Ti,g as U_,w as ka,a as Jh,o as Y_,b as $_,h as jh,n as Z_,e as X_,u as q_}from"./arco.2329baeb.js";/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */var Iu=function(r,t){return Iu=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,i){e.__proto__=i}||function(e,i){for(var n in i)Object.prototype.hasOwnProperty.call(i,n)&&(e[n]=i[n])},Iu(r,t)};function N(r,t){if(typeof t!="function"&&t!==null)throw new TypeError("Class extends value "+String(t)+" is not a constructor or null");Iu(r,t);function e(){this.constructor=r}r.prototype=t===null?Object.create(t):(e.prototype=t.prototype,new e)}var K_=function(){function r(){this.firefox=!1,this.ie=!1,this.edge=!1,this.newEdge=!1,this.weChat=!1}return r}(),Q_=function(){function r(){this.browser=new K_,this.node=!1,this.wxa=!1,this.worker=!1,this.svgSupported=!1,this.touchEventsSupported=!1,this.pointerEventsSupported=!1,this.domSupported=!1,this.transformSupported=!1,this.transform3dSupported=!1,this.hasGlobalWindow=typeof window<"u"}return r}(),yr=new Q_;typeof wx=="object"&&typeof wx.getSystemInfoSync=="function"?(yr.wxa=!0,yr.touchEventsSupported=!0):typeof document>"u"&&typeof self<"u"?yr.worker=!0:!yr.hasGlobalWindow||"Deno"in window?(yr.node=!0,yr.svgSupported=!0):J_(navigator.userAgent,yr);function J_(r,t){var e=t.browser,i=r.match(/Firefox\/([\d.]+)/),n=r.match(/MSIE\s([\d.]+)/)||r.match(/Trident\/.+?rv:(([\d.]+))/),a=r.match(/Edge?\/([\d.]+)/),o=/micromessenger/i.test(r);i&&(e.firefox=!0,e.version=i[1]),n&&(e.ie=!0,e.version=n[1]),a&&(e.edge=!0,e.version=a[1],e.newEdge=+a[1].split(".")[0]>18),o&&(e.weChat=!0),t.svgSupported=typeof SVGRect<"u",t.touchEventsSupported="ontouchstart"in window&&!e.ie&&!e.edge,t.pointerEventsSupported="onpointerdown"in window&&(e.edge||e.ie&&+e.version>=11),t.domSupported=typeof document<"u";var s=document.documentElement.style;t.transform3dSupported=(e.ie&&"transition"in s||e.edge||"WebKitCSSMatrix"in window&&"m11"in new WebKitCSSMatrix||"MozPerspective"in s)&&!("OTransition"in s),t.transformSupported=t.transform3dSupported||e.ie&&+e.version>=9}const tt=yr;var Ff=12,j_="sans-serif",si=Ff+"px "+j_,t1=20,e1=100,r1="007LLmW'55;N0500LLLLLLLLLL00NNNLzWW\\\\WQb\\0FWLg\\bWb\\WQ\\WrWWQ000CL5LLFLL0LL**F*gLLLL5F0LF\\FFF5.5N";function i1(r){var t={};if(typeof JSON>"u")return t;for(var e=0;e<r.length;e++){var i=String.fromCharCode(e+32),n=(r.charCodeAt(e)-t1)/e1;t[i]=n}return t}var n1=i1(r1),gi={createCanvas:function(){return typeof document<"u"&&document.createElement("canvas")},measureText:function(){var r,t;return function(e,i){if(!r){var n=gi.createCanvas();r=n&&n.getContext("2d")}if(r)return t!==i&&(t=r.font=i||si),r.measureText(e);e=e||"",i=i||si;var a=/((?:\d+)?\.?\d*)px/.exec(i),o=a&&+a[1]||Ff,s=0;if(i.indexOf("mono")>=0)s=o*e.length;else for(var l=0;l<e.length;l++){var u=n1[e[l]];s+=u==null?o:u*o}return{width:s}}}(),loadImage:function(r,t,e){var i=new Image;return i.onload=t,i.onerror=e,i.src=r,i}},sg=je(["Function","RegExp","Date","Error","CanvasGradient","CanvasPattern","Image","Canvas"],function(r,t){return r["[object "+t+"]"]=!0,r},{}),lg=je(["Int8","Uint8","Uint8Clamped","Int16","Uint16","Int32","Uint32","Float32","Float64"],function(r,t){return r["[object "+t+"Array]"]=!0,r},{}),Ca=Object.prototype.toString,ws=Array.prototype,a1=ws.forEach,o1=ws.filter,Vf=ws.slice,s1=ws.map,tv=function(){}.constructor,Oa=tv?tv.prototype:null,Hf="__proto__",l1=2311;function ug(){return l1++}function Gf(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];typeof console<"u"&&console.error.apply(console,r)}function et(r){if(r==null||typeof r!="object")return r;var t=r,e=Ca.call(r);if(e==="[object Array]"){if(!Qn(r)){t=[];for(var i=0,n=r.length;i<n;i++)t[i]=et(r[i])}}else if(lg[e]){if(!Qn(r)){var a=r.constructor;if(a.from)t=a.from(r);else{t=new a(r.length);for(var i=0,n=r.length;i<n;i++)t[i]=r[i]}}}else if(!sg[e]&&!Qn(r)&&!ha(r)){t={};for(var o in r)r.hasOwnProperty(o)&&o!==Hf&&(t[o]=et(r[o]))}return t}function nt(r,t,e){if(!Y(t)||!Y(r))return e?et(t):r;for(var i in t)if(t.hasOwnProperty(i)&&i!==Hf){var n=r[i],a=t[i];Y(a)&&Y(n)&&!V(a)&&!V(n)&&!ha(a)&&!ha(n)&&!ev(a)&&!ev(n)&&!Qn(a)&&!Qn(n)?nt(n,a,e):(e||!(i in r))&&(r[i]=et(t[i]))}return r}function O(r,t){if(Object.assign)Object.assign(r,t);else for(var e in t)t.hasOwnProperty(e)&&e!==Hf&&(r[e]=t[e]);return r}function rt(r,t,e){for(var i=vt(t),n=0,a=i.length;n<a;n++){var o=i[n];(e?t[o]!=null:r[o]==null)&&(r[o]=t[o])}return r}gi.createCanvas;function at(r,t){if(r){if(r.indexOf)return r.indexOf(t);for(var e=0,i=r.length;e<i;e++)if(r[e]===t)return e}return-1}function u1(r,t){var e=r.prototype;function i(){}i.prototype=t.prototype,r.prototype=new i;for(var n in e)e.hasOwnProperty(n)&&(r.prototype[n]=e[n]);r.prototype.constructor=r,r.superClass=t}function Me(r,t,e){if(r="prototype"in r?r.prototype:r,t="prototype"in t?t.prototype:t,Object.getOwnPropertyNames)for(var i=Object.getOwnPropertyNames(t),n=0;n<i.length;n++){var a=i[n];a!=="constructor"&&(e?t[a]!=null:r[a]==null)&&(r[a]=t[a])}else rt(r,t,e)}function Wt(r){return!r||typeof r=="string"?!1:typeof r.length=="number"}function A(r,t,e){if(!!(r&&t))if(r.forEach&&r.forEach===a1)r.forEach(t,e);else if(r.length===+r.length)for(var i=0,n=r.length;i<n;i++)t.call(e,r[i],i,r);else for(var a in r)r.hasOwnProperty(a)&&t.call(e,r[a],a,r)}function G(r,t,e){if(!r)return[];if(!t)return Wf(r);if(r.map&&r.map===s1)return r.map(t,e);for(var i=[],n=0,a=r.length;n<a;n++)i.push(t.call(e,r[n],n,r));return i}function je(r,t,e,i){if(!!(r&&t)){for(var n=0,a=r.length;n<a;n++)e=t.call(i,e,r[n],n,r);return e}}function Ct(r,t,e){if(!r)return[];if(!t)return Wf(r);if(r.filter&&r.filter===o1)return r.filter(t,e);for(var i=[],n=0,a=r.length;n<a;n++)t.call(e,r[n],n,r)&&i.push(r[n]);return i}function f1(r,t,e){if(!!(r&&t)){for(var i=0,n=r.length;i<n;i++)if(t.call(e,r[i],i,r))return r[i]}}function vt(r){if(!r)return[];if(Object.keys)return Object.keys(r);var t=[];for(var e in r)r.hasOwnProperty(e)&&t.push(e);return t}function h1(r,t){for(var e=[],i=2;i<arguments.length;i++)e[i-2]=arguments[i];return function(){return r.apply(t,e.concat(Vf.call(arguments)))}}var $=Oa&&K(Oa.bind)?Oa.call.bind(Oa.bind):h1;function yt(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return function(){return r.apply(this,t.concat(Vf.call(arguments)))}}function V(r){return Array.isArray?Array.isArray(r):Ca.call(r)==="[object Array]"}function K(r){return typeof r=="function"}function W(r){return typeof r=="string"}function Pu(r){return Ca.call(r)==="[object String]"}function dt(r){return typeof r=="number"}function Y(r){var t=typeof r;return t==="function"||!!r&&t==="object"}function ev(r){return!!sg[Ca.call(r)]}function jt(r){return!!lg[Ca.call(r)]}function ha(r){return typeof r=="object"&&typeof r.nodeType=="number"&&typeof r.ownerDocument=="object"}function xs(r){return r.colorStops!=null}function v1(r){return r.image!=null}function Wo(r){return r!==r}function va(){for(var r=[],t=0;t<arguments.length;t++)r[t]=arguments[t];for(var e=0,i=r.length;e<i;e++)if(r[e]!=null)return r[e]}function j(r,t){return r!=null?r:t}function Kn(r,t,e){return r!=null?r:t!=null?t:e}function Wf(r){for(var t=[],e=1;e<arguments.length;e++)t[e-1]=arguments[e];return Vf.apply(r,t)}function fg(r){if(typeof r=="number")return[r,r,r,r];var t=r.length;return t===2?[r[0],r[1],r[0],r[1]]:t===3?[r[0],r[1],r[2],r[1]]:r}function tr(r,t){if(!r)throw new Error(t)}function Fe(r){return r==null?null:typeof r.trim=="function"?r.trim():r.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")}var hg="__ec_primitive__";function Ru(r){r[hg]=!0}function Qn(r){return r[hg]}var c1=function(){function r(){this.data={}}return r.prototype.delete=function(t){var e=this.has(t);return e&&delete this.data[t],e},r.prototype.has=function(t){return this.data.hasOwnProperty(t)},r.prototype.get=function(t){return this.data[t]},r.prototype.set=function(t,e){return this.data[t]=e,this},r.prototype.keys=function(){return vt(this.data)},r.prototype.forEach=function(t){var e=this.data;for(var i in e)e.hasOwnProperty(i)&&t(e[i],i)},r}(),vg=typeof Map=="function";function d1(){return vg?new Map:new c1}var p1=function(){function r(t){var e=V(t);this.data=d1();var i=this;t instanceof r?t.each(n):t&&A(t,n);function n(a,o){e?i.set(a,o):i.set(o,a)}}return r.prototype.hasKey=function(t){return this.data.has(t)},r.prototype.get=function(t){return this.data.get(t)},r.prototype.set=function(t,e){return this.data.set(t,e),e},r.prototype.each=function(t,e){this.data.forEach(function(i,n){t.call(e,i,n)})},r.prototype.keys=function(){var t=this.data.keys();return vg?Array.from(t):t},r.prototype.removeKey=function(t){this.data.delete(t)},r}();function Z(r){return new p1(r)}function g1(r,t){for(var e=new r.constructor(r.length+t.length),i=0;i<r.length;i++)e[i]=r[i];for(var n=r.length,i=0;i<t.length;i++)e[i+n]=t[i];return e}function bs(r,t){var e;if(Object.create)e=Object.create(r);else{var i=function(){};i.prototype=r,e=new i}return t&&O(e,t),e}function cg(r){var t=r.style;t.webkitUserSelect="none",t.userSelect="none",t.webkitTapHighlightColor="rgba(0,0,0,0)",t["-webkit-touch-callout"]="none"}function Q(r,t){return r.hasOwnProperty(t)}function Gt(){}var y1=180/Math.PI;function ln(r,t){return r==null&&(r=0),t==null&&(t=0),[r,t]}function m1(r){return[r[0],r[1]]}function rv(r,t,e){return r[0]=t[0]+e[0],r[1]=t[1]+e[1],r}function _1(r,t,e){return r[0]=t[0]-e[0],r[1]=t[1]-e[1],r}function S1(r){return Math.sqrt(w1(r))}function w1(r){return r[0]*r[0]+r[1]*r[1]}function tl(r,t,e){return r[0]=t[0]*e,r[1]=t[1]*e,r}function x1(r,t){var e=S1(t);return e===0?(r[0]=0,r[1]=0):(r[0]=t[0]/e,r[1]=t[1]/e),r}function Eu(r,t){return Math.sqrt((r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1]))}var ku=Eu;function b1(r,t){return(r[0]-t[0])*(r[0]-t[0])+(r[1]-t[1])*(r[1]-t[1])}var Xi=b1;function el(r,t,e,i){return r[0]=t[0]+i*(e[0]-t[0]),r[1]=t[1]+i*(e[1]-t[1]),r}function ge(r,t,e){var i=t[0],n=t[1];return r[0]=e[0]*i+e[2]*n+e[4],r[1]=e[1]*i+e[3]*n+e[5],r}function Ui(r,t,e){return r[0]=Math.min(t[0],e[0]),r[1]=Math.min(t[1],e[1]),r}function Yi(r,t,e){return r[0]=Math.max(t[0],e[0]),r[1]=Math.max(t[1],e[1]),r}var Ci=function(){function r(t,e){this.target=t,this.topTarget=e&&e.topTarget}return r}(),T1=function(){function r(t){this.handler=t,t.on("mousedown",this._dragStart,this),t.on("mousemove",this._drag,this),t.on("mouseup",this._dragEnd,this)}return r.prototype._dragStart=function(t){for(var e=t.target;e&&!e.draggable;)e=e.parent||e.__hostTarget;e&&(this._draggingTarget=e,e.dragging=!0,this._x=t.offsetX,this._y=t.offsetY,this.handler.dispatchToElement(new Ci(e,t),"dragstart",t.event))},r.prototype._drag=function(t){var e=this._draggingTarget;if(e){var i=t.offsetX,n=t.offsetY,a=i-this._x,o=n-this._y;this._x=i,this._y=n,e.drift(a,o,t),this.handler.dispatchToElement(new Ci(e,t),"drag",t.event);var s=this.handler.findHover(i,n,e).target,l=this._dropTarget;this._dropTarget=s,e!==s&&(l&&s!==l&&this.handler.dispatchToElement(new Ci(l,t),"dragleave",t.event),s&&s!==l&&this.handler.dispatchToElement(new Ci(s,t),"dragenter",t.event))}},r.prototype._dragEnd=function(t){var e=this._draggingTarget;e&&(e.dragging=!1),this.handler.dispatchToElement(new Ci(e,t),"dragend",t.event),this._dropTarget&&this.handler.dispatchToElement(new Ci(this._dropTarget,t),"drop",t.event),this._draggingTarget=null,this._dropTarget=null},r}();const C1=T1;var M1=function(){function r(t){t&&(this._$eventProcessor=t)}return r.prototype.on=function(t,e,i,n){this._$handlers||(this._$handlers={});var a=this._$handlers;if(typeof e=="function"&&(n=i,i=e,e=null),!i||!t)return this;var o=this._$eventProcessor;e!=null&&o&&o.normalizeQuery&&(e=o.normalizeQuery(e)),a[t]||(a[t]=[]);for(var s=0;s<a[t].length;s++)if(a[t][s].h===i)return this;var l={h:i,query:e,ctx:n||this,callAtLast:i.zrEventfulCallAtLast},u=a[t].length-1,f=a[t][u];return f&&f.callAtLast?a[t].splice(u,0,l):a[t].push(l),this},r.prototype.isSilent=function(t){var e=this._$handlers;return!e||!e[t]||!e[t].length},r.prototype.off=function(t,e){var i=this._$handlers;if(!i)return this;if(!t)return this._$handlers={},this;if(e){if(i[t]){for(var n=[],a=0,o=i[t].length;a<o;a++)i[t][a].h!==e&&n.push(i[t][a]);i[t]=n}i[t]&&i[t].length===0&&delete i[t]}else delete i[t];return this},r.prototype.trigger=function(t){for(var e=[],i=1;i<arguments.length;i++)e[i-1]=arguments[i];if(!this._$handlers)return this;var n=this._$handlers[t],a=this._$eventProcessor;if(n)for(var o=e.length,s=n.length,l=0;l<s;l++){var u=n[l];if(!(a&&a.filter&&u.query!=null&&!a.filter(t,u.query)))switch(o){case 0:u.h.call(u.ctx);break;case 1:u.h.call(u.ctx,e[0]);break;case 2:u.h.call(u.ctx,e[0],e[1]);break;default:u.h.apply(u.ctx,e);break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},r.prototype.triggerWithContext=function(t){for(var e=[],i=1;i<arguments.length;i++)e[i-1]=arguments[i];if(!this._$handlers)return this;var n=this._$handlers[t],a=this._$eventProcessor;if(n)for(var o=e.length,s=e[o-1],l=n.length,u=0;u<l;u++){var f=n[u];if(!(a&&a.filter&&f.query!=null&&!a.filter(t,f.query)))switch(o){case 0:f.h.call(s);break;case 1:f.h.call(s,e[0]);break;case 2:f.h.call(s,e[0],e[1]);break;default:f.h.apply(s,e.slice(1,o-1));break}}return a&&a.afterTrigger&&a.afterTrigger(t),this},r}();const Ae=M1;var A1=Math.log(2);function Ou(r,t,e,i,n,a){var o=i+"-"+n,s=r.length;if(a.hasOwnProperty(o))return a[o];if(t===1){var l=Math.round(Math.log((1<<s)-1&~n)/A1);return r[e][l]}for(var u=i|1<<e,f=e+1;i&1<<f;)f++;for(var h=0,c=0,v=0;c<s;c++){var d=1<<c;d&n||(h+=(v%2?-1:1)*r[e][c]*Ou(r,t-1,f,u,n|d,a),v++)}return a[o]=h,h}function iv(r,t){var e=[[r[0],r[1],1,0,0,0,-t[0]*r[0],-t[0]*r[1]],[0,0,0,r[0],r[1],1,-t[1]*r[0],-t[1]*r[1]],[r[2],r[3],1,0,0,0,-t[2]*r[2],-t[2]*r[3]],[0,0,0,r[2],r[3],1,-t[3]*r[2],-t[3]*r[3]],[r[4],r[5],1,0,0,0,-t[4]*r[4],-t[4]*r[5]],[0,0,0,r[4],r[5],1,-t[5]*r[4],-t[5]*r[5]],[r[6],r[7],1,0,0,0,-t[6]*r[6],-t[6]*r[7]],[0,0,0,r[6],r[7],1,-t[7]*r[6],-t[7]*r[7]]],i={},n=Ou(e,8,0,0,0,i);if(n!==0){for(var a=[],o=0;o<8;o++)for(var s=0;s<8;s++)a[s]==null&&(a[s]=0),a[s]+=((o+s)%2?-1:1)*Ou(e,7,o===0?1:0,1<<o,1<<s,i)/n*t[o];return function(l,u,f){var h=u*a[6]+f*a[7]+1;l[0]=(u*a[0]+f*a[1]+a[2])/h,l[1]=(u*a[3]+f*a[4]+a[5])/h}}}var nv="___zrEVENTSAVED",rl=[];function D1(r,t,e,i,n){return Bu(rl,t,i,n,!0)&&Bu(r,e,rl[0],rl[1])}function Bu(r,t,e,i,n){if(t.getBoundingClientRect&&tt.domSupported&&!dg(t)){var a=t[nv]||(t[nv]={}),o=L1(t,a),s=I1(o,a,n);if(s)return s(r,e,i),!0}return!1}function L1(r,t){var e=t.markers;if(e)return e;e=t.markers=[];for(var i=["left","right"],n=["top","bottom"],a=0;a<4;a++){var o=document.createElement("div"),s=o.style,l=a%2,u=(a>>1)%2;s.cssText=["position: absolute","visibility: hidden","padding: 0","margin: 0","border-width: 0","user-select: none","width:0","height:0",i[l]+":0",n[u]+":0",i[1-l]+":auto",n[1-u]+":auto",""].join("!important;"),r.appendChild(o),e.push(o)}return e}function I1(r,t,e){for(var i=e?"invTrans":"trans",n=t[i],a=t.srcCoords,o=[],s=[],l=!0,u=0;u<4;u++){var f=r[u].getBoundingClientRect(),h=2*u,c=f.left,v=f.top;o.push(c,v),l=l&&a&&c===a[h]&&v===a[h+1],s.push(r[u].offsetLeft,r[u].offsetTop)}return l&&n?n:(t.srcCoords=o,t[i]=e?iv(s,o):iv(o,s))}function dg(r){return r.nodeName.toUpperCase()==="CANVAS"}var P1=/([&<>"'])/g,R1={"&":"&amp;","<":"&lt;",">":"&gt;",'"':"&quot;","'":"&#39;"};function Zt(r){return r==null?"":(r+"").replace(P1,function(t,e){return R1[e]})}var E1=/^(?:mouse|pointer|contextmenu|drag|drop)|click/,il=[],k1=tt.browser.firefox&&+tt.browser.version.split(".")[0]<39;function Nu(r,t,e,i){return e=e||{},i?av(r,t,e):k1&&t.layerX!=null&&t.layerX!==t.offsetX?(e.zrX=t.layerX,e.zrY=t.layerY):t.offsetX!=null?(e.zrX=t.offsetX,e.zrY=t.offsetY):av(r,t,e),e}function av(r,t,e){if(tt.domSupported&&r.getBoundingClientRect){var i=t.clientX,n=t.clientY;if(dg(r)){var a=r.getBoundingClientRect();e.zrX=i-a.left,e.zrY=n-a.top;return}else if(Bu(il,r,i,n)){e.zrX=il[0],e.zrY=il[1];return}}e.zrX=e.zrY=0}function Uf(r){return r||window.event}function le(r,t,e){if(t=Uf(t),t.zrX!=null)return t;var i=t.type,n=i&&i.indexOf("touch")>=0;if(n){var o=i!=="touchend"?t.targetTouches[0]:t.changedTouches[0];o&&Nu(r,o,t,e)}else{Nu(r,t,t,e);var a=O1(t);t.zrDelta=a?a/120:-(t.detail||0)/3}var s=t.button;return t.which==null&&s!==void 0&&E1.test(t.type)&&(t.which=s&1?1:s&2?3:s&4?2:0),t}function O1(r){var t=r.wheelDelta;if(t)return t;var e=r.deltaX,i=r.deltaY;if(e==null||i==null)return t;var n=Math.abs(i!==0?i:e),a=i>0?-1:i<0?1:e>0?-1:1;return 3*n*a}function B1(r,t,e,i){r.addEventListener(t,e,i)}function N1(r,t,e,i){r.removeEventListener(t,e,i)}var en=function(r){r.preventDefault(),r.stopPropagation(),r.cancelBubble=!0};function ov(r){return r.which===2||r.which===3}var z1=function(){function r(){this._track=[]}return r.prototype.recognize=function(t,e,i){return this._doTrack(t,e,i),this._recognize(t)},r.prototype.clear=function(){return this._track.length=0,this},r.prototype._doTrack=function(t,e,i){var n=t.touches;if(!!n){for(var a={points:[],touches:[],target:e,event:t},o=0,s=n.length;o<s;o++){var l=n[o],u=Nu(i,l,{});a.points.push([u.zrX,u.zrY]),a.touches.push(l)}this._track.push(a)}},r.prototype._recognize=function(t){for(var e in nl)if(nl.hasOwnProperty(e)){var i=nl[e](this._track,t);if(i)return i}},r}();function sv(r){var t=r[1][0]-r[0][0],e=r[1][1]-r[0][1];return Math.sqrt(t*t+e*e)}function F1(r){return[(r[0][0]+r[1][0])/2,(r[0][1]+r[1][1])/2]}var nl={pinch:function(r,t){var e=r.length;if(!!e){var i=(r[e-1]||{}).points,n=(r[e-2]||{}).points||i;if(n&&n.length>1&&i&&i.length>1){var a=sv(i)/sv(n);!isFinite(a)&&(a=1),t.pinchScale=a;var o=F1(i);return t.pinchX=o[0],t.pinchY=o[1],{type:"pinch",target:r[0].target,event:t}}}}};function qi(){return[1,0,0,1,0,0]}function Yf(r){return r[0]=1,r[1]=0,r[2]=0,r[3]=1,r[4]=0,r[5]=0,r}function V1(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4],r[5]=t[5],r}function Ki(r,t,e){var i=t[0]*e[0]+t[2]*e[1],n=t[1]*e[0]+t[3]*e[1],a=t[0]*e[2]+t[2]*e[3],o=t[1]*e[2]+t[3]*e[3],s=t[0]*e[4]+t[2]*e[5]+t[4],l=t[1]*e[4]+t[3]*e[5]+t[5];return r[0]=i,r[1]=n,r[2]=a,r[3]=o,r[4]=s,r[5]=l,r}function zu(r,t,e){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r[4]=t[4]+e[0],r[5]=t[5]+e[1],r}function $f(r,t,e,i){i===void 0&&(i=[0,0]);var n=t[0],a=t[2],o=t[4],s=t[1],l=t[3],u=t[5],f=Math.sin(e),h=Math.cos(e);return r[0]=n*h+s*f,r[1]=-n*f+s*h,r[2]=a*h+l*f,r[3]=-a*f+h*l,r[4]=h*(o-i[0])+f*(u-i[1])+i[0],r[5]=h*(u-i[1])-f*(o-i[0])+i[1],r}function H1(r,t,e){var i=e[0],n=e[1];return r[0]=t[0]*i,r[1]=t[1]*n,r[2]=t[2]*i,r[3]=t[3]*n,r[4]=t[4]*i,r[5]=t[5]*n,r}function Zf(r,t){var e=t[0],i=t[2],n=t[4],a=t[1],o=t[3],s=t[5],l=e*o-a*i;return l?(l=1/l,r[0]=o*l,r[1]=-a*l,r[2]=-i*l,r[3]=e*l,r[4]=(i*s-o*n)*l,r[5]=(a*n-e*s)*l,r):null}var G1=function(){function r(t,e){this.x=t||0,this.y=e||0}return r.prototype.copy=function(t){return this.x=t.x,this.y=t.y,this},r.prototype.clone=function(){return new r(this.x,this.y)},r.prototype.set=function(t,e){return this.x=t,this.y=e,this},r.prototype.equal=function(t){return t.x===this.x&&t.y===this.y},r.prototype.add=function(t){return this.x+=t.x,this.y+=t.y,this},r.prototype.scale=function(t){this.x*=t,this.y*=t},r.prototype.scaleAndAdd=function(t,e){this.x+=t.x*e,this.y+=t.y*e},r.prototype.sub=function(t){return this.x-=t.x,this.y-=t.y,this},r.prototype.dot=function(t){return this.x*t.x+this.y*t.y},r.prototype.len=function(){return Math.sqrt(this.x*this.x+this.y*this.y)},r.prototype.lenSquare=function(){return this.x*this.x+this.y*this.y},r.prototype.normalize=function(){var t=this.len();return this.x/=t,this.y/=t,this},r.prototype.distance=function(t){var e=this.x-t.x,i=this.y-t.y;return Math.sqrt(e*e+i*i)},r.prototype.distanceSquare=function(t){var e=this.x-t.x,i=this.y-t.y;return e*e+i*i},r.prototype.negate=function(){return this.x=-this.x,this.y=-this.y,this},r.prototype.transform=function(t){if(!!t){var e=this.x,i=this.y;return this.x=t[0]*e+t[2]*i+t[4],this.y=t[1]*e+t[3]*i+t[5],this}},r.prototype.toArray=function(t){return t[0]=this.x,t[1]=this.y,t},r.prototype.fromArray=function(t){this.x=t[0],this.y=t[1]},r.set=function(t,e,i){t.x=e,t.y=i},r.copy=function(t,e){t.x=e.x,t.y=e.y},r.len=function(t){return Math.sqrt(t.x*t.x+t.y*t.y)},r.lenSquare=function(t){return t.x*t.x+t.y*t.y},r.dot=function(t,e){return t.x*e.x+t.y*e.y},r.add=function(t,e,i){t.x=e.x+i.x,t.y=e.y+i.y},r.sub=function(t,e,i){t.x=e.x-i.x,t.y=e.y-i.y},r.scale=function(t,e,i){t.x=e.x*i,t.y=e.y*i},r.scaleAndAdd=function(t,e,i,n){t.x=e.x+i.x*n,t.y=e.y+i.y*n},r.lerp=function(t,e,i,n){var a=1-n;t.x=a*e.x+n*i.x,t.y=a*e.y+n*i.y},r}();const q=G1;var Ba=Math.min,Na=Math.max,Ir=new q,Pr=new q,Rr=new q,Er=new q,gn=new q,yn=new q,W1=function(){function r(t,e,i,n){i<0&&(t=t+i,i=-i),n<0&&(e=e+n,n=-n),this.x=t,this.y=e,this.width=i,this.height=n}return r.prototype.union=function(t){var e=Ba(t.x,this.x),i=Ba(t.y,this.y);isFinite(this.x)&&isFinite(this.width)?this.width=Na(t.x+t.width,this.x+this.width)-e:this.width=t.width,isFinite(this.y)&&isFinite(this.height)?this.height=Na(t.y+t.height,this.y+this.height)-i:this.height=t.height,this.x=e,this.y=i},r.prototype.applyTransform=function(t){r.applyTransform(this,this,t)},r.prototype.calculateTransform=function(t){var e=this,i=t.width/e.width,n=t.height/e.height,a=qi();return zu(a,a,[-e.x,-e.y]),H1(a,a,[i,n]),zu(a,a,[t.x,t.y]),a},r.prototype.intersect=function(t,e){if(!t)return!1;t instanceof r||(t=r.create(t));var i=this,n=i.x,a=i.x+i.width,o=i.y,s=i.y+i.height,l=t.x,u=t.x+t.width,f=t.y,h=t.y+t.height,c=!(a<l||u<n||s<f||h<o);if(e){var v=1/0,d=0,p=Math.abs(a-l),g=Math.abs(u-n),y=Math.abs(s-f),m=Math.abs(h-o),_=Math.min(p,g),S=Math.min(y,m);a<l||u<n?_>d&&(d=_,p<g?q.set(yn,-p,0):q.set(yn,g,0)):_<v&&(v=_,p<g?q.set(gn,p,0):q.set(gn,-g,0)),s<f||h<o?S>d&&(d=S,y<m?q.set(yn,0,-y):q.set(yn,0,m)):_<v&&(v=_,y<m?q.set(gn,0,y):q.set(gn,0,-m))}return e&&q.copy(e,c?gn:yn),c},r.prototype.contain=function(t,e){var i=this;return t>=i.x&&t<=i.x+i.width&&e>=i.y&&e<=i.y+i.height},r.prototype.clone=function(){return new r(this.x,this.y,this.width,this.height)},r.prototype.copy=function(t){r.copy(this,t)},r.prototype.plain=function(){return{x:this.x,y:this.y,width:this.width,height:this.height}},r.prototype.isFinite=function(){return isFinite(this.x)&&isFinite(this.y)&&isFinite(this.width)&&isFinite(this.height)},r.prototype.isZero=function(){return this.width===0||this.height===0},r.create=function(t){return new r(t.x,t.y,t.width,t.height)},r.copy=function(t,e){t.x=e.x,t.y=e.y,t.width=e.width,t.height=e.height},r.applyTransform=function(t,e,i){if(!i){t!==e&&r.copy(t,e);return}if(i[1]<1e-5&&i[1]>-1e-5&&i[2]<1e-5&&i[2]>-1e-5){var n=i[0],a=i[3],o=i[4],s=i[5];t.x=e.x*n+o,t.y=e.y*a+s,t.width=e.width*n,t.height=e.height*a,t.width<0&&(t.x+=t.width,t.width=-t.width),t.height<0&&(t.y+=t.height,t.height=-t.height);return}Ir.x=Rr.x=e.x,Ir.y=Er.y=e.y,Pr.x=Er.x=e.x+e.width,Pr.y=Rr.y=e.y+e.height,Ir.transform(i),Er.transform(i),Pr.transform(i),Rr.transform(i),t.x=Ba(Ir.x,Pr.x,Rr.x,Er.x),t.y=Ba(Ir.y,Pr.y,Rr.y,Er.y);var l=Na(Ir.x,Pr.x,Rr.x,Er.x),u=Na(Ir.y,Pr.y,Rr.y,Er.y);t.width=l-t.x,t.height=u-t.y},r}();const ut=W1;var pg="silent";function U1(r,t,e){return{type:r,event:e,target:t.target,topTarget:t.topTarget,cancelBubble:!1,offsetX:e.zrX,offsetY:e.zrY,gestureEvent:e.gestureEvent,pinchX:e.pinchX,pinchY:e.pinchY,pinchScale:e.pinchScale,wheelDelta:e.zrDelta,zrByTouch:e.zrByTouch,which:e.which,stop:Y1}}function Y1(){en(this.event)}var $1=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.handler=null,e}return t.prototype.dispose=function(){},t.prototype.setCursor=function(){},t}(Ae),mn=function(){function r(t,e){this.x=t,this.y=e}return r}(),Z1=["click","dblclick","mousewheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],al=new ut(0,0,0,0),gg=function(r){N(t,r);function t(e,i,n,a,o){var s=r.call(this)||this;return s._hovered=new mn(0,0),s.storage=e,s.painter=i,s.painterRoot=a,s._pointerSize=o,n=n||new $1,s.proxy=null,s.setHandlerProxy(n),s._draggingMgr=new C1(s),s}return t.prototype.setHandlerProxy=function(e){this.proxy&&this.proxy.dispose(),e&&(A(Z1,function(i){e.on&&e.on(i,this[i],this)},this),e.handler=this),this.proxy=e},t.prototype.mousemove=function(e){var i=e.zrX,n=e.zrY,a=yg(this,i,n),o=this._hovered,s=o.target;s&&!s.__zr&&(o=this.findHover(o.x,o.y),s=o.target);var l=this._hovered=a?new mn(i,n):this.findHover(i,n),u=l.target,f=this.proxy;f.setCursor&&f.setCursor(u?u.cursor:"default"),s&&u!==s&&this.dispatchToElement(o,"mouseout",e),this.dispatchToElement(l,"mousemove",e),u&&u!==s&&this.dispatchToElement(l,"mouseover",e)},t.prototype.mouseout=function(e){var i=e.zrEventControl;i!=="only_globalout"&&this.dispatchToElement(this._hovered,"mouseout",e),i!=="no_globalout"&&this.trigger("globalout",{type:"globalout",event:e})},t.prototype.resize=function(){this._hovered=new mn(0,0)},t.prototype.dispatch=function(e,i){var n=this[e];n&&n.call(this,i)},t.prototype.dispose=function(){this.proxy.dispose(),this.storage=null,this.proxy=null,this.painter=null},t.prototype.setCursorStyle=function(e){var i=this.proxy;i.setCursor&&i.setCursor(e)},t.prototype.dispatchToElement=function(e,i,n){e=e||{};var a=e.target;if(!(a&&a.silent)){for(var o="on"+i,s=U1(i,e,n);a&&(a[o]&&(s.cancelBubble=!!a[o].call(a,s)),a.trigger(i,s),a=a.__hostTarget?a.__hostTarget:a.parent,!s.cancelBubble););s.cancelBubble||(this.trigger(i,s),this.painter&&this.painter.eachOtherLayer&&this.painter.eachOtherLayer(function(l){typeof l[o]=="function"&&l[o].call(l,s),l.trigger&&l.trigger(i,s)}))}},t.prototype.findHover=function(e,i,n){var a=this.storage.getDisplayList(),o=new mn(e,i);if(lv(a,o,e,i,n),this._pointerSize&&!o.target){for(var s=[],l=this._pointerSize,u=l/2,f=new ut(e-u,i-u,l,l),h=a.length-1;h>=0;h--){var c=a[h];c!==n&&!c.ignore&&!c.ignoreCoarsePointer&&(!c.parent||!c.parent.ignoreCoarsePointer)&&(al.copy(c.getBoundingRect()),c.transform&&al.applyTransform(c.transform),al.intersect(f)&&s.push(c))}if(s.length)for(var v=4,d=Math.PI/12,p=Math.PI*2,g=0;g<u;g+=v)for(var y=0;y<p;y+=d){var m=e+g*Math.cos(y),_=i+g*Math.sin(y);if(lv(s,o,m,_,n),o.target)return o}}return o},t.prototype.processGesture=function(e,i){this._gestureMgr||(this._gestureMgr=new z1);var n=this._gestureMgr;i==="start"&&n.clear();var a=n.recognize(e,this.findHover(e.zrX,e.zrY,null).target,this.proxy.dom);if(i==="end"&&n.clear(),a){var o=a.type;e.gestureEvent=o;var s=new mn;s.target=a.target,this.dispatchToElement(s,o,a.event)}},t}(Ae);A(["click","mousedown","mouseup","mousewheel","dblclick","contextmenu"],function(r){gg.prototype[r]=function(t){var e=t.zrX,i=t.zrY,n=yg(this,e,i),a,o;if((r!=="mouseup"||!n)&&(a=this.findHover(e,i),o=a.target),r==="mousedown")this._downEl=o,this._downPoint=[t.zrX,t.zrY],this._upEl=o;else if(r==="mouseup")this._upEl=o;else if(r==="click"){if(this._downEl!==this._upEl||!this._downPoint||ku(this._downPoint,[t.zrX,t.zrY])>4)return;this._downPoint=null}this.dispatchToElement(a,r,t)}});function X1(r,t,e){if(r[r.rectHover?"rectContain":"contain"](t,e)){for(var i=r,n=void 0,a=!1;i;){if(i.ignoreClip&&(a=!0),!a){var o=i.getClipPath();if(o&&!o.contain(t,e))return!1}i.silent&&(n=!0);var s=i.__hostTarget;i=s||i.parent}return n?pg:!0}return!1}function lv(r,t,e,i,n){for(var a=r.length-1;a>=0;a--){var o=r[a],s=void 0;if(o!==n&&!o.ignore&&(s=X1(o,e,i))&&(!t.topTarget&&(t.topTarget=o),s!==pg)){t.target=o;break}}}function yg(r,t,e){var i=r.painter;return t<0||t>i.getWidth()||e<0||e>i.getHeight()}const q1=gg;var mg=32,_n=7;function K1(r){for(var t=0;r>=mg;)t|=r&1,r>>=1;return r+t}function uv(r,t,e,i){var n=t+1;if(n===e)return 1;if(i(r[n++],r[t])<0){for(;n<e&&i(r[n],r[n-1])<0;)n++;Q1(r,t,n)}else for(;n<e&&i(r[n],r[n-1])>=0;)n++;return n-t}function Q1(r,t,e){for(e--;t<e;){var i=r[t];r[t++]=r[e],r[e--]=i}}function fv(r,t,e,i,n){for(i===t&&i++;i<e;i++){for(var a=r[i],o=t,s=i,l;o<s;)l=o+s>>>1,n(a,r[l])<0?s=l:o=l+1;var u=i-o;switch(u){case 3:r[o+3]=r[o+2];case 2:r[o+2]=r[o+1];case 1:r[o+1]=r[o];break;default:for(;u>0;)r[o+u]=r[o+u-1],u--}r[o]=a}}function ol(r,t,e,i,n,a){var o=0,s=0,l=1;if(a(r,t[e+n])>0){for(s=i-n;l<s&&a(r,t[e+n+l])>0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=n,l+=n}else{for(s=n+1;l<s&&a(r,t[e+n-l])<=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=n-l,l=n-u}for(o++;o<l;){var f=o+(l-o>>>1);a(r,t[e+f])>0?o=f+1:l=f}return l}function sl(r,t,e,i,n,a){var o=0,s=0,l=1;if(a(r,t[e+n])<0){for(s=n+1;l<s&&a(r,t[e+n-l])<0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s);var u=o;o=n-l,l=n-u}else{for(s=i-n;l<s&&a(r,t[e+n+l])>=0;)o=l,l=(l<<1)+1,l<=0&&(l=s);l>s&&(l=s),o+=n,l+=n}for(o++;o<l;){var f=o+(l-o>>>1);a(r,t[e+f])<0?l=f:o=f+1}return l}function J1(r,t){var e=_n,i,n,a=0,o=[];i=[],n=[];function s(v,d){i[a]=v,n[a]=d,a+=1}function l(){for(;a>1;){var v=a-2;if(v>=1&&n[v-1]<=n[v]+n[v+1]||v>=2&&n[v-2]<=n[v]+n[v-1])n[v-1]<n[v+1]&&v--;else if(n[v]>n[v+1])break;f(v)}}function u(){for(;a>1;){var v=a-2;v>0&&n[v-1]<n[v+1]&&v--,f(v)}}function f(v){var d=i[v],p=n[v],g=i[v+1],y=n[v+1];n[v]=p+y,v===a-3&&(i[v+1]=i[v+2],n[v+1]=n[v+2]),a--;var m=sl(r[g],r,d,p,0,t);d+=m,p-=m,p!==0&&(y=ol(r[d+p-1],r,g,y,y-1,t),y!==0&&(p<=y?h(d,p,g,y):c(d,p,g,y)))}function h(v,d,p,g){var y=0;for(y=0;y<d;y++)o[y]=r[v+y];var m=0,_=p,S=v;if(r[S++]=r[_++],--g===0){for(y=0;y<d;y++)r[S+y]=o[m+y];return}if(d===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m];return}for(var x=e,w,b,T;;){w=0,b=0,T=!1;do if(t(r[_],o[m])<0){if(r[S++]=r[_++],b++,w=0,--g===0){T=!0;break}}else if(r[S++]=o[m++],w++,b=0,--d===1){T=!0;break}while((w|b)<x);if(T)break;do{if(w=sl(r[_],o,m,d,0,t),w!==0){for(y=0;y<w;y++)r[S+y]=o[m+y];if(S+=w,m+=w,d-=w,d<=1){T=!0;break}}if(r[S++]=r[_++],--g===0){T=!0;break}if(b=ol(o[m],r,_,g,0,t),b!==0){for(y=0;y<b;y++)r[S+y]=r[_+y];if(S+=b,_+=b,g-=b,g===0){T=!0;break}}if(r[S++]=o[m++],--d===1){T=!0;break}x--}while(w>=_n||b>=_n);if(T)break;x<0&&(x=0),x+=2}if(e=x,e<1&&(e=1),d===1){for(y=0;y<g;y++)r[S+y]=r[_+y];r[S+g]=o[m]}else{if(d===0)throw new Error;for(y=0;y<d;y++)r[S+y]=o[m+y]}}function c(v,d,p,g){var y=0;for(y=0;y<g;y++)o[y]=r[p+y];var m=v+d-1,_=g-1,S=p+g-1,x=0,w=0;if(r[S--]=r[m--],--d===0){for(x=S-(g-1),y=0;y<g;y++)r[x+y]=o[y];return}if(g===1){for(S-=d,m-=d,w=S+1,x=m+1,y=d-1;y>=0;y--)r[w+y]=r[x+y];r[S]=o[_];return}for(var b=e;;){var T=0,M=0,D=!1;do if(t(o[_],r[m])<0){if(r[S--]=r[m--],T++,M=0,--d===0){D=!0;break}}else if(r[S--]=o[_--],M++,T=0,--g===1){D=!0;break}while((T|M)<b);if(D)break;do{if(T=d-sl(o[_],r,v,d,d-1,t),T!==0){for(S-=T,m-=T,d-=T,w=S+1,x=m+1,y=T-1;y>=0;y--)r[w+y]=r[x+y];if(d===0){D=!0;break}}if(r[S--]=o[_--],--g===1){D=!0;break}if(M=g-ol(r[m],o,0,g,g-1,t),M!==0){for(S-=M,_-=M,g-=M,w=S+1,x=_+1,y=0;y<M;y++)r[w+y]=o[x+y];if(g<=1){D=!0;break}}if(r[S--]=r[m--],--d===0){D=!0;break}b--}while(T>=_n||M>=_n);if(D)break;b<0&&(b=0),b+=2}if(e=b,e<1&&(e=1),g===1){for(S-=d,m-=d,w=S+1,x=m+1,y=d-1;y>=0;y--)r[w+y]=r[x+y];r[S]=o[_]}else{if(g===0)throw new Error;for(x=S-(g-1),y=0;y<g;y++)r[x+y]=o[y]}}return{mergeRuns:l,forceMergeRuns:u,pushRun:s}}function Ao(r,t,e,i){e||(e=0),i||(i=r.length);var n=i-e;if(!(n<2)){var a=0;if(n<mg){a=uv(r,e,i,t),fv(r,e,i,e+a,t);return}var o=J1(r,t),s=K1(n);do{if(a=uv(r,e,i,t),a<s){var l=n;l>s&&(l=s),fv(r,e,e+l,e+a,t),a=l}o.pushRun(e,a),o.mergeRuns(),n-=a,e+=a}while(n!==0);o.forceMergeRuns()}}var re=1,Hn=2,Hi=4,hv=!1;function ll(){hv||(hv=!0,console.warn("z / z2 / zlevel of displayable is invalid, which may cause unexpected errors"))}function vv(r,t){return r.zlevel===t.zlevel?r.z===t.z?r.z2-t.z2:r.z-t.z:r.zlevel-t.zlevel}var j1=function(){function r(){this._roots=[],this._displayList=[],this._displayListLen=0,this.displayableSortFunc=vv}return r.prototype.traverse=function(t,e){for(var i=0;i<this._roots.length;i++)this._roots[i].traverse(t,e)},r.prototype.getDisplayList=function(t,e){e=e||!1;var i=this._displayList;return(t||!i.length)&&this.updateDisplayList(e),i},r.prototype.updateDisplayList=function(t){this._displayListLen=0;for(var e=this._roots,i=this._displayList,n=0,a=e.length;n<a;n++)this._updateAndAddDisplayable(e[n],null,t);i.length=this._displayListLen,Ao(i,vv)},r.prototype._updateAndAddDisplayable=function(t,e,i){if(!(t.ignore&&!i)){t.beforeUpdate(),t.update(),t.afterUpdate();var n=t.getClipPath();if(t.ignoreClip)e=null;else if(n){e?e=e.slice():e=[];for(var a=n,o=t;a;)a.parent=o,a.updateTransform(),e.push(a),o=a,a=a.getClipPath()}if(t.childrenRef){for(var s=t.childrenRef(),l=0;l<s.length;l++){var u=s[l];t.__dirty&&(u.__dirty|=re),this._updateAndAddDisplayable(u,e,i)}t.__dirty=0}else{var f=t;e&&e.length?f.__clipPaths=e:f.__clipPaths&&f.__clipPaths.length>0&&(f.__clipPaths=[]),isNaN(f.z)&&(ll(),f.z=0),isNaN(f.z2)&&(ll(),f.z2=0),isNaN(f.zlevel)&&(ll(),f.zlevel=0),this._displayList[this._displayListLen++]=f}var h=t.getDecalElement&&t.getDecalElement();h&&this._updateAndAddDisplayable(h,e,i);var c=t.getTextGuideLine();c&&this._updateAndAddDisplayable(c,e,i);var v=t.getTextContent();v&&this._updateAndAddDisplayable(v,e,i)}},r.prototype.addRoot=function(t){t.__zr&&t.__zr.storage===this||this._roots.push(t)},r.prototype.delRoot=function(t){if(t instanceof Array){for(var e=0,i=t.length;e<i;e++)this.delRoot(t[e]);return}var n=at(this._roots,t);n>=0&&this._roots.splice(n,1)},r.prototype.delAllRoots=function(){this._roots=[],this._displayList=[],this._displayListLen=0},r.prototype.getRoots=function(){return this._roots},r.prototype.dispose=function(){this._displayList=null,this._roots=null},r}();const tS=j1;var _g;_g=tt.hasGlobalWindow&&(window.requestAnimationFrame&&window.requestAnimationFrame.bind(window)||window.msRequestAnimationFrame&&window.msRequestAnimationFrame.bind(window)||window.mozRequestAnimationFrame||window.webkitRequestAnimationFrame)||function(r){return setTimeout(r,16)};const Fu=_g;var Do={linear:function(r){return r},quadraticIn:function(r){return r*r},quadraticOut:function(r){return r*(2-r)},quadraticInOut:function(r){return(r*=2)<1?.5*r*r:-.5*(--r*(r-2)-1)},cubicIn:function(r){return r*r*r},cubicOut:function(r){return--r*r*r+1},cubicInOut:function(r){return(r*=2)<1?.5*r*r*r:.5*((r-=2)*r*r+2)},quarticIn:function(r){return r*r*r*r},quarticOut:function(r){return 1- --r*r*r*r},quarticInOut:function(r){return(r*=2)<1?.5*r*r*r*r:-.5*((r-=2)*r*r*r-2)},quinticIn:function(r){return r*r*r*r*r},quinticOut:function(r){return--r*r*r*r*r+1},quinticInOut:function(r){return(r*=2)<1?.5*r*r*r*r*r:.5*((r-=2)*r*r*r*r+2)},sinusoidalIn:function(r){return 1-Math.cos(r*Math.PI/2)},sinusoidalOut:function(r){return Math.sin(r*Math.PI/2)},sinusoidalInOut:function(r){return .5*(1-Math.cos(Math.PI*r))},exponentialIn:function(r){return r===0?0:Math.pow(1024,r-1)},exponentialOut:function(r){return r===1?1:1-Math.pow(2,-10*r)},exponentialInOut:function(r){return r===0?0:r===1?1:(r*=2)<1?.5*Math.pow(1024,r-1):.5*(-Math.pow(2,-10*(r-1))+2)},circularIn:function(r){return 1-Math.sqrt(1-r*r)},circularOut:function(r){return Math.sqrt(1- --r*r)},circularInOut:function(r){return(r*=2)<1?-.5*(Math.sqrt(1-r*r)-1):.5*(Math.sqrt(1-(r-=2)*r)+1)},elasticIn:function(r){var t,e=.1,i=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=i/4):t=i*Math.asin(1/e)/(2*Math.PI),-(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/i)))},elasticOut:function(r){var t,e=.1,i=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=i/4):t=i*Math.asin(1/e)/(2*Math.PI),e*Math.pow(2,-10*r)*Math.sin((r-t)*(2*Math.PI)/i)+1)},elasticInOut:function(r){var t,e=.1,i=.4;return r===0?0:r===1?1:(!e||e<1?(e=1,t=i/4):t=i*Math.asin(1/e)/(2*Math.PI),(r*=2)<1?-.5*(e*Math.pow(2,10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/i)):e*Math.pow(2,-10*(r-=1))*Math.sin((r-t)*(2*Math.PI)/i)*.5+1)},backIn:function(r){var t=1.70158;return r*r*((t+1)*r-t)},backOut:function(r){var t=1.70158;return--r*r*((t+1)*r+t)+1},backInOut:function(r){var t=2.5949095;return(r*=2)<1?.5*(r*r*((t+1)*r-t)):.5*((r-=2)*r*((t+1)*r+t)+2)},bounceIn:function(r){return 1-Do.bounceOut(1-r)},bounceOut:function(r){return r<1/2.75?7.5625*r*r:r<2/2.75?7.5625*(r-=1.5/2.75)*r+.75:r<2.5/2.75?7.5625*(r-=2.25/2.75)*r+.9375:7.5625*(r-=2.625/2.75)*r+.984375},bounceInOut:function(r){return r<.5?Do.bounceIn(r*2)*.5:Do.bounceOut(r*2-1)*.5+.5}};const Sg=Do;var za=Math.pow,Cr=Math.sqrt,Uo=1e-8,wg=1e-4,cv=Cr(3),Fa=1/3,Ne=ln(),ve=ln(),Qi=ln();function Sr(r){return r>-Uo&&r<Uo}function xg(r){return r>Uo||r<-Uo}function Tt(r,t,e,i,n){var a=1-n;return a*a*(a*r+3*n*t)+n*n*(n*i+3*a*e)}function dv(r,t,e,i,n){var a=1-n;return 3*(((t-r)*a+2*(e-t)*n)*a+(i-e)*n*n)}function Yo(r,t,e,i,n,a){var o=i+3*(t-e)-r,s=3*(e-t*2+r),l=3*(t-r),u=r-n,f=s*s-3*o*l,h=s*l-9*o*u,c=l*l-3*s*u,v=0;if(Sr(f)&&Sr(h))if(Sr(s))a[0]=0;else{var d=-l/s;d>=0&&d<=1&&(a[v++]=d)}else{var p=h*h-4*f*c;if(Sr(p)){var g=h/f,d=-s/o+g,y=-g/2;d>=0&&d<=1&&(a[v++]=d),y>=0&&y<=1&&(a[v++]=y)}else if(p>0){var m=Cr(p),_=f*s+1.5*o*(-h+m),S=f*s+1.5*o*(-h-m);_<0?_=-za(-_,Fa):_=za(_,Fa),S<0?S=-za(-S,Fa):S=za(S,Fa);var d=(-s-(_+S))/(3*o);d>=0&&d<=1&&(a[v++]=d)}else{var x=(2*f*s-3*o*h)/(2*Cr(f*f*f)),w=Math.acos(x)/3,b=Cr(f),T=Math.cos(w),d=(-s-2*b*T)/(3*o),y=(-s+b*(T+cv*Math.sin(w)))/(3*o),M=(-s+b*(T-cv*Math.sin(w)))/(3*o);d>=0&&d<=1&&(a[v++]=d),y>=0&&y<=1&&(a[v++]=y),M>=0&&M<=1&&(a[v++]=M)}}return v}function bg(r,t,e,i,n){var a=6*e-12*t+6*r,o=9*t+3*i-3*r-9*e,s=3*t-3*r,l=0;if(Sr(o)){if(xg(a)){var u=-s/a;u>=0&&u<=1&&(n[l++]=u)}}else{var f=a*a-4*o*s;if(Sr(f))n[0]=-a/(2*o);else if(f>0){var h=Cr(f),u=(-a+h)/(2*o),c=(-a-h)/(2*o);u>=0&&u<=1&&(n[l++]=u),c>=0&&c<=1&&(n[l++]=c)}}return l}function $o(r,t,e,i,n,a){var o=(t-r)*n+r,s=(e-t)*n+t,l=(i-e)*n+e,u=(s-o)*n+o,f=(l-s)*n+s,h=(f-u)*n+u;a[0]=r,a[1]=o,a[2]=u,a[3]=h,a[4]=h,a[5]=f,a[6]=l,a[7]=i}function eS(r,t,e,i,n,a,o,s,l,u,f){var h,c=.005,v=1/0,d,p,g,y;Ne[0]=l,Ne[1]=u;for(var m=0;m<1;m+=.05)ve[0]=Tt(r,e,n,o,m),ve[1]=Tt(t,i,a,s,m),g=Xi(Ne,ve),g<v&&(h=m,v=g);v=1/0;for(var _=0;_<32&&!(c<wg);_++)d=h-c,p=h+c,ve[0]=Tt(r,e,n,o,d),ve[1]=Tt(t,i,a,s,d),g=Xi(ve,Ne),d>=0&&g<v?(h=d,v=g):(Qi[0]=Tt(r,e,n,o,p),Qi[1]=Tt(t,i,a,s,p),y=Xi(Qi,Ne),p<=1&&y<v?(h=p,v=y):c*=.5);return f&&(f[0]=Tt(r,e,n,o,h),f[1]=Tt(t,i,a,s,h)),Cr(v)}function rS(r,t,e,i,n,a,o,s,l){for(var u=r,f=t,h=0,c=1/l,v=1;v<=l;v++){var d=v*c,p=Tt(r,e,n,o,d),g=Tt(t,i,a,s,d),y=p-u,m=g-f;h+=Math.sqrt(y*y+m*m),u=p,f=g}return h}function zt(r,t,e,i){var n=1-i;return n*(n*r+2*i*t)+i*i*e}function pv(r,t,e,i){return 2*((1-i)*(t-r)+i*(e-t))}function iS(r,t,e,i,n){var a=r-2*t+e,o=2*(t-r),s=r-i,l=0;if(Sr(a)){if(xg(o)){var u=-s/o;u>=0&&u<=1&&(n[l++]=u)}}else{var f=o*o-4*a*s;if(Sr(f)){var u=-o/(2*a);u>=0&&u<=1&&(n[l++]=u)}else if(f>0){var h=Cr(f),u=(-o+h)/(2*a),c=(-o-h)/(2*a);u>=0&&u<=1&&(n[l++]=u),c>=0&&c<=1&&(n[l++]=c)}}return l}function Tg(r,t,e){var i=r+e-2*t;return i===0?.5:(r-t)/i}function Zo(r,t,e,i,n){var a=(t-r)*i+r,o=(e-t)*i+t,s=(o-a)*i+a;n[0]=r,n[1]=a,n[2]=s,n[3]=s,n[4]=o,n[5]=e}function nS(r,t,e,i,n,a,o,s,l){var u,f=.005,h=1/0;Ne[0]=o,Ne[1]=s;for(var c=0;c<1;c+=.05){ve[0]=zt(r,e,n,c),ve[1]=zt(t,i,a,c);var v=Xi(Ne,ve);v<h&&(u=c,h=v)}h=1/0;for(var d=0;d<32&&!(f<wg);d++){var p=u-f,g=u+f;ve[0]=zt(r,e,n,p),ve[1]=zt(t,i,a,p);var v=Xi(ve,Ne);if(p>=0&&v<h)u=p,h=v;else{Qi[0]=zt(r,e,n,g),Qi[1]=zt(t,i,a,g);var y=Xi(Qi,Ne);g<=1&&y<h?(u=g,h=y):f*=.5}}return l&&(l[0]=zt(r,e,n,u),l[1]=zt(t,i,a,u)),Cr(h)}function aS(r,t,e,i,n,a,o){for(var s=r,l=t,u=0,f=1/o,h=1;h<=o;h++){var c=h*f,v=zt(r,e,n,c),d=zt(t,i,a,c),p=v-s,g=d-l;u+=Math.sqrt(p*p+g*g),s=v,l=d}return u}var oS=/cubic-bezier\(([0-9,\.e ]+)\)/;function Cg(r){var t=r&&oS.exec(r);if(t){var e=t[1].split(","),i=+Fe(e[0]),n=+Fe(e[1]),a=+Fe(e[2]),o=+Fe(e[3]);if(isNaN(i+n+a+o))return;var s=[];return function(l){return l<=0?0:l>=1?1:Yo(0,i,a,1,l,s)&&Tt(0,n,o,1,s[0])}}}var sS=function(){function r(t){this._inited=!1,this._startTime=0,this._pausedTime=0,this._paused=!1,this._life=t.life||1e3,this._delay=t.delay||0,this.loop=t.loop||!1,this.onframe=t.onframe||Gt,this.ondestroy=t.ondestroy||Gt,this.onrestart=t.onrestart||Gt,t.easing&&this.setEasing(t.easing)}return r.prototype.step=function(t,e){if(this._inited||(this._startTime=t+this._delay,this._inited=!0),this._paused){this._pausedTime+=e;return}var i=this._life,n=t-this._startTime-this._pausedTime,a=n/i;a<0&&(a=0),a=Math.min(a,1);var o=this.easingFunc,s=o?o(a):a;if(this.onframe(s),a===1)if(this.loop){var l=n%i;this._startTime=t-l,this._pausedTime=0,this.onrestart()}else return!0;return!1},r.prototype.pause=function(){this._paused=!0},r.prototype.resume=function(){this._paused=!1},r.prototype.setEasing=function(t){this.easing=t,this.easingFunc=K(t)?t:Sg[t]||Cg(t)},r}();const lS=sS;var Mg=function(){function r(t){this.value=t}return r}(),uS=function(){function r(){this._len=0}return r.prototype.insert=function(t){var e=new Mg(t);return this.insertEntry(e),e},r.prototype.insertEntry=function(t){this.head?(this.tail.next=t,t.prev=this.tail,t.next=null,this.tail=t):this.head=this.tail=t,this._len++},r.prototype.remove=function(t){var e=t.prev,i=t.next;e?e.next=i:this.head=i,i?i.prev=e:this.tail=e,t.next=t.prev=null,this._len--},r.prototype.len=function(){return this._len},r.prototype.clear=function(){this.head=this.tail=null,this._len=0},r}(),fS=function(){function r(t){this._list=new uS,this._maxSize=10,this._map={},this._maxSize=t}return r.prototype.put=function(t,e){var i=this._list,n=this._map,a=null;if(n[t]==null){var o=i.len(),s=this._lastRemovedEntry;if(o>=this._maxSize&&o>0){var l=i.head;i.remove(l),delete n[l.key],a=l.value,this._lastRemovedEntry=l}s?s.value=e:s=new Mg(e),s.key=t,i.insertEntry(s),n[t]=s}return a},r.prototype.get=function(t){var e=this._map[t],i=this._list;if(e!=null)return e!==i.tail&&(i.remove(e),i.insertEntry(e)),e.value},r.prototype.clear=function(){this._list.clear(),this._map={}},r.prototype.len=function(){return this._list.len()},r}();const Ma=fS;var gv={transparent:[0,0,0,0],aliceblue:[240,248,255,1],antiquewhite:[250,235,215,1],aqua:[0,255,255,1],aquamarine:[127,255,212,1],azure:[240,255,255,1],beige:[245,245,220,1],bisque:[255,228,196,1],black:[0,0,0,1],blanchedalmond:[255,235,205,1],blue:[0,0,255,1],blueviolet:[138,43,226,1],brown:[165,42,42,1],burlywood:[222,184,135,1],cadetblue:[95,158,160,1],chartreuse:[127,255,0,1],chocolate:[210,105,30,1],coral:[255,127,80,1],cornflowerblue:[100,149,237,1],cornsilk:[255,248,220,1],crimson:[220,20,60,1],cyan:[0,255,255,1],darkblue:[0,0,139,1],darkcyan:[0,139,139,1],darkgoldenrod:[184,134,11,1],darkgray:[169,169,169,1],darkgreen:[0,100,0,1],darkgrey:[169,169,169,1],darkkhaki:[189,183,107,1],darkmagenta:[139,0,139,1],darkolivegreen:[85,107,47,1],darkorange:[255,140,0,1],darkorchid:[153,50,204,1],darkred:[139,0,0,1],darksalmon:[233,150,122,1],darkseagreen:[143,188,143,1],darkslateblue:[72,61,139,1],darkslategray:[47,79,79,1],darkslategrey:[47,79,79,1],darkturquoise:[0,206,209,1],darkviolet:[148,0,211,1],deeppink:[255,20,147,1],deepskyblue:[0,191,255,1],dimgray:[105,105,105,1],dimgrey:[105,105,105,1],dodgerblue:[30,144,255,1],firebrick:[178,34,34,1],floralwhite:[255,250,240,1],forestgreen:[34,139,34,1],fuchsia:[255,0,255,1],gainsboro:[220,220,220,1],ghostwhite:[248,248,255,1],gold:[255,215,0,1],goldenrod:[218,165,32,1],gray:[128,128,128,1],green:[0,128,0,1],greenyellow:[173,255,47,1],grey:[128,128,128,1],honeydew:[240,255,240,1],hotpink:[255,105,180,1],indianred:[205,92,92,1],indigo:[75,0,130,1],ivory:[255,255,240,1],khaki:[240,230,140,1],lavender:[230,230,250,1],lavenderblush:[255,240,245,1],lawngreen:[124,252,0,1],lemonchiffon:[255,250,205,1],lightblue:[173,216,230,1],lightcoral:[240,128,128,1],lightcyan:[224,255,255,1],lightgoldenrodyellow:[250,250,210,1],lightgray:[211,211,211,1],lightgreen:[144,238,144,1],lightgrey:[211,211,211,1],lightpink:[255,182,193,1],lightsalmon:[255,160,122,1],lightseagreen:[32,178,170,1],lightskyblue:[135,206,250,1],lightslategray:[119,136,153,1],lightslategrey:[119,136,153,1],lightsteelblue:[176,196,222,1],lightyellow:[255,255,224,1],lime:[0,255,0,1],limegreen:[50,205,50,1],linen:[250,240,230,1],magenta:[255,0,255,1],maroon:[128,0,0,1],mediumaquamarine:[102,205,170,1],mediumblue:[0,0,205,1],mediumorchid:[186,85,211,1],mediumpurple:[147,112,219,1],mediumseagreen:[60,179,113,1],mediumslateblue:[123,104,238,1],mediumspringgreen:[0,250,154,1],mediumturquoise:[72,209,204,1],mediumvioletred:[199,21,133,1],midnightblue:[25,25,112,1],mintcream:[245,255,250,1],mistyrose:[255,228,225,1],moccasin:[255,228,181,1],navajowhite:[255,222,173,1],navy:[0,0,128,1],oldlace:[253,245,230,1],olive:[128,128,0,1],olivedrab:[107,142,35,1],orange:[255,165,0,1],orangered:[255,69,0,1],orchid:[218,112,214,1],palegoldenrod:[238,232,170,1],palegreen:[152,251,152,1],paleturquoise:[175,238,238,1],palevioletred:[219,112,147,1],papayawhip:[255,239,213,1],peachpuff:[255,218,185,1],peru:[205,133,63,1],pink:[255,192,203,1],plum:[221,160,221,1],powderblue:[176,224,230,1],purple:[128,0,128,1],red:[255,0,0,1],rosybrown:[188,143,143,1],royalblue:[65,105,225,1],saddlebrown:[139,69,19,1],salmon:[250,128,114,1],sandybrown:[244,164,96,1],seagreen:[46,139,87,1],seashell:[255,245,238,1],sienna:[160,82,45,1],silver:[192,192,192,1],skyblue:[135,206,235,1],slateblue:[106,90,205,1],slategray:[112,128,144,1],slategrey:[112,128,144,1],snow:[255,250,250,1],springgreen:[0,255,127,1],steelblue:[70,130,180,1],tan:[210,180,140,1],teal:[0,128,128,1],thistle:[216,191,216,1],tomato:[255,99,71,1],turquoise:[64,224,208,1],violet:[238,130,238,1],wheat:[245,222,179,1],white:[255,255,255,1],whitesmoke:[245,245,245,1],yellow:[255,255,0,1],yellowgreen:[154,205,50,1]};function Mr(r){return r=Math.round(r),r<0?0:r>255?255:r}function Vu(r){return r<0?0:r>1?1:r}function ul(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?Mr(parseFloat(t)/100*255):Mr(parseInt(t,10))}function Jn(r){var t=r;return t.length&&t.charAt(t.length-1)==="%"?Vu(parseFloat(t)/100):Vu(parseFloat(t))}function fl(r,t,e){return e<0?e+=1:e>1&&(e-=1),e*6<1?r+(t-r)*e*6:e*2<1?t:e*3<2?r+(t-r)*(2/3-e)*6:r}function Va(r,t,e){return r+(t-r)*e}function se(r,t,e,i,n){return r[0]=t,r[1]=e,r[2]=i,r[3]=n,r}function Hu(r,t){return r[0]=t[0],r[1]=t[1],r[2]=t[2],r[3]=t[3],r}var Ag=new Ma(20),Ha=null;function Mi(r,t){Ha&&Hu(Ha,t),Ha=Ag.put(r,Ha||t.slice())}function Qe(r,t){if(!!r){t=t||[];var e=Ag.get(r);if(e)return Hu(t,e);r=r+"";var i=r.replace(/ /g,"").toLowerCase();if(i in gv)return Hu(t,gv[i]),Mi(r,t),t;var n=i.length;if(i.charAt(0)==="#"){if(n===4||n===5){var a=parseInt(i.slice(1,4),16);if(!(a>=0&&a<=4095)){se(t,0,0,0,1);return}return se(t,(a&3840)>>4|(a&3840)>>8,a&240|(a&240)>>4,a&15|(a&15)<<4,n===5?parseInt(i.slice(4),16)/15:1),Mi(r,t),t}else if(n===7||n===9){var a=parseInt(i.slice(1,7),16);if(!(a>=0&&a<=16777215)){se(t,0,0,0,1);return}return se(t,(a&16711680)>>16,(a&65280)>>8,a&255,n===9?parseInt(i.slice(7),16)/255:1),Mi(r,t),t}return}var o=i.indexOf("("),s=i.indexOf(")");if(o!==-1&&s+1===n){var l=i.substr(0,o),u=i.substr(o+1,s-(o+1)).split(","),f=1;switch(l){case"rgba":if(u.length!==4)return u.length===3?se(t,+u[0],+u[1],+u[2],1):se(t,0,0,0,1);f=Jn(u.pop());case"rgb":if(u.length>=3)return se(t,ul(u[0]),ul(u[1]),ul(u[2]),u.length===3?f:Jn(u[3])),Mi(r,t),t;se(t,0,0,0,1);return;case"hsla":if(u.length!==4){se(t,0,0,0,1);return}return u[3]=Jn(u[3]),yv(u,t),Mi(r,t),t;case"hsl":if(u.length!==3){se(t,0,0,0,1);return}return yv(u,t),Mi(r,t),t;default:return}}se(t,0,0,0,1)}}function yv(r,t){var e=(parseFloat(r[0])%360+360)%360/360,i=Jn(r[1]),n=Jn(r[2]),a=n<=.5?n*(i+1):n+i-n*i,o=n*2-a;return t=t||[],se(t,Mr(fl(o,a,e+1/3)*255),Mr(fl(o,a,e)*255),Mr(fl(o,a,e-1/3)*255),1),r.length===4&&(t[3]=r[3]),t}function mv(r,t){var e=Qe(r);if(e){for(var i=0;i<3;i++)t<0?e[i]=e[i]*(1-t)|0:e[i]=(255-e[i])*t+e[i]|0,e[i]>255?e[i]=255:e[i]<0&&(e[i]=0);return Ts(e,e.length===4?"rgba":"rgb")}}function hS(r,t,e){if(!(!(t&&t.length)||!(r>=0&&r<=1))){var i=r*(t.length-1),n=Math.floor(i),a=Math.ceil(i),o=Qe(t[n]),s=Qe(t[a]),l=i-n,u=Ts([Mr(Va(o[0],s[0],l)),Mr(Va(o[1],s[1],l)),Mr(Va(o[2],s[2],l)),Vu(Va(o[3],s[3],l))],"rgba");return e?{color:u,leftIndex:n,rightIndex:a,value:i}:u}}function Ts(r,t){if(!(!r||!r.length)){var e=r[0]+","+r[1]+","+r[2];return(t==="rgba"||t==="hsva"||t==="hsla")&&(e+=","+r[3]),t+"("+e+")"}}function Xo(r,t){var e=Qe(r);return e?(.299*e[0]+.587*e[1]+.114*e[2])*e[3]/255+(1-e[3])*t:0}var _v=new Ma(100);function Sv(r){if(W(r)){var t=_v.get(r);return t||(t=mv(r,-.1),_v.put(r,t)),t}else if(xs(r)){var e=O({},r);return e.colorStops=G(r.colorStops,function(i){return{offset:i.offset,color:mv(i.color,-.1)}}),e}return r}function vS(r){return r.type==="linear"}function cS(r){return r.type==="radial"}(function(){return tt.hasGlobalWindow&&K(window.btoa)?function(r){return window.btoa(unescape(encodeURIComponent(r)))}:typeof Buffer<"u"?function(r){return Buffer.from(r).toString("base64")}:function(r){return null}})();var Gu=Array.prototype.slice;function Ze(r,t,e){return(t-r)*e+r}function hl(r,t,e,i){for(var n=t.length,a=0;a<n;a++)r[a]=Ze(t[a],e[a],i);return r}function dS(r,t,e,i){for(var n=t.length,a=n&&t[0].length,o=0;o<n;o++){r[o]||(r[o]=[]);for(var s=0;s<a;s++)r[o][s]=Ze(t[o][s],e[o][s],i)}return r}function Ga(r,t,e,i){for(var n=t.length,a=0;a<n;a++)r[a]=t[a]+e[a]*i;return r}function wv(r,t,e,i){for(var n=t.length,a=n&&t[0].length,o=0;o<n;o++){r[o]||(r[o]=[]);for(var s=0;s<a;s++)r[o][s]=t[o][s]+e[o][s]*i}return r}function pS(r,t){for(var e=r.length,i=t.length,n=e>i?t:r,a=Math.min(e,i),o=n[a-1]||{color:[0,0,0,0],offset:0},s=a;s<Math.max(e,i);s++)n.push({offset:o.offset,color:o.color.slice()})}function gS(r,t,e){var i=r,n=t;if(!(!i.push||!n.push)){var a=i.length,o=n.length;if(a!==o){var s=a>o;if(s)i.length=o;else for(var l=a;l<o;l++)i.push(e===1?n[l]:Gu.call(n[l]))}for(var u=i[0]&&i[0].length,l=0;l<i.length;l++)if(e===1)isNaN(i[l])&&(i[l]=n[l]);else for(var f=0;f<u;f++)isNaN(i[l][f])&&(i[l][f]=n[l][f])}}function jn(r){if(Wt(r)){var t=r.length;if(Wt(r[0])){for(var e=[],i=0;i<t;i++)e.push(Gu.call(r[i]));return e}return Gu.call(r)}return r}function Lo(r){return r[0]=Math.floor(r[0])||0,r[1]=Math.floor(r[1])||0,r[2]=Math.floor(r[2])||0,r[3]=r[3]==null?1:r[3],"rgba("+r.join(",")+")"}function yS(r){return Wt(r&&r[0])?2:1}var Wa=0,Io=1,Dg=2,Gn=3,Wu=4,Uu=5,xv=6;function bv(r){return r===Wu||r===Uu}function Ua(r){return r===Io||r===Dg}var Sn=[0,0,0,0],mS=function(){function r(t){this.keyframes=[],this.discrete=!1,this._invalid=!1,this._needsSort=!1,this._lastFr=0,this._lastFrP=0,this.propName=t}return r.prototype.isFinished=function(){return this._finished},r.prototype.setFinished=function(){this._finished=!0,this._additiveTrack&&this._additiveTrack.setFinished()},r.prototype.needsAnimate=function(){return this.keyframes.length>=1},r.prototype.getAdditiveTrack=function(){return this._additiveTrack},r.prototype.addKeyframe=function(t,e,i){this._needsSort=!0;var n=this.keyframes,a=n.length,o=!1,s=xv,l=e;if(Wt(e)){var u=yS(e);s=u,(u===1&&!dt(e[0])||u===2&&!dt(e[0][0]))&&(o=!0)}else if(dt(e)&&!Wo(e))s=Wa;else if(W(e))if(!isNaN(+e))s=Wa;else{var f=Qe(e);f&&(l=f,s=Gn)}else if(xs(e)){var h=O({},l);h.colorStops=G(e.colorStops,function(v){return{offset:v.offset,color:Qe(v.color)}}),vS(e)?s=Wu:cS(e)&&(s=Uu),l=h}a===0?this.valType=s:(s!==this.valType||s===xv)&&(o=!0),this.discrete=this.discrete||o;var c={time:t,value:l,rawValue:e,percent:0};return i&&(c.easing=i,c.easingFunc=K(i)?i:Sg[i]||Cg(i)),n.push(c),c},r.prototype.prepare=function(t,e){var i=this.keyframes;this._needsSort&&i.sort(function(p,g){return p.time-g.time});for(var n=this.valType,a=i.length,o=i[a-1],s=this.discrete,l=Ua(n),u=bv(n),f=0;f<a;f++){var h=i[f],c=h.value,v=o.value;h.percent=h.time/t,s||(l&&f!==a-1?gS(c,v,n):u&&pS(c.colorStops,v.colorStops))}if(!s&&n!==Uu&&e&&this.needsAnimate()&&e.needsAnimate()&&n===e.valType&&!e._finished){this._additiveTrack=e;for(var d=i[0].value,f=0;f<a;f++)n===Wa?i[f].additiveValue=i[f].value-d:n===Gn?i[f].additiveValue=Ga([],i[f].value,d,-1):Ua(n)&&(i[f].additiveValue=n===Io?Ga([],i[f].value,d,-1):wv([],i[f].value,d,-1))}},r.prototype.step=function(t,e){if(!this._finished){this._additiveTrack&&this._additiveTrack._finished&&(this._additiveTrack=null);var i=this._additiveTrack!=null,n=i?"additiveValue":"value",a=this.valType,o=this.keyframes,s=o.length,l=this.propName,u=a===Gn,f,h=this._lastFr,c=Math.min,v,d;if(s===1)v=d=o[0];else{if(e<0)f=0;else if(e<this._lastFrP){var p=c(h+1,s-1);for(f=p;f>=0&&!(o[f].percent<=e);f--);f=c(f,s-2)}else{for(f=h;f<s&&!(o[f].percent>e);f++);f=c(f-1,s-2)}d=o[f+1],v=o[f]}if(!!(v&&d)){this._lastFr=f,this._lastFrP=e;var g=d.percent-v.percent,y=g===0?1:c((e-v.percent)/g,1);d.easingFunc&&(y=d.easingFunc(y));var m=i?this._additiveValue:u?Sn:t[l];if((Ua(a)||u)&&!m&&(m=this._additiveValue=[]),this.discrete)t[l]=y<1?v.rawValue:d.rawValue;else if(Ua(a))a===Io?hl(m,v[n],d[n],y):dS(m,v[n],d[n],y);else if(bv(a)){var _=v[n],S=d[n],x=a===Wu;t[l]={type:x?"linear":"radial",x:Ze(_.x,S.x,y),y:Ze(_.y,S.y,y),colorStops:G(_.colorStops,function(b,T){var M=S.colorStops[T];return{offset:Ze(b.offset,M.offset,y),color:Lo(hl([],b.color,M.color,y))}}),global:S.global},x?(t[l].x2=Ze(_.x2,S.x2,y),t[l].y2=Ze(_.y2,S.y2,y)):t[l].r=Ze(_.r,S.r,y)}else if(u)hl(m,v[n],d[n],y),i||(t[l]=Lo(m));else{var w=Ze(v[n],d[n],y);i?this._additiveValue=w:t[l]=w}i&&this._addToTarget(t)}}},r.prototype._addToTarget=function(t){var e=this.valType,i=this.propName,n=this._additiveValue;e===Wa?t[i]=t[i]+n:e===Gn?(Qe(t[i],Sn),Ga(Sn,Sn,n,1),t[i]=Lo(Sn)):e===Io?Ga(t[i],t[i],n,1):e===Dg&&wv(t[i],t[i],n,1)},r}(),Xf=function(){function r(t,e,i,n){if(this._tracks={},this._trackKeys=[],this._maxTime=0,this._started=0,this._clip=null,this._target=t,this._loop=e,e&&n){Gf("Can' use additive animation on looped animation.");return}this._additiveAnimators=n,this._allowDiscrete=i}return r.prototype.getMaxTime=function(){return this._maxTime},r.prototype.getDelay=function(){return this._delay},r.prototype.getLoop=function(){return this._loop},r.prototype.getTarget=function(){return this._target},r.prototype.changeTarget=function(t){this._target=t},r.prototype.when=function(t,e,i){return this.whenWithKeys(t,e,vt(e),i)},r.prototype.whenWithKeys=function(t,e,i,n){for(var a=this._tracks,o=0;o<i.length;o++){var s=i[o],l=a[s];if(!l){l=a[s]=new mS(s);var u=void 0,f=this._getAdditiveTrack(s);if(f){var h=f.keyframes,c=h[h.length-1];u=c&&c.value,f.valType===Gn&&u&&(u=Lo(u))}else u=this._target[s];if(u==null)continue;t>0&&l.addKeyframe(0,jn(u),n),this._trackKeys.push(s)}l.addKeyframe(t,jn(e[s]),n)}return this._maxTime=Math.max(this._maxTime,t),this},r.prototype.pause=function(){this._clip.pause(),this._paused=!0},r.prototype.resume=function(){this._clip.resume(),this._paused=!1},r.prototype.isPaused=function(){return!!this._paused},r.prototype.duration=function(t){return this._maxTime=t,this._force=!0,this},r.prototype._doneCallback=function(){this._setTracksFinished(),this._clip=null;var t=this._doneCbs;if(t)for(var e=t.length,i=0;i<e;i++)t[i].call(this)},r.prototype._abortedCallback=function(){this._setTracksFinished();var t=this.animation,e=this._abortedCbs;if(t&&t.removeClip(this._clip),this._clip=null,e)for(var i=0;i<e.length;i++)e[i].call(this)},r.prototype._setTracksFinished=function(){for(var t=this._tracks,e=this._trackKeys,i=0;i<e.length;i++)t[e[i]].setFinished()},r.prototype._getAdditiveTrack=function(t){var e,i=this._additiveAnimators;if(i)for(var n=0;n<i.length;n++){var a=i[n].getTrack(t);a&&(e=a)}return e},r.prototype.start=function(t){if(!(this._started>0)){this._started=1;for(var e=this,i=[],n=this._maxTime||0,a=0;a<this._trackKeys.length;a++){var o=this._trackKeys[a],s=this._tracks[o],l=this._getAdditiveTrack(o),u=s.keyframes,f=u.length;if(s.prepare(n,l),s.needsAnimate())if(!this._allowDiscrete&&s.discrete){var h=u[f-1];h&&(e._target[s.propName]=h.rawValue),s.setFinished()}else i.push(s)}if(i.length||this._force){var c=new lS({life:n,loop:this._loop,delay:this._delay||0,onframe:function(v){e._started=2;var d=e._additiveAnimators;if(d){for(var p=!1,g=0;g<d.length;g++)if(d[g]._clip){p=!0;break}p||(e._additiveAnimators=null)}for(var g=0;g<i.length;g++)i[g].step(e._target,v);var y=e._onframeCbs;if(y)for(var g=0;g<y.length;g++)y[g](e._target,v)},ondestroy:function(){e._doneCallback()}});this._clip=c,this.animation&&this.animation.addClip(c),t&&c.setEasing(t)}else this._doneCallback();return this}},r.prototype.stop=function(t){if(!!this._clip){var e=this._clip;t&&e.onframe(1),this._abortedCallback()}},r.prototype.delay=function(t){return this._delay=t,this},r.prototype.during=function(t){return t&&(this._onframeCbs||(this._onframeCbs=[]),this._onframeCbs.push(t)),this},r.prototype.done=function(t){return t&&(this._doneCbs||(this._doneCbs=[]),this._doneCbs.push(t)),this},r.prototype.aborted=function(t){return t&&(this._abortedCbs||(this._abortedCbs=[]),this._abortedCbs.push(t)),this},r.prototype.getClip=function(){return this._clip},r.prototype.getTrack=function(t){return this._tracks[t]},r.prototype.getTracks=function(){var t=this;return G(this._trackKeys,function(e){return t._tracks[e]})},r.prototype.stopTracks=function(t,e){if(!t.length||!this._clip)return!0;for(var i=this._tracks,n=this._trackKeys,a=0;a<t.length;a++){var o=i[t[a]];o&&!o.isFinished()&&(e?o.step(this._target,1):this._started===1&&o.step(this._target,0),o.setFinished())}for(var s=!0,a=0;a<n.length;a++)if(!i[n[a]].isFinished()){s=!1;break}return s&&this._abortedCallback(),s},r.prototype.saveTo=function(t,e,i){if(!!t){e=e||this._trackKeys;for(var n=0;n<e.length;n++){var a=e[n],o=this._tracks[a];if(!(!o||o.isFinished())){var s=o.keyframes,l=s[i?0:s.length-1];l&&(t[a]=jn(l.rawValue))}}}},r.prototype.__changeFinalValue=function(t,e){e=e||vt(t);for(var i=0;i<e.length;i++){var n=e[i],a=this._tracks[n];if(!!a){var o=a.keyframes;if(o.length>1){var s=o.pop();a.addKeyframe(s.time,t[n]),a.prepare(this._maxTime,a.getAdditiveTrack())}}}},r}();function $i(){return new Date().getTime()}var _S=function(r){N(t,r);function t(e){var i=r.call(this)||this;return i._running=!1,i._time=0,i._pausedTime=0,i._pauseStart=0,i._paused=!1,e=e||{},i.stage=e.stage||{},i}return t.prototype.addClip=function(e){e.animation&&this.removeClip(e),this._head?(this._tail.next=e,e.prev=this._tail,e.next=null,this._tail=e):this._head=this._tail=e,e.animation=this},t.prototype.addAnimator=function(e){e.animation=this;var i=e.getClip();i&&this.addClip(i)},t.prototype.removeClip=function(e){if(!!e.animation){var i=e.prev,n=e.next;i?i.next=n:this._head=n,n?n.prev=i:this._tail=i,e.next=e.prev=e.animation=null}},t.prototype.removeAnimator=function(e){var i=e.getClip();i&&this.removeClip(i),e.animation=null},t.prototype.update=function(e){for(var i=$i()-this._pausedTime,n=i-this._time,a=this._head;a;){var o=a.next,s=a.step(i,n);s&&(a.ondestroy(),this.removeClip(a)),a=o}this._time=i,e||(this.trigger("frame",n),this.stage.update&&this.stage.update())},t.prototype._startLoop=function(){var e=this;this._running=!0;function i(){e._running&&(Fu(i),!e._paused&&e.update())}Fu(i)},t.prototype.start=function(){this._running||(this._time=$i(),this._pausedTime=0,this._startLoop())},t.prototype.stop=function(){this._running=!1},t.prototype.pause=function(){this._paused||(this._pauseStart=$i(),this._paused=!0)},t.prototype.resume=function(){this._paused&&(this._pausedTime+=$i()-this._pauseStart,this._paused=!1)},t.prototype.clear=function(){for(var e=this._head;e;){var i=e.next;e.prev=e.next=e.animation=null,e=i}this._head=this._tail=null},t.prototype.isFinished=function(){return this._head==null},t.prototype.animate=function(e,i){i=i||{},this.start();var n=new Xf(e,i.loop);return this.addAnimator(n),n},t}(Ae);const SS=_S;var wS=300,vl=tt.domSupported,cl=function(){var r=["click","dblclick","mousewheel","wheel","mouseout","mouseup","mousedown","mousemove","contextmenu"],t=["touchstart","touchend","touchmove"],e={pointerdown:1,pointerup:1,pointermove:1,pointerout:1},i=G(r,function(n){var a=n.replace("mouse","pointer");return e.hasOwnProperty(a)?a:n});return{mouse:r,touch:t,pointer:i}}(),Tv={mouse:["mousemove","mouseup"],pointer:["pointermove","pointerup"]},Cv=!1;function Yu(r){var t=r.pointerType;return t==="pen"||t==="touch"}function xS(r){r.touching=!0,r.touchTimer!=null&&(clearTimeout(r.touchTimer),r.touchTimer=null),r.touchTimer=setTimeout(function(){r.touching=!1,r.touchTimer=null},700)}function dl(r){r&&(r.zrByTouch=!0)}function bS(r,t){return le(r.dom,new TS(r,t),!0)}function Lg(r,t){for(var e=t,i=!1;e&&e.nodeType!==9&&!(i=e.domBelongToZr||e!==t&&e===r.painterRoot);)e=e.parentNode;return i}var TS=function(){function r(t,e){this.stopPropagation=Gt,this.stopImmediatePropagation=Gt,this.preventDefault=Gt,this.type=e.type,this.target=this.currentTarget=t.dom,this.pointerType=e.pointerType,this.clientX=e.clientX,this.clientY=e.clientY}return r}(),xe={mousedown:function(r){r=le(this.dom,r),this.__mayPointerCapture=[r.zrX,r.zrY],this.trigger("mousedown",r)},mousemove:function(r){r=le(this.dom,r);var t=this.__mayPointerCapture;t&&(r.zrX!==t[0]||r.zrY!==t[1])&&this.__togglePointerCapture(!0),this.trigger("mousemove",r)},mouseup:function(r){r=le(this.dom,r),this.__togglePointerCapture(!1),this.trigger("mouseup",r)},mouseout:function(r){r=le(this.dom,r);var t=r.toElement||r.relatedTarget;Lg(this,t)||(this.__pointerCapturing&&(r.zrEventControl="no_globalout"),this.trigger("mouseout",r))},wheel:function(r){Cv=!0,r=le(this.dom,r),this.trigger("mousewheel",r)},mousewheel:function(r){Cv||(r=le(this.dom,r),this.trigger("mousewheel",r))},touchstart:function(r){r=le(this.dom,r),dl(r),this.__lastTouchMoment=new Date,this.handler.processGesture(r,"start"),xe.mousemove.call(this,r),xe.mousedown.call(this,r)},touchmove:function(r){r=le(this.dom,r),dl(r),this.handler.processGesture(r,"change"),xe.mousemove.call(this,r)},touchend:function(r){r=le(this.dom,r),dl(r),this.handler.processGesture(r,"end"),xe.mouseup.call(this,r),+new Date-+this.__lastTouchMoment<wS&&xe.click.call(this,r)},pointerdown:function(r){xe.mousedown.call(this,r)},pointermove:function(r){Yu(r)||xe.mousemove.call(this,r)},pointerup:function(r){xe.mouseup.call(this,r)},pointerout:function(r){Yu(r)||xe.mouseout.call(this,r)}};A(["click","dblclick","contextmenu"],function(r){xe[r]=function(t){t=le(this.dom,t),this.trigger(r,t)}});var $u={pointermove:function(r){Yu(r)||$u.mousemove.call(this,r)},pointerup:function(r){$u.mouseup.call(this,r)},mousemove:function(r){this.trigger("mousemove",r)},mouseup:function(r){var t=this.__pointerCapturing;this.__togglePointerCapture(!1),this.trigger("mouseup",r),t&&(r.zrEventControl="only_globalout",this.trigger("mouseout",r))}};function CS(r,t){var e=t.domHandlers;tt.pointerEventsSupported?A(cl.pointer,function(i){Po(t,i,function(n){e[i].call(r,n)})}):(tt.touchEventsSupported&&A(cl.touch,function(i){Po(t,i,function(n){e[i].call(r,n),xS(t)})}),A(cl.mouse,function(i){Po(t,i,function(n){n=Uf(n),t.touching||e[i].call(r,n)})}))}function MS(r,t){tt.pointerEventsSupported?A(Tv.pointer,e):tt.touchEventsSupported||A(Tv.mouse,e);function e(i){function n(a){a=Uf(a),Lg(r,a.target)||(a=bS(r,a),t.domHandlers[i].call(r,a))}Po(t,i,n,{capture:!0})}}function Po(r,t,e,i){r.mounted[t]=e,r.listenerOpts[t]=i,B1(r.domTarget,t,e,i)}function pl(r){var t=r.mounted;for(var e in t)t.hasOwnProperty(e)&&N1(r.domTarget,e,t[e],r.listenerOpts[e]);r.mounted={}}var Mv=function(){function r(t,e){this.mounted={},this.listenerOpts={},this.touching=!1,this.domTarget=t,this.domHandlers=e}return r}(),AS=function(r){N(t,r);function t(e,i){var n=r.call(this)||this;return n.__pointerCapturing=!1,n.dom=e,n.painterRoot=i,n._localHandlerScope=new Mv(e,xe),vl&&(n._globalHandlerScope=new Mv(document,$u)),CS(n,n._localHandlerScope),n}return t.prototype.dispose=function(){pl(this._localHandlerScope),vl&&pl(this._globalHandlerScope)},t.prototype.setCursor=function(e){this.dom.style&&(this.dom.style.cursor=e||"default")},t.prototype.__togglePointerCapture=function(e){if(this.__mayPointerCapture=null,vl&&+this.__pointerCapturing^+e){this.__pointerCapturing=e;var i=this._globalHandlerScope;e?MS(this,i):pl(i)}},t}(Ae);const DS=AS;var Ig=1;tt.hasGlobalWindow&&(Ig=Math.max(window.devicePixelRatio||window.screen&&window.screen.deviceXDPI/window.screen.logicalXDPI||1,1));var qo=Ig,Zu=.4,Xu="#333",qu="#ccc",LS="#eee",Av=Yf,Dv=5e-5;function kr(r){return r>Dv||r<-Dv}var Or=[],Ai=[],gl=qi(),yl=Math.abs,qf=function(){function r(){}return r.prototype.getLocalTransform=function(t){return r.getLocalTransform(this,t)},r.prototype.setPosition=function(t){this.x=t[0],this.y=t[1]},r.prototype.setScale=function(t){this.scaleX=t[0],this.scaleY=t[1]},r.prototype.setSkew=function(t){this.skewX=t[0],this.skewY=t[1]},r.prototype.setOrigin=function(t){this.originX=t[0],this.originY=t[1]},r.prototype.needLocalTransform=function(){return kr(this.rotation)||kr(this.x)||kr(this.y)||kr(this.scaleX-1)||kr(this.scaleY-1)||kr(this.skewX)||kr(this.skewY)},r.prototype.updateTransform=function(){var t=this.parent&&this.parent.transform,e=this.needLocalTransform(),i=this.transform;if(!(e||t)){i&&(Av(i),this.invTransform=null);return}i=i||qi(),e?this.getLocalTransform(i):Av(i),t&&(e?Ki(i,t,i):V1(i,t)),this.transform=i,this._resolveGlobalScaleRatio(i)},r.prototype._resolveGlobalScaleRatio=function(t){var e=this.globalScaleRatio;if(e!=null&&e!==1){this.getGlobalScale(Or);var i=Or[0]<0?-1:1,n=Or[1]<0?-1:1,a=((Or[0]-i)*e+i)/Or[0]||0,o=((Or[1]-n)*e+n)/Or[1]||0;t[0]*=a,t[1]*=a,t[2]*=o,t[3]*=o}this.invTransform=this.invTransform||qi(),Zf(this.invTransform,t)},r.prototype.getComputedTransform=function(){for(var t=this,e=[];t;)e.push(t),t=t.parent;for(;t=e.pop();)t.updateTransform();return this.transform},r.prototype.setLocalTransform=function(t){if(!!t){var e=t[0]*t[0]+t[1]*t[1],i=t[2]*t[2]+t[3]*t[3],n=Math.atan2(t[1],t[0]),a=Math.PI/2+n-Math.atan2(t[3],t[2]);i=Math.sqrt(i)*Math.cos(a),e=Math.sqrt(e),this.skewX=a,this.skewY=0,this.rotation=-n,this.x=+t[4],this.y=+t[5],this.scaleX=e,this.scaleY=i,this.originX=0,this.originY=0}},r.prototype.decomposeTransform=function(){if(!!this.transform){var t=this.parent,e=this.transform;t&&t.transform&&(t.invTransform=t.invTransform||qi(),Ki(Ai,t.invTransform,e),e=Ai);var i=this.originX,n=this.originY;(i||n)&&(gl[4]=i,gl[5]=n,Ki(Ai,e,gl),Ai[4]-=i,Ai[5]-=n,e=Ai),this.setLocalTransform(e)}},r.prototype.getGlobalScale=function(t){var e=this.transform;return t=t||[],e?(t[0]=Math.sqrt(e[0]*e[0]+e[1]*e[1]),t[1]=Math.sqrt(e[2]*e[2]+e[3]*e[3]),e[0]<0&&(t[0]=-t[0]),e[3]<0&&(t[1]=-t[1]),t):(t[0]=1,t[1]=1,t)},r.prototype.transformCoordToLocal=function(t,e){var i=[t,e],n=this.invTransform;return n&&ge(i,i,n),i},r.prototype.transformCoordToGlobal=function(t,e){var i=[t,e],n=this.transform;return n&&ge(i,i,n),i},r.prototype.getLineScale=function(){var t=this.transform;return t&&yl(t[0]-1)>1e-10&&yl(t[3]-1)>1e-10?Math.sqrt(yl(t[0]*t[3]-t[2]*t[1])):1},r.prototype.copyTransform=function(t){IS(this,t)},r.getLocalTransform=function(t,e){e=e||[];var i=t.originX||0,n=t.originY||0,a=t.scaleX,o=t.scaleY,s=t.anchorX,l=t.anchorY,u=t.rotation||0,f=t.x,h=t.y,c=t.skewX?Math.tan(t.skewX):0,v=t.skewY?Math.tan(-t.skewY):0;if(i||n||s||l){var d=i+s,p=n+l;e[4]=-d*a-c*p*o,e[5]=-p*o-v*d*a}else e[4]=e[5]=0;return e[0]=a,e[3]=o,e[1]=v*a,e[2]=c*o,u&&$f(e,e,u),e[4]+=i+f,e[5]+=n+h,e},r.initDefaultProps=function(){var t=r.prototype;t.scaleX=t.scaleY=t.globalScaleRatio=1,t.x=t.y=t.originX=t.originY=t.skewX=t.skewY=t.rotation=t.anchorX=t.anchorY=0}(),r}(),He=["x","y","originX","originY","anchorX","anchorY","rotation","scaleX","scaleY","skewX","skewY"];function IS(r,t){for(var e=0;e<He.length;e++){var i=He[e];r[i]=t[i]}}var Lv={};function ie(r,t){t=t||si;var e=Lv[t];e||(e=Lv[t]=new Ma(500));var i=e.get(r);return i==null&&(i=gi.measureText(r,t).width,e.put(r,i)),i}function Iv(r,t,e,i){var n=ie(r,t),a=Qf(t),o=Wn(0,n,e),s=Gi(0,a,i),l=new ut(o,s,n,a);return l}function Kf(r,t,e,i){var n=((r||"")+"").split(`
`),a=n.length;if(a===1)return Iv(n[0],t,e,i);for(var o=new ut(0,0,0,0),s=0;s<n.length;s++){var l=Iv(n[s],t,e,i);s===0?o.copy(l):o.union(l)}return o}function Wn(r,t,e){return e==="right"?r-=t:e==="center"&&(r-=t/2),r}function Gi(r,t,e){return e==="middle"?r-=t/2:e==="bottom"&&(r-=t),r}function Qf(r){return ie("\u56FD",r)}function Dr(r,t){return typeof r=="string"?r.lastIndexOf("%")>=0?parseFloat(r)/100*t:parseFloat(r):r}function Ko(r,t,e){var i=t.position||"inside",n=t.distance!=null?t.distance:5,a=e.height,o=e.width,s=a/2,l=e.x,u=e.y,f="left",h="top";if(i instanceof Array)l+=Dr(i[0],e.width),u+=Dr(i[1],e.height),f=null,h=null;else switch(i){case"left":l-=n,u+=s,f="right",h="middle";break;case"right":l+=n+o,u+=s,h="middle";break;case"top":l+=o/2,u-=n,f="center",h="bottom";break;case"bottom":l+=o/2,u+=a+n,f="center";break;case"inside":l+=o/2,u+=s,f="center",h="middle";break;case"insideLeft":l+=n,u+=s,h="middle";break;case"insideRight":l+=o-n,u+=s,f="right",h="middle";break;case"insideTop":l+=o/2,u+=n,f="center";break;case"insideBottom":l+=o/2,u+=a-n,f="center",h="bottom";break;case"insideTopLeft":l+=n,u+=n;break;case"insideTopRight":l+=o-n,u+=n,f="right";break;case"insideBottomLeft":l+=n,u+=a-n,h="bottom";break;case"insideBottomRight":l+=o-n,u+=a-n,f="right",h="bottom";break}return r=r||{},r.x=l,r.y=u,r.align=f,r.verticalAlign=h,r}var ml="__zr_normal__",_l=He.concat(["ignore"]),PS=je(He,function(r,t){return r[t]=!0,r},{ignore:!1}),Di={},RS=new ut(0,0,0,0),Jf=function(){function r(t){this.id=ug(),this.animators=[],this.currentStates=[],this.states={},this._init(t)}return r.prototype._init=function(t){this.attr(t)},r.prototype.drift=function(t,e,i){switch(this.draggable){case"horizontal":e=0;break;case"vertical":t=0;break}var n=this.transform;n||(n=this.transform=[1,0,0,1,0,0]),n[4]+=t,n[5]+=e,this.decomposeTransform(),this.markRedraw()},r.prototype.beforeUpdate=function(){},r.prototype.afterUpdate=function(){},r.prototype.update=function(){this.updateTransform(),this.__dirty&&this.updateInnerText()},r.prototype.updateInnerText=function(t){var e=this._textContent;if(e&&(!e.ignore||t)){this.textConfig||(this.textConfig={});var i=this.textConfig,n=i.local,a=e.innerTransformable,o=void 0,s=void 0,l=!1;a.parent=n?this:null;var u=!1;if(a.copyTransform(e),i.position!=null){var f=RS;i.layoutRect?f.copy(i.layoutRect):f.copy(this.getBoundingRect()),n||f.applyTransform(this.transform),this.calculateTextPosition?this.calculateTextPosition(Di,i,f):Ko(Di,i,f),a.x=Di.x,a.y=Di.y,o=Di.align,s=Di.verticalAlign;var h=i.origin;if(h&&i.rotation!=null){var c=void 0,v=void 0;h==="center"?(c=f.width*.5,v=f.height*.5):(c=Dr(h[0],f.width),v=Dr(h[1],f.height)),u=!0,a.originX=-a.x+c+(n?0:f.x),a.originY=-a.y+v+(n?0:f.y)}}i.rotation!=null&&(a.rotation=i.rotation);var d=i.offset;d&&(a.x+=d[0],a.y+=d[1],u||(a.originX=-d[0],a.originY=-d[1]));var p=i.inside==null?typeof i.position=="string"&&i.position.indexOf("inside")>=0:i.inside,g=this._innerTextDefaultStyle||(this._innerTextDefaultStyle={}),y=void 0,m=void 0,_=void 0;p&&this.canBeInsideText()?(y=i.insideFill,m=i.insideStroke,(y==null||y==="auto")&&(y=this.getInsideTextFill()),(m==null||m==="auto")&&(m=this.getInsideTextStroke(y),_=!0)):(y=i.outsideFill,m=i.outsideStroke,(y==null||y==="auto")&&(y=this.getOutsideFill()),(m==null||m==="auto")&&(m=this.getOutsideStroke(y),_=!0)),y=y||"#000",(y!==g.fill||m!==g.stroke||_!==g.autoStroke||o!==g.align||s!==g.verticalAlign)&&(l=!0,g.fill=y,g.stroke=m,g.autoStroke=_,g.align=o,g.verticalAlign=s,e.setDefaultTextStyle(g)),e.__dirty|=re,l&&e.dirtyStyle(!0)}},r.prototype.canBeInsideText=function(){return!0},r.prototype.getInsideTextFill=function(){return"#fff"},r.prototype.getInsideTextStroke=function(t){return"#000"},r.prototype.getOutsideFill=function(){return this.__zr&&this.__zr.isDarkMode()?qu:Xu},r.prototype.getOutsideStroke=function(t){var e=this.__zr&&this.__zr.getBackgroundColor(),i=typeof e=="string"&&Qe(e);i||(i=[255,255,255,1]);for(var n=i[3],a=this.__zr.isDarkMode(),o=0;o<3;o++)i[o]=i[o]*n+(a?0:255)*(1-n);return i[3]=1,Ts(i,"rgba")},r.prototype.traverse=function(t,e){},r.prototype.attrKV=function(t,e){t==="textConfig"?this.setTextConfig(e):t==="textContent"?this.setTextContent(e):t==="clipPath"?this.setClipPath(e):t==="extra"?(this.extra=this.extra||{},O(this.extra,e)):this[t]=e},r.prototype.hide=function(){this.ignore=!0,this.markRedraw()},r.prototype.show=function(){this.ignore=!1,this.markRedraw()},r.prototype.attr=function(t,e){if(typeof t=="string")this.attrKV(t,e);else if(Y(t))for(var i=t,n=vt(i),a=0;a<n.length;a++){var o=n[a];this.attrKV(o,t[o])}return this.markRedraw(),this},r.prototype.saveCurrentToNormalState=function(t){this._innerSaveToNormal(t);for(var e=this._normalState,i=0;i<this.animators.length;i++){var n=this.animators[i],a=n.__fromStateTransition;if(!(n.getLoop()||a&&a!==ml)){var o=n.targetName,s=o?e[o]:e;n.saveTo(s)}}},r.prototype._innerSaveToNormal=function(t){var e=this._normalState;e||(e=this._normalState={}),t.textConfig&&!e.textConfig&&(e.textConfig=this.textConfig),this._savePrimaryToNormal(t,e,_l)},r.prototype._savePrimaryToNormal=function(t,e,i){for(var n=0;n<i.length;n++){var a=i[n];t[a]!=null&&!(a in e)&&(e[a]=this[a])}},r.prototype.hasState=function(){return this.currentStates.length>0},r.prototype.getState=function(t){return this.states[t]},r.prototype.ensureState=function(t){var e=this.states;return e[t]||(e[t]={}),e[t]},r.prototype.clearStates=function(t){this.useState(ml,!1,t)},r.prototype.useState=function(t,e,i,n){var a=t===ml,o=this.hasState();if(!(!o&&a)){var s=this.currentStates,l=this.stateTransition;if(!(at(s,t)>=0&&(e||s.length===1))){var u;if(this.stateProxy&&!a&&(u=this.stateProxy(t)),u||(u=this.states&&this.states[t]),!u&&!a){Gf("State "+t+" not exists.");return}a||this.saveCurrentToNormalState(u);var f=!!(u&&u.hoverLayer||n);f&&this._toggleHoverLayerFlag(!0),this._applyStateObj(t,u,this._normalState,e,!i&&!this.__inHover&&l&&l.duration>0,l);var h=this._textContent,c=this._textGuide;return h&&h.useState(t,e,i,f),c&&c.useState(t,e,i,f),a?(this.currentStates=[],this._normalState={}):e?this.currentStates.push(t):this.currentStates=[t],this._updateAnimationTargets(),this.markRedraw(),!f&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~re),u}}},r.prototype.useStates=function(t,e,i){if(!t.length)this.clearStates();else{var n=[],a=this.currentStates,o=t.length,s=o===a.length;if(s){for(var l=0;l<o;l++)if(t[l]!==a[l]){s=!1;break}}if(s)return;for(var l=0;l<o;l++){var u=t[l],f=void 0;this.stateProxy&&(f=this.stateProxy(u,t)),f||(f=this.states[u]),f&&n.push(f)}var h=n[o-1],c=!!(h&&h.hoverLayer||i);c&&this._toggleHoverLayerFlag(!0);var v=this._mergeStates(n),d=this.stateTransition;this.saveCurrentToNormalState(v),this._applyStateObj(t.join(","),v,this._normalState,!1,!e&&!this.__inHover&&d&&d.duration>0,d);var p=this._textContent,g=this._textGuide;p&&p.useStates(t,e,c),g&&g.useStates(t,e,c),this._updateAnimationTargets(),this.currentStates=t.slice(),this.markRedraw(),!c&&this.__inHover&&(this._toggleHoverLayerFlag(!1),this.__dirty&=~re)}},r.prototype.isSilent=function(){for(var t=this.silent,e=this.parent;!t&&e;){if(e.silent){t=!0;break}e=e.parent}return t},r.prototype._updateAnimationTargets=function(){for(var t=0;t<this.animators.length;t++){var e=this.animators[t];e.targetName&&e.changeTarget(this[e.targetName])}},r.prototype.removeState=function(t){var e=at(this.currentStates,t);if(e>=0){var i=this.currentStates.slice();i.splice(e,1),this.useStates(i)}},r.prototype.replaceState=function(t,e,i){var n=this.currentStates.slice(),a=at(n,t),o=at(n,e)>=0;a>=0?o?n.splice(a,1):n[a]=e:i&&!o&&n.push(e),this.useStates(n)},r.prototype.toggleState=function(t,e){e?this.useState(t,!0):this.removeState(t)},r.prototype._mergeStates=function(t){for(var e={},i,n=0;n<t.length;n++){var a=t[n];O(e,a),a.textConfig&&(i=i||{},O(i,a.textConfig))}return i&&(e.textConfig=i),e},r.prototype._applyStateObj=function(t,e,i,n,a,o){var s=!(e&&n);e&&e.textConfig?(this.textConfig=O({},n?this.textConfig:i.textConfig),O(this.textConfig,e.textConfig)):s&&i.textConfig&&(this.textConfig=i.textConfig);for(var l={},u=!1,f=0;f<_l.length;f++){var h=_l[f],c=a&&PS[h];e&&e[h]!=null?c?(u=!0,l[h]=e[h]):this[h]=e[h]:s&&i[h]!=null&&(c?(u=!0,l[h]=i[h]):this[h]=i[h])}if(!a)for(var f=0;f<this.animators.length;f++){var v=this.animators[f],d=v.targetName;v.getLoop()||v.__changeFinalValue(d?(e||i)[d]:e||i)}u&&this._transitionState(t,l,o)},r.prototype._attachComponent=function(t){if(!(t.__zr&&!t.__hostTarget)&&t!==this){var e=this.__zr;e&&t.addSelfToZr(e),t.__zr=e,t.__hostTarget=this}},r.prototype._detachComponent=function(t){t.__zr&&t.removeSelfFromZr(t.__zr),t.__zr=null,t.__hostTarget=null},r.prototype.getClipPath=function(){return this._clipPath},r.prototype.setClipPath=function(t){this._clipPath&&this._clipPath!==t&&this.removeClipPath(),this._attachComponent(t),this._clipPath=t,this.markRedraw()},r.prototype.removeClipPath=function(){var t=this._clipPath;t&&(this._detachComponent(t),this._clipPath=null,this.markRedraw())},r.prototype.getTextContent=function(){return this._textContent},r.prototype.setTextContent=function(t){var e=this._textContent;e!==t&&(e&&e!==t&&this.removeTextContent(),t.innerTransformable=new qf,this._attachComponent(t),this._textContent=t,this.markRedraw())},r.prototype.setTextConfig=function(t){this.textConfig||(this.textConfig={}),O(this.textConfig,t),this.markRedraw()},r.prototype.removeTextConfig=function(){this.textConfig=null,this.markRedraw()},r.prototype.removeTextContent=function(){var t=this._textContent;t&&(t.innerTransformable=null,this._detachComponent(t),this._textContent=null,this._innerTextDefaultStyle=null,this.markRedraw())},r.prototype.getTextGuideLine=function(){return this._textGuide},r.prototype.setTextGuideLine=function(t){this._textGuide&&this._textGuide!==t&&this.removeTextGuideLine(),this._attachComponent(t),this._textGuide=t,this.markRedraw()},r.prototype.removeTextGuideLine=function(){var t=this._textGuide;t&&(this._detachComponent(t),this._textGuide=null,this.markRedraw())},r.prototype.markRedraw=function(){this.__dirty|=re;var t=this.__zr;t&&(this.__inHover?t.refreshHover():t.refresh()),this.__hostTarget&&this.__hostTarget.markRedraw()},r.prototype.dirty=function(){this.markRedraw()},r.prototype._toggleHoverLayerFlag=function(t){this.__inHover=t;var e=this._textContent,i=this._textGuide;e&&(e.__inHover=t),i&&(i.__inHover=t)},r.prototype.addSelfToZr=function(t){if(this.__zr!==t){this.__zr=t;var e=this.animators;if(e)for(var i=0;i<e.length;i++)t.animation.addAnimator(e[i]);this._clipPath&&this._clipPath.addSelfToZr(t),this._textContent&&this._textContent.addSelfToZr(t),this._textGuide&&this._textGuide.addSelfToZr(t)}},r.prototype.removeSelfFromZr=function(t){if(!!this.__zr){this.__zr=null;var e=this.animators;if(e)for(var i=0;i<e.length;i++)t.animation.removeAnimator(e[i]);this._clipPath&&this._clipPath.removeSelfFromZr(t),this._textContent&&this._textContent.removeSelfFromZr(t),this._textGuide&&this._textGuide.removeSelfFromZr(t)}},r.prototype.animate=function(t,e,i){var n=t?this[t]:this,a=new Xf(n,e,i);return t&&(a.targetName=t),this.addAnimator(a,t),a},r.prototype.addAnimator=function(t,e){var i=this.__zr,n=this;t.during(function(){n.updateDuringAnimation(e)}).done(function(){var a=n.animators,o=at(a,t);o>=0&&a.splice(o,1)}),this.animators.push(t),i&&i.animation.addAnimator(t),i&&i.wakeUp()},r.prototype.updateDuringAnimation=function(t){this.markRedraw()},r.prototype.stopAnimation=function(t,e){for(var i=this.animators,n=i.length,a=[],o=0;o<n;o++){var s=i[o];!t||t===s.scope?s.stop(e):a.push(s)}return this.animators=a,this},r.prototype.animateTo=function(t,e,i){Sl(this,t,e,i)},r.prototype.animateFrom=function(t,e,i){Sl(this,t,e,i,!0)},r.prototype._transitionState=function(t,e,i,n){for(var a=Sl(this,e,i,n),o=0;o<a.length;o++)a[o].__fromStateTransition=t},r.prototype.getBoundingRect=function(){return null},r.prototype.getPaintRect=function(){return null},r.initDefaultProps=function(){var t=r.prototype;t.type="element",t.name="",t.ignore=t.silent=t.isGroup=t.draggable=t.dragging=t.ignoreClip=t.__inHover=!1,t.__dirty=re;function e(i,n,a,o){Object.defineProperty(t,i,{get:function(){if(!this[n]){var l=this[n]=[];s(this,l)}return this[n]},set:function(l){this[a]=l[0],this[o]=l[1],this[n]=l,s(this,l)}});function s(l,u){Object.defineProperty(u,0,{get:function(){return l[a]},set:function(f){l[a]=f}}),Object.defineProperty(u,1,{get:function(){return l[o]},set:function(f){l[o]=f}})}}Object.defineProperty&&(e("position","_legacyPos","x","y"),e("scale","_legacyScale","scaleX","scaleY"),e("origin","_legacyOrigin","originX","originY"))}(),r}();Me(Jf,Ae);Me(Jf,qf);function Sl(r,t,e,i,n){e=e||{};var a=[];Pg(r,"",r,t,e,i,a,n);var o=a.length,s=!1,l=e.done,u=e.aborted,f=function(){s=!0,o--,o<=0&&(s?l&&l():u&&u())},h=function(){o--,o<=0&&(s?l&&l():u&&u())};o||l&&l(),a.length>0&&e.during&&a[0].during(function(d,p){e.during(p)});for(var c=0;c<a.length;c++){var v=a[c];f&&v.done(f),h&&v.aborted(h),e.force&&v.duration(e.duration),v.start(e.easing)}return a}function wl(r,t,e){for(var i=0;i<e;i++)r[i]=t[i]}function ES(r){return Wt(r[0])}function kS(r,t,e){if(Wt(t[e]))if(Wt(r[e])||(r[e]=[]),jt(t[e])){var i=t[e].length;r[e].length!==i&&(r[e]=new t[e].constructor(i),wl(r[e],t[e],i))}else{var n=t[e],a=r[e],o=n.length;if(ES(n))for(var s=n[0].length,l=0;l<o;l++)a[l]?wl(a[l],n[l],s):a[l]=Array.prototype.slice.call(n[l]);else wl(a,n,o);a.length=n.length}else r[e]=t[e]}function OS(r,t){return r===t||Wt(r)&&Wt(t)&&BS(r,t)}function BS(r,t){var e=r.length;if(e!==t.length)return!1;for(var i=0;i<e;i++)if(r[i]!==t[i])return!1;return!0}function Pg(r,t,e,i,n,a,o,s){for(var l=vt(i),u=n.duration,f=n.delay,h=n.additive,c=n.setToFinal,v=!Y(a),d=r.animators,p=[],g=0;g<l.length;g++){var y=l[g],m=i[y];if(m!=null&&e[y]!=null&&(v||a[y]))if(Y(m)&&!Wt(m)&&!xs(m)){if(t){s||(e[y]=m,r.updateDuringAnimation(t));continue}Pg(r,y,e[y],m,n,a&&a[y],o,s)}else p.push(y);else s||(e[y]=m,r.updateDuringAnimation(t),p.push(y))}var _=p.length;if(!h&&_)for(var S=0;S<d.length;S++){var x=d[S];if(x.targetName===t){var w=x.stopTracks(p);if(w){var b=at(d,x);d.splice(b,1)}}}if(n.force||(p=Ct(p,function(C){return!OS(i[C],e[C])}),_=p.length),_>0||n.force&&!o.length){var T=void 0,M=void 0,D=void 0;if(s){M={},c&&(T={});for(var S=0;S<_;S++){var y=p[S];M[y]=e[y],c?T[y]=i[y]:e[y]=i[y]}}else if(c){D={};for(var S=0;S<_;S++){var y=p[S];D[y]=jn(e[y]),kS(e,i,y)}}var x=new Xf(e,!1,!1,h?Ct(d,function(L){return L.targetName===t}):null);x.targetName=t,n.scope&&(x.scope=n.scope),c&&T&&x.whenWithKeys(0,T,p),D&&x.whenWithKeys(0,D,p),x.whenWithKeys(u==null?500:u,s?M:i,p).delay(f||0),r.addAnimator(x,t),o.push(x)}}const Rg=Jf;var Eg=function(r){N(t,r);function t(e){var i=r.call(this)||this;return i.isGroup=!0,i._children=[],i.attr(e),i}return t.prototype.childrenRef=function(){return this._children},t.prototype.children=function(){return this._children.slice()},t.prototype.childAt=function(e){return this._children[e]},t.prototype.childOfName=function(e){for(var i=this._children,n=0;n<i.length;n++)if(i[n].name===e)return i[n]},t.prototype.childCount=function(){return this._children.length},t.prototype.add=function(e){return e&&e!==this&&e.parent!==this&&(this._children.push(e),this._doAdd(e)),this},t.prototype.addBefore=function(e,i){if(e&&e!==this&&e.parent!==this&&i&&i.parent===this){var n=this._children,a=n.indexOf(i);a>=0&&(n.splice(a,0,e),this._doAdd(e))}return this},t.prototype.replace=function(e,i){var n=at(this._children,e);return n>=0&&this.replaceAt(i,n),this},t.prototype.replaceAt=function(e,i){var n=this._children,a=n[i];if(e&&e!==this&&e.parent!==this&&e!==a){n[i]=e,a.parent=null;var o=this.__zr;o&&a.removeSelfFromZr(o),this._doAdd(e)}return this},t.prototype._doAdd=function(e){e.parent&&e.parent.remove(e),e.parent=this;var i=this.__zr;i&&i!==e.__zr&&e.addSelfToZr(i),i&&i.refresh()},t.prototype.remove=function(e){var i=this.__zr,n=this._children,a=at(n,e);return a<0?this:(n.splice(a,1),e.parent=null,i&&e.removeSelfFromZr(i),i&&i.refresh(),this)},t.prototype.removeAll=function(){for(var e=this._children,i=this.__zr,n=0;n<e.length;n++){var a=e[n];i&&a.removeSelfFromZr(i),a.parent=null}return e.length=0,this},t.prototype.eachChild=function(e,i){for(var n=this._children,a=0;a<n.length;a++){var o=n[a];e.call(i,o,a)}return this},t.prototype.traverse=function(e,i){for(var n=0;n<this._children.length;n++){var a=this._children[n],o=e.call(i,a);a.isGroup&&!o&&a.traverse(e,i)}return this},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var i=0;i<this._children.length;i++){var n=this._children[i];n.addSelfToZr(e)}},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var i=0;i<this._children.length;i++){var n=this._children[i];n.removeSelfFromZr(e)}},t.prototype.getBoundingRect=function(e){for(var i=new ut(0,0,0,0),n=e||this._children,a=[],o=null,s=0;s<n.length;s++){var l=n[s];if(!(l.ignore||l.invisible)){var u=l.getBoundingRect(),f=l.getLocalTransform(a);f?(ut.applyTransform(i,u,f),o=o||i.clone(),o.union(i)):(o=o||u.clone(),o.union(u))}}return o||i},t}(Rg);Eg.prototype.type="group";const xt=Eg;/*!
* ZRender, a high performance 2d drawing library.
*
* Copyright (c) 2013, Baidu Inc.
* All rights reserved.
*
* LICENSE
* https://github.com/ecomfe/zrender/blob/master/LICENSE.txt
*/var Ro={},kg={};function NS(r){delete kg[r]}function zS(r){if(!r)return!1;if(typeof r=="string")return Xo(r,1)<Zu;if(r.colorStops){for(var t=r.colorStops,e=0,i=t.length,n=0;n<i;n++)e+=Xo(t[n].color,1);return e/=i,e<Zu}return!1}var FS=function(){function r(t,e,i){var n=this;this._sleepAfterStill=10,this._stillFrameAccum=0,this._needsRefresh=!0,this._needsRefreshHover=!0,this._darkMode=!1,i=i||{},this.dom=e,this.id=t;var a=new tS,o=i.renderer||"canvas";Ro[o]||(o=vt(Ro)[0]),i.useDirtyRect=i.useDirtyRect==null?!1:i.useDirtyRect;var s=new Ro[o](e,a,i,t),l=i.ssr||s.ssrOnly;this.storage=a,this.painter=s;var u=!tt.node&&!tt.worker&&!l?new DS(s.getViewportRoot(),s.root):null,f=i.useCoarsePointer,h=f==null||f==="auto"?tt.touchEventsSupported:!!f,c=44,v;h&&(v=j(i.pointerSize,c)),this.handler=new q1(a,s,u,s.root,v),this.animation=new SS({stage:{update:l?null:function(){return n._flush(!0)}}}),l||this.animation.start()}return r.prototype.add=function(t){this._disposed||!t||(this.storage.addRoot(t),t.addSelfToZr(this),this.refresh())},r.prototype.remove=function(t){this._disposed||!t||(this.storage.delRoot(t),t.removeSelfFromZr(this),this.refresh())},r.prototype.configLayer=function(t,e){this._disposed||(this.painter.configLayer&&this.painter.configLayer(t,e),this.refresh())},r.prototype.setBackgroundColor=function(t){this._disposed||(this.painter.setBackgroundColor&&this.painter.setBackgroundColor(t),this.refresh(),this._backgroundColor=t,this._darkMode=zS(t))},r.prototype.getBackgroundColor=function(){return this._backgroundColor},r.prototype.setDarkMode=function(t){this._darkMode=t},r.prototype.isDarkMode=function(){return this._darkMode},r.prototype.refreshImmediately=function(t){this._disposed||(t||this.animation.update(!0),this._needsRefresh=!1,this.painter.refresh(),this._needsRefresh=!1)},r.prototype.refresh=function(){this._disposed||(this._needsRefresh=!0,this.animation.start())},r.prototype.flush=function(){this._disposed||this._flush(!1)},r.prototype._flush=function(t){var e,i=$i();this._needsRefresh&&(e=!0,this.refreshImmediately(t)),this._needsRefreshHover&&(e=!0,this.refreshHoverImmediately());var n=$i();e?(this._stillFrameAccum=0,this.trigger("rendered",{elapsedTime:n-i})):this._sleepAfterStill>0&&(this._stillFrameAccum++,this._stillFrameAccum>this._sleepAfterStill&&this.animation.stop())},r.prototype.setSleepAfterStill=function(t){this._sleepAfterStill=t},r.prototype.wakeUp=function(){this._disposed||(this.animation.start(),this._stillFrameAccum=0)},r.prototype.refreshHover=function(){this._needsRefreshHover=!0},r.prototype.refreshHoverImmediately=function(){this._disposed||(this._needsRefreshHover=!1,this.painter.refreshHover&&this.painter.getType()==="canvas"&&this.painter.refreshHover())},r.prototype.resize=function(t){this._disposed||(t=t||{},this.painter.resize(t.width,t.height),this.handler.resize())},r.prototype.clearAnimation=function(){this._disposed||this.animation.clear()},r.prototype.getWidth=function(){if(!this._disposed)return this.painter.getWidth()},r.prototype.getHeight=function(){if(!this._disposed)return this.painter.getHeight()},r.prototype.setCursorStyle=function(t){this._disposed||this.handler.setCursorStyle(t)},r.prototype.findHover=function(t,e){if(!this._disposed)return this.handler.findHover(t,e)},r.prototype.on=function(t,e,i){return this._disposed||this.handler.on(t,e,i),this},r.prototype.off=function(t,e){this._disposed||this.handler.off(t,e)},r.prototype.trigger=function(t,e){this._disposed||this.handler.trigger(t,e)},r.prototype.clear=function(){if(!this._disposed){for(var t=this.storage.getRoots(),e=0;e<t.length;e++)t[e]instanceof xt&&t[e].removeSelfFromZr(this);this.storage.delAllRoots(),this.painter.clear()}},r.prototype.dispose=function(){this._disposed||(this.animation.stop(),this.clear(),this.storage.dispose(),this.painter.dispose(),this.handler.dispose(),this.animation=this.storage=this.painter=this.handler=null,this._disposed=!0,NS(this.id))},r}();function Pv(r,t){var e=new FS(ug(),r,t);return kg[e.id]=e,e}function VS(r,t){Ro[r]=t}var Rv=1e-4,Og=20;function HS(r){return r.replace(/^\s+|\s+$/g,"")}function Rt(r,t,e,i){var n=t[0],a=t[1],o=e[0],s=e[1],l=a-n,u=s-o;if(l===0)return u===0?o:(o+s)/2;if(i)if(l>0){if(r<=n)return o;if(r>=a)return s}else{if(r>=n)return o;if(r<=a)return s}else{if(r===n)return o;if(r===a)return s}return(r-n)/l*u+o}function st(r,t){switch(r){case"center":case"middle":r="50%";break;case"left":case"top":r="0%";break;case"right":case"bottom":r="100%";break}return W(r)?HS(r).match(/%$/)?parseFloat(r)/100*t:parseFloat(r):r==null?NaN:+r}function bt(r,t,e){return t==null&&(t=10),t=Math.min(Math.max(0,t),Og),r=(+r).toFixed(t),e?r:+r}function Un(r){return r.sort(function(t,e){return t-e}),r}function Xe(r){if(r=+r,isNaN(r))return 0;if(r>1e-14){for(var t=1,e=0;e<15;e++,t*=10)if(Math.round(r*t)/t===r)return e}return GS(r)}function GS(r){var t=r.toString().toLowerCase(),e=t.indexOf("e"),i=e>0?+t.slice(e+1):0,n=e>0?e:t.length,a=t.indexOf("."),o=a<0?0:n-1-a;return Math.max(0,o-i)}function Bg(r,t){var e=Math.log,i=Math.LN10,n=Math.floor(e(r[1]-r[0])/i),a=Math.round(e(Math.abs(t[1]-t[0]))/i),o=Math.min(Math.max(-n+a,0),20);return isFinite(o)?o:20}function WS(r,t){var e=je(r,function(v,d){return v+(isNaN(d)?0:d)},0);if(e===0)return[];for(var i=Math.pow(10,t),n=G(r,function(v){return(isNaN(v)?0:v)/e*i*100}),a=i*100,o=G(n,function(v){return Math.floor(v)}),s=je(o,function(v,d){return v+d},0),l=G(n,function(v,d){return v-o[d]});s<a;){for(var u=Number.NEGATIVE_INFINITY,f=null,h=0,c=l.length;h<c;++h)l[h]>u&&(u=l[h],f=h);++o[f],l[f]=0,++s}return G(o,function(v){return v/i})}function US(r,t){var e=Math.max(Xe(r),Xe(t)),i=r+t;return e>Og?i:bt(i,e)}function Ng(r){var t=Math.PI*2;return(r%t+t)%t}function Qo(r){return r>-Rv&&r<Rv}var YS=/^(?:(\d{4})(?:[-\/](\d{1,2})(?:[-\/](\d{1,2})(?:[T ](\d{1,2})(?::(\d{1,2})(?::(\d{1,2})(?:[.,](\d+))?)?)?(Z|[\+\-]\d\d:?\d\d)?)?)?)?)?$/;function er(r){if(r instanceof Date)return r;if(W(r)){var t=YS.exec(r);if(!t)return new Date(NaN);if(t[8]){var e=+t[4]||0;return t[8].toUpperCase()!=="Z"&&(e-=+t[8].slice(0,3)),new Date(Date.UTC(+t[1],+(t[2]||1)-1,+t[3]||1,e,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0))}else return new Date(+t[1],+(t[2]||1)-1,+t[3]||1,+t[4]||0,+(t[5]||0),+t[6]||0,t[7]?+t[7].substring(0,3):0)}else if(r==null)return new Date(NaN);return new Date(Math.round(r))}function $S(r){return Math.pow(10,jf(r))}function jf(r){if(r===0)return 0;var t=Math.floor(Math.log(r)/Math.LN10);return r/Math.pow(10,t)>=10&&t++,t}function zg(r,t){var e=jf(r),i=Math.pow(10,e),n=r/i,a;return t?n<1.5?a=1:n<2.5?a=2:n<4?a=3:n<7?a=5:a=10:n<1?a=1:n<2?a=2:n<3?a=3:n<5?a=5:a=10,r=a*i,e>=-20?+r.toFixed(e<0?-e:0):r}function Jo(r){var t=parseFloat(r);return t==r&&(t!==0||!W(r)||r.indexOf("x")<=0)?t:NaN}function ZS(r){return!isNaN(Jo(r))}function Fg(){return Math.round(Math.random()*9)}function Vg(r,t){return t===0?r:Vg(t,r%t)}function Ev(r,t){return r==null?t:t==null?r:r*t/Vg(r,t)}function Xt(r){throw new Error(r)}function kv(r,t,e){return(t-r)*e+r}var Hg="series\0",XS="\0_ec_\0";function At(r){return r instanceof Array?r:r==null?[]:[r]}function Ku(r,t,e){if(r){r[t]=r[t]||{},r.emphasis=r.emphasis||{},r.emphasis[t]=r.emphasis[t]||{};for(var i=0,n=e.length;i<n;i++){var a=e[i];!r.emphasis[t].hasOwnProperty(a)&&r[t].hasOwnProperty(a)&&(r.emphasis[t][a]=r[t][a])}}}var Ov=["fontStyle","fontWeight","fontSize","fontFamily","rich","tag","color","textBorderColor","textBorderWidth","width","height","lineHeight","align","verticalAlign","baseline","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY","backgroundColor","borderColor","borderWidth","borderRadius","padding"];function Aa(r){return Y(r)&&!V(r)&&!(r instanceof Date)?r.value:r}function qS(r){return Y(r)&&!(r instanceof Array)}function Gg(r,t,e){var i=e==="normalMerge",n=e==="replaceMerge",a=e==="replaceAll";r=r||[],t=(t||[]).slice();var o=Z();A(t,function(l,u){if(!Y(l)){t[u]=null;return}});var s=KS(r,o,e);return(i||n)&&QS(s,r,o,t),i&&JS(s,t),i||n?jS(s,t,n):a&&tw(s,t),ew(s),s}function KS(r,t,e){var i=[];if(e==="replaceAll")return i;for(var n=0;n<r.length;n++){var a=r[n];a&&a.id!=null&&t.set(a.id,n),i.push({existing:e==="replaceMerge"||ca(a)?null:a,newOption:null,keyInfo:null,brandNew:null})}return i}function QS(r,t,e,i){A(i,function(n,a){if(!(!n||n.id==null)){var o=ta(n.id),s=e.get(o);if(s!=null){var l=r[s];tr(!l.newOption,'Duplicated option on id "'+o+'".'),l.newOption=n,l.existing=t[s],i[a]=null}}})}function JS(r,t){A(t,function(e,i){if(!(!e||e.name==null))for(var n=0;n<r.length;n++){var a=r[n].existing;if(!r[n].newOption&&a&&(a.id==null||e.id==null)&&!ca(e)&&!ca(a)&&Wg("name",a,e)){r[n].newOption=e,t[i]=null;return}}})}function jS(r,t,e){A(t,function(i){if(!!i){for(var n,a=0;(n=r[a])&&(n.newOption||ca(n.existing)||n.existing&&i.id!=null&&!Wg("id",i,n.existing));)a++;n?(n.newOption=i,n.brandNew=e):r.push({newOption:i,brandNew:e,existing:null,keyInfo:null}),a++}})}function tw(r,t){A(t,function(e){r.push({newOption:e,brandNew:!0,existing:null,keyInfo:null})})}function ew(r){var t=Z();A(r,function(e){var i=e.existing;i&&t.set(i.id,e)}),A(r,function(e){var i=e.newOption;tr(!i||i.id==null||!t.get(i.id)||t.get(i.id)===e,"id duplicates: "+(i&&i.id)),i&&i.id!=null&&t.set(i.id,e),!e.keyInfo&&(e.keyInfo={})}),A(r,function(e,i){var n=e.existing,a=e.newOption,o=e.keyInfo;if(!!Y(a)){if(o.name=a.name!=null?ta(a.name):n?n.name:Hg+i,n)o.id=ta(n.id);else if(a.id!=null)o.id=ta(a.id);else{var s=0;do o.id="\0"+o.name+"\0"+s++;while(t.get(o.id))}t.set(o.id,e)}})}function Wg(r,t,e){var i=Kt(t[r],null),n=Kt(e[r],null);return i!=null&&n!=null&&i===n}function ta(r){return Kt(r,"")}function Kt(r,t){return r==null?t:W(r)?r:dt(r)||Pu(r)?r+"":t}function th(r){var t=r.name;return!!(t&&t.indexOf(Hg))}function ca(r){return r&&r.id!=null&&ta(r.id).indexOf(XS)===0}function rw(r,t,e){A(r,function(i){var n=i.newOption;Y(n)&&(i.keyInfo.mainType=t,i.keyInfo.subType=iw(t,n,i.existing,e))})}function iw(r,t,e,i){var n=t.type?t.type:e?e.subType:i.determineSubType(r,t);return n}function li(r,t){if(t.dataIndexInside!=null)return t.dataIndexInside;if(t.dataIndex!=null)return V(t.dataIndex)?G(t.dataIndex,function(e){return r.indexOfRawIndex(e)}):r.indexOfRawIndex(t.dataIndex);if(t.name!=null)return V(t.name)?G(t.name,function(e){return r.indexOfName(e)}):r.indexOfName(t.name)}function gt(){var r="__ec_inner_"+nw++;return function(t){return t[r]||(t[r]={})}}var nw=Fg();function xl(r,t,e){var i=eh(t,e),n=i.mainTypeSpecified,a=i.queryOptionMap,o=i.others,s=o,l=e?e.defaultMainType:null;return!n&&l&&a.set(l,{}),a.each(function(u,f){var h=Da(r,f,u,{useDefault:l===f,enableAll:e&&e.enableAll!=null?e.enableAll:!0,enableNone:e&&e.enableNone!=null?e.enableNone:!0});s[f+"Models"]=h.models,s[f+"Model"]=h.models[0]}),s}function eh(r,t){var e;if(W(r)){var i={};i[r+"Index"]=0,e=i}else e=r;var n=Z(),a={},o=!1;return A(e,function(s,l){if(l==="dataIndex"||l==="dataIndexInside"){a[l]=s;return}var u=l.match(/^(\w+)(Index|Id|Name)$/)||[],f=u[1],h=(u[2]||"").toLowerCase();if(!(!f||!h||t&&t.includeMainTypes&&at(t.includeMainTypes,f)<0)){o=o||!!f;var c=n.get(f)||n.set(f,{});c[h]=s}}),{mainTypeSpecified:o,queryOptionMap:n,others:a}}var Qt={useDefault:!0,enableAll:!1,enableNone:!1},aw={useDefault:!1,enableAll:!0,enableNone:!0};function Da(r,t,e,i){i=i||Qt;var n=e.index,a=e.id,o=e.name,s={models:null,specified:n!=null||a!=null||o!=null};if(!s.specified){var l=void 0;return s.models=i.useDefault&&(l=r.getComponent(t))?[l]:[],s}return n==="none"||n===!1?(tr(i.enableNone,'`"none"` or `false` is not a valid value on index option.'),s.models=[],s):(n==="all"&&(tr(i.enableAll,'`"all"` is not a valid value on index option.'),n=a=o=null),s.models=r.queryComponents({mainType:t,index:n,id:a,name:o}),s)}function Ug(r,t,e){r.setAttribute?r.setAttribute(t,e):r[t]=e}function ow(r,t){return r.getAttribute?r.getAttribute(t):r[t]}function sw(r){return r==="auto"?tt.domSupported?"html":"richText":r||"html"}function lw(r,t,e,i,n){var a=t==null||t==="auto";if(i==null)return i;if(dt(i)){var o=kv(e||0,i,n);return bt(o,a?Math.max(Xe(e||0),Xe(i)):t)}else{if(W(i))return n<1?e:i;for(var s=[],l=e,u=i,f=Math.max(l?l.length:0,u.length),h=0;h<f;++h){var c=r.getDimensionInfo(h);if(c&&c.type==="ordinal")s[h]=(n<1&&l?l:u)[h];else{var v=l&&l[h]?l[h]:0,d=u[h],o=kv(v,d,n);s[h]=bt(o,a?Math.max(Xe(v),Xe(d)):t)}}return s}}var uw=".",Br="___EC__COMPONENT__CONTAINER___",Yg="___EC__EXTENDED_CLASS___";function Ve(r){var t={main:"",sub:""};if(r){var e=r.split(uw);t.main=e[0]||"",t.sub=e[1]||""}return t}function fw(r){tr(/^[a-zA-Z0-9_]+([.][a-zA-Z0-9_]+)?$/.test(r),'componentType "'+r+'" illegal')}function hw(r){return!!(r&&r[Yg])}function rh(r,t){r.$constructor=r,r.extend=function(e){var i=this,n;return vw(i)?n=function(a){N(o,a);function o(){return a.apply(this,arguments)||this}return o}(i):(n=function(){(e.$constructor||i).apply(this,arguments)},u1(n,this)),O(n.prototype,e),n[Yg]=!0,n.extend=this.extend,n.superCall=pw,n.superApply=gw,n.superClass=i,n}}function vw(r){return K(r)&&/^class\s/.test(Function.prototype.toString.call(r))}function $g(r,t){r.extend=t.extend}var cw=Math.round(Math.random()*10);function dw(r){var t=["__\0is_clz",cw++].join("_");r.prototype[t]=!0,r.isInstance=function(e){return!!(e&&e[t])}}function pw(r,t){for(var e=[],i=2;i<arguments.length;i++)e[i-2]=arguments[i];return this.superClass.prototype[t].apply(r,e)}function gw(r,t,e){return this.superClass.prototype[t].apply(r,e)}function Cs(r){var t={};r.registerClass=function(i){var n=i.type||i.prototype.type;if(n){fw(n),i.prototype.type=n;var a=Ve(n);if(!a.sub)t[a.main]=i;else if(a.sub!==Br){var o=e(a);o[a.sub]=i}}return i},r.getClass=function(i,n,a){var o=t[i];if(o&&o[Br]&&(o=n?o[n]:null),a&&!o)throw new Error(n?"Component "+i+"."+(n||"")+" is used but not imported.":i+".type should be specified.");return o},r.getClassesByMainType=function(i){var n=Ve(i),a=[],o=t[n.main];return o&&o[Br]?A(o,function(s,l){l!==Br&&a.push(s)}):a.push(o),a},r.hasClass=function(i){var n=Ve(i);return!!t[n.main]},r.getAllClassMainTypes=function(){var i=[];return A(t,function(n,a){i.push(a)}),i},r.hasSubTypes=function(i){var n=Ve(i),a=t[n.main];return a&&a[Br]};function e(i){var n=t[i.main];return(!n||!n[Br])&&(n=t[i.main]={},n[Br]=!0),n}}function da(r,t){for(var e=0;e<r.length;e++)r[e][1]||(r[e][1]=r[e][0]);return t=t||!1,function(i,n,a){for(var o={},s=0;s<r.length;s++){var l=r[s][1];if(!(n&&at(n,l)>=0||a&&at(a,l)<0)){var u=i.getShallow(l,t);u!=null&&(o[r[s][0]]=u)}}return o}}var yw=[["fill","color"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["opacity"],["shadowColor"]],mw=da(yw),_w=function(){function r(){}return r.prototype.getAreaStyle=function(t,e){return mw(this,t,e)},r}(),Qu=new Ma(50);function Sw(r){if(typeof r=="string"){var t=Qu.get(r);return t&&t.image}else return r}function Zg(r,t,e,i,n){if(r)if(typeof r=="string"){if(t&&t.__zrImageSrc===r||!e)return t;var a=Qu.get(r),o={hostEl:e,cb:i,cbPayload:n};return a?(t=a.image,!Ms(t)&&a.pending.push(o)):(t=gi.loadImage(r,Bv,Bv),t.__zrImageSrc=r,Qu.put(r,t.__cachedImgObj={image:t,pending:[o]})),t}else return r;else return t}function Bv(){var r=this.__cachedImgObj;this.onload=this.onerror=this.__cachedImgObj=null;for(var t=0;t<r.pending.length;t++){var e=r.pending[t],i=e.cb;i&&i(this,e.cbPayload),e.hostEl.dirty()}r.pending.length=0}function Ms(r){return r&&r.width&&r.height}var bl=/\{([a-zA-Z0-9_]+)\|([^}]*)\}/g;function ww(r,t,e,i,n,a){if(!e){r.text="",r.isTruncated=!1;return}var o=(t+"").split(`
`);a=Xg(e,i,n,a);for(var s=!1,l={},u=0,f=o.length;u<f;u++)qg(l,o[u],a),o[u]=l.textLine,s=s||l.isTruncated;r.text=o.join(`
`),r.isTruncated=s}function Xg(r,t,e,i){i=i||{};var n=O({},i);n.font=t,e=j(e,"..."),n.maxIterations=j(i.maxIterations,2);var a=n.minChar=j(i.minChar,0);n.cnCharWidth=ie("\u56FD",t);var o=n.ascCharWidth=ie("a",t);n.placeholder=j(i.placeholder,"");for(var s=r=Math.max(0,r-1),l=0;l<a&&s>=o;l++)s-=o;var u=ie(e,t);return u>s&&(e="",u=0),s=r-u,n.ellipsis=e,n.ellipsisWidth=u,n.contentWidth=s,n.containerWidth=r,n}function qg(r,t,e){var i=e.containerWidth,n=e.font,a=e.contentWidth;if(!i){r.textLine="",r.isTruncated=!1;return}var o=ie(t,n);if(o<=i){r.textLine=t,r.isTruncated=!1;return}for(var s=0;;s++){if(o<=a||s>=e.maxIterations){t+=e.ellipsis;break}var l=s===0?xw(t,a,e.ascCharWidth,e.cnCharWidth):o>0?Math.floor(t.length*a/o):0;t=t.substr(0,l),o=ie(t,n)}t===""&&(t=e.placeholder),r.textLine=t,r.isTruncated=!0}function xw(r,t,e,i){for(var n=0,a=0,o=r.length;a<o&&n<t;a++){var s=r.charCodeAt(a);n+=0<=s&&s<=127?e:i}return a}function bw(r,t){r!=null&&(r+="");var e=t.overflow,i=t.padding,n=t.font,a=e==="truncate",o=Qf(n),s=j(t.lineHeight,o),l=!!t.backgroundColor,u=t.lineOverflow==="truncate",f=!1,h=t.width,c;h!=null&&(e==="break"||e==="breakAll")?c=r?Kg(r,t.font,h,e==="breakAll",0).lines:[]:c=r?r.split(`
`):[];var v=c.length*s,d=j(t.height,v);if(v>d&&u){var p=Math.floor(d/s);f=f||c.length>p,c=c.slice(0,p)}if(r&&a&&h!=null)for(var g=Xg(h,n,t.ellipsis,{minChar:t.truncateMinChar,placeholder:t.placeholder}),y={},m=0;m<c.length;m++)qg(y,c[m],g),c[m]=y.textLine,f=f||y.isTruncated;for(var _=d,S=0,m=0;m<c.length;m++)S=Math.max(ie(c[m],n),S);h==null&&(h=S);var x=S;return i&&(_+=i[0]+i[2],x+=i[1]+i[3],h+=i[1]+i[3]),l&&(x=h),{lines:c,height:d,outerWidth:x,outerHeight:_,lineHeight:s,calculatedLineHeight:o,contentWidth:S,contentHeight:v,width:h,isTruncated:f}}var Tw=function(){function r(){}return r}(),Nv=function(){function r(t){this.tokens=[],t&&(this.tokens=t)}return r}(),Cw=function(){function r(){this.width=0,this.height=0,this.contentWidth=0,this.contentHeight=0,this.outerWidth=0,this.outerHeight=0,this.lines=[],this.isTruncated=!1}return r}();function Mw(r,t){var e=new Cw;if(r!=null&&(r+=""),!r)return e;for(var i=t.width,n=t.height,a=t.overflow,o=(a==="break"||a==="breakAll")&&i!=null?{width:i,accumWidth:0,breakAll:a==="breakAll"}:null,s=bl.lastIndex=0,l;(l=bl.exec(r))!=null;){var u=l.index;u>s&&Tl(e,r.substring(s,u),t,o),Tl(e,l[2],t,o,l[1]),s=bl.lastIndex}s<r.length&&Tl(e,r.substring(s,r.length),t,o);var f=[],h=0,c=0,v=t.padding,d=a==="truncate",p=t.lineOverflow==="truncate",g={};function y(F,H,U){F.width=H,F.lineHeight=U,h+=U,c=Math.max(c,H)}t:for(var m=0;m<e.lines.length;m++){for(var _=e.lines[m],S=0,x=0,w=0;w<_.tokens.length;w++){var b=_.tokens[w],T=b.styleName&&t.rich[b.styleName]||{},M=b.textPadding=T.padding,D=M?M[1]+M[3]:0,C=b.font=T.font||t.font;b.contentHeight=Qf(C);var L=j(T.height,b.contentHeight);if(b.innerHeight=L,M&&(L+=M[0]+M[2]),b.height=L,b.lineHeight=Kn(T.lineHeight,t.lineHeight,L),b.align=T&&T.align||t.align,b.verticalAlign=T&&T.verticalAlign||"middle",p&&n!=null&&h+b.lineHeight>n){var I=e.lines.length;w>0?(_.tokens=_.tokens.slice(0,w),y(_,x,S),e.lines=e.lines.slice(0,m+1)):e.lines=e.lines.slice(0,m),e.isTruncated=e.isTruncated||e.lines.length<I;break t}var P=T.width,R=P==null||P==="auto";if(typeof P=="string"&&P.charAt(P.length-1)==="%")b.percentWidth=P,f.push(b),b.contentWidth=ie(b.text,C);else{if(R){var E=T.backgroundColor,z=E&&E.image;z&&(z=Sw(z),Ms(z)&&(b.width=Math.max(b.width,z.width*L/z.height)))}var k=d&&i!=null?i-x:null;k!=null&&k<b.width?!R||k<D?(b.text="",b.width=b.contentWidth=0):(ww(g,b.text,k-D,C,t.ellipsis,{minChar:t.truncateMinChar}),b.text=g.text,e.isTruncated=e.isTruncated||g.isTruncated,b.width=b.contentWidth=ie(b.text,C)):b.contentWidth=ie(b.text,C)}b.width+=D,x+=b.width,T&&(S=Math.max(S,b.lineHeight))}y(_,x,S)}e.outerWidth=e.width=j(i,c),e.outerHeight=e.height=j(n,h),e.contentHeight=h,e.contentWidth=c,v&&(e.outerWidth+=v[1]+v[3],e.outerHeight+=v[0]+v[2]);for(var m=0;m<f.length;m++){var b=f[m],B=b.percentWidth;b.width=parseInt(B,10)/100*e.width}return e}function Tl(r,t,e,i,n){var a=t==="",o=n&&e.rich[n]||{},s=r.lines,l=o.font||e.font,u=!1,f,h;if(i){var c=o.padding,v=c?c[1]+c[3]:0;if(o.width!=null&&o.width!=="auto"){var d=Dr(o.width,i.width)+v;s.length>0&&d+i.accumWidth>i.width&&(f=t.split(`
`),u=!0),i.accumWidth=d}else{var p=Kg(t,l,i.width,i.breakAll,i.accumWidth);i.accumWidth=p.accumWidth+v,h=p.linesWidths,f=p.lines}}else f=t.split(`
`);for(var g=0;g<f.length;g++){var y=f[g],m=new Tw;if(m.styleName=n,m.text=y,m.isLineHolder=!y&&!a,typeof o.width=="number"?m.width=o.width:m.width=h?h[g]:ie(y,l),!g&&!u){var _=(s[s.length-1]||(s[0]=new Nv)).tokens,S=_.length;S===1&&_[0].isLineHolder?_[0]=m:(y||!S||a)&&_.push(m)}else s.push(new Nv([m]))}}function Aw(r){var t=r.charCodeAt(0);return t>=32&&t<=591||t>=880&&t<=4351||t>=4608&&t<=5119||t>=7680&&t<=8303}var Dw=je(",&?/;] ".split(""),function(r,t){return r[t]=!0,r},{});function Lw(r){return Aw(r)?!!Dw[r]:!0}function Kg(r,t,e,i,n){for(var a=[],o=[],s="",l="",u=0,f=0,h=0;h<r.length;h++){var c=r.charAt(h);if(c===`
`){l&&(s+=l,f+=u),a.push(s),o.push(f),s="",l="",u=0,f=0;continue}var v=ie(c,t),d=i?!1:!Lw(c);if(a.length?f+v>e:n+f+v>e){f?(s||l)&&(d?(s||(s=l,l="",u=0,f=u),a.push(s),o.push(f-u),l+=c,u+=v,s="",f=u):(l&&(s+=l,l="",u=0),a.push(s),o.push(f),s=c,f=v)):d?(a.push(l),o.push(u),l=c,u=v):(a.push(c),o.push(v));continue}f+=v,d?(l+=c,u+=v):(l&&(s+=l,l="",u=0),s+=c)}return!a.length&&!s&&(s=r,l="",u=0),l&&(s+=l),s&&(a.push(s),o.push(f)),a.length===1&&(f+=n),{accumWidth:f,lines:a,linesWidths:o}}var Ju="__zr_style_"+Math.round(Math.random()*10),ri={shadowBlur:0,shadowOffsetX:0,shadowOffsetY:0,shadowColor:"#000",opacity:1,blend:"source-over"},As={style:{shadowBlur:!0,shadowOffsetX:!0,shadowOffsetY:!0,shadowColor:!0,opacity:!0}};ri[Ju]=!0;var zv=["z","z2","invisible"],Iw=["invisible"],Pw=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype._init=function(e){for(var i=vt(e),n=0;n<i.length;n++){var a=i[n];a==="style"?this.useStyle(e[a]):r.prototype.attrKV.call(this,a,e[a])}this.style||this.useStyle({})},t.prototype.beforeBrush=function(){},t.prototype.afterBrush=function(){},t.prototype.innerBeforeBrush=function(){},t.prototype.innerAfterBrush=function(){},t.prototype.shouldBePainted=function(e,i,n,a){var o=this.transform;if(this.ignore||this.invisible||this.style.opacity===0||this.culling&&Rw(this,e,i)||o&&!o[0]&&!o[3])return!1;if(n&&this.__clipPaths){for(var s=0;s<this.__clipPaths.length;++s)if(this.__clipPaths[s].isZeroArea())return!1}if(a&&this.parent)for(var l=this.parent;l;){if(l.ignore)return!1;l=l.parent}return!0},t.prototype.contain=function(e,i){return this.rectContain(e,i)},t.prototype.traverse=function(e,i){e.call(i,this)},t.prototype.rectContain=function(e,i){var n=this.transformCoordToLocal(e,i),a=this.getBoundingRect();return a.contain(n[0],n[1])},t.prototype.getPaintRect=function(){var e=this._paintRect;if(!this._paintRect||this.__dirty){var i=this.transform,n=this.getBoundingRect(),a=this.style,o=a.shadowBlur||0,s=a.shadowOffsetX||0,l=a.shadowOffsetY||0;e=this._paintRect||(this._paintRect=new ut(0,0,0,0)),i?ut.applyTransform(e,n,i):e.copy(n),(o||s||l)&&(e.width+=o*2+Math.abs(s),e.height+=o*2+Math.abs(l),e.x=Math.min(e.x,e.x+s-o),e.y=Math.min(e.y,e.y+l-o));var u=this.dirtyRectTolerance;e.isZero()||(e.x=Math.floor(e.x-u),e.y=Math.floor(e.y-u),e.width=Math.ceil(e.width+1+u*2),e.height=Math.ceil(e.height+1+u*2))}return e},t.prototype.setPrevPaintRect=function(e){e?(this._prevPaintRect=this._prevPaintRect||new ut(0,0,0,0),this._prevPaintRect.copy(e)):this._prevPaintRect=null},t.prototype.getPrevPaintRect=function(){return this._prevPaintRect},t.prototype.animateStyle=function(e){return this.animate("style",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():this.markRedraw()},t.prototype.attrKV=function(e,i){e!=="style"?r.prototype.attrKV.call(this,e,i):this.style?this.setStyle(i):this.useStyle(i)},t.prototype.setStyle=function(e,i){return typeof e=="string"?this.style[e]=i:O(this.style,e),this.dirtyStyle(),this},t.prototype.dirtyStyle=function(e){e||this.markRedraw(),this.__dirty|=Hn,this._rect&&(this._rect=null)},t.prototype.dirty=function(){this.dirtyStyle()},t.prototype.styleChanged=function(){return!!(this.__dirty&Hn)},t.prototype.styleUpdated=function(){this.__dirty&=~Hn},t.prototype.createStyle=function(e){return bs(ri,e)},t.prototype.useStyle=function(e){e[Ju]||(e=this.createStyle(e)),this.__inHover?this.__hoverStyle=e:this.style=e,this.dirtyStyle()},t.prototype.isStyleObject=function(e){return e[Ju]},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var i=this._normalState;e.style&&!i.style&&(i.style=this._mergeStyle(this.createStyle(),this.style)),this._savePrimaryToNormal(e,i,zv)},t.prototype._applyStateObj=function(e,i,n,a,o,s){r.prototype._applyStateObj.call(this,e,i,n,a,o,s);var l=!(i&&a),u;if(i&&i.style?o?a?u=i.style:(u=this._mergeStyle(this.createStyle(),n.style),this._mergeStyle(u,i.style)):(u=this._mergeStyle(this.createStyle(),a?this.style:n.style),this._mergeStyle(u,i.style)):l&&(u=n.style),u)if(o){var f=this.style;if(this.style=this.createStyle(l?{}:f),l)for(var h=vt(f),c=0;c<h.length;c++){var v=h[c];v in u&&(u[v]=u[v],this.style[v]=f[v])}for(var d=vt(u),c=0;c<d.length;c++){var v=d[c];this.style[v]=this.style[v]}this._transitionState(e,{style:u},s,this.getAnimationStyleProps())}else this.useStyle(u);for(var p=this.__inHover?Iw:zv,c=0;c<p.length;c++){var v=p[c];i&&i[v]!=null?this[v]=i[v]:l&&n[v]!=null&&(this[v]=n[v])}},t.prototype._mergeStates=function(e){for(var i=r.prototype._mergeStates.call(this,e),n,a=0;a<e.length;a++){var o=e[a];o.style&&(n=n||{},this._mergeStyle(n,o.style))}return n&&(i.style=n),i},t.prototype._mergeStyle=function(e,i){return O(e,i),e},t.prototype.getAnimationStyleProps=function(){return As},t.initDefaultProps=function(){var e=t.prototype;e.type="displayable",e.invisible=!1,e.z=0,e.z2=0,e.zlevel=0,e.culling=!1,e.cursor="pointer",e.rectHover=!1,e.incremental=!1,e._rect=null,e.dirtyRectTolerance=0,e.__dirty=re|Hn}(),t}(Rg),Cl=new ut(0,0,0,0),Ml=new ut(0,0,0,0);function Rw(r,t,e){return Cl.copy(r.getBoundingRect()),r.transform&&Cl.applyTransform(r.transform),Ml.width=t,Ml.height=e,!Cl.intersect(Ml)}const yi=Pw;var ce=Math.min,de=Math.max,Al=Math.sin,Dl=Math.cos,Nr=Math.PI*2,Ya=ln(),$a=ln(),Za=ln();function Fv(r,t,e,i,n,a){n[0]=ce(r,e),n[1]=ce(t,i),a[0]=de(r,e),a[1]=de(t,i)}var Vv=[],Hv=[];function Ew(r,t,e,i,n,a,o,s,l,u){var f=bg,h=Tt,c=f(r,e,n,o,Vv);l[0]=1/0,l[1]=1/0,u[0]=-1/0,u[1]=-1/0;for(var v=0;v<c;v++){var d=h(r,e,n,o,Vv[v]);l[0]=ce(d,l[0]),u[0]=de(d,u[0])}c=f(t,i,a,s,Hv);for(var v=0;v<c;v++){var p=h(t,i,a,s,Hv[v]);l[1]=ce(p,l[1]),u[1]=de(p,u[1])}l[0]=ce(r,l[0]),u[0]=de(r,u[0]),l[0]=ce(o,l[0]),u[0]=de(o,u[0]),l[1]=ce(t,l[1]),u[1]=de(t,u[1]),l[1]=ce(s,l[1]),u[1]=de(s,u[1])}function kw(r,t,e,i,n,a,o,s){var l=Tg,u=zt,f=de(ce(l(r,e,n),1),0),h=de(ce(l(t,i,a),1),0),c=u(r,e,n,f),v=u(t,i,a,h);o[0]=ce(r,n,c),o[1]=ce(t,a,v),s[0]=de(r,n,c),s[1]=de(t,a,v)}function Ow(r,t,e,i,n,a,o,s,l){var u=Ui,f=Yi,h=Math.abs(n-a);if(h%Nr<1e-4&&h>1e-4){s[0]=r-e,s[1]=t-i,l[0]=r+e,l[1]=t+i;return}if(Ya[0]=Dl(n)*e+r,Ya[1]=Al(n)*i+t,$a[0]=Dl(a)*e+r,$a[1]=Al(a)*i+t,u(s,Ya,$a),f(l,Ya,$a),n=n%Nr,n<0&&(n=n+Nr),a=a%Nr,a<0&&(a=a+Nr),n>a&&!o?a+=Nr:n<a&&o&&(n+=Nr),o){var c=a;a=n,n=c}for(var v=0;v<a;v+=Math.PI/2)v>n&&(Za[0]=Dl(v)*e+r,Za[1]=Al(v)*i+t,u(s,Za,s),f(l,Za,l))}var ht={M:1,L:2,C:3,Q:4,A:5,Z:6,R:7},zr=[],Fr=[],Pe=[],lr=[],Re=[],Ee=[],Ll=Math.min,Il=Math.max,Vr=Math.cos,Hr=Math.sin,Ye=Math.abs,ju=Math.PI,mr=ju*2,Pl=typeof Float32Array<"u",wn=[];function Rl(r){var t=Math.round(r/ju*1e8)/1e8;return t%2*ju}function Qg(r,t){var e=Rl(r[0]);e<0&&(e+=mr);var i=e-r[0],n=r[1];n+=i,!t&&n-e>=mr?n=e+mr:t&&e-n>=mr?n=e-mr:!t&&e>n?n=e+(mr-Rl(e-n)):t&&e<n&&(n=e-(mr-Rl(n-e))),r[0]=e,r[1]=n}var Bw=function(){function r(t){this.dpr=1,this._xi=0,this._yi=0,this._x0=0,this._y0=0,this._len=0,t&&(this._saveData=!1),this._saveData&&(this.data=[])}return r.prototype.increaseVersion=function(){this._version++},r.prototype.getVersion=function(){return this._version},r.prototype.setScale=function(t,e,i){i=i||0,i>0&&(this._ux=Ye(i/qo/t)||0,this._uy=Ye(i/qo/e)||0)},r.prototype.setDPR=function(t){this.dpr=t},r.prototype.setContext=function(t){this._ctx=t},r.prototype.getContext=function(){return this._ctx},r.prototype.beginPath=function(){return this._ctx&&this._ctx.beginPath(),this.reset(),this},r.prototype.reset=function(){this._saveData&&(this._len=0),this._pathSegLen&&(this._pathSegLen=null,this._pathLen=0),this._version++},r.prototype.moveTo=function(t,e){return this._drawPendingPt(),this.addData(ht.M,t,e),this._ctx&&this._ctx.moveTo(t,e),this._x0=t,this._y0=e,this._xi=t,this._yi=e,this},r.prototype.lineTo=function(t,e){var i=Ye(t-this._xi),n=Ye(e-this._yi),a=i>this._ux||n>this._uy;if(this.addData(ht.L,t,e),this._ctx&&a&&this._ctx.lineTo(t,e),a)this._xi=t,this._yi=e,this._pendingPtDist=0;else{var o=i*i+n*n;o>this._pendingPtDist&&(this._pendingPtX=t,this._pendingPtY=e,this._pendingPtDist=o)}return this},r.prototype.bezierCurveTo=function(t,e,i,n,a,o){return this._drawPendingPt(),this.addData(ht.C,t,e,i,n,a,o),this._ctx&&this._ctx.bezierCurveTo(t,e,i,n,a,o),this._xi=a,this._yi=o,this},r.prototype.quadraticCurveTo=function(t,e,i,n){return this._drawPendingPt(),this.addData(ht.Q,t,e,i,n),this._ctx&&this._ctx.quadraticCurveTo(t,e,i,n),this._xi=i,this._yi=n,this},r.prototype.arc=function(t,e,i,n,a,o){this._drawPendingPt(),wn[0]=n,wn[1]=a,Qg(wn,o),n=wn[0],a=wn[1];var s=a-n;return this.addData(ht.A,t,e,i,i,n,s,0,o?0:1),this._ctx&&this._ctx.arc(t,e,i,n,a,o),this._xi=Vr(a)*i+t,this._yi=Hr(a)*i+e,this},r.prototype.arcTo=function(t,e,i,n,a){return this._drawPendingPt(),this._ctx&&this._ctx.arcTo(t,e,i,n,a),this},r.prototype.rect=function(t,e,i,n){return this._drawPendingPt(),this._ctx&&this._ctx.rect(t,e,i,n),this.addData(ht.R,t,e,i,n),this},r.prototype.closePath=function(){this._drawPendingPt(),this.addData(ht.Z);var t=this._ctx,e=this._x0,i=this._y0;return t&&t.closePath(),this._xi=e,this._yi=i,this},r.prototype.fill=function(t){t&&t.fill(),this.toStatic()},r.prototype.stroke=function(t){t&&t.stroke(),this.toStatic()},r.prototype.len=function(){return this._len},r.prototype.setData=function(t){var e=t.length;!(this.data&&this.data.length===e)&&Pl&&(this.data=new Float32Array(e));for(var i=0;i<e;i++)this.data[i]=t[i];this._len=e},r.prototype.appendPath=function(t){t instanceof Array||(t=[t]);for(var e=t.length,i=0,n=this._len,a=0;a<e;a++)i+=t[a].len();Pl&&this.data instanceof Float32Array&&(this.data=new Float32Array(n+i));for(var a=0;a<e;a++)for(var o=t[a].data,s=0;s<o.length;s++)this.data[n++]=o[s];this._len=n},r.prototype.addData=function(t,e,i,n,a,o,s,l,u){if(!!this._saveData){var f=this.data;this._len+arguments.length>f.length&&(this._expandData(),f=this.data);for(var h=0;h<arguments.length;h++)f[this._len++]=arguments[h]}},r.prototype._drawPendingPt=function(){this._pendingPtDist>0&&(this._ctx&&this._ctx.lineTo(this._pendingPtX,this._pendingPtY),this._pendingPtDist=0)},r.prototype._expandData=function(){if(!(this.data instanceof Array)){for(var t=[],e=0;e<this._len;e++)t[e]=this.data[e];this.data=t}},r.prototype.toStatic=function(){if(!!this._saveData){this._drawPendingPt();var t=this.data;t instanceof Array&&(t.length=this._len,Pl&&this._len>11&&(this.data=new Float32Array(t)))}},r.prototype.getBoundingRect=function(){Pe[0]=Pe[1]=Re[0]=Re[1]=Number.MAX_VALUE,lr[0]=lr[1]=Ee[0]=Ee[1]=-Number.MAX_VALUE;var t=this.data,e=0,i=0,n=0,a=0,o;for(o=0;o<this._len;){var s=t[o++],l=o===1;switch(l&&(e=t[o],i=t[o+1],n=e,a=i),s){case ht.M:e=n=t[o++],i=a=t[o++],Re[0]=n,Re[1]=a,Ee[0]=n,Ee[1]=a;break;case ht.L:Fv(e,i,t[o],t[o+1],Re,Ee),e=t[o++],i=t[o++];break;case ht.C:Ew(e,i,t[o++],t[o++],t[o++],t[o++],t[o],t[o+1],Re,Ee),e=t[o++],i=t[o++];break;case ht.Q:kw(e,i,t[o++],t[o++],t[o],t[o+1],Re,Ee),e=t[o++],i=t[o++];break;case ht.A:var u=t[o++],f=t[o++],h=t[o++],c=t[o++],v=t[o++],d=t[o++]+v;o+=1;var p=!t[o++];l&&(n=Vr(v)*h+u,a=Hr(v)*c+f),Ow(u,f,h,c,v,d,p,Re,Ee),e=Vr(d)*h+u,i=Hr(d)*c+f;break;case ht.R:n=e=t[o++],a=i=t[o++];var g=t[o++],y=t[o++];Fv(n,a,n+g,a+y,Re,Ee);break;case ht.Z:e=n,i=a;break}Ui(Pe,Pe,Re),Yi(lr,lr,Ee)}return o===0&&(Pe[0]=Pe[1]=lr[0]=lr[1]=0),new ut(Pe[0],Pe[1],lr[0]-Pe[0],lr[1]-Pe[1])},r.prototype._calculateLength=function(){var t=this.data,e=this._len,i=this._ux,n=this._uy,a=0,o=0,s=0,l=0;this._pathSegLen||(this._pathSegLen=[]);for(var u=this._pathSegLen,f=0,h=0,c=0;c<e;){var v=t[c++],d=c===1;d&&(a=t[c],o=t[c+1],s=a,l=o);var p=-1;switch(v){case ht.M:a=s=t[c++],o=l=t[c++];break;case ht.L:{var g=t[c++],y=t[c++],m=g-a,_=y-o;(Ye(m)>i||Ye(_)>n||c===e-1)&&(p=Math.sqrt(m*m+_*_),a=g,o=y);break}case ht.C:{var S=t[c++],x=t[c++],g=t[c++],y=t[c++],w=t[c++],b=t[c++];p=rS(a,o,S,x,g,y,w,b,10),a=w,o=b;break}case ht.Q:{var S=t[c++],x=t[c++],g=t[c++],y=t[c++];p=aS(a,o,S,x,g,y,10),a=g,o=y;break}case ht.A:var T=t[c++],M=t[c++],D=t[c++],C=t[c++],L=t[c++],I=t[c++],P=I+L;c+=1,d&&(s=Vr(L)*D+T,l=Hr(L)*C+M),p=Il(D,C)*Ll(mr,Math.abs(I)),a=Vr(P)*D+T,o=Hr(P)*C+M;break;case ht.R:{s=a=t[c++],l=o=t[c++];var R=t[c++],E=t[c++];p=R*2+E*2;break}case ht.Z:{var m=s-a,_=l-o;p=Math.sqrt(m*m+_*_),a=s,o=l;break}}p>=0&&(u[h++]=p,f+=p)}return this._pathLen=f,f},r.prototype.rebuildPath=function(t,e){var i=this.data,n=this._ux,a=this._uy,o=this._len,s,l,u,f,h,c,v=e<1,d,p,g=0,y=0,m,_=0,S,x;if(v&&(this._pathSegLen||this._calculateLength(),d=this._pathSegLen,p=this._pathLen,m=e*p,!m))return;t:for(var w=0;w<o;){var b=i[w++],T=w===1;switch(T&&(u=i[w],f=i[w+1],s=u,l=f),b!==ht.L&&_>0&&(t.lineTo(S,x),_=0),b){case ht.M:s=u=i[w++],l=f=i[w++],t.moveTo(u,f);break;case ht.L:{h=i[w++],c=i[w++];var M=Ye(h-u),D=Ye(c-f);if(M>n||D>a){if(v){var C=d[y++];if(g+C>m){var L=(m-g)/C;t.lineTo(u*(1-L)+h*L,f*(1-L)+c*L);break t}g+=C}t.lineTo(h,c),u=h,f=c,_=0}else{var I=M*M+D*D;I>_&&(S=h,x=c,_=I)}break}case ht.C:{var P=i[w++],R=i[w++],E=i[w++],z=i[w++],k=i[w++],B=i[w++];if(v){var C=d[y++];if(g+C>m){var L=(m-g)/C;$o(u,P,E,k,L,zr),$o(f,R,z,B,L,Fr),t.bezierCurveTo(zr[1],Fr[1],zr[2],Fr[2],zr[3],Fr[3]);break t}g+=C}t.bezierCurveTo(P,R,E,z,k,B),u=k,f=B;break}case ht.Q:{var P=i[w++],R=i[w++],E=i[w++],z=i[w++];if(v){var C=d[y++];if(g+C>m){var L=(m-g)/C;Zo(u,P,E,L,zr),Zo(f,R,z,L,Fr),t.quadraticCurveTo(zr[1],Fr[1],zr[2],Fr[2]);break t}g+=C}t.quadraticCurveTo(P,R,E,z),u=E,f=z;break}case ht.A:var F=i[w++],H=i[w++],U=i[w++],J=i[w++],ot=i[w++],ft=i[w++],Ut=i[w++],ne=!i[w++],ee=U>J?U:J,It=Ye(U-J)>.001,St=ot+ft,X=!1;if(v){var C=d[y++];g+C>m&&(St=ot+ft*(m-g)/C,X=!0),g+=C}if(It&&t.ellipse?t.ellipse(F,H,U,J,Ut,ot,St,ne):t.arc(F,H,ee,ot,St,ne),X)break t;T&&(s=Vr(ot)*U+F,l=Hr(ot)*J+H),u=Vr(St)*U+F,f=Hr(St)*J+H;break;case ht.R:s=u=i[w],l=f=i[w+1],h=i[w++],c=i[w++];var it=i[w++],Ie=i[w++];if(v){var C=d[y++];if(g+C>m){var Mt=m-g;t.moveTo(h,c),t.lineTo(h+Ll(Mt,it),c),Mt-=it,Mt>0&&t.lineTo(h+it,c+Ll(Mt,Ie)),Mt-=Ie,Mt>0&&t.lineTo(h+Il(it-Mt,0),c+Ie),Mt-=it,Mt>0&&t.lineTo(h,c+Il(Ie-Mt,0));break t}g+=C}t.rect(h,c,it,Ie);break;case ht.Z:if(v){var C=d[y++];if(g+C>m){var L=(m-g)/C;t.lineTo(u*(1-L)+s*L,f*(1-L)+l*L);break t}g+=C}t.closePath(),u=s,f=l}}},r.prototype.clone=function(){var t=new r,e=this.data;return t.data=e.slice?e.slice():Array.prototype.slice.call(e),t._len=this._len,t},r.CMD=ht,r.initDefaultProps=function(){var t=r.prototype;t._saveData=!0,t._ux=0,t._uy=0,t._pendingPtDist=0,t._version=0}(),r}();const Lr=Bw;function Li(r,t,e,i,n,a,o){if(n===0)return!1;var s=n,l=0,u=r;if(o>t+s&&o>i+s||o<t-s&&o<i-s||a>r+s&&a>e+s||a<r-s&&a<e-s)return!1;if(r!==e)l=(t-i)/(r-e),u=(r*i-e*t)/(r-e);else return Math.abs(a-r)<=s/2;var f=l*a-o+u,h=f*f/(l*l+1);return h<=s/2*s/2}function Nw(r,t,e,i,n,a,o,s,l,u,f){if(l===0)return!1;var h=l;if(f>t+h&&f>i+h&&f>a+h&&f>s+h||f<t-h&&f<i-h&&f<a-h&&f<s-h||u>r+h&&u>e+h&&u>n+h&&u>o+h||u<r-h&&u<e-h&&u<n-h&&u<o-h)return!1;var c=eS(r,t,e,i,n,a,o,s,u,f,null);return c<=h/2}function zw(r,t,e,i,n,a,o,s,l){if(o===0)return!1;var u=o;if(l>t+u&&l>i+u&&l>a+u||l<t-u&&l<i-u&&l<a-u||s>r+u&&s>e+u&&s>n+u||s<r-u&&s<e-u&&s<n-u)return!1;var f=nS(r,t,e,i,n,a,s,l,null);return f<=u/2}var Gv=Math.PI*2;function Xa(r){return r%=Gv,r<0&&(r+=Gv),r}var xn=Math.PI*2;function Fw(r,t,e,i,n,a,o,s,l){if(o===0)return!1;var u=o;s-=r,l-=t;var f=Math.sqrt(s*s+l*l);if(f-u>e||f+u<e)return!1;if(Math.abs(i-n)%xn<1e-4)return!0;if(a){var h=i;i=Xa(n),n=Xa(h)}else i=Xa(i),n=Xa(n);i>n&&(n+=xn);var c=Math.atan2(l,s);return c<0&&(c+=xn),c>=i&&c<=n||c+xn>=i&&c+xn<=n}function Gr(r,t,e,i,n,a){if(a>t&&a>i||a<t&&a<i||i===t)return 0;var o=(a-t)/(i-t),s=i<t?1:-1;(o===1||o===0)&&(s=i<t?.5:-.5);var l=o*(e-r)+r;return l===n?1/0:l>n?s:0}var ur=Lr.CMD,Wr=Math.PI*2,Vw=1e-4;function Hw(r,t){return Math.abs(r-t)<Vw}var Vt=[-1,-1,-1],fe=[-1,-1];function Gw(){var r=fe[0];fe[0]=fe[1],fe[1]=r}function Ww(r,t,e,i,n,a,o,s,l,u){if(u>t&&u>i&&u>a&&u>s||u<t&&u<i&&u<a&&u<s)return 0;var f=Yo(t,i,a,s,u,Vt);if(f===0)return 0;for(var h=0,c=-1,v=void 0,d=void 0,p=0;p<f;p++){var g=Vt[p],y=g===0||g===1?.5:1,m=Tt(r,e,n,o,g);m<l||(c<0&&(c=bg(t,i,a,s,fe),fe[1]<fe[0]&&c>1&&Gw(),v=Tt(t,i,a,s,fe[0]),c>1&&(d=Tt(t,i,a,s,fe[1]))),c===2?g<fe[0]?h+=v<t?y:-y:g<fe[1]?h+=d<v?y:-y:h+=s<d?y:-y:g<fe[0]?h+=v<t?y:-y:h+=s<v?y:-y)}return h}function Uw(r,t,e,i,n,a,o,s){if(s>t&&s>i&&s>a||s<t&&s<i&&s<a)return 0;var l=iS(t,i,a,s,Vt);if(l===0)return 0;var u=Tg(t,i,a);if(u>=0&&u<=1){for(var f=0,h=zt(t,i,a,u),c=0;c<l;c++){var v=Vt[c]===0||Vt[c]===1?.5:1,d=zt(r,e,n,Vt[c]);d<o||(Vt[c]<u?f+=h<t?v:-v:f+=a<h?v:-v)}return f}else{var v=Vt[0]===0||Vt[0]===1?.5:1,d=zt(r,e,n,Vt[0]);return d<o?0:a<t?v:-v}}function Yw(r,t,e,i,n,a,o,s){if(s-=t,s>e||s<-e)return 0;var l=Math.sqrt(e*e-s*s);Vt[0]=-l,Vt[1]=l;var u=Math.abs(i-n);if(u<1e-4)return 0;if(u>=Wr-1e-4){i=0,n=Wr;var f=a?1:-1;return o>=Vt[0]+r&&o<=Vt[1]+r?f:0}if(i>n){var h=i;i=n,n=h}i<0&&(i+=Wr,n+=Wr);for(var c=0,v=0;v<2;v++){var d=Vt[v];if(d+r>o){var p=Math.atan2(s,d),f=a?1:-1;p<0&&(p=Wr+p),(p>=i&&p<=n||p+Wr>=i&&p+Wr<=n)&&(p>Math.PI/2&&p<Math.PI*1.5&&(f=-f),c+=f)}}return c}function Jg(r,t,e,i,n){for(var a=r.data,o=r.len(),s=0,l=0,u=0,f=0,h=0,c,v,d=0;d<o;){var p=a[d++],g=d===1;switch(p===ur.M&&d>1&&(e||(s+=Gr(l,u,f,h,i,n))),g&&(l=a[d],u=a[d+1],f=l,h=u),p){case ur.M:f=a[d++],h=a[d++],l=f,u=h;break;case ur.L:if(e){if(Li(l,u,a[d],a[d+1],t,i,n))return!0}else s+=Gr(l,u,a[d],a[d+1],i,n)||0;l=a[d++],u=a[d++];break;case ur.C:if(e){if(Nw(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],t,i,n))return!0}else s+=Ww(l,u,a[d++],a[d++],a[d++],a[d++],a[d],a[d+1],i,n)||0;l=a[d++],u=a[d++];break;case ur.Q:if(e){if(zw(l,u,a[d++],a[d++],a[d],a[d+1],t,i,n))return!0}else s+=Uw(l,u,a[d++],a[d++],a[d],a[d+1],i,n)||0;l=a[d++],u=a[d++];break;case ur.A:var y=a[d++],m=a[d++],_=a[d++],S=a[d++],x=a[d++],w=a[d++];d+=1;var b=!!(1-a[d++]);c=Math.cos(x)*_+y,v=Math.sin(x)*S+m,g?(f=c,h=v):s+=Gr(l,u,c,v,i,n);var T=(i-y)*S/_+y;if(e){if(Fw(y,m,S,x,x+w,b,t,T,n))return!0}else s+=Yw(y,m,S,x,x+w,b,T,n);l=Math.cos(x+w)*_+y,u=Math.sin(x+w)*S+m;break;case ur.R:f=l=a[d++],h=u=a[d++];var M=a[d++],D=a[d++];if(c=f+M,v=h+D,e){if(Li(f,h,c,h,t,i,n)||Li(c,h,c,v,t,i,n)||Li(c,v,f,v,t,i,n)||Li(f,v,f,h,t,i,n))return!0}else s+=Gr(c,h,c,v,i,n),s+=Gr(f,v,f,h,i,n);break;case ur.Z:if(e){if(Li(l,u,f,h,t,i,n))return!0}else s+=Gr(l,u,f,h,i,n);l=f,u=h;break}}return!e&&!Hw(u,h)&&(s+=Gr(l,u,f,h,i,n)||0),s!==0}function $w(r,t,e){return Jg(r,0,!1,t,e)}function Zw(r,t,e,i){return Jg(r,t,!0,e,i)}var jg=rt({fill:"#000",stroke:null,strokePercent:1,fillOpacity:1,strokeOpacity:1,lineDashOffset:0,lineWidth:1,lineCap:"butt",miterLimit:10,strokeNoScale:!1,strokeFirst:!1},ri),Xw={style:rt({fill:!0,stroke:!0,strokePercent:!0,fillOpacity:!0,strokeOpacity:!0,lineDashOffset:!0,lineWidth:!0,miterLimit:!0},As.style)},El=He.concat(["invisible","culling","z","z2","zlevel","parent"]),qw=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.update=function(){var e=this;r.prototype.update.call(this);var i=this.style;if(i.decal){var n=this._decalEl=this._decalEl||new t;n.buildPath===t.prototype.buildPath&&(n.buildPath=function(l){e.buildPath(l,e.shape)}),n.silent=!0;var a=n.style;for(var o in i)a[o]!==i[o]&&(a[o]=i[o]);a.fill=i.fill?i.decal:null,a.decal=null,a.shadowColor=null,i.strokeFirst&&(a.stroke=null);for(var s=0;s<El.length;++s)n[El[s]]=this[El[s]];n.__dirty|=re}else this._decalEl&&(this._decalEl=null)},t.prototype.getDecalElement=function(){return this._decalEl},t.prototype._init=function(e){var i=vt(e);this.shape=this.getDefaultShape();var n=this.getDefaultStyle();n&&this.useStyle(n);for(var a=0;a<i.length;a++){var o=i[a],s=e[o];o==="style"?this.style?O(this.style,s):this.useStyle(s):o==="shape"?O(this.shape,s):r.prototype.attrKV.call(this,o,s)}this.style||this.useStyle({})},t.prototype.getDefaultStyle=function(){return null},t.prototype.getDefaultShape=function(){return{}},t.prototype.canBeInsideText=function(){return this.hasFill()},t.prototype.getInsideTextFill=function(){var e=this.style.fill;if(e!=="none"){if(W(e)){var i=Xo(e,0);return i>.5?Xu:i>.2?LS:qu}else if(e)return qu}return Xu},t.prototype.getInsideTextStroke=function(e){var i=this.style.fill;if(W(i)){var n=this.__zr,a=!!(n&&n.isDarkMode()),o=Xo(e,0)<Zu;if(a===o)return i}},t.prototype.buildPath=function(e,i,n){},t.prototype.pathUpdated=function(){this.__dirty&=~Hi},t.prototype.getUpdatedPathProxy=function(e){return!this.path&&this.createPathProxy(),this.path.beginPath(),this.buildPath(this.path,this.shape,e),this.path},t.prototype.createPathProxy=function(){this.path=new Lr(!1)},t.prototype.hasStroke=function(){var e=this.style,i=e.stroke;return!(i==null||i==="none"||!(e.lineWidth>0))},t.prototype.hasFill=function(){var e=this.style,i=e.fill;return i!=null&&i!=="none"},t.prototype.getBoundingRect=function(){var e=this._rect,i=this.style,n=!e;if(n){var a=!1;this.path||(a=!0,this.createPathProxy());var o=this.path;(a||this.__dirty&Hi)&&(o.beginPath(),this.buildPath(o,this.shape,!1),this.pathUpdated()),e=o.getBoundingRect()}if(this._rect=e,this.hasStroke()&&this.path&&this.path.len()>0){var s=this._rectStroke||(this._rectStroke=e.clone());if(this.__dirty||n){s.copy(e);var l=i.strokeNoScale?this.getLineScale():1,u=i.lineWidth;if(!this.hasFill()){var f=this.strokeContainThreshold;u=Math.max(u,f==null?4:f)}l>1e-10&&(s.width+=u/l,s.height+=u/l,s.x-=u/l/2,s.y-=u/l/2)}return s}return e},t.prototype.contain=function(e,i){var n=this.transformCoordToLocal(e,i),a=this.getBoundingRect(),o=this.style;if(e=n[0],i=n[1],a.contain(e,i)){var s=this.path;if(this.hasStroke()){var l=o.lineWidth,u=o.strokeNoScale?this.getLineScale():1;if(u>1e-10&&(this.hasFill()||(l=Math.max(l,this.strokeContainThreshold)),Zw(s,l/u,e,i)))return!0}if(this.hasFill())return $w(s,e,i)}return!1},t.prototype.dirtyShape=function(){this.__dirty|=Hi,this._rect&&(this._rect=null),this._decalEl&&this._decalEl.dirtyShape(),this.markRedraw()},t.prototype.dirty=function(){this.dirtyStyle(),this.dirtyShape()},t.prototype.animateShape=function(e){return this.animate("shape",e)},t.prototype.updateDuringAnimation=function(e){e==="style"?this.dirtyStyle():e==="shape"?this.dirtyShape():this.markRedraw()},t.prototype.attrKV=function(e,i){e==="shape"?this.setShape(i):r.prototype.attrKV.call(this,e,i)},t.prototype.setShape=function(e,i){var n=this.shape;return n||(n=this.shape={}),typeof e=="string"?n[e]=i:O(n,e),this.dirtyShape(),this},t.prototype.shapeChanged=function(){return!!(this.__dirty&Hi)},t.prototype.createStyle=function(e){return bs(jg,e)},t.prototype._innerSaveToNormal=function(e){r.prototype._innerSaveToNormal.call(this,e);var i=this._normalState;e.shape&&!i.shape&&(i.shape=O({},this.shape))},t.prototype._applyStateObj=function(e,i,n,a,o,s){r.prototype._applyStateObj.call(this,e,i,n,a,o,s);var l=!(i&&a),u;if(i&&i.shape?o?a?u=i.shape:(u=O({},n.shape),O(u,i.shape)):(u=O({},a?this.shape:n.shape),O(u,i.shape)):l&&(u=n.shape),u)if(o){this.shape=O({},this.shape);for(var f={},h=vt(u),c=0;c<h.length;c++){var v=h[c];typeof u[v]=="object"?this.shape[v]=u[v]:f[v]=u[v]}this._transitionState(e,{shape:f},s)}else this.shape=u,this.dirtyShape()},t.prototype._mergeStates=function(e){for(var i=r.prototype._mergeStates.call(this,e),n,a=0;a<e.length;a++){var o=e[a];o.shape&&(n=n||{},this._mergeStyle(n,o.shape))}return n&&(i.shape=n),i},t.prototype.getAnimationStyleProps=function(){return Xw},t.prototype.isZeroArea=function(){return!1},t.extend=function(e){var i=function(a){N(o,a);function o(s){var l=a.call(this,s)||this;return e.init&&e.init.call(l,s),l}return o.prototype.getDefaultStyle=function(){return et(e.style)},o.prototype.getDefaultShape=function(){return et(e.shape)},o}(t);for(var n in e)typeof e[n]=="function"&&(i.prototype[n]=e[n]);return i},t.initDefaultProps=function(){var e=t.prototype;e.type="path",e.strokeContainThreshold=5,e.segmentIgnoreThreshold=0,e.subPixelOptimize=!1,e.autoBatch=!1,e.__dirty=re|Hn|Hi}(),t}(yi);const ct=qw;var Kw=rt({strokeFirst:!0,font:si,x:0,y:0,textAlign:"left",textBaseline:"top",miterLimit:2},jg),ty=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.hasStroke=function(){var e=this.style,i=e.stroke;return i!=null&&i!=="none"&&e.lineWidth>0},t.prototype.hasFill=function(){var e=this.style,i=e.fill;return i!=null&&i!=="none"},t.prototype.createStyle=function(e){return bs(Kw,e)},t.prototype.setBoundingRect=function(e){this._rect=e},t.prototype.getBoundingRect=function(){var e=this.style;if(!this._rect){var i=e.text;i!=null?i+="":i="";var n=Kf(i,e.font,e.textAlign,e.textBaseline);if(n.x+=e.x||0,n.y+=e.y||0,this.hasStroke()){var a=e.lineWidth;n.x-=a/2,n.y-=a/2,n.width+=a,n.height+=a}this._rect=n}return this._rect},t.initDefaultProps=function(){var e=t.prototype;e.dirtyRectTolerance=10}(),t}(yi);ty.prototype.type="tspan";const tf=ty;var Qw=rt({x:0,y:0},ri),Jw={style:rt({x:!0,y:!0,width:!0,height:!0,sx:!0,sy:!0,sWidth:!0,sHeight:!0},As.style)};function jw(r){return!!(r&&typeof r!="string"&&r.width&&r.height)}var ey=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.createStyle=function(e){return bs(Qw,e)},t.prototype._getSize=function(e){var i=this.style,n=i[e];if(n!=null)return n;var a=jw(i.image)?i.image:this.__image;if(!a)return 0;var o=e==="width"?"height":"width",s=i[o];return s==null?a[e]:a[e]/a[o]*s},t.prototype.getWidth=function(){return this._getSize("width")},t.prototype.getHeight=function(){return this._getSize("height")},t.prototype.getAnimationStyleProps=function(){return Jw},t.prototype.getBoundingRect=function(){var e=this.style;return this._rect||(this._rect=new ut(e.x||0,e.y||0,this.getWidth(),this.getHeight())),this._rect},t}(yi);ey.prototype.type="image";const nr=ey;function tx(r,t){var e=t.x,i=t.y,n=t.width,a=t.height,o=t.r,s,l,u,f;n<0&&(e=e+n,n=-n),a<0&&(i=i+a,a=-a),typeof o=="number"?s=l=u=f=o:o instanceof Array?o.length===1?s=l=u=f=o[0]:o.length===2?(s=u=o[0],l=f=o[1]):o.length===3?(s=o[0],l=f=o[1],u=o[2]):(s=o[0],l=o[1],u=o[2],f=o[3]):s=l=u=f=0;var h;s+l>n&&(h=s+l,s*=n/h,l*=n/h),u+f>n&&(h=u+f,u*=n/h,f*=n/h),l+u>a&&(h=l+u,l*=a/h,u*=a/h),s+f>a&&(h=s+f,s*=a/h,f*=a/h),r.moveTo(e+s,i),r.lineTo(e+n-l,i),l!==0&&r.arc(e+n-l,i+l,l,-Math.PI/2,0),r.lineTo(e+n,i+a-u),u!==0&&r.arc(e+n-u,i+a-u,u,0,Math.PI/2),r.lineTo(e+f,i+a),f!==0&&r.arc(e+f,i+a-f,f,Math.PI/2,Math.PI),r.lineTo(e,i+s),s!==0&&r.arc(e+s,i+s,s,Math.PI,Math.PI*1.5)}var Zi=Math.round;function ry(r,t,e){if(!!t){var i=t.x1,n=t.x2,a=t.y1,o=t.y2;r.x1=i,r.x2=n,r.y1=a,r.y2=o;var s=e&&e.lineWidth;return s&&(Zi(i*2)===Zi(n*2)&&(r.x1=r.x2=jr(i,s,!0)),Zi(a*2)===Zi(o*2)&&(r.y1=r.y2=jr(a,s,!0))),r}}function iy(r,t,e){if(!!t){var i=t.x,n=t.y,a=t.width,o=t.height;r.x=i,r.y=n,r.width=a,r.height=o;var s=e&&e.lineWidth;return s&&(r.x=jr(i,s,!0),r.y=jr(n,s,!0),r.width=Math.max(jr(i+a,s,!1)-r.x,a===0?0:1),r.height=Math.max(jr(n+o,s,!1)-r.y,o===0?0:1)),r}}function jr(r,t,e){if(!t)return r;var i=Zi(r*2);return(i+Zi(t))%2===0?i/2:(i+(e?1:-1))/2}var ex=function(){function r(){this.x=0,this.y=0,this.width=0,this.height=0}return r}(),rx={},ny=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new ex},t.prototype.buildPath=function(e,i){var n,a,o,s;if(this.subPixelOptimize){var l=iy(rx,i,this.style);n=l.x,a=l.y,o=l.width,s=l.height,l.r=i.r,i=l}else n=i.x,a=i.y,o=i.width,s=i.height;i.r?tx(e,i):e.rect(n,a,o,s)},t.prototype.isZeroArea=function(){return!this.shape.width||!this.shape.height},t}(ct);ny.prototype.type="rect";const _t=ny;var Wv={fill:"#000"},Uv=2,ix={style:rt({fill:!0,stroke:!0,fillOpacity:!0,strokeOpacity:!0,lineWidth:!0,fontSize:!0,lineHeight:!0,width:!0,height:!0,textShadowColor:!0,textShadowBlur:!0,textShadowOffsetX:!0,textShadowOffsetY:!0,backgroundColor:!0,padding:!0,borderColor:!0,borderWidth:!0,borderRadius:!0},As.style)},ay=function(r){N(t,r);function t(e){var i=r.call(this)||this;return i.type="text",i._children=[],i._defaultStyle=Wv,i.attr(e),i}return t.prototype.childrenRef=function(){return this._children},t.prototype.update=function(){r.prototype.update.call(this),this.styleChanged()&&this._updateSubTexts();for(var e=0;e<this._children.length;e++){var i=this._children[e];i.zlevel=this.zlevel,i.z=this.z,i.z2=this.z2,i.culling=this.culling,i.cursor=this.cursor,i.invisible=this.invisible}},t.prototype.updateTransform=function(){var e=this.innerTransformable;e?(e.updateTransform(),e.transform&&(this.transform=e.transform)):r.prototype.updateTransform.call(this)},t.prototype.getLocalTransform=function(e){var i=this.innerTransformable;return i?i.getLocalTransform(e):r.prototype.getLocalTransform.call(this,e)},t.prototype.getComputedTransform=function(){return this.__hostTarget&&(this.__hostTarget.getComputedTransform(),this.__hostTarget.updateInnerText(!0)),r.prototype.getComputedTransform.call(this)},t.prototype._updateSubTexts=function(){this._childCursor=0,lx(this.style),this.style.rich?this._updateRichTexts():this._updatePlainTexts(),this._children.length=this._childCursor,this.styleUpdated()},t.prototype.addSelfToZr=function(e){r.prototype.addSelfToZr.call(this,e);for(var i=0;i<this._children.length;i++)this._children[i].__zr=e},t.prototype.removeSelfFromZr=function(e){r.prototype.removeSelfFromZr.call(this,e);for(var i=0;i<this._children.length;i++)this._children[i].__zr=null},t.prototype.getBoundingRect=function(){if(this.styleChanged()&&this._updateSubTexts(),!this._rect){for(var e=new ut(0,0,0,0),i=this._children,n=[],a=null,o=0;o<i.length;o++){var s=i[o],l=s.getBoundingRect(),u=s.getLocalTransform(n);u?(e.copy(l),e.applyTransform(u),a=a||e.clone(),a.union(e)):(a=a||l.clone(),a.union(l))}this._rect=a||e}return this._rect},t.prototype.setDefaultTextStyle=function(e){this._defaultStyle=e||Wv},t.prototype.setTextContent=function(e){},t.prototype._mergeStyle=function(e,i){if(!i)return e;var n=i.rich,a=e.rich||n&&{};return O(e,i),n&&a?(this._mergeRich(a,n),e.rich=a):a&&(e.rich=a),e},t.prototype._mergeRich=function(e,i){for(var n=vt(i),a=0;a<n.length;a++){var o=n[a];e[o]=e[o]||{},O(e[o],i[o])}},t.prototype.getAnimationStyleProps=function(){return ix},t.prototype._getOrCreateChild=function(e){var i=this._children[this._childCursor];return(!i||!(i instanceof e))&&(i=new e),this._children[this._childCursor++]=i,i.__zr=this.__zr,i.parent=this,i},t.prototype._updatePlainTexts=function(){var e=this.style,i=e.font||si,n=e.padding,a=Qv(e),o=bw(a,e),s=kl(e),l=!!e.backgroundColor,u=o.outerHeight,f=o.outerWidth,h=o.contentWidth,c=o.lines,v=o.lineHeight,d=this._defaultStyle;this.isTruncated=!!o.isTruncated;var p=e.x||0,g=e.y||0,y=e.align||d.align||"left",m=e.verticalAlign||d.verticalAlign||"top",_=p,S=Gi(g,o.contentHeight,m);if(s||n){var x=Wn(p,f,y),w=Gi(g,u,m);s&&this._renderBackground(e,e,x,w,f,u)}S+=v/2,n&&(_=Kv(p,y,n),m==="top"?S+=n[0]:m==="bottom"&&(S-=n[2]));for(var b=0,T=!1,M=qv("fill"in e?e.fill:(T=!0,d.fill)),D=Xv("stroke"in e?e.stroke:!l&&(!d.autoStroke||T)?(b=Uv,d.stroke):null),C=e.textShadowBlur>0,L=e.width!=null&&(e.overflow==="truncate"||e.overflow==="break"||e.overflow==="breakAll"),I=o.calculatedLineHeight,P=0;P<c.length;P++){var R=this._getOrCreateChild(tf),E=R.createStyle();R.useStyle(E),E.text=c[P],E.x=_,E.y=S,y&&(E.textAlign=y),E.textBaseline="middle",E.opacity=e.opacity,E.strokeFirst=!0,C&&(E.shadowBlur=e.textShadowBlur||0,E.shadowColor=e.textShadowColor||"transparent",E.shadowOffsetX=e.textShadowOffsetX||0,E.shadowOffsetY=e.textShadowOffsetY||0),E.stroke=D,E.fill=M,D&&(E.lineWidth=e.lineWidth||b,E.lineDash=e.lineDash,E.lineDashOffset=e.lineDashOffset||0),E.font=i,$v(E,e),S+=v,L&&R.setBoundingRect(new ut(Wn(E.x,h,E.textAlign),Gi(E.y,I,E.textBaseline),h,I))}},t.prototype._updateRichTexts=function(){var e=this.style,i=Qv(e),n=Mw(i,e),a=n.width,o=n.outerWidth,s=n.outerHeight,l=e.padding,u=e.x||0,f=e.y||0,h=this._defaultStyle,c=e.align||h.align,v=e.verticalAlign||h.verticalAlign;this.isTruncated=!!n.isTruncated;var d=Wn(u,o,c),p=Gi(f,s,v),g=d,y=p;l&&(g+=l[3],y+=l[0]);var m=g+a;kl(e)&&this._renderBackground(e,e,d,p,o,s);for(var _=!!e.backgroundColor,S=0;S<n.lines.length;S++){for(var x=n.lines[S],w=x.tokens,b=w.length,T=x.lineHeight,M=x.width,D=0,C=g,L=m,I=b-1,P=void 0;D<b&&(P=w[D],!P.align||P.align==="left");)this._placeToken(P,e,T,y,C,"left",_),M-=P.width,C+=P.width,D++;for(;I>=0&&(P=w[I],P.align==="right");)this._placeToken(P,e,T,y,L,"right",_),M-=P.width,L-=P.width,I--;for(C+=(a-(C-g)-(m-L)-M)/2;D<=I;)P=w[D],this._placeToken(P,e,T,y,C+P.width/2,"center",_),C+=P.width,D++;y+=T}},t.prototype._placeToken=function(e,i,n,a,o,s,l){var u=i.rich[e.styleName]||{};u.text=e.text;var f=e.verticalAlign,h=a+n/2;f==="top"?h=a+e.height/2:f==="bottom"&&(h=a+n-e.height/2);var c=!e.isLineHolder&&kl(u);c&&this._renderBackground(u,i,s==="right"?o-e.width:s==="center"?o-e.width/2:o,h-e.height/2,e.width,e.height);var v=!!u.backgroundColor,d=e.textPadding;d&&(o=Kv(o,s,d),h-=e.height/2-d[0]-e.innerHeight/2);var p=this._getOrCreateChild(tf),g=p.createStyle();p.useStyle(g);var y=this._defaultStyle,m=!1,_=0,S=qv("fill"in u?u.fill:"fill"in i?i.fill:(m=!0,y.fill)),x=Xv("stroke"in u?u.stroke:"stroke"in i?i.stroke:!v&&!l&&(!y.autoStroke||m)?(_=Uv,y.stroke):null),w=u.textShadowBlur>0||i.textShadowBlur>0;g.text=e.text,g.x=o,g.y=h,w&&(g.shadowBlur=u.textShadowBlur||i.textShadowBlur||0,g.shadowColor=u.textShadowColor||i.textShadowColor||"transparent",g.shadowOffsetX=u.textShadowOffsetX||i.textShadowOffsetX||0,g.shadowOffsetY=u.textShadowOffsetY||i.textShadowOffsetY||0),g.textAlign=s,g.textBaseline="middle",g.font=e.font||si,g.opacity=Kn(u.opacity,i.opacity,1),$v(g,u),x&&(g.lineWidth=Kn(u.lineWidth,i.lineWidth,_),g.lineDash=j(u.lineDash,i.lineDash),g.lineDashOffset=i.lineDashOffset||0,g.stroke=x),S&&(g.fill=S);var b=e.contentWidth,T=e.contentHeight;p.setBoundingRect(new ut(Wn(g.x,b,g.textAlign),Gi(g.y,T,g.textBaseline),b,T))},t.prototype._renderBackground=function(e,i,n,a,o,s){var l=e.backgroundColor,u=e.borderWidth,f=e.borderColor,h=l&&l.image,c=l&&!h,v=e.borderRadius,d=this,p,g;if(c||e.lineHeight||u&&f){p=this._getOrCreateChild(_t),p.useStyle(p.createStyle()),p.style.fill=null;var y=p.shape;y.x=n,y.y=a,y.width=o,y.height=s,y.r=v,p.dirtyShape()}if(c){var m=p.style;m.fill=l||null,m.fillOpacity=j(e.fillOpacity,1)}else if(h){g=this._getOrCreateChild(nr),g.onload=function(){d.dirtyStyle()};var _=g.style;_.image=l.image,_.x=n,_.y=a,_.width=o,_.height=s}if(u&&f){var m=p.style;m.lineWidth=u,m.stroke=f,m.strokeOpacity=j(e.strokeOpacity,1),m.lineDash=e.borderDash,m.lineDashOffset=e.borderDashOffset||0,p.strokeContainThreshold=0,p.hasFill()&&p.hasStroke()&&(m.strokeFirst=!0,m.lineWidth*=2)}var S=(p||g).style;S.shadowBlur=e.shadowBlur||0,S.shadowColor=e.shadowColor||"transparent",S.shadowOffsetX=e.shadowOffsetX||0,S.shadowOffsetY=e.shadowOffsetY||0,S.opacity=Kn(e.opacity,i.opacity,1)},t.makeFont=function(e){var i="";return sx(e)&&(i=[e.fontStyle,e.fontWeight,ox(e.fontSize),e.fontFamily||"sans-serif"].join(" ")),i&&Fe(i)||e.textFont||e.font},t}(yi),nx={left:!0,right:1,center:1},ax={top:1,bottom:1,middle:1},Yv=["fontStyle","fontWeight","fontSize","fontFamily"];function ox(r){return typeof r=="string"&&(r.indexOf("px")!==-1||r.indexOf("rem")!==-1||r.indexOf("em")!==-1)?r:isNaN(+r)?Ff+"px":r+"px"}function $v(r,t){for(var e=0;e<Yv.length;e++){var i=Yv[e],n=t[i];n!=null&&(r[i]=n)}}function sx(r){return r.fontSize!=null||r.fontFamily||r.fontWeight}function lx(r){return Zv(r),A(r.rich,Zv),r}function Zv(r){if(r){r.font=ay.makeFont(r);var t=r.align;t==="middle"&&(t="center"),r.align=t==null||nx[t]?t:"left";var e=r.verticalAlign;e==="center"&&(e="middle"),r.verticalAlign=e==null||ax[e]?e:"top";var i=r.padding;i&&(r.padding=fg(r.padding))}}function Xv(r,t){return r==null||t<=0||r==="transparent"||r==="none"?null:r.image||r.colorStops?"#000":r}function qv(r){return r==null||r==="none"?null:r.image||r.colorStops?"#000":r}function Kv(r,t,e){return t==="right"?r-e[1]:t==="center"?r+e[3]/2-e[1]/2:r+e[3]}function Qv(r){var t=r.text;return t!=null&&(t+=""),t}function kl(r){return!!(r.backgroundColor||r.lineHeight||r.borderWidth&&r.borderColor)}const Dt=ay;var lt=gt(),ux=function(r,t,e,i){if(i){var n=lt(i);n.dataIndex=e,n.dataType=t,n.seriesIndex=r,n.ssrType="chart",i.type==="group"&&i.traverse(function(a){var o=lt(a);o.seriesIndex=r,o.dataIndex=e,o.dataType=t,o.ssrType="chart"})}},Jv=1,jv={},oy=gt(),ih=gt(),nh=0,Ds=1,Ls=2,ye=["emphasis","blur","select"],jo=["normal","emphasis","blur","select"],fx=10,hx=9,ii="highlight",Eo="downplay",ea="select",ko="unselect",ra="toggleSelect";function Ii(r){return r!=null&&r!=="none"}function Is(r,t,e){r.onHoverStateChange&&(r.hoverState||0)!==e&&r.onHoverStateChange(t),r.hoverState=e}function sy(r){Is(r,"emphasis",Ls)}function ly(r){r.hoverState===Ls&&Is(r,"normal",nh)}function ah(r){Is(r,"blur",Ds)}function uy(r){r.hoverState===Ds&&Is(r,"normal",nh)}function vx(r){r.selected=!0}function cx(r){r.selected=!1}function tc(r,t,e){t(r,e)}function ar(r,t,e){tc(r,t,e),r.isGroup&&r.traverse(function(i){tc(i,t,e)})}function ec(r,t){switch(t){case"emphasis":r.hoverState=Ls;break;case"normal":r.hoverState=nh;break;case"blur":r.hoverState=Ds;break;case"select":r.selected=!0}}function dx(r,t,e,i){for(var n=r.style,a={},o=0;o<t.length;o++){var s=t[o],l=n[s];a[s]=l==null?i&&i[s]:l}for(var o=0;o<r.animators.length;o++){var u=r.animators[o];u.__fromStateTransition&&u.__fromStateTransition.indexOf(e)<0&&u.targetName==="style"&&u.saveTo(a,t)}return a}function px(r,t,e,i){var n=e&&at(e,"select")>=0,a=!1;if(r instanceof ct){var o=oy(r),s=n&&o.selectFill||o.normalFill,l=n&&o.selectStroke||o.normalStroke;if(Ii(s)||Ii(l)){i=i||{};var u=i.style||{};u.fill==="inherit"?(a=!0,i=O({},i),u=O({},u),u.fill=s):!Ii(u.fill)&&Ii(s)?(a=!0,i=O({},i),u=O({},u),u.fill=Sv(s)):!Ii(u.stroke)&&Ii(l)&&(a||(i=O({},i),u=O({},u)),u.stroke=Sv(l)),i.style=u}}if(i&&i.z2==null){a||(i=O({},i));var f=r.z2EmphasisLift;i.z2=r.z2+(f!=null?f:fx)}return i}function gx(r,t,e){if(e&&e.z2==null){e=O({},e);var i=r.z2SelectLift;e.z2=r.z2+(i!=null?i:hx)}return e}function yx(r,t,e){var i=at(r.currentStates,t)>=0,n=r.style.opacity,a=i?null:dx(r,["opacity"],t,{opacity:1});e=e||{};var o=e.style||{};return o.opacity==null&&(e=O({},e),o=O({opacity:i?n:a.opacity*.1},o),e.style=o),e}function Ol(r,t){var e=this.states[r];if(this.style){if(r==="emphasis")return px(this,r,t,e);if(r==="blur")return yx(this,r,e);if(r==="select")return gx(this,r,e)}return e}function mx(r){r.stateProxy=Ol;var t=r.getTextContent(),e=r.getTextGuideLine();t&&(t.stateProxy=Ol),e&&(e.stateProxy=Ol)}function rc(r,t){!cy(r,t)&&!r.__highByOuter&&ar(r,sy)}function ic(r,t){!cy(r,t)&&!r.__highByOuter&&ar(r,ly)}function ts(r,t){r.__highByOuter|=1<<(t||0),ar(r,sy)}function es(r,t){!(r.__highByOuter&=~(1<<(t||0)))&&ar(r,ly)}function _x(r){ar(r,ah)}function fy(r){ar(r,uy)}function hy(r){ar(r,vx)}function vy(r){ar(r,cx)}function cy(r,t){return r.__highDownSilentOnTouch&&t.zrByTouch}function dy(r){var t=r.getModel(),e=[],i=[];t.eachComponent(function(n,a){var o=ih(a),s=n==="series",l=s?r.getViewOfSeriesModel(a):r.getViewOfComponentModel(a);!s&&i.push(l),o.isBlured&&(l.group.traverse(function(u){uy(u)}),s&&e.push(a)),o.isBlured=!1}),A(i,function(n){n&&n.toggleBlurSeries&&n.toggleBlurSeries(e,!1,t)})}function ef(r,t,e,i){var n=i.getModel();e=e||"coordinateSystem";function a(u,f){for(var h=0;h<f.length;h++){var c=u.getItemGraphicEl(f[h]);c&&fy(c)}}if(r!=null&&!(!t||t==="none")){var o=n.getSeriesByIndex(r),s=o.coordinateSystem;s&&s.master&&(s=s.master);var l=[];n.eachSeries(function(u){var f=o===u,h=u.coordinateSystem;h&&h.master&&(h=h.master);var c=h&&s?h===s:f;if(!(e==="series"&&!f||e==="coordinateSystem"&&!c||t==="series"&&f)){var v=i.getViewOfSeriesModel(u);if(v.group.traverse(function(g){g.__highByOuter&&f&&t==="self"||ah(g)}),Wt(t))a(u.getData(),t);else if(Y(t))for(var d=vt(t),p=0;p<d.length;p++)a(u.getData(d[p]),t[d[p]]);l.push(u),ih(u).isBlured=!0}}),n.eachComponent(function(u,f){if(u!=="series"){var h=i.getViewOfComponentModel(f);h&&h.toggleBlurSeries&&h.toggleBlurSeries(l,!0,n)}})}}function rf(r,t,e){if(!(r==null||t==null)){var i=e.getModel().getComponent(r,t);if(!!i){ih(i).isBlured=!0;var n=e.getViewOfComponentModel(i);!n||!n.focusBlurEnabled||n.group.traverse(function(a){ah(a)})}}}function Sx(r,t,e){var i=r.seriesIndex,n=r.getData(t.dataType);if(!!n){var a=li(n,t);a=(V(a)?a[0]:a)||0;var o=n.getItemGraphicEl(a);if(!o)for(var s=n.count(),l=0;!o&&l<s;)o=n.getItemGraphicEl(l++);if(o){var u=lt(o);ef(i,u.focus,u.blurScope,e)}else{var f=r.get(["emphasis","focus"]),h=r.get(["emphasis","blurScope"]);f!=null&&ef(i,f,h,e)}}}function oh(r,t,e,i){var n={focusSelf:!1,dispatchers:null};if(r==null||r==="series"||t==null||e==null)return n;var a=i.getModel().getComponent(r,t);if(!a)return n;var o=i.getViewOfComponentModel(a);if(!o||!o.findHighDownDispatchers)return n;for(var s=o.findHighDownDispatchers(e),l,u=0;u<s.length;u++)if(lt(s[u]).focus==="self"){l=!0;break}return{focusSelf:l,dispatchers:s}}function xx(r,t,e){var i=lt(r),n=oh(i.componentMainType,i.componentIndex,i.componentHighDownName,e),a=n.dispatchers,o=n.focusSelf;a?(o&&rf(i.componentMainType,i.componentIndex,e),A(a,function(s){return rc(s,t)})):(ef(i.seriesIndex,i.focus,i.blurScope,e),i.focus==="self"&&rf(i.componentMainType,i.componentIndex,e),rc(r,t))}function bx(r,t,e){dy(e);var i=lt(r),n=oh(i.componentMainType,i.componentIndex,i.componentHighDownName,e).dispatchers;n?A(n,function(a){return ic(a,t)}):ic(r,t)}function Tx(r,t,e){if(!!af(t)){var i=t.dataType,n=r.getData(i),a=li(n,t);V(a)||(a=[a]),r[t.type===ra?"toggleSelect":t.type===ea?"select":"unselect"](a,i)}}function nc(r){var t=r.getAllData();A(t,function(e){var i=e.data,n=e.type;i.eachItemGraphicEl(function(a,o){r.isSelected(o,n)?hy(a):vy(a)})})}function Cx(r){var t=[];return r.eachSeries(function(e){var i=e.getAllData();A(i,function(n){n.data;var a=n.type,o=e.getSelectedDataIndices();if(o.length>0){var s={dataIndex:o,seriesIndex:e.seriesIndex};a!=null&&(s.dataType=a),t.push(s)}})}),t}function rs(r,t,e){py(r,!0),ar(r,mx),Ax(r,t,e)}function Mx(r){py(r,!1)}function rn(r,t,e,i){i?Mx(r):rs(r,t,e)}function Ax(r,t,e){var i=lt(r);t!=null?(i.focus=t,i.blurScope=e):i.focus&&(i.focus=null)}var ac=["emphasis","blur","select"],Dx={itemStyle:"getItemStyle",lineStyle:"getLineStyle",areaStyle:"getAreaStyle"};function nn(r,t,e,i){e=e||"itemStyle";for(var n=0;n<ac.length;n++){var a=ac[n],o=t.getModel([a,e]),s=r.ensureState(a);s.style=i?i(o):o[Dx[e]]()}}function py(r,t){var e=t===!1,i=r;r.highDownSilentOnTouch&&(i.__highDownSilentOnTouch=r.highDownSilentOnTouch),(!e||i.__highDownDispatcher)&&(i.__highByOuter=i.__highByOuter||0,i.__highDownDispatcher=!e)}function nf(r){return!!(r&&r.__highDownDispatcher)}function Lx(r){var t=jv[r];return t==null&&Jv<=32&&(t=jv[r]=Jv++),t}function af(r){var t=r.type;return t===ea||t===ko||t===ra}function oc(r){var t=r.type;return t===ii||t===Eo}function Ix(r){var t=oy(r);t.normalFill=r.style.fill,t.normalStroke=r.style.stroke;var e=r.states.select||{};t.selectFill=e.style&&e.style.fill||null,t.selectStroke=e.style&&e.style.stroke||null}var Pi=Lr.CMD,Px=[[],[],[]],sc=Math.sqrt,Rx=Math.atan2;function Ex(r,t){if(!!t){var e=r.data,i=r.len(),n,a,o,s,l,u,f=Pi.M,h=Pi.C,c=Pi.L,v=Pi.R,d=Pi.A,p=Pi.Q;for(o=0,s=0;o<i;){switch(n=e[o++],s=o,a=0,n){case f:a=1;break;case c:a=1;break;case h:a=3;break;case p:a=2;break;case d:var g=t[4],y=t[5],m=sc(t[0]*t[0]+t[1]*t[1]),_=sc(t[2]*t[2]+t[3]*t[3]),S=Rx(-t[1]/_,t[0]/m);e[o]*=m,e[o++]+=g,e[o]*=_,e[o++]+=y,e[o++]*=m,e[o++]*=_,e[o++]+=S,e[o++]+=S,o+=2,s=o;break;case v:u[0]=e[o++],u[1]=e[o++],ge(u,u,t),e[s++]=u[0],e[s++]=u[1],u[0]+=e[o++],u[1]+=e[o++],ge(u,u,t),e[s++]=u[0],e[s++]=u[1]}for(l=0;l<a;l++){var x=Px[l];x[0]=e[o++],x[1]=e[o++],ge(x,x,t),e[s++]=x[0],e[s++]=x[1]}}r.increaseVersion()}}var Bl=Math.sqrt,qa=Math.sin,Ka=Math.cos,bn=Math.PI;function lc(r){return Math.sqrt(r[0]*r[0]+r[1]*r[1])}function of(r,t){return(r[0]*t[0]+r[1]*t[1])/(lc(r)*lc(t))}function uc(r,t){return(r[0]*t[1]<r[1]*t[0]?-1:1)*Math.acos(of(r,t))}function fc(r,t,e,i,n,a,o,s,l,u,f){var h=l*(bn/180),c=Ka(h)*(r-e)/2+qa(h)*(t-i)/2,v=-1*qa(h)*(r-e)/2+Ka(h)*(t-i)/2,d=c*c/(o*o)+v*v/(s*s);d>1&&(o*=Bl(d),s*=Bl(d));var p=(n===a?-1:1)*Bl((o*o*(s*s)-o*o*(v*v)-s*s*(c*c))/(o*o*(v*v)+s*s*(c*c)))||0,g=p*o*v/s,y=p*-s*c/o,m=(r+e)/2+Ka(h)*g-qa(h)*y,_=(t+i)/2+qa(h)*g+Ka(h)*y,S=uc([1,0],[(c-g)/o,(v-y)/s]),x=[(c-g)/o,(v-y)/s],w=[(-1*c-g)/o,(-1*v-y)/s],b=uc(x,w);if(of(x,w)<=-1&&(b=bn),of(x,w)>=1&&(b=0),b<0){var T=Math.round(b/bn*1e6)/1e6;b=bn*2+T%2*bn}f.addData(u,m,_,o,s,S,b,h,a)}var kx=/([mlvhzcqtsa])([^mlvhzcqtsa]*)/ig,Ox=/-?([0-9]*\.)?[0-9]+([eE]-?[0-9]+)?/g;function Bx(r){var t=new Lr;if(!r)return t;var e=0,i=0,n=e,a=i,o,s=Lr.CMD,l=r.match(kx);if(!l)return t;for(var u=0;u<l.length;u++){for(var f=l[u],h=f.charAt(0),c=void 0,v=f.match(Ox)||[],d=v.length,p=0;p<d;p++)v[p]=parseFloat(v[p]);for(var g=0;g<d;){var y=void 0,m=void 0,_=void 0,S=void 0,x=void 0,w=void 0,b=void 0,T=e,M=i,D=void 0,C=void 0;switch(h){case"l":e+=v[g++],i+=v[g++],c=s.L,t.addData(c,e,i);break;case"L":e=v[g++],i=v[g++],c=s.L,t.addData(c,e,i);break;case"m":e+=v[g++],i+=v[g++],c=s.M,t.addData(c,e,i),n=e,a=i,h="l";break;case"M":e=v[g++],i=v[g++],c=s.M,t.addData(c,e,i),n=e,a=i,h="L";break;case"h":e+=v[g++],c=s.L,t.addData(c,e,i);break;case"H":e=v[g++],c=s.L,t.addData(c,e,i);break;case"v":i+=v[g++],c=s.L,t.addData(c,e,i);break;case"V":i=v[g++],c=s.L,t.addData(c,e,i);break;case"C":c=s.C,t.addData(c,v[g++],v[g++],v[g++],v[g++],v[g++],v[g++]),e=v[g-2],i=v[g-1];break;case"c":c=s.C,t.addData(c,v[g++]+e,v[g++]+i,v[g++]+e,v[g++]+i,v[g++]+e,v[g++]+i),e+=v[g-2],i+=v[g-1];break;case"S":y=e,m=i,D=t.len(),C=t.data,o===s.C&&(y+=e-C[D-4],m+=i-C[D-3]),c=s.C,T=v[g++],M=v[g++],e=v[g++],i=v[g++],t.addData(c,y,m,T,M,e,i);break;case"s":y=e,m=i,D=t.len(),C=t.data,o===s.C&&(y+=e-C[D-4],m+=i-C[D-3]),c=s.C,T=e+v[g++],M=i+v[g++],e+=v[g++],i+=v[g++],t.addData(c,y,m,T,M,e,i);break;case"Q":T=v[g++],M=v[g++],e=v[g++],i=v[g++],c=s.Q,t.addData(c,T,M,e,i);break;case"q":T=v[g++]+e,M=v[g++]+i,e+=v[g++],i+=v[g++],c=s.Q,t.addData(c,T,M,e,i);break;case"T":y=e,m=i,D=t.len(),C=t.data,o===s.Q&&(y+=e-C[D-4],m+=i-C[D-3]),e=v[g++],i=v[g++],c=s.Q,t.addData(c,y,m,e,i);break;case"t":y=e,m=i,D=t.len(),C=t.data,o===s.Q&&(y+=e-C[D-4],m+=i-C[D-3]),e+=v[g++],i+=v[g++],c=s.Q,t.addData(c,y,m,e,i);break;case"A":_=v[g++],S=v[g++],x=v[g++],w=v[g++],b=v[g++],T=e,M=i,e=v[g++],i=v[g++],c=s.A,fc(T,M,e,i,w,b,_,S,x,c,t);break;case"a":_=v[g++],S=v[g++],x=v[g++],w=v[g++],b=v[g++],T=e,M=i,e+=v[g++],i+=v[g++],c=s.A,fc(T,M,e,i,w,b,_,S,x,c,t);break}}(h==="z"||h==="Z")&&(c=s.Z,t.addData(c),e=n,i=a),o=c}return t.toStatic(),t}var gy=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.applyTransform=function(e){},t}(ct);function yy(r){return r.setData!=null}function my(r,t){var e=Bx(r),i=O({},t);return i.buildPath=function(n){if(yy(n)){n.setData(e.data);var a=n.getContext();a&&n.rebuildPath(a,1)}else{var a=n;e.rebuildPath(a,1)}},i.applyTransform=function(n){Ex(e,n),this.dirtyShape()},i}function Nx(r,t){return new gy(my(r,t))}function zx(r,t){var e=my(r,t),i=function(n){N(a,n);function a(o){var s=n.call(this,o)||this;return s.applyTransform=e.applyTransform,s.buildPath=e.buildPath,s}return a}(gy);return i}function Fx(r,t){for(var e=[],i=r.length,n=0;n<i;n++){var a=r[n];e.push(a.getUpdatedPathProxy(!0))}var o=new ct(t);return o.createPathProxy(),o.buildPath=function(s){if(yy(s)){s.appendPath(e);var l=s.getContext();l&&s.rebuildPath(l,1)}},o}var Vx=function(){function r(){this.cx=0,this.cy=0,this.r=0}return r}(),_y=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new Vx},t.prototype.buildPath=function(e,i){e.moveTo(i.cx+i.r,i.cy),e.arc(i.cx,i.cy,i.r,0,Math.PI*2)},t}(ct);_y.prototype.type="circle";const Ps=_y;var Hx=function(){function r(){this.cx=0,this.cy=0,this.rx=0,this.ry=0}return r}(),Sy=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new Hx},t.prototype.buildPath=function(e,i){var n=.5522848,a=i.cx,o=i.cy,s=i.rx,l=i.ry,u=s*n,f=l*n;e.moveTo(a-s,o),e.bezierCurveTo(a-s,o-f,a-u,o-l,a,o-l),e.bezierCurveTo(a+u,o-l,a+s,o-f,a+s,o),e.bezierCurveTo(a+s,o+f,a+u,o+l,a,o+l),e.bezierCurveTo(a-u,o+l,a-s,o+f,a-s,o),e.closePath()},t}(ct);Sy.prototype.type="ellipse";const wy=Sy;var xy=Math.PI,Nl=xy*2,Ur=Math.sin,Ri=Math.cos,Gx=Math.acos,Ot=Math.atan2,hc=Math.abs,ia=Math.sqrt,Yn=Math.max,ke=Math.min,we=1e-4;function Wx(r,t,e,i,n,a,o,s){var l=e-r,u=i-t,f=o-n,h=s-a,c=h*l-f*u;if(!(c*c<we))return c=(f*(t-a)-h*(r-n))/c,[r+c*l,t+c*u]}function Qa(r,t,e,i,n,a,o){var s=r-e,l=t-i,u=(o?a:-a)/ia(s*s+l*l),f=u*l,h=-u*s,c=r+f,v=t+h,d=e+f,p=i+h,g=(c+d)/2,y=(v+p)/2,m=d-c,_=p-v,S=m*m+_*_,x=n-a,w=c*p-d*v,b=(_<0?-1:1)*ia(Yn(0,x*x*S-w*w)),T=(w*_-m*b)/S,M=(-w*m-_*b)/S,D=(w*_+m*b)/S,C=(-w*m+_*b)/S,L=T-g,I=M-y,P=D-g,R=C-y;return L*L+I*I>P*P+R*R&&(T=D,M=C),{cx:T,cy:M,x0:-f,y0:-h,x1:T*(n/x-1),y1:M*(n/x-1)}}function Ux(r){var t;if(V(r)){var e=r.length;if(!e)return r;e===1?t=[r[0],r[0],0,0]:e===2?t=[r[0],r[0],r[1],r[1]]:e===3?t=r.concat(r[2]):t=r}else t=[r,r,r,r];return t}function Yx(r,t){var e,i=Yn(t.r,0),n=Yn(t.r0||0,0),a=i>0,o=n>0;if(!(!a&&!o)){if(a||(i=n,n=0),n>i){var s=i;i=n,n=s}var l=t.startAngle,u=t.endAngle;if(!(isNaN(l)||isNaN(u))){var f=t.cx,h=t.cy,c=!!t.clockwise,v=hc(u-l),d=v>Nl&&v%Nl;if(d>we&&(v=d),!(i>we))r.moveTo(f,h);else if(v>Nl-we)r.moveTo(f+i*Ri(l),h+i*Ur(l)),r.arc(f,h,i,l,u,!c),n>we&&(r.moveTo(f+n*Ri(u),h+n*Ur(u)),r.arc(f,h,n,u,l,c));else{var p=void 0,g=void 0,y=void 0,m=void 0,_=void 0,S=void 0,x=void 0,w=void 0,b=void 0,T=void 0,M=void 0,D=void 0,C=void 0,L=void 0,I=void 0,P=void 0,R=i*Ri(l),E=i*Ur(l),z=n*Ri(u),k=n*Ur(u),B=v>we;if(B){var F=t.cornerRadius;F&&(e=Ux(F),p=e[0],g=e[1],y=e[2],m=e[3]);var H=hc(i-n)/2;if(_=ke(H,y),S=ke(H,m),x=ke(H,p),w=ke(H,g),M=b=Yn(_,S),D=T=Yn(x,w),(b>we||T>we)&&(C=i*Ri(u),L=i*Ur(u),I=n*Ri(l),P=n*Ur(l),v<xy)){var U=Wx(R,E,I,P,C,L,z,k);if(U){var J=R-U[0],ot=E-U[1],ft=C-U[0],Ut=L-U[1],ne=1/Ur(Gx((J*ft+ot*Ut)/(ia(J*J+ot*ot)*ia(ft*ft+Ut*Ut)))/2),ee=ia(U[0]*U[0]+U[1]*U[1]);M=ke(b,(i-ee)/(ne+1)),D=ke(T,(n-ee)/(ne-1))}}}if(!B)r.moveTo(f+R,h+E);else if(M>we){var It=ke(y,M),St=ke(m,M),X=Qa(I,P,R,E,i,It,c),it=Qa(C,L,z,k,i,St,c);r.moveTo(f+X.cx+X.x0,h+X.cy+X.y0),M<b&&It===St?r.arc(f+X.cx,h+X.cy,M,Ot(X.y0,X.x0),Ot(it.y0,it.x0),!c):(It>0&&r.arc(f+X.cx,h+X.cy,It,Ot(X.y0,X.x0),Ot(X.y1,X.x1),!c),r.arc(f,h,i,Ot(X.cy+X.y1,X.cx+X.x1),Ot(it.cy+it.y1,it.cx+it.x1),!c),St>0&&r.arc(f+it.cx,h+it.cy,St,Ot(it.y1,it.x1),Ot(it.y0,it.x0),!c))}else r.moveTo(f+R,h+E),r.arc(f,h,i,l,u,!c);if(!(n>we)||!B)r.lineTo(f+z,h+k);else if(D>we){var It=ke(p,D),St=ke(g,D),X=Qa(z,k,C,L,n,-St,c),it=Qa(R,E,I,P,n,-It,c);r.lineTo(f+X.cx+X.x0,h+X.cy+X.y0),D<T&&It===St?r.arc(f+X.cx,h+X.cy,D,Ot(X.y0,X.x0),Ot(it.y0,it.x0),!c):(St>0&&r.arc(f+X.cx,h+X.cy,St,Ot(X.y0,X.x0),Ot(X.y1,X.x1),!c),r.arc(f,h,n,Ot(X.cy+X.y1,X.cx+X.x1),Ot(it.cy+it.y1,it.cx+it.x1),c),It>0&&r.arc(f+it.cx,h+it.cy,It,Ot(it.y1,it.x1),Ot(it.y0,it.x0),!c))}else r.lineTo(f+z,h+k),r.arc(f,h,n,u,l,c)}r.closePath()}}}var $x=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0,this.cornerRadius=0}return r}(),by=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new $x},t.prototype.buildPath=function(e,i){Yx(e,i)},t.prototype.isZeroArea=function(){return this.shape.startAngle===this.shape.endAngle||this.shape.r===this.shape.r0},t}(ct);by.prototype.type="sector";const mi=by;var Zx=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.r0=0}return r}(),Ty=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new Zx},t.prototype.buildPath=function(e,i){var n=i.cx,a=i.cy,o=Math.PI*2;e.moveTo(n+i.r,a),e.arc(n,a,i.r,0,o,!1),e.moveTo(n+i.r0,a),e.arc(n,a,i.r0,0,o,!0)},t}(ct);Ty.prototype.type="ring";const sh=Ty;function Xx(r,t,e,i){var n=[],a=[],o=[],s=[],l,u,f,h;if(i){f=[1/0,1/0],h=[-1/0,-1/0];for(var c=0,v=r.length;c<v;c++)Ui(f,f,r[c]),Yi(h,h,r[c]);Ui(f,f,i[0]),Yi(h,h,i[1])}for(var c=0,v=r.length;c<v;c++){var d=r[c];if(e)l=r[c?c-1:v-1],u=r[(c+1)%v];else if(c===0||c===v-1){n.push(m1(r[c]));continue}else l=r[c-1],u=r[c+1];_1(a,u,l),tl(a,a,t);var p=Eu(d,l),g=Eu(d,u),y=p+g;y!==0&&(p/=y,g/=y),tl(o,a,-p),tl(s,a,g);var m=rv([],d,o),_=rv([],d,s);i&&(Yi(m,m,f),Ui(m,m,h),Yi(_,_,f),Ui(_,_,h)),n.push(m),n.push(_)}return e&&n.push(n.shift()),n}function Cy(r,t,e){var i=t.smooth,n=t.points;if(n&&n.length>=2){if(i){var a=Xx(n,i,e,t.smoothConstraint);r.moveTo(n[0][0],n[0][1]);for(var o=n.length,s=0;s<(e?o:o-1);s++){var l=a[s*2],u=a[s*2+1],f=n[(s+1)%o];r.bezierCurveTo(l[0],l[1],u[0],u[1],f[0],f[1])}}else{r.moveTo(n[0][0],n[0][1]);for(var s=1,h=n.length;s<h;s++)r.lineTo(n[s][0],n[s][1])}e&&r.closePath()}}var qx=function(){function r(){this.points=null,this.smooth=0,this.smoothConstraint=null}return r}(),My=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultShape=function(){return new qx},t.prototype.buildPath=function(e,i){Cy(e,i,!0)},t}(ct);My.prototype.type="polygon";const La=My;var Kx=function(){function r(){this.points=null,this.percent=1,this.smooth=0,this.smoothConstraint=null}return r}(),Ay=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Kx},t.prototype.buildPath=function(e,i){Cy(e,i,!1)},t}(ct);Ay.prototype.type="polyline";const _i=Ay;var Qx={},Jx=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.percent=1}return r}(),Dy=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new Jx},t.prototype.buildPath=function(e,i){var n,a,o,s;if(this.subPixelOptimize){var l=ry(Qx,i,this.style);n=l.x1,a=l.y1,o=l.x2,s=l.y2}else n=i.x1,a=i.y1,o=i.x2,s=i.y2;var u=i.percent;u!==0&&(e.moveTo(n,a),u<1&&(o=n*(1-u)+o*u,s=a*(1-u)+s*u),e.lineTo(o,s))},t.prototype.pointAt=function(e){var i=this.shape;return[i.x1*(1-e)+i.x2*e,i.y1*(1-e)+i.y2*e]},t}(ct);Dy.prototype.type="line";const ui=Dy;var Yt=[],jx=function(){function r(){this.x1=0,this.y1=0,this.x2=0,this.y2=0,this.cpx1=0,this.cpy1=0,this.percent=1}return r}();function vc(r,t,e){var i=r.cpx2,n=r.cpy2;return i!=null||n!=null?[(e?dv:Tt)(r.x1,r.cpx1,r.cpx2,r.x2,t),(e?dv:Tt)(r.y1,r.cpy1,r.cpy2,r.y2,t)]:[(e?pv:zt)(r.x1,r.cpx1,r.x2,t),(e?pv:zt)(r.y1,r.cpy1,r.y2,t)]}var Ly=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new jx},t.prototype.buildPath=function(e,i){var n=i.x1,a=i.y1,o=i.x2,s=i.y2,l=i.cpx1,u=i.cpy1,f=i.cpx2,h=i.cpy2,c=i.percent;c!==0&&(e.moveTo(n,a),f==null||h==null?(c<1&&(Zo(n,l,o,c,Yt),l=Yt[1],o=Yt[2],Zo(a,u,s,c,Yt),u=Yt[1],s=Yt[2]),e.quadraticCurveTo(l,u,o,s)):(c<1&&($o(n,l,f,o,c,Yt),l=Yt[1],f=Yt[2],o=Yt[3],$o(a,u,h,s,c,Yt),u=Yt[1],h=Yt[2],s=Yt[3]),e.bezierCurveTo(l,u,f,h,o,s)))},t.prototype.pointAt=function(e){return vc(this.shape,e,!1)},t.prototype.tangentAt=function(e){var i=vc(this.shape,e,!0);return x1(i,i)},t}(ct);Ly.prototype.type="bezier-curve";const Iy=Ly;var tb=function(){function r(){this.cx=0,this.cy=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),Py=function(r){N(t,r);function t(e){return r.call(this,e)||this}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new tb},t.prototype.buildPath=function(e,i){var n=i.cx,a=i.cy,o=Math.max(i.r,0),s=i.startAngle,l=i.endAngle,u=i.clockwise,f=Math.cos(s),h=Math.sin(s);e.moveTo(f*o+n,h*o+a),e.arc(n,a,o,s,l,!u)},t}(ct);Py.prototype.type="arc";const lh=Py;var eb=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="compound",e}return t.prototype._updatePathDirty=function(){for(var e=this.shape.paths,i=this.shapeChanged(),n=0;n<e.length;n++)i=i||e[n].shapeChanged();i&&this.dirtyShape()},t.prototype.beforeBrush=function(){this._updatePathDirty();for(var e=this.shape.paths||[],i=this.getGlobalScale(),n=0;n<e.length;n++)e[n].path||e[n].createPathProxy(),e[n].path.setScale(i[0],i[1],e[n].segmentIgnoreThreshold)},t.prototype.buildPath=function(e,i){for(var n=i.paths||[],a=0;a<n.length;a++)n[a].buildPath(e,n[a].shape,!0)},t.prototype.afterBrush=function(){for(var e=this.shape.paths||[],i=0;i<e.length;i++)e[i].pathUpdated()},t.prototype.getBoundingRect=function(){return this._updatePathDirty.call(this),ct.prototype.getBoundingRect.call(this)},t}(ct);const rb=eb;var ib=function(){function r(t){this.colorStops=t||[]}return r.prototype.addColorStop=function(t,e){this.colorStops.push({offset:t,color:e})},r}();const Ry=ib;var nb=function(r){N(t,r);function t(e,i,n,a,o,s){var l=r.call(this,o)||this;return l.x=e==null?0:e,l.y=i==null?0:i,l.x2=n==null?1:n,l.y2=a==null?0:a,l.type="linear",l.global=s||!1,l}return t}(Ry);const Ey=nb;var ab=function(r){N(t,r);function t(e,i,n,a,o){var s=r.call(this,a)||this;return s.x=e==null?.5:e,s.y=i==null?.5:i,s.r=n==null?.5:n,s.type="radial",s.global=o||!1,s}return t}(Ry);const ob=ab;var Yr=[0,0],$r=[0,0],Ja=new q,ja=new q,sb=function(){function r(t,e){this._corners=[],this._axes=[],this._origin=[0,0];for(var i=0;i<4;i++)this._corners[i]=new q;for(var i=0;i<2;i++)this._axes[i]=new q;t&&this.fromBoundingRect(t,e)}return r.prototype.fromBoundingRect=function(t,e){var i=this._corners,n=this._axes,a=t.x,o=t.y,s=a+t.width,l=o+t.height;if(i[0].set(a,o),i[1].set(s,o),i[2].set(s,l),i[3].set(a,l),e)for(var u=0;u<4;u++)i[u].transform(e);q.sub(n[0],i[1],i[0]),q.sub(n[1],i[3],i[0]),n[0].normalize(),n[1].normalize();for(var u=0;u<2;u++)this._origin[u]=n[u].dot(i[0])},r.prototype.intersect=function(t,e){var i=!0,n=!e;return Ja.set(1/0,1/0),ja.set(0,0),!this._intersectCheckOneSide(this,t,Ja,ja,n,1)&&(i=!1,n)||!this._intersectCheckOneSide(t,this,Ja,ja,n,-1)&&(i=!1,n)||n||q.copy(e,i?Ja:ja),i},r.prototype._intersectCheckOneSide=function(t,e,i,n,a,o){for(var s=!0,l=0;l<2;l++){var u=this._axes[l];if(this._getProjMinMaxOnAxis(l,t._corners,Yr),this._getProjMinMaxOnAxis(l,e._corners,$r),Yr[1]<$r[0]||Yr[0]>$r[1]){if(s=!1,a)return s;var f=Math.abs($r[0]-Yr[1]),h=Math.abs(Yr[0]-$r[1]);Math.min(f,h)>n.len()&&(f<h?q.scale(n,u,-f*o):q.scale(n,u,h*o))}else if(i){var f=Math.abs($r[0]-Yr[1]),h=Math.abs(Yr[0]-$r[1]);Math.min(f,h)<i.len()&&(f<h?q.scale(i,u,f*o):q.scale(i,u,-h*o))}}return s},r.prototype._getProjMinMaxOnAxis=function(t,e,i){for(var n=this._axes[t],a=this._origin,o=e[0].dot(n)+a[t],s=o,l=o,u=1;u<e.length;u++){var f=e[u].dot(n)+a[t];s=Math.min(f,s),l=Math.max(f,l)}i[0]=s,i[1]=l},r}();const is=sb;var lb=[],ub=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.notClear=!0,e.incremental=!0,e._displayables=[],e._temporaryDisplayables=[],e._cursor=0,e}return t.prototype.traverse=function(e,i){e.call(i,this)},t.prototype.useStyle=function(){this.style={}},t.prototype.getCursor=function(){return this._cursor},t.prototype.innerAfterBrush=function(){this._cursor=this._displayables.length},t.prototype.clearDisplaybles=function(){this._displayables=[],this._temporaryDisplayables=[],this._cursor=0,this.markRedraw(),this.notClear=!1},t.prototype.clearTemporalDisplayables=function(){this._temporaryDisplayables=[]},t.prototype.addDisplayable=function(e,i){i?this._temporaryDisplayables.push(e):this._displayables.push(e),this.markRedraw()},t.prototype.addDisplayables=function(e,i){i=i||!1;for(var n=0;n<e.length;n++)this.addDisplayable(e[n],i)},t.prototype.getDisplayables=function(){return this._displayables},t.prototype.getTemporalDisplayables=function(){return this._temporaryDisplayables},t.prototype.eachPendingDisplayable=function(e){for(var i=this._cursor;i<this._displayables.length;i++)e&&e(this._displayables[i]);for(var i=0;i<this._temporaryDisplayables.length;i++)e&&e(this._temporaryDisplayables[i])},t.prototype.update=function(){this.updateTransform();for(var e=this._cursor;e<this._displayables.length;e++){var i=this._displayables[e];i.parent=this,i.update(),i.parent=null}for(var e=0;e<this._temporaryDisplayables.length;e++){var i=this._temporaryDisplayables[e];i.parent=this,i.update(),i.parent=null}},t.prototype.getBoundingRect=function(){if(!this._rect){for(var e=new ut(1/0,1/0,-1/0,-1/0),i=0;i<this._displayables.length;i++){var n=this._displayables[i],a=n.getBoundingRect().clone();n.needLocalTransform()&&a.applyTransform(n.getLocalTransform(lb)),e.union(a)}this._rect=e}return this._rect},t.prototype.contain=function(e,i){var n=this.transformCoordToLocal(e,i),a=this.getBoundingRect();if(a.contain(n[0],n[1]))for(var o=0;o<this._displayables.length;o++){var s=this._displayables[o];if(s.contain(e,i))return!0}return!1},t}(yi);const fb=ub;var hb=gt();function uh(r,t,e,i,n){var a;if(t&&t.ecModel){var o=t.ecModel.getUpdatePayload();a=o&&o.animation}var s=t&&t.isAnimationEnabled(),l=r==="update";if(s){var u=void 0,f=void 0,h=void 0;i?(u=j(i.duration,200),f=j(i.easing,"cubicOut"),h=0):(u=t.getShallow(l?"animationDurationUpdate":"animationDuration"),f=t.getShallow(l?"animationEasingUpdate":"animationEasing"),h=t.getShallow(l?"animationDelayUpdate":"animationDelay")),a&&(a.duration!=null&&(u=a.duration),a.easing!=null&&(f=a.easing),a.delay!=null&&(h=a.delay)),K(h)&&(h=h(e,n)),K(u)&&(u=u(e));var c={duration:u||0,delay:h,easing:f};return c}else return null}function fh(r,t,e,i,n,a,o){var s=!1,l;K(n)?(o=a,a=n,n=null):Y(n)&&(a=n.cb,o=n.during,s=n.isFrom,l=n.removeOpt,n=n.dataIndex);var u=r==="leave";u||t.stopAnimation("leave");var f=uh(r,i,n,u?l||{}:null,i&&i.getAnimationDelayParams?i.getAnimationDelayParams(t,n):null);if(f&&f.duration>0){var h=f.duration,c=f.delay,v=f.easing,d={duration:h,delay:c||0,easing:v,done:a,force:!!a||!!o,setToFinal:!u,scope:r,during:o};s?t.animateFrom(e,d):t.animateTo(e,d)}else t.stopAnimation(),!s&&t.attr(e),o&&o(1),a&&a()}function Lt(r,t,e,i,n,a){fh("update",r,t,e,i,n,a)}function Jt(r,t,e,i,n,a){fh("enter",r,t,e,i,n,a)}function na(r){if(!r.__zr)return!0;for(var t=0;t<r.animators.length;t++){var e=r.animators[t];if(e.scope==="leave")return!0}return!1}function ns(r,t,e,i,n,a){na(r)||fh("leave",r,t,e,i,n,a)}function cc(r,t,e,i){r.removeTextContent(),r.removeTextGuideLine(),ns(r,{style:{opacity:0}},t,e,i)}function as(r,t,e){function i(){r.parent&&r.parent.remove(r)}r.isGroup?r.traverse(function(n){n.isGroup||cc(n,t,e,i)}):cc(r,t,e,i)}function pa(r){hb(r).oldStyle=r.style}var os=Math.max,ss=Math.min,sf={};function vb(r){return ct.extend(r)}var cb=zx;function db(r,t){return cb(r,t)}function De(r,t){sf[r]=t}function ky(r){if(sf.hasOwnProperty(r))return sf[r]}function hh(r,t,e,i){var n=Nx(r,t);return e&&(i==="center"&&(e=By(e,n.getBoundingRect())),Ny(n,e)),n}function Oy(r,t,e){var i=new nr({style:{image:r,x:t.x,y:t.y,width:t.width,height:t.height},onload:function(n){if(e==="center"){var a={width:n.width,height:n.height};i.setStyle(By(t,a))}}});return i}function By(r,t){var e=t.width/t.height,i=r.height*e,n;i<=r.width?n=r.height:(i=r.width,n=i/e);var a=r.x+r.width/2,o=r.y+r.height/2;return{x:a-i/2,y:o-n/2,width:i,height:n}}var lf=Fx;function Ny(r,t){if(!!r.applyTransform){var e=r.getBoundingRect(),i=e.calculateTransform(t);r.applyTransform(i)}}function ga(r,t){return ry(r,r,{lineWidth:t}),r}function pb(r){return iy(r.shape,r.shape,r.style),r}var gb=jr;function zy(r,t){for(var e=Yf([]);r&&r!==t;)Ki(e,r.getLocalTransform(),e),r=r.parent;return e}function ya(r,t,e){return t&&!Wt(t)&&(t=qf.getLocalTransform(t)),e&&(t=Zf([],t)),ge([],r,t)}function Fy(r,t,e){var i=t[4]===0||t[5]===0||t[0]===0?1:Math.abs(2*t[4]/t[0]),n=t[4]===0||t[5]===0||t[2]===0?1:Math.abs(2*t[4]/t[2]),a=[r==="left"?-i:r==="right"?i:0,r==="top"?-n:r==="bottom"?n:0];return a=ya(a,t,e),Math.abs(a[0])>Math.abs(a[1])?a[0]>0?"right":"left":a[1]>0?"bottom":"top"}function dc(r){return!r.isGroup}function yb(r){return r.shape!=null}function Vy(r,t,e){if(!r||!t)return;function i(o){var s={};return o.traverse(function(l){dc(l)&&l.anid&&(s[l.anid]=l)}),s}function n(o){var s={x:o.x,y:o.y,rotation:o.rotation};return yb(o)&&(s.shape=O({},o.shape)),s}var a=i(r);t.traverse(function(o){if(dc(o)&&o.anid){var s=a[o.anid];if(s){var l=n(o);o.attr(n(s)),Lt(o,l,e,lt(o).dataIndex)}}})}function mb(r,t){return G(r,function(e){var i=e[0];i=os(i,t.x),i=ss(i,t.x+t.width);var n=e[1];return n=os(n,t.y),n=ss(n,t.y+t.height),[i,n]})}function _b(r,t){var e=os(r.x,t.x),i=ss(r.x+r.width,t.x+t.width),n=os(r.y,t.y),a=ss(r.y+r.height,t.y+t.height);if(i>=e&&a>=n)return{x:e,y:n,width:i-e,height:a-n}}function vh(r,t,e){var i=O({rectHover:!0},t),n=i.style={strokeNoScale:!0};if(e=e||{x:-1,y:-1,width:2,height:2},r)return r.indexOf("image://")===0?(n.image=r.slice(8),rt(n,e),new nr(i)):hh(r.replace("path://",""),i,e,"center")}function Sb(r,t,e,i,n){for(var a=0,o=n[n.length-1];a<n.length;a++){var s=n[a];if(Hy(r,t,e,i,s[0],s[1],o[0],o[1]))return!0;o=s}}function Hy(r,t,e,i,n,a,o,s){var l=e-r,u=i-t,f=o-n,h=s-a,c=zl(f,h,l,u);if(wb(c))return!1;var v=r-n,d=t-a,p=zl(v,d,l,u)/c;if(p<0||p>1)return!1;var g=zl(v,d,f,h)/c;return!(g<0||g>1)}function zl(r,t,e,i){return r*i-e*t}function wb(r){return r<=1e-6&&r>=-1e-6}function Ia(r){var t=r.itemTooltipOption,e=r.componentModel,i=r.itemName,n=W(t)?{formatter:t}:t,a=e.mainType,o=e.componentIndex,s={componentType:a,name:i,$vars:["name"]};s[a+"Index"]=o;var l=r.formatterParamsExtra;l&&A(vt(l),function(f){Q(s,f)||(s[f]=l[f],s.$vars.push(f))});var u=lt(r.el);u.componentMainType=a,u.componentIndex=o,u.tooltipConfig={name:i,option:rt({content:i,encodeHTMLContent:!0,formatterParams:s},n)}}function pc(r,t){var e;r.isGroup&&(e=t(r)),e||r.traverse(t)}function Rs(r,t){if(r)if(V(r))for(var e=0;e<r.length;e++)pc(r[e],t);else pc(r,t)}De("circle",Ps);De("ellipse",wy);De("sector",mi);De("ring",sh);De("polygon",La);De("polyline",_i);De("rect",_t);De("line",ui);De("bezierCurve",Iy);De("arc",lh);const Gy=Object.freeze(Object.defineProperty({__proto__:null,updateProps:Lt,initProps:Jt,removeElement:ns,removeElementWithFadeOut:as,isElementRemoved:na,extendShape:vb,extendPath:db,registerShape:De,getShapeClass:ky,makePath:hh,makeImage:Oy,mergePath:lf,resizePath:Ny,subPixelOptimizeLine:ga,subPixelOptimizeRect:pb,subPixelOptimize:gb,getTransform:zy,applyTransform:ya,transformDirection:Fy,groupTransition:Vy,clipPointsByRect:mb,clipRectByRect:_b,createIcon:vh,linePolygonIntersect:Sb,lineLineIntersect:Hy,setTooltipConfig:Ia,traverseElements:Rs,Group:xt,Image:nr,Text:Dt,Circle:Ps,Ellipse:wy,Sector:mi,Ring:sh,Polygon:La,Polyline:_i,Rect:_t,Line:ui,BezierCurve:Iy,Arc:lh,IncrementalDisplayable:fb,CompoundPath:rb,LinearGradient:Ey,RadialGradient:ob,BoundingRect:ut,OrientedBoundingRect:is,Point:q,Path:ct},Symbol.toStringTag,{value:"Module"}));var Es={};function xb(r,t){for(var e=0;e<ye.length;e++){var i=ye[e],n=t[i],a=r.ensureState(i);a.style=a.style||{},a.style.text=n}var o=r.currentStates.slice();r.clearStates(!0),r.setStyle({text:t.normal}),r.useStates(o,!0)}function gc(r,t,e){var i=r.labelFetcher,n=r.labelDataIndex,a=r.labelDimIndex,o=t.normal,s;i&&(s=i.getFormattedLabel(n,"normal",null,a,o&&o.get("formatter"),e!=null?{interpolatedValue:e}:null)),s==null&&(s=K(r.defaultText)?r.defaultText(n,r,e):r.defaultText);for(var l={normal:s},u=0;u<ye.length;u++){var f=ye[u],h=t[f];l[f]=j(i?i.getFormattedLabel(n,f,null,a,h&&h.get("formatter")):null,s)}return l}function un(r,t,e,i){e=e||Es;for(var n=r instanceof Dt,a=!1,o=0;o<jo.length;o++){var s=t[jo[o]];if(s&&s.getShallow("show")){a=!0;break}}var l=n?r:r.getTextContent();if(a){n||(l||(l=new Dt,r.setTextContent(l)),r.stateProxy&&(l.stateProxy=r.stateProxy));var u=gc(e,t),f=t.normal,h=!!f.getShallow("show"),c=fi(f,i&&i.normal,e,!1,!n);c.text=u.normal,n||r.setTextConfig(yc(f,e,!1));for(var o=0;o<ye.length;o++){var v=ye[o],s=t[v];if(s){var d=l.ensureState(v),p=!!j(s.getShallow("show"),h);if(p!==h&&(d.ignore=!p),d.style=fi(s,i&&i[v],e,!0,!n),d.style.text=u[v],!n){var g=r.ensureState(v);g.textConfig=yc(s,e,!0)}}}l.silent=!!f.getShallow("silent"),l.style.x!=null&&(c.x=l.style.x),l.style.y!=null&&(c.y=l.style.y),l.ignore=!h,l.useStyle(c),l.dirty(),e.enableTextSetter&&(ks(l).setLabelText=function(y){var m=gc(e,t,y);xb(l,m)})}else l&&(l.ignore=!0);r.dirty()}function fn(r,t){t=t||"label";for(var e={normal:r.getModel(t)},i=0;i<ye.length;i++){var n=ye[i];e[n]=r.getModel([n,t])}return e}function fi(r,t,e,i,n){var a={};return bb(a,r,e,i,n),t&&O(a,t),a}function yc(r,t,e){t=t||{};var i={},n,a=r.getShallow("rotate"),o=j(r.getShallow("distance"),e?null:5),s=r.getShallow("offset");return n=r.getShallow("position")||(e?null:"inside"),n==="outside"&&(n=t.defaultOutsidePosition||"top"),n!=null&&(i.position=n),s!=null&&(i.offset=s),a!=null&&(a*=Math.PI/180,i.rotation=a),o!=null&&(i.distance=o),i.outsideFill=r.get("color")==="inherit"?t.inheritColor||null:"auto",i}function bb(r,t,e,i,n){e=e||Es;var a=t.ecModel,o=a&&a.option.textStyle,s=Tb(t),l;if(s){l={};for(var u in s)if(s.hasOwnProperty(u)){var f=t.getModel(["rich",u]);wc(l[u]={},f,o,e,i,n,!1,!0)}}l&&(r.rich=l);var h=t.get("overflow");h&&(r.overflow=h);var c=t.get("minMargin");c!=null&&(r.margin=c),wc(r,t,o,e,i,n,!0,!1)}function Tb(r){for(var t;r&&r!==r.ecModel;){var e=(r.option||Es).rich;if(e){t=t||{};for(var i=vt(e),n=0;n<i.length;n++){var a=i[n];t[a]=1}}r=r.parentModel}return t}var mc=["fontStyle","fontWeight","fontSize","fontFamily","textShadowColor","textShadowBlur","textShadowOffsetX","textShadowOffsetY"],_c=["align","lineHeight","width","height","tag","verticalAlign","ellipsis"],Sc=["padding","borderWidth","borderRadius","borderDashOffset","backgroundColor","borderColor","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"];function wc(r,t,e,i,n,a,o,s){e=!n&&e||Es;var l=i&&i.inheritColor,u=t.getShallow("color"),f=t.getShallow("textBorderColor"),h=j(t.getShallow("opacity"),e.opacity);(u==="inherit"||u==="auto")&&(l?u=l:u=null),(f==="inherit"||f==="auto")&&(l?f=l:f=null),a||(u=u||e.color,f=f||e.textBorderColor),u!=null&&(r.fill=u),f!=null&&(r.stroke=f);var c=j(t.getShallow("textBorderWidth"),e.textBorderWidth);c!=null&&(r.lineWidth=c);var v=j(t.getShallow("textBorderType"),e.textBorderType);v!=null&&(r.lineDash=v);var d=j(t.getShallow("textBorderDashOffset"),e.textBorderDashOffset);d!=null&&(r.lineDashOffset=d),!n&&h==null&&!s&&(h=i&&i.defaultOpacity),h!=null&&(r.opacity=h),!n&&!a&&r.fill==null&&i.inheritColor&&(r.fill=i.inheritColor);for(var p=0;p<mc.length;p++){var g=mc[p],y=j(t.getShallow(g),e[g]);y!=null&&(r[g]=y)}for(var p=0;p<_c.length;p++){var g=_c[p],y=t.getShallow(g);y!=null&&(r[g]=y)}if(r.verticalAlign==null){var m=t.getShallow("baseline");m!=null&&(r.verticalAlign=m)}if(!o||!i.disableBox){for(var p=0;p<Sc.length;p++){var g=Sc[p],y=t.getShallow(g);y!=null&&(r[g]=y)}var _=t.getShallow("borderType");_!=null&&(r.borderDash=_),(r.backgroundColor==="auto"||r.backgroundColor==="inherit")&&l&&(r.backgroundColor=l),(r.borderColor==="auto"||r.borderColor==="inherit")&&l&&(r.borderColor=l)}}function Cb(r,t){var e=t&&t.getModel("textStyle");return Fe([r.fontStyle||e&&e.getShallow("fontStyle")||"",r.fontWeight||e&&e.getShallow("fontWeight")||"",(r.fontSize||e&&e.getShallow("fontSize")||12)+"px",r.fontFamily||e&&e.getShallow("fontFamily")||"sans-serif"].join(" "))}var ks=gt();function Mb(r,t,e,i){if(!!r){var n=ks(r);n.prevValue=n.value,n.value=e;var a=t.normal;n.valueAnimation=a.get("valueAnimation"),n.valueAnimation&&(n.precision=a.get("precision"),n.defaultInterpolatedText=i,n.statesModels=t)}}var Ab=["textStyle","color"],Fl=["fontStyle","fontWeight","fontSize","fontFamily","padding","lineHeight","rich","width","height","overflow"],Vl=new Dt,Db=function(){function r(){}return r.prototype.getTextColor=function(t){var e=this.ecModel;return this.getShallow("color")||(!t&&e?e.get(Ab):null)},r.prototype.getFont=function(){return Cb({fontStyle:this.getShallow("fontStyle"),fontWeight:this.getShallow("fontWeight"),fontSize:this.getShallow("fontSize"),fontFamily:this.getShallow("fontFamily")},this.ecModel)},r.prototype.getTextRect=function(t){for(var e={text:t,verticalAlign:this.getShallow("verticalAlign")||this.getShallow("baseline")},i=0;i<Fl.length;i++)e[Fl[i]]=this.getShallow(Fl[i]);return Vl.useStyle(e),Vl.update(),Vl.getBoundingRect()},r}();const Lb=Db;var Wy=[["lineWidth","width"],["stroke","color"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","type"],["lineDashOffset","dashOffset"],["lineCap","cap"],["lineJoin","join"],["miterLimit"]],Ib=da(Wy),Pb=function(){function r(){}return r.prototype.getLineStyle=function(t){return Ib(this,t)},r}(),Uy=[["fill","color"],["stroke","borderColor"],["lineWidth","borderWidth"],["opacity"],["shadowBlur"],["shadowOffsetX"],["shadowOffsetY"],["shadowColor"],["lineDash","borderType"],["lineDashOffset","borderDashOffset"],["lineCap","borderCap"],["lineJoin","borderJoin"],["miterLimit","borderMiterLimit"]],Rb=da(Uy),Eb=function(){function r(){}return r.prototype.getItemStyle=function(t,e){return Rb(this,t,e)},r}(),Si=function(){function r(t,e,i){this.parentModel=e,this.ecModel=i,this.option=t}return r.prototype.init=function(t,e,i){},r.prototype.mergeOption=function(t,e){nt(this.option,t,!0)},r.prototype.get=function(t,e){return t==null?this.option:this._doGet(this.parsePath(t),!e&&this.parentModel)},r.prototype.getShallow=function(t,e){var i=this.option,n=i==null?i:i[t];if(n==null&&!e){var a=this.parentModel;a&&(n=a.getShallow(t))}return n},r.prototype.getModel=function(t,e){var i=t!=null,n=i?this.parsePath(t):null,a=i?this._doGet(n):this.option;return e=e||this.parentModel&&this.parentModel.getModel(this.resolveParentPath(n)),new r(a,e,this.ecModel)},r.prototype.isEmpty=function(){return this.option==null},r.prototype.restoreData=function(){},r.prototype.clone=function(){var t=this.constructor;return new t(et(this.option))},r.prototype.parsePath=function(t){return typeof t=="string"?t.split("."):t},r.prototype.resolveParentPath=function(t){return t},r.prototype.isAnimationEnabled=function(){if(!tt.node&&this.option){if(this.option.animation!=null)return!!this.option.animation;if(this.parentModel)return this.parentModel.isAnimationEnabled()}},r.prototype._doGet=function(t,e){var i=this.option;if(!t)return i;for(var n=0;n<t.length&&!(!!t[n]&&(i=i&&typeof i=="object"?i[t[n]]:null,i==null));n++);return i==null&&e&&(i=e._doGet(this.resolveParentPath(t),e.parentModel)),i},r}();rh(Si);dw(Si);Me(Si,Pb);Me(Si,Eb);Me(Si,_w);Me(Si,Lb);const kt=Si;var kb=Math.round(Math.random()*10);function Os(r){return[r||"",kb++].join("_")}function Ob(r){var t={};r.registerSubTypeDefaulter=function(e,i){var n=Ve(e);t[n.main]=i},r.determineSubType=function(e,i){var n=i.type;if(!n){var a=Ve(e).main;r.hasSubTypes(e)&&t[a]&&(n=t[a](i))}return n}}function Bb(r,t){r.topologicalTravel=function(a,o,s,l){if(!a.length)return;var u=e(o),f=u.graph,h=u.noEntryList,c={};for(A(a,function(m){c[m]=!0});h.length;){var v=h.pop(),d=f[v],p=!!c[v];p&&(s.call(l,v,d.originalDeps.slice()),delete c[v]),A(d.successor,p?y:g)}A(c,function(){var m="";throw new Error(m)});function g(m){f[m].entryCount--,f[m].entryCount===0&&h.push(m)}function y(m){c[m]=!0,g(m)}};function e(a){var o={},s=[];return A(a,function(l){var u=i(o,l),f=u.originalDeps=t(l),h=n(f,a);u.entryCount=h.length,u.entryCount===0&&s.push(l),A(h,function(c){at(u.predecessor,c)<0&&u.predecessor.push(c);var v=i(o,c);at(v.successor,c)<0&&v.successor.push(l)})}),{graph:o,noEntryList:s}}function i(a,o){return a[o]||(a[o]={predecessor:[],successor:[]}),a[o]}function n(a,o){var s=[];return A(a,function(l){at(o,l)>=0&&s.push(l)}),s}}function Bs(r,t){return nt(nt({},r,!0),t,!0)}const Nb={time:{month:["January","February","March","April","May","June","July","August","September","October","November","December"],monthAbbr:["Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"],dayOfWeek:["Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday"],dayOfWeekAbbr:["Sun","Mon","Tue","Wed","Thu","Fri","Sat"]},legend:{selector:{all:"All",inverse:"Inv"}},toolbox:{brush:{title:{rect:"Box Select",polygon:"Lasso Select",lineX:"Horizontally Select",lineY:"Vertically Select",keep:"Keep Selections",clear:"Clear Selections"}},dataView:{title:"Data View",lang:["Data View","Close","Refresh"]},dataZoom:{title:{zoom:"Zoom",back:"Zoom Reset"}},magicType:{title:{line:"Switch to Line Chart",bar:"Switch to Bar Chart",stack:"Stack",tiled:"Tile"}},restore:{title:"Restore"},saveAsImage:{title:"Save as Image",lang:["Right Click to Save Image"]}},series:{typeNames:{pie:"Pie chart",bar:"Bar chart",line:"Line chart",scatter:"Scatter plot",effectScatter:"Ripple scatter plot",radar:"Radar chart",tree:"Tree",treemap:"Treemap",boxplot:"Boxplot",candlestick:"Candlestick",k:"K line chart",heatmap:"Heat map",map:"Map",parallel:"Parallel coordinate map",lines:"Line graph",graph:"Relationship graph",sankey:"Sankey diagram",funnel:"Funnel chart",gauge:"Gauge",pictorialBar:"Pictorial bar",themeRiver:"Theme River Map",sunburst:"Sunburst",custom:"Custom chart",chart:"Chart"}},aria:{general:{withTitle:'This is a chart about "{title}"',withoutTitle:"This is a chart"},series:{single:{prefix:"",withName:" with type {seriesType} named {seriesName}.",withoutName:" with type {seriesType}."},multiple:{prefix:". It consists of {seriesCount} series count.",withName:" The {seriesId} series is a {seriesType} representing {seriesName}.",withoutName:" The {seriesId} series is a {seriesType}.",separator:{middle:"",end:""}}},data:{allData:"The data is as follows: ",partialData:"The first {displayCnt} items are: ",withName:"the data for {name} is {value}",withoutName:"{value}",separator:{middle:", ",end:". "}}}},zb={time:{month:["\u4E00\u6708","\u4E8C\u6708","\u4E09\u6708","\u56DB\u6708","\u4E94\u6708","\u516D\u6708","\u4E03\u6708","\u516B\u6708","\u4E5D\u6708","\u5341\u6708","\u5341\u4E00\u6708","\u5341\u4E8C\u6708"],monthAbbr:["1\u6708","2\u6708","3\u6708","4\u6708","5\u6708","6\u6708","7\u6708","8\u6708","9\u6708","10\u6708","11\u6708","12\u6708"],dayOfWeek:["\u661F\u671F\u65E5","\u661F\u671F\u4E00","\u661F\u671F\u4E8C","\u661F\u671F\u4E09","\u661F\u671F\u56DB","\u661F\u671F\u4E94","\u661F\u671F\u516D"],dayOfWeekAbbr:["\u65E5","\u4E00","\u4E8C","\u4E09","\u56DB","\u4E94","\u516D"]},legend:{selector:{all:"\u5168\u9009",inverse:"\u53CD\u9009"}},toolbox:{brush:{title:{rect:"\u77E9\u5F62\u9009\u62E9",polygon:"\u5708\u9009",lineX:"\u6A2A\u5411\u9009\u62E9",lineY:"\u7EB5\u5411\u9009\u62E9",keep:"\u4FDD\u6301\u9009\u62E9",clear:"\u6E05\u9664\u9009\u62E9"}},dataView:{title:"\u6570\u636E\u89C6\u56FE",lang:["\u6570\u636E\u89C6\u56FE","\u5173\u95ED","\u5237\u65B0"]},dataZoom:{title:{zoom:"\u533A\u57DF\u7F29\u653E",back:"\u533A\u57DF\u7F29\u653E\u8FD8\u539F"}},magicType:{title:{line:"\u5207\u6362\u4E3A\u6298\u7EBF\u56FE",bar:"\u5207\u6362\u4E3A\u67F1\u72B6\u56FE",stack:"\u5207\u6362\u4E3A\u5806\u53E0",tiled:"\u5207\u6362\u4E3A\u5E73\u94FA"}},restore:{title:"\u8FD8\u539F"},saveAsImage:{title:"\u4FDD\u5B58\u4E3A\u56FE\u7247",lang:["\u53F3\u952E\u53E6\u5B58\u4E3A\u56FE\u7247"]}},series:{typeNames:{pie:"\u997C\u56FE",bar:"\u67F1\u72B6\u56FE",line:"\u6298\u7EBF\u56FE",scatter:"\u6563\u70B9\u56FE",effectScatter:"\u6D9F\u6F2A\u6563\u70B9\u56FE",radar:"\u96F7\u8FBE\u56FE",tree:"\u6811\u56FE",treemap:"\u77E9\u5F62\u6811\u56FE",boxplot:"\u7BB1\u578B\u56FE",candlestick:"K\u7EBF\u56FE",k:"K\u7EBF\u56FE",heatmap:"\u70ED\u529B\u56FE",map:"\u5730\u56FE",parallel:"\u5E73\u884C\u5750\u6807\u56FE",lines:"\u7EBF\u56FE",graph:"\u5173\u7CFB\u56FE",sankey:"\u6851\u57FA\u56FE",funnel:"\u6F0F\u6597\u56FE",gauge:"\u4EEA\u8868\u76D8\u56FE",pictorialBar:"\u8C61\u5F62\u67F1\u56FE",themeRiver:"\u4E3B\u9898\u6CB3\u6D41\u56FE",sunburst:"\u65ED\u65E5\u56FE",custom:"\u81EA\u5B9A\u4E49\u56FE\u8868",chart:"\u56FE\u8868"}},aria:{general:{withTitle:"\u8FD9\u662F\u4E00\u4E2A\u5173\u4E8E\u201C{title}\u201D\u7684\u56FE\u8868\u3002",withoutTitle:"\u8FD9\u662F\u4E00\u4E2A\u56FE\u8868\uFF0C"},series:{single:{prefix:"",withName:"\u56FE\u8868\u7C7B\u578B\u662F{seriesType}\uFF0C\u8868\u793A{seriesName}\u3002",withoutName:"\u56FE\u8868\u7C7B\u578B\u662F{seriesType}\u3002"},multiple:{prefix:"\u5B83\u7531{seriesCount}\u4E2A\u56FE\u8868\u7CFB\u5217\u7EC4\u6210\u3002",withName:"\u7B2C{seriesId}\u4E2A\u7CFB\u5217\u662F\u4E00\u4E2A\u8868\u793A{seriesName}\u7684{seriesType}\uFF0C",withoutName:"\u7B2C{seriesId}\u4E2A\u7CFB\u5217\u662F\u4E00\u4E2A{seriesType}\uFF0C",separator:{middle:"\uFF1B",end:"\u3002"}}},data:{allData:"\u5176\u6570\u636E\u662F\u2014\u2014",partialData:"\u5176\u4E2D\uFF0C\u524D{displayCnt}\u9879\u662F\u2014\u2014",withName:"{name}\u7684\u6570\u636E\u662F{value}",withoutName:"{value}",separator:{middle:"\uFF0C",end:""}}}};var ls="ZH",ch="EN",Ji=ch,Oo={},dh={},Yy=tt.domSupported?function(){var r=(document.documentElement.lang||navigator.language||navigator.browserLanguage||Ji).toUpperCase();return r.indexOf(ls)>-1?ls:Ji}():Ji;function $y(r,t){r=r.toUpperCase(),dh[r]=new kt(t),Oo[r]=t}function Fb(r){if(W(r)){var t=Oo[r.toUpperCase()]||{};return r===ls||r===ch?et(t):nt(et(t),et(Oo[Ji]),!1)}else return nt(et(r),et(Oo[Ji]),!1)}function Vb(r){return dh[r]}function Hb(){return dh[Ji]}$y(ch,Nb);$y(ls,zb);var ph=1e3,gh=ph*60,aa=gh*60,pe=aa*24,xc=pe*365,$n={year:"{yyyy}",month:"{MMM}",day:"{d}",hour:"{HH}:{mm}",minute:"{HH}:{mm}",second:"{HH}:{mm}:{ss}",millisecond:"{HH}:{mm}:{ss} {SSS}",none:"{yyyy}-{MM}-{dd} {HH}:{mm}:{ss} {SSS}"},to="{yyyy}-{MM}-{dd}",bc={year:"{yyyy}",month:"{yyyy}-{MM}",day:to,hour:to+" "+$n.hour,minute:to+" "+$n.minute,second:to+" "+$n.second,millisecond:$n.none},Hl=["year","month","day","hour","minute","second","millisecond"],Zy=["year","half-year","quarter","month","week","half-week","day","half-day","quarter-day","hour","minute","second","millisecond"];function fr(r,t){return r+="","0000".substr(0,t-r.length)+r}function ji(r){switch(r){case"half-year":case"quarter":return"month";case"week":case"half-week":return"day";case"half-day":case"quarter-day":return"hour";default:return r}}function Gb(r){return r===ji(r)}function Wb(r){switch(r){case"year":case"month":return"day";case"millisecond":return"millisecond";default:return"second"}}function Ns(r,t,e,i){var n=er(r),a=n[yh(e)](),o=n[tn(e)]()+1,s=Math.floor((o-1)/3)+1,l=n[zs(e)](),u=n["get"+(e?"UTC":"")+"Day"](),f=n[ma(e)](),h=(f-1)%12+1,c=n[Fs(e)](),v=n[Vs(e)](),d=n[Hs(e)](),p=f>=12?"pm":"am",g=p.toUpperCase(),y=i instanceof kt?i:Vb(i||Yy)||Hb(),m=y.getModel("time"),_=m.get("month"),S=m.get("monthAbbr"),x=m.get("dayOfWeek"),w=m.get("dayOfWeekAbbr");return(t||"").replace(/{a}/g,p+"").replace(/{A}/g,g+"").replace(/{yyyy}/g,a+"").replace(/{yy}/g,fr(a%100+"",2)).replace(/{Q}/g,s+"").replace(/{MMMM}/g,_[o-1]).replace(/{MMM}/g,S[o-1]).replace(/{MM}/g,fr(o,2)).replace(/{M}/g,o+"").replace(/{dd}/g,fr(l,2)).replace(/{d}/g,l+"").replace(/{eeee}/g,x[u]).replace(/{ee}/g,w[u]).replace(/{e}/g,u+"").replace(/{HH}/g,fr(f,2)).replace(/{H}/g,f+"").replace(/{hh}/g,fr(h+"",2)).replace(/{h}/g,h+"").replace(/{mm}/g,fr(c,2)).replace(/{m}/g,c+"").replace(/{ss}/g,fr(v,2)).replace(/{s}/g,v+"").replace(/{SSS}/g,fr(d,3)).replace(/{S}/g,d+"")}function Ub(r,t,e,i,n){var a=null;if(W(e))a=e;else if(K(e))a=e(r.value,t,{level:r.level});else{var o=O({},$n);if(r.level>0)for(var s=0;s<Hl.length;++s)o[Hl[s]]="{primary|"+o[Hl[s]]+"}";var l=e?e.inherit===!1?e:rt(e,o):o,u=Xy(r.value,n);if(l[u])a=l[u];else if(l.inherit){for(var f=Zy.indexOf(u),s=f-1;s>=0;--s)if(l[u]){a=l[u];break}a=a||o.none}if(V(a)){var h=r.level==null?0:r.level>=0?r.level:a.length+r.level;h=Math.min(h,a.length-1),a=a[h]}}return Ns(new Date(r.value),a,n,i)}function Xy(r,t){var e=er(r),i=e[tn(t)]()+1,n=e[zs(t)](),a=e[ma(t)](),o=e[Fs(t)](),s=e[Vs(t)](),l=e[Hs(t)](),u=l===0,f=u&&s===0,h=f&&o===0,c=h&&a===0,v=c&&n===1,d=v&&i===1;return d?"year":v?"month":c?"day":h?"hour":f?"minute":u?"second":"millisecond"}function Tc(r,t,e){var i=dt(r)?er(r):r;switch(t=t||Xy(r,e),t){case"year":return i[yh(e)]();case"half-year":return i[tn(e)]()>=6?1:0;case"quarter":return Math.floor((i[tn(e)]()+1)/4);case"month":return i[tn(e)]();case"day":return i[zs(e)]();case"half-day":return i[ma(e)]()/24;case"hour":return i[ma(e)]();case"minute":return i[Fs(e)]();case"second":return i[Vs(e)]();case"millisecond":return i[Hs(e)]()}}function yh(r){return r?"getUTCFullYear":"getFullYear"}function tn(r){return r?"getUTCMonth":"getMonth"}function zs(r){return r?"getUTCDate":"getDate"}function ma(r){return r?"getUTCHours":"getHours"}function Fs(r){return r?"getUTCMinutes":"getMinutes"}function Vs(r){return r?"getUTCSeconds":"getSeconds"}function Hs(r){return r?"getUTCMilliseconds":"getMilliseconds"}function Yb(r){return r?"setUTCFullYear":"setFullYear"}function qy(r){return r?"setUTCMonth":"setMonth"}function Ky(r){return r?"setUTCDate":"setDate"}function Qy(r){return r?"setUTCHours":"setHours"}function Jy(r){return r?"setUTCMinutes":"setMinutes"}function jy(r){return r?"setUTCSeconds":"setSeconds"}function tm(r){return r?"setUTCMilliseconds":"setMilliseconds"}function em(r){if(!ZS(r))return W(r)?r:"-";var t=(r+"").split(".");return t[0].replace(/(\d{1,3})(?=(?:\d{3})+(?!\d))/g,"$1,")+(t.length>1?"."+t[1]:"")}function rm(r,t){return r=(r||"").toLowerCase().replace(/-(.)/g,function(e,i){return i.toUpperCase()}),t&&r&&(r=r.charAt(0).toUpperCase()+r.slice(1)),r}var Gs=fg;function uf(r,t,e){var i="{yyyy}-{MM}-{dd} {HH}:{mm}:{ss}";function n(f){return f&&Fe(f)?f:"-"}function a(f){return!!(f!=null&&!isNaN(f)&&isFinite(f))}var o=t==="time",s=r instanceof Date;if(o||s){var l=o?er(r):r;if(isNaN(+l)){if(s)return"-"}else return Ns(l,i,e)}if(t==="ordinal")return Pu(r)?n(r):dt(r)&&a(r)?r+"":"-";var u=Jo(r);return a(u)?em(u):Pu(r)?n(r):typeof r=="boolean"?r+"":"-"}var Cc=["a","b","c","d","e","f","g"],Gl=function(r,t){return"{"+r+(t==null?"":t)+"}"};function im(r,t,e){V(t)||(t=[t]);var i=t.length;if(!i)return"";for(var n=t[0].$vars||[],a=0;a<n.length;a++){var o=Cc[a];r=r.replace(Gl(o),Gl(o,0))}for(var s=0;s<i;s++)for(var l=0;l<n.length;l++){var u=t[s][n[l]];r=r.replace(Gl(Cc[l],s),e?Zt(u):u)}return r}function $b(r,t){var e=W(r)?{color:r,extraCssText:t}:r||{},i=e.color,n=e.type;t=e.extraCssText;var a=e.renderMode||"html";if(!i)return"";if(a==="html")return n==="subItem"?'<span style="display:inline-block;vertical-align:middle;margin-right:8px;margin-left:3px;border-radius:4px;width:4px;height:4px;background-color:'+Zt(i)+";"+(t||"")+'"></span>':'<span style="display:inline-block;margin-right:4px;border-radius:10px;width:10px;height:10px;background-color:'+Zt(i)+";"+(t||"")+'"></span>';var o=e.markerId||"markerX";return{renderMode:a,content:"{"+o+"|}  ",style:n==="subItem"?{width:4,height:4,borderRadius:2,backgroundColor:i}:{width:10,height:10,borderRadius:5,backgroundColor:i}}}function hi(r,t){return t=t||"transparent",W(r)?r:Y(r)&&r.colorStops&&(r.colorStops[0]||{}).color||t}var Bo=A,nm=["left","right","top","bottom","width","height"],eo=[["width","left","right"],["height","top","bottom"]];function mh(r,t,e,i,n){var a=0,o=0;i==null&&(i=1/0),n==null&&(n=1/0);var s=0;t.eachChild(function(l,u){var f=l.getBoundingRect(),h=t.childAt(u+1),c=h&&h.getBoundingRect(),v,d;if(r==="horizontal"){var p=f.width+(c?-c.x+f.x:0);v=a+p,v>i||l.newline?(a=0,v=p,o+=s+e,s=f.height):s=Math.max(s,f.height)}else{var g=f.height+(c?-c.y+f.y:0);d=o+g,d>n||l.newline?(a+=s+e,o=0,d=g,s=f.width):s=Math.max(s,f.width)}l.newline||(l.x=a,l.y=o,l.markRedraw(),r==="horizontal"?a=v+e:o=d+e)})}var oa=mh;yt(mh,"vertical");yt(mh,"horizontal");function vi(r,t,e){e=Gs(e||0);var i=t.width,n=t.height,a=st(r.left,i),o=st(r.top,n),s=st(r.right,i),l=st(r.bottom,n),u=st(r.width,i),f=st(r.height,n),h=e[2]+e[0],c=e[1]+e[3],v=r.aspect;switch(isNaN(u)&&(u=i-s-c-a),isNaN(f)&&(f=n-l-h-o),v!=null&&(isNaN(u)&&isNaN(f)&&(v>i/n?u=i*.8:f=n*.8),isNaN(u)&&(u=v*f),isNaN(f)&&(f=u/v)),isNaN(a)&&(a=i-s-u-c),isNaN(o)&&(o=n-l-f-h),r.left||r.right){case"center":a=i/2-u/2-e[3];break;case"right":a=i-u-c;break}switch(r.top||r.bottom){case"middle":case"center":o=n/2-f/2-e[0];break;case"bottom":o=n-f-h;break}a=a||0,o=o||0,isNaN(u)&&(u=i-c-a-(s||0)),isNaN(f)&&(f=n-h-o-(l||0));var d=new ut(a+e[3],o+e[0],u,f);return d.margin=e,d}function Zb(r,t,e,i,n,a){var o=!n||!n.hv||n.hv[0],s=!n||!n.hv||n.hv[1],l=n&&n.boundingMode||"all";if(a=a||r,a.x=r.x,a.y=r.y,!o&&!s)return!1;var u;if(l==="raw")u=r.type==="group"?new ut(0,0,+t.width||0,+t.height||0):r.getBoundingRect();else if(u=r.getBoundingRect(),r.needLocalTransform()){var f=r.getLocalTransform();u=u.clone(),u.applyTransform(f)}var h=vi(rt({width:u.width,height:u.height},t),e,i),c=o?h.x-u.x:0,v=s?h.y-u.y:0;return l==="raw"?(a.x=c,a.y=v):(a.x+=c,a.y+=v),a===r&&r.markRedraw(),!0}function _a(r){var t=r.layoutMode||r.constructor.layoutMode;return Y(t)?t:t?{type:t}:null}function ci(r,t,e){var i=e&&e.ignoreSize;!V(i)&&(i=[i,i]);var n=o(eo[0],0),a=o(eo[1],1);u(eo[0],r,n),u(eo[1],r,a);function o(f,h){var c={},v=0,d={},p=0,g=2;if(Bo(f,function(_){d[_]=r[_]}),Bo(f,function(_){s(t,_)&&(c[_]=d[_]=t[_]),l(c,_)&&v++,l(d,_)&&p++}),i[h])return l(t,f[1])?d[f[2]]=null:l(t,f[2])&&(d[f[1]]=null),d;if(p===g||!v)return d;if(v>=g)return c;for(var y=0;y<f.length;y++){var m=f[y];if(!s(c,m)&&s(r,m)){c[m]=r[m];break}}return c}function s(f,h){return f.hasOwnProperty(h)}function l(f,h){return f[h]!=null&&f[h]!=="auto"}function u(f,h,c){Bo(f,function(v){h[v]=c[v]})}}function Pa(r){return am({},r)}function am(r,t){return t&&r&&Bo(nm,function(e){t.hasOwnProperty(e)&&(r[e]=t[e])}),r}var Xb=gt(),hn=function(r){N(t,r);function t(e,i,n){var a=r.call(this,e,i,n)||this;return a.uid=Os("ec_cpt_model"),a}return t.prototype.init=function(e,i,n){this.mergeDefaultAndTheme(e,n)},t.prototype.mergeDefaultAndTheme=function(e,i){var n=_a(this),a=n?Pa(e):{},o=i.getTheme();nt(e,o.get(this.mainType)),nt(e,this.getDefaultOption()),n&&ci(e,a,n)},t.prototype.mergeOption=function(e,i){nt(this.option,e,!0);var n=_a(this);n&&ci(this.option,e,n)},t.prototype.optionUpdated=function(e,i){},t.prototype.getDefaultOption=function(){var e=this.constructor;if(!hw(e))return e.defaultOption;var i=Xb(this);if(!i.defaultOption){for(var n=[],a=e;a;){var o=a.prototype.defaultOption;o&&n.push(o),a=a.superClass}for(var s={},l=n.length-1;l>=0;l--)s=nt(s,n[l],!0);i.defaultOption=s}return i.defaultOption},t.prototype.getReferringComponents=function(e,i){var n=e+"Index",a=e+"Id";return Da(this.ecModel,e,{index:this.get(n,!0),id:this.get(a,!0)},i)},t.prototype.getBoxLayoutParams=function(){var e=this;return{left:e.get("left"),top:e.get("top"),right:e.get("right"),bottom:e.get("bottom"),width:e.get("width"),height:e.get("height")}},t.prototype.getZLevelKey=function(){return""},t.prototype.setZLevel=function(e){this.option.zlevel=e},t.protoInitialize=function(){var e=t.prototype;e.type="component",e.id="",e.name="",e.mainType="",e.subType="",e.componentIndex=0}(),t}(kt);$g(hn,kt);Cs(hn);Ob(hn);Bb(hn,qb);function qb(r){var t=[];return A(hn.getClassesByMainType(r),function(e){t=t.concat(e.dependencies||e.prototype.dependencies||[])}),t=G(t,function(e){return Ve(e).main}),r!=="dataset"&&at(t,"dataset")<=0&&t.unshift("dataset"),t}const pt=hn;var om="";typeof navigator<"u"&&(om=navigator.platform||"");var Ei="rgba(0, 0, 0, 0.2)";const Kb={darkMode:"auto",colorBy:"series",color:["#5470c6","#91cc75","#fac858","#ee6666","#73c0de","#3ba272","#fc8452","#9a60b4","#ea7ccc"],gradientColor:["#f6efa6","#d88273","#bf444c"],aria:{decal:{decals:[{color:Ei,dashArrayX:[1,0],dashArrayY:[2,5],symbolSize:1,rotation:Math.PI/6},{color:Ei,symbol:"circle",dashArrayX:[[8,8],[0,8,8,0]],dashArrayY:[6,0],symbolSize:.8},{color:Ei,dashArrayX:[1,0],dashArrayY:[4,3],rotation:-Math.PI/4},{color:Ei,dashArrayX:[[6,6],[0,6,6,0]],dashArrayY:[6,0]},{color:Ei,dashArrayX:[[1,0],[1,6]],dashArrayY:[1,0,6,0],rotation:Math.PI/4},{color:Ei,symbol:"triangle",dashArrayX:[[9,9],[0,9,9,0]],dashArrayY:[7,2],symbolSize:.75}]}},textStyle:{fontFamily:om.match(/^Win/)?"Microsoft YaHei":"sans-serif",fontSize:12,fontStyle:"normal",fontWeight:"normal"},blendMode:null,stateAnimation:{duration:300,easing:"cubicOut"},animation:"auto",animationDuration:1e3,animationDurationUpdate:500,animationEasing:"cubicInOut",animationEasingUpdate:"cubicInOut",animationThreshold:2e3,progressiveThreshold:3e3,progressive:400,hoverLayerThreshold:3e3,useUTC:!1};var sm=Z(["tooltip","label","itemName","itemId","itemGroupId","itemChildGroupId","seriesName"]),me="original",te="arrayRows",Le="objectRows",We="keyedColumns",Ar="typedArray",lm="unknown",Je="column",vn="row",Pt={Must:1,Might:2,Not:3},um=gt();function Qb(r){um(r).datasetMap=Z()}function Jb(r,t,e){var i={},n=_h(t);if(!n||!r)return i;var a=[],o=[],s=t.ecModel,l=um(s).datasetMap,u=n.uid+"_"+e.seriesLayoutBy,f,h;r=r.slice(),A(r,function(p,g){var y=Y(p)?p:r[g]={name:p};y.type==="ordinal"&&f==null&&(f=g,h=d(y)),i[y.name]=[]});var c=l.get(u)||l.set(u,{categoryWayDim:h,valueWayDim:0});A(r,function(p,g){var y=p.name,m=d(p);if(f==null){var _=c.valueWayDim;v(i[y],_,m),v(o,_,m),c.valueWayDim+=m}else if(f===g)v(i[y],0,m),v(a,0,m);else{var _=c.categoryWayDim;v(i[y],_,m),v(o,_,m),c.categoryWayDim+=m}});function v(p,g,y){for(var m=0;m<y;m++)p.push(g+m)}function d(p){var g=p.dimsDef;return g?g.length:1}return a.length&&(i.itemName=a),o.length&&(i.seriesName=o),i}function jb(r,t,e){var i={},n=_h(r);if(!n)return i;var a=t.sourceFormat,o=t.dimensionsDefine,s;(a===Le||a===We)&&A(o,function(f,h){(Y(f)?f.name:f)==="name"&&(s=h)});var l=function(){for(var f={},h={},c=[],v=0,d=Math.min(5,e);v<d;v++){var p=hm(t.data,a,t.seriesLayoutBy,o,t.startIndex,v);c.push(p);var g=p===Pt.Not;if(g&&f.v==null&&v!==s&&(f.v=v),(f.n==null||f.n===f.v||!g&&c[f.n]===Pt.Not)&&(f.n=v),y(f)&&c[f.n]!==Pt.Not)return f;g||(p===Pt.Might&&h.v==null&&v!==s&&(h.v=v),(h.n==null||h.n===h.v)&&(h.n=v))}function y(m){return m.v!=null&&m.n!=null}return y(f)?f:y(h)?h:null}();if(l){i.value=[l.v];var u=s!=null?s:l.n;i.itemName=[u],i.seriesName=[u]}return i}function _h(r){var t=r.get("data",!0);if(!t)return Da(r.ecModel,"dataset",{index:r.get("datasetIndex",!0),id:r.get("datasetId",!0)},Qt).models[0]}function tT(r){return!r.get("transform",!0)&&!r.get("fromTransformResult",!0)?[]:Da(r.ecModel,"dataset",{index:r.get("fromDatasetIndex",!0),id:r.get("fromDatasetId",!0)},Qt).models}function fm(r,t){return hm(r.data,r.sourceFormat,r.seriesLayoutBy,r.dimensionsDefine,r.startIndex,t)}function hm(r,t,e,i,n,a){var o,s=5;if(jt(r))return Pt.Not;var l,u;if(i){var f=i[a];Y(f)?(l=f.name,u=f.type):W(f)&&(l=f)}if(u!=null)return u==="ordinal"?Pt.Must:Pt.Not;if(t===te){var h=r;if(e===vn){for(var c=h[a],v=0;v<(c||[]).length&&v<s;v++)if((o=S(c[n+v]))!=null)return o}else for(var v=0;v<h.length&&v<s;v++){var d=h[n+v];if(d&&(o=S(d[a]))!=null)return o}}else if(t===Le){var p=r;if(!l)return Pt.Not;for(var v=0;v<p.length&&v<s;v++){var g=p[v];if(g&&(o=S(g[l]))!=null)return o}}else if(t===We){var y=r;if(!l)return Pt.Not;var c=y[l];if(!c||jt(c))return Pt.Not;for(var v=0;v<c.length&&v<s;v++)if((o=S(c[v]))!=null)return o}else if(t===me)for(var m=r,v=0;v<m.length&&v<s;v++){var g=m[v],_=Aa(g);if(!V(_))return Pt.Not;if((o=S(_[a]))!=null)return o}function S(x){var w=W(x);if(x!=null&&Number.isFinite(Number(x))&&x!=="")return w?Pt.Might:Pt.Not;if(w&&x!=="-")return Pt.Must}return Pt.Not}var eT=Z();function rT(r,t,e){var i=eT.get(t);if(!i)return e;var n=i(r);return n?e.concat(n):e}var Mc=gt();gt();var Sh=function(){function r(){}return r.prototype.getColorFromPalette=function(t,e,i){var n=At(this.get("color",!0)),a=this.get("colorLayer",!0);return nT(this,Mc,n,a,t,e,i)},r.prototype.clearColorPalette=function(){aT(this,Mc)},r}();function iT(r,t){for(var e=r.length,i=0;i<e;i++)if(r[i].length>t)return r[i];return r[e-1]}function nT(r,t,e,i,n,a,o){a=a||r;var s=t(a),l=s.paletteIdx||0,u=s.paletteNameMap=s.paletteNameMap||{};if(u.hasOwnProperty(n))return u[n];var f=o==null||!i?e:iT(i,o);if(f=f||e,!(!f||!f.length)){var h=f[l];return n&&(u[n]=h),s.paletteIdx=(l+1)%f.length,h}}function aT(r,t){t(r).paletteIdx=0,t(r).paletteNameMap={}}var ro,Tn,Ac,Dc="\0_ec_inner",oT=1,vm=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(e,i,n,a,o,s){a=a||{},this.option=null,this._theme=new kt(a),this._locale=new kt(o),this._optionManager=s},t.prototype.setOption=function(e,i,n){var a=Pc(i);this._optionManager.setOption(e,n,a),this._resetOption(null,a)},t.prototype.resetOption=function(e,i){return this._resetOption(e,Pc(i))},t.prototype._resetOption=function(e,i){var n=!1,a=this._optionManager;if(!e||e==="recreate"){var o=a.mountOption(e==="recreate");!this.option||e==="recreate"?Ac(this,o):(this.restoreData(),this._mergeOption(o,i)),n=!0}if((e==="timeline"||e==="media")&&this.restoreData(),!e||e==="recreate"||e==="timeline"){var s=a.getTimelineOption(this);s&&(n=!0,this._mergeOption(s,i))}if(!e||e==="recreate"||e==="media"){var l=a.getMediaOption(this);l.length&&A(l,function(u){n=!0,this._mergeOption(u,i)},this)}return n},t.prototype.mergeOption=function(e){this._mergeOption(e,null)},t.prototype._mergeOption=function(e,i){var n=this.option,a=this._componentsMap,o=this._componentsCount,s=[],l=Z(),u=i&&i.replaceMergeMainTypeMap;Qb(this),A(e,function(h,c){h!=null&&(pt.hasClass(c)?c&&(s.push(c),l.set(c,!0)):n[c]=n[c]==null?et(h):nt(n[c],h,!0))}),u&&u.each(function(h,c){pt.hasClass(c)&&!l.get(c)&&(s.push(c),l.set(c,!0))}),pt.topologicalTravel(s,pt.getAllClassMainTypes(),f,this);function f(h){var c=rT(this,h,At(e[h])),v=a.get(h),d=v?u&&u.get(h)?"replaceMerge":"normalMerge":"replaceAll",p=Gg(v,c,d);rw(p,h,pt),n[h]=null,a.set(h,null),o.set(h,0);var g=[],y=[],m=0,_;A(p,function(S,x){var w=S.existing,b=S.newOption;if(!b)w&&(w.mergeOption({},this),w.optionUpdated({},!1));else{var T=h==="series",M=pt.getClass(h,S.keyInfo.subType,!T);if(!M)return;if(h==="tooltip"){if(_)return;_=!0}if(w&&w.constructor===M)w.name=S.keyInfo.name,w.mergeOption(b,this),w.optionUpdated(b,!1);else{var D=O({componentIndex:x},S.keyInfo);w=new M(b,this,this,D),O(w,D),S.brandNew&&(w.__requireNewView=!0),w.init(b,this,this),w.optionUpdated(null,!0)}}w?(g.push(w.option),y.push(w),m++):(g.push(void 0),y.push(void 0))},this),n[h]=g,a.set(h,y),o.set(h,m),h==="series"&&ro(this)}this._seriesIndices||ro(this)},t.prototype.getOption=function(){var e=et(this.option);return A(e,function(i,n){if(pt.hasClass(n)){for(var a=At(i),o=a.length,s=!1,l=o-1;l>=0;l--)a[l]&&!ca(a[l])?s=!0:(a[l]=null,!s&&o--);a.length=o,e[n]=a}}),delete e[Dc],e},t.prototype.getTheme=function(){return this._theme},t.prototype.getLocaleModel=function(){return this._locale},t.prototype.setUpdatePayload=function(e){this._payload=e},t.prototype.getUpdatePayload=function(){return this._payload},t.prototype.getComponent=function(e,i){var n=this._componentsMap.get(e);if(n){var a=n[i||0];if(a)return a;if(i==null){for(var o=0;o<n.length;o++)if(n[o])return n[o]}}},t.prototype.queryComponents=function(e){var i=e.mainType;if(!i)return[];var n=e.index,a=e.id,o=e.name,s=this._componentsMap.get(i);if(!s||!s.length)return[];var l;return n!=null?(l=[],A(At(n),function(u){s[u]&&l.push(s[u])})):a!=null?l=Lc("id",a,s):o!=null?l=Lc("name",o,s):l=Ct(s,function(u){return!!u}),Ic(l,e)},t.prototype.findComponents=function(e){var i=e.query,n=e.mainType,a=s(i),o=a?this.queryComponents(a):Ct(this._componentsMap.get(n),function(u){return!!u});return l(Ic(o,e));function s(u){var f=n+"Index",h=n+"Id",c=n+"Name";return u&&(u[f]!=null||u[h]!=null||u[c]!=null)?{mainType:n,index:u[f],id:u[h],name:u[c]}:null}function l(u){return e.filter?Ct(u,e.filter):u}},t.prototype.eachComponent=function(e,i,n){var a=this._componentsMap;if(K(e)){var o=i,s=e;a.each(function(h,c){for(var v=0;h&&v<h.length;v++){var d=h[v];d&&s.call(o,c,d,d.componentIndex)}})}else for(var l=W(e)?a.get(e):Y(e)?this.findComponents(e):null,u=0;l&&u<l.length;u++){var f=l[u];f&&i.call(n,f,f.componentIndex)}},t.prototype.getSeriesByName=function(e){var i=Kt(e,null);return Ct(this._componentsMap.get("series"),function(n){return!!n&&i!=null&&n.name===i})},t.prototype.getSeriesByIndex=function(e){return this._componentsMap.get("series")[e]},t.prototype.getSeriesByType=function(e){return Ct(this._componentsMap.get("series"),function(i){return!!i&&i.subType===e})},t.prototype.getSeries=function(){return Ct(this._componentsMap.get("series"),function(e){return!!e})},t.prototype.getSeriesCount=function(){return this._componentsCount.get("series")},t.prototype.eachSeries=function(e,i){Tn(this),A(this._seriesIndices,function(n){var a=this._componentsMap.get("series")[n];e.call(i,a,n)},this)},t.prototype.eachRawSeries=function(e,i){A(this._componentsMap.get("series"),function(n){n&&e.call(i,n,n.componentIndex)})},t.prototype.eachSeriesByType=function(e,i,n){Tn(this),A(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];o.subType===e&&i.call(n,o,a)},this)},t.prototype.eachRawSeriesByType=function(e,i,n){return A(this.getSeriesByType(e),i,n)},t.prototype.isSeriesFiltered=function(e){return Tn(this),this._seriesIndicesMap.get(e.componentIndex)==null},t.prototype.getCurrentSeriesIndices=function(){return(this._seriesIndices||[]).slice()},t.prototype.filterSeries=function(e,i){Tn(this);var n=[];A(this._seriesIndices,function(a){var o=this._componentsMap.get("series")[a];e.call(i,o,a)&&n.push(a)},this),this._seriesIndices=n,this._seriesIndicesMap=Z(n)},t.prototype.restoreData=function(e){ro(this);var i=this._componentsMap,n=[];i.each(function(a,o){pt.hasClass(o)&&n.push(o)}),pt.topologicalTravel(n,pt.getAllClassMainTypes(),function(a){A(i.get(a),function(o){o&&(a!=="series"||!sT(o,e))&&o.restoreData()})})},t.internalField=function(){ro=function(e){var i=e._seriesIndices=[];A(e._componentsMap.get("series"),function(n){n&&i.push(n.componentIndex)}),e._seriesIndicesMap=Z(i)},Tn=function(e){},Ac=function(e,i){e.option={},e.option[Dc]=oT,e._componentsMap=Z({series:[]}),e._componentsCount=Z();var n=i.aria;Y(n)&&n.enabled==null&&(n.enabled=!0),lT(i,e._theme.option),nt(i,Kb,!1),e._mergeOption(i,null)}}(),t}(kt);function sT(r,t){if(t){var e=t.seriesIndex,i=t.seriesId,n=t.seriesName;return e!=null&&r.componentIndex!==e||i!=null&&r.id!==i||n!=null&&r.name!==n}}function lT(r,t){var e=r.color&&!r.colorLayer;A(t,function(i,n){n==="colorLayer"&&e||pt.hasClass(n)||(typeof i=="object"?r[n]=r[n]?nt(r[n],i,!1):et(i):r[n]==null&&(r[n]=i))})}function Lc(r,t,e){if(V(t)){var i=Z();return A(t,function(a){if(a!=null){var o=Kt(a,null);o!=null&&i.set(a,!0)}}),Ct(e,function(a){return a&&i.get(a[r])})}else{var n=Kt(t,null);return Ct(e,function(a){return a&&n!=null&&a[r]===n})}}function Ic(r,t){return t.hasOwnProperty("subType")?Ct(r,function(e){return e&&e.subType===t.subType}):r}function Pc(r){var t=Z();return r&&A(At(r.replaceMerge),function(e){t.set(e,!0)}),{replaceMergeMainTypeMap:t}}Me(vm,Sh);const cm=vm;var uT=["getDom","getZr","getWidth","getHeight","getDevicePixelRatio","dispatchAction","isSSR","isDisposed","on","off","getDataURL","getConnectedDataURL","getOption","getId","updateLabelLayout"],fT=function(){function r(t){A(uT,function(e){this[e]=$(t[e],t)},this)}return r}();const dm=fT;var Wl={},hT=function(){function r(){this._coordinateSystems=[]}return r.prototype.create=function(t,e){var i=[];A(Wl,function(n,a){var o=n.create(t,e);i=i.concat(o||[])}),this._coordinateSystems=i},r.prototype.update=function(t,e){A(this._coordinateSystems,function(i){i.update&&i.update(t,e)})},r.prototype.getCoordinateSystems=function(){return this._coordinateSystems.slice()},r.register=function(t,e){Wl[t]=e},r.get=function(t){return Wl[t]},r}();const wh=hT;var vT=/^(min|max)?(.+)$/,cT=function(){function r(t){this._timelineOptions=[],this._mediaList=[],this._currentMediaIndices=[],this._api=t}return r.prototype.setOption=function(t,e,i){t&&(A(At(t.series),function(o){o&&o.data&&jt(o.data)&&Ru(o.data)}),A(At(t.dataset),function(o){o&&o.source&&jt(o.source)&&Ru(o.source)})),t=et(t);var n=this._optionBackup,a=dT(t,e,!n);this._newBaseOption=a.baseOption,n?(a.timelineOptions.length&&(n.timelineOptions=a.timelineOptions),a.mediaList.length&&(n.mediaList=a.mediaList),a.mediaDefault&&(n.mediaDefault=a.mediaDefault)):this._optionBackup=a},r.prototype.mountOption=function(t){var e=this._optionBackup;return this._timelineOptions=e.timelineOptions,this._mediaList=e.mediaList,this._mediaDefault=e.mediaDefault,this._currentMediaIndices=[],et(t?e.baseOption:this._newBaseOption)},r.prototype.getTimelineOption=function(t){var e,i=this._timelineOptions;if(i.length){var n=t.getComponent("timeline");n&&(e=et(i[n.getCurrentIndex()]))}return e},r.prototype.getMediaOption=function(t){var e=this._api.getWidth(),i=this._api.getHeight(),n=this._mediaList,a=this._mediaDefault,o=[],s=[];if(!n.length&&!a)return s;for(var l=0,u=n.length;l<u;l++)pT(n[l].query,e,i)&&o.push(l);return!o.length&&a&&(o=[-1]),o.length&&!yT(o,this._currentMediaIndices)&&(s=G(o,function(f){return et(f===-1?a.option:n[f].option)})),this._currentMediaIndices=o,s},r}();function dT(r,t,e){var i=[],n,a,o=r.baseOption,s=r.timeline,l=r.options,u=r.media,f=!!r.media,h=!!(l||s||o&&o.timeline);o?(a=o,a.timeline||(a.timeline=s)):((h||f)&&(r.options=r.media=null),a=r),f&&V(u)&&A(u,function(v){v&&v.option&&(v.query?i.push(v):n||(n=v))}),c(a),A(l,function(v){return c(v)}),A(i,function(v){return c(v.option)});function c(v){A(t,function(d){d(v,e)})}return{baseOption:a,timelineOptions:l||[],mediaDefault:n,mediaList:i}}function pT(r,t,e){var i={width:t,height:e,aspectratio:t/e},n=!0;return A(r,function(a,o){var s=o.match(vT);if(!(!s||!s[1]||!s[2])){var l=s[1],u=s[2].toLowerCase();gT(i[u],a,l)||(n=!1)}}),n}function gT(r,t,e){return e==="min"?r>=t:e==="max"?r<=t:r===t}function yT(r,t){return r.join(",")===t.join(",")}const mT=cT;var _e=A,Sa=Y,Rc=["areaStyle","lineStyle","nodeStyle","linkStyle","chordStyle","label","labelLine"];function Ul(r){var t=r&&r.itemStyle;if(!!t)for(var e=0,i=Rc.length;e<i;e++){var n=Rc[e],a=t.normal,o=t.emphasis;a&&a[n]&&(r[n]=r[n]||{},r[n].normal?nt(r[n].normal,a[n]):r[n].normal=a[n],a[n]=null),o&&o[n]&&(r[n]=r[n]||{},r[n].emphasis?nt(r[n].emphasis,o[n]):r[n].emphasis=o[n],o[n]=null)}}function Ft(r,t,e){if(r&&r[t]&&(r[t].normal||r[t].emphasis)){var i=r[t].normal,n=r[t].emphasis;i&&(e?(r[t].normal=r[t].emphasis=null,rt(r[t],i)):r[t]=i),n&&(r.emphasis=r.emphasis||{},r.emphasis[t]=n,n.focus&&(r.emphasis.focus=n.focus),n.blurScope&&(r.emphasis.blurScope=n.blurScope))}}function Zn(r){Ft(r,"itemStyle"),Ft(r,"lineStyle"),Ft(r,"areaStyle"),Ft(r,"label"),Ft(r,"labelLine"),Ft(r,"upperLabel"),Ft(r,"edgeLabel")}function wt(r,t){var e=Sa(r)&&r[t],i=Sa(e)&&e.textStyle;if(i)for(var n=0,a=Ov.length;n<a;n++){var o=Ov[n];i.hasOwnProperty(o)&&(e[o]=i[o])}}function ue(r){r&&(Zn(r),wt(r,"label"),r.emphasis&&wt(r.emphasis,"label"))}function _T(r){if(!!Sa(r)){Ul(r),Zn(r),wt(r,"label"),wt(r,"upperLabel"),wt(r,"edgeLabel"),r.emphasis&&(wt(r.emphasis,"label"),wt(r.emphasis,"upperLabel"),wt(r.emphasis,"edgeLabel"));var t=r.markPoint;t&&(Ul(t),ue(t));var e=r.markLine;e&&(Ul(e),ue(e));var i=r.markArea;i&&ue(i);var n=r.data;if(r.type==="graph"){n=n||r.nodes;var a=r.links||r.edges;if(a&&!jt(a))for(var o=0;o<a.length;o++)ue(a[o]);A(r.categories,function(u){Zn(u)})}if(n&&!jt(n))for(var o=0;o<n.length;o++)ue(n[o]);if(t=r.markPoint,t&&t.data)for(var s=t.data,o=0;o<s.length;o++)ue(s[o]);if(e=r.markLine,e&&e.data)for(var l=e.data,o=0;o<l.length;o++)V(l[o])?(ue(l[o][0]),ue(l[o][1])):ue(l[o]);r.type==="gauge"?(wt(r,"axisLabel"),wt(r,"title"),wt(r,"detail")):r.type==="treemap"?(Ft(r.breadcrumb,"itemStyle"),A(r.levels,function(u){Zn(u)})):r.type==="tree"&&Zn(r.leaves)}}function $e(r){return V(r)?r:r?[r]:[]}function Ec(r){return(V(r)?r[0]:r)||{}}function ST(r,t){_e($e(r.series),function(i){Sa(i)&&_T(i)});var e=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","parallelAxis","radar"];t&&e.push("valueAxis","categoryAxis","logAxis","timeAxis"),_e(e,function(i){_e($e(r[i]),function(n){n&&(wt(n,"axisLabel"),wt(n.axisPointer,"label"))})}),_e($e(r.parallel),function(i){var n=i&&i.parallelAxisDefault;wt(n,"axisLabel"),wt(n&&n.axisPointer,"label")}),_e($e(r.calendar),function(i){Ft(i,"itemStyle"),wt(i,"dayLabel"),wt(i,"monthLabel"),wt(i,"yearLabel")}),_e($e(r.radar),function(i){wt(i,"name"),i.name&&i.axisName==null&&(i.axisName=i.name,delete i.name),i.nameGap!=null&&i.axisNameGap==null&&(i.axisNameGap=i.nameGap,delete i.nameGap)}),_e($e(r.geo),function(i){Sa(i)&&(ue(i),_e($e(i.regions),function(n){ue(n)}))}),_e($e(r.timeline),function(i){ue(i),Ft(i,"label"),Ft(i,"itemStyle"),Ft(i,"controlStyle",!0);var n=i.data;V(n)&&A(n,function(a){Y(a)&&(Ft(a,"label"),Ft(a,"itemStyle"))})}),_e($e(r.toolbox),function(i){Ft(i,"iconStyle"),_e(i.feature,function(n){Ft(n,"iconStyle")})}),wt(Ec(r.axisPointer),"label"),wt(Ec(r.tooltip).axisPointer,"label")}function wT(r,t){for(var e=t.split(","),i=r,n=0;n<e.length&&(i=i&&i[e[n]],i!=null);n++);return i}function xT(r,t,e,i){for(var n=t.split(","),a=r,o,s=0;s<n.length-1;s++)o=n[s],a[o]==null&&(a[o]={}),a=a[o];(i||a[n[s]]==null)&&(a[n[s]]=e)}function kc(r){r&&A(bT,function(t){t[0]in r&&!(t[1]in r)&&(r[t[1]]=r[t[0]])})}var bT=[["x","left"],["y","top"],["x2","right"],["y2","bottom"]],TT=["grid","geo","parallel","legend","toolbox","title","visualMap","dataZoom","timeline"],Yl=[["borderRadius","barBorderRadius"],["borderColor","barBorderColor"],["borderWidth","barBorderWidth"]];function Cn(r){var t=r&&r.itemStyle;if(t)for(var e=0;e<Yl.length;e++){var i=Yl[e][1],n=Yl[e][0];t[i]!=null&&(t[n]=t[i])}}function Oc(r){!r||r.alignTo==="edge"&&r.margin!=null&&r.edgeDistance==null&&(r.edgeDistance=r.margin)}function Bc(r){!r||r.downplay&&!r.blur&&(r.blur=r.downplay)}function CT(r){!r||r.focusNodeAdjacency!=null&&(r.emphasis=r.emphasis||{},r.emphasis.focus==null&&(r.emphasis.focus="adjacency"))}function pm(r,t){if(r)for(var e=0;e<r.length;e++)t(r[e]),r[e]&&pm(r[e].children,t)}function gm(r,t){ST(r,t),r.series=At(r.series),A(r.series,function(e){if(!!Y(e)){var i=e.type;if(i==="line")e.clipOverflow!=null&&(e.clip=e.clipOverflow);else if(i==="pie"||i==="gauge"){e.clockWise!=null&&(e.clockwise=e.clockWise),Oc(e.label);var n=e.data;if(n&&!jt(n))for(var a=0;a<n.length;a++)Oc(n[a]);e.hoverOffset!=null&&(e.emphasis=e.emphasis||{},(e.emphasis.scaleSize=null)&&(e.emphasis.scaleSize=e.hoverOffset))}else if(i==="gauge"){var o=wT(e,"pointer.color");o!=null&&xT(e,"itemStyle.color",o)}else if(i==="bar"){Cn(e),Cn(e.backgroundStyle),Cn(e.emphasis);var n=e.data;if(n&&!jt(n))for(var a=0;a<n.length;a++)typeof n[a]=="object"&&(Cn(n[a]),Cn(n[a]&&n[a].emphasis))}else if(i==="sunburst"){var s=e.highlightPolicy;s&&(e.emphasis=e.emphasis||{},e.emphasis.focus||(e.emphasis.focus=s)),Bc(e),pm(e.data,Bc)}else i==="graph"||i==="sankey"?CT(e):i==="map"&&(e.mapType&&!e.map&&(e.map=e.mapType),e.mapLocation&&rt(e,e.mapLocation));e.hoverAnimation!=null&&(e.emphasis=e.emphasis||{},e.emphasis&&e.emphasis.scale==null&&(e.emphasis.scale=e.hoverAnimation)),kc(e)}}),r.dataRange&&(r.visualMap=r.dataRange),A(TT,function(e){var i=r[e];i&&(V(i)||(i=[i]),A(i,function(n){kc(n)}))})}function MT(r){var t=Z();r.eachSeries(function(e){var i=e.get("stack");if(i){var n=t.get(i)||t.set(i,[]),a=e.getData(),o={stackResultDimension:a.getCalculationInfo("stackResultDimension"),stackedOverDimension:a.getCalculationInfo("stackedOverDimension"),stackedDimension:a.getCalculationInfo("stackedDimension"),stackedByDimension:a.getCalculationInfo("stackedByDimension"),isStackedByIndex:a.getCalculationInfo("isStackedByIndex"),data:a,seriesModel:e};if(!o.stackedDimension||!(o.isStackedByIndex||o.stackedByDimension))return;n.length&&a.setCalculationInfo("stackedOnSeries",n[n.length-1].seriesModel),n.push(o)}}),t.each(AT)}function AT(r){A(r,function(t,e){var i=[],n=[NaN,NaN],a=[t.stackResultDimension,t.stackedOverDimension],o=t.data,s=t.isStackedByIndex,l=t.seriesModel.get("stackStrategy")||"samesign";o.modify(a,function(u,f,h){var c=o.get(t.stackedDimension,h);if(isNaN(c))return n;var v,d;s?d=o.getRawIndex(h):v=o.get(t.stackedByDimension,h);for(var p=NaN,g=e-1;g>=0;g--){var y=r[g];if(s||(d=y.data.rawIndexOf(y.stackedByDimension,v)),d>=0){var m=y.data.getByRawIndex(y.stackResultDimension,d);if(l==="all"||l==="positive"&&m>0||l==="negative"&&m<0||l==="samesign"&&c>=0&&m>0||l==="samesign"&&c<=0&&m<0){c=US(c,m),p=m;break}}}return i[0]=c,i[1]=p,i})})}var Ws=function(){function r(t){this.data=t.data||(t.sourceFormat===We?{}:[]),this.sourceFormat=t.sourceFormat||lm,this.seriesLayoutBy=t.seriesLayoutBy||Je,this.startIndex=t.startIndex||0,this.dimensionsDetectedCount=t.dimensionsDetectedCount,this.metaRawOption=t.metaRawOption;var e=this.dimensionsDefine=t.dimensionsDefine;if(e)for(var i=0;i<e.length;i++){var n=e[i];n.type==null&&fm(this,i)===Pt.Must&&(n.type="ordinal")}}return r}();function xh(r){return r instanceof Ws}function ff(r,t,e){e=e||ym(r);var i=t.seriesLayoutBy,n=LT(r,e,i,t.sourceHeader,t.dimensions),a=new Ws({data:r,sourceFormat:e,seriesLayoutBy:i,dimensionsDefine:n.dimensionsDefine,startIndex:n.startIndex,dimensionsDetectedCount:n.dimensionsDetectedCount,metaRawOption:et(t)});return a}function bh(r){return new Ws({data:r,sourceFormat:jt(r)?Ar:me})}function DT(r){return new Ws({data:r.data,sourceFormat:r.sourceFormat,seriesLayoutBy:r.seriesLayoutBy,dimensionsDefine:et(r.dimensionsDefine),startIndex:r.startIndex,dimensionsDetectedCount:r.dimensionsDetectedCount})}function ym(r){var t=lm;if(jt(r))t=Ar;else if(V(r)){r.length===0&&(t=te);for(var e=0,i=r.length;e<i;e++){var n=r[e];if(n!=null){if(V(n)||jt(n)){t=te;break}else if(Y(n)){t=Le;break}}}}else if(Y(r)){for(var a in r)if(Q(r,a)&&Wt(r[a])){t=We;break}}return t}function LT(r,t,e,i,n){var a,o;if(!r)return{dimensionsDefine:Nc(n),startIndex:o,dimensionsDetectedCount:a};if(t===te){var s=r;i==="auto"||i==null?zc(function(u){u!=null&&u!=="-"&&(W(u)?o==null&&(o=1):o=0)},e,s,10):o=dt(i)?i:i?1:0,!n&&o===1&&(n=[],zc(function(u,f){n[f]=u!=null?u+"":""},e,s,1/0)),a=n?n.length:e===vn?s.length:s[0]?s[0].length:null}else if(t===Le)n||(n=IT(r));else if(t===We)n||(n=[],A(r,function(u,f){n.push(f)}));else if(t===me){var l=Aa(r[0]);a=V(l)&&l.length||1}return{startIndex:o,dimensionsDefine:Nc(n),dimensionsDetectedCount:a}}function IT(r){for(var t=0,e;t<r.length&&!(e=r[t++]););if(e)return vt(e)}function Nc(r){if(!!r){var t=Z();return G(r,function(e,i){e=Y(e)?e:{name:e};var n={name:e.name,displayName:e.displayName,type:e.type};if(n.name==null)return n;n.name+="",n.displayName==null&&(n.displayName=n.name);var a=t.get(n.name);return a?n.name+="-"+a.count++:t.set(n.name,{count:1}),n})}}function zc(r,t,e,i){if(t===vn)for(var n=0;n<e.length&&n<i;n++)r(e[n]?e[n][0]:null,n);else for(var a=e[0]||[],n=0;n<a.length&&n<i;n++)r(a[n],n)}function mm(r){var t=r.sourceFormat;return t===Le||t===We}var Zr,Xr,qr,Fc,Vc,_m=function(){function r(t,e){var i=xh(t)?t:bh(t);this._source=i;var n=this._data=i.data;i.sourceFormat===Ar&&(this._offset=0,this._dimSize=e,this._data=n),Vc(this,n,i)}return r.prototype.getSource=function(){return this._source},r.prototype.count=function(){return 0},r.prototype.getItem=function(t,e){},r.prototype.appendData=function(t){},r.prototype.clean=function(){},r.protoInitialize=function(){var t=r.prototype;t.pure=!1,t.persistent=!0}(),r.internalField=function(){var t;Vc=function(o,s,l){var u=l.sourceFormat,f=l.seriesLayoutBy,h=l.startIndex,c=l.dimensionsDefine,v=Fc[Th(u,f)];if(O(o,v),u===Ar)o.getItem=e,o.count=n,o.fillStorage=i;else{var d=Sm(u,f);o.getItem=$(d,null,s,h,c);var p=wm(u,f);o.count=$(p,null,s,h,c)}};var e=function(o,s){o=o-this._offset,s=s||[];for(var l=this._data,u=this._dimSize,f=u*o,h=0;h<u;h++)s[h]=l[f+h];return s},i=function(o,s,l,u){for(var f=this._data,h=this._dimSize,c=0;c<h;c++){for(var v=u[c],d=v[0]==null?1/0:v[0],p=v[1]==null?-1/0:v[1],g=s-o,y=l[c],m=0;m<g;m++){var _=f[m*h+c];y[o+m]=_,_<d&&(d=_),_>p&&(p=_)}v[0]=d,v[1]=p}},n=function(){return this._data?this._data.length/this._dimSize:0};Fc=(t={},t[te+"_"+Je]={pure:!0,appendData:a},t[te+"_"+vn]={pure:!0,appendData:function(){throw new Error('Do not support appendData when set seriesLayoutBy: "row".')}},t[Le]={pure:!0,appendData:a},t[We]={pure:!0,appendData:function(o){var s=this._data;A(o,function(l,u){for(var f=s[u]||(s[u]=[]),h=0;h<(l||[]).length;h++)f.push(l[h])})}},t[me]={appendData:a},t[Ar]={persistent:!1,pure:!0,appendData:function(o){this._data=o},clean:function(){this._offset+=this.count(),this._data=null}},t);function a(o){for(var s=0;s<o.length;s++)this._data.push(o[s])}}(),r}(),Hc=function(r,t,e,i){return r[i]},PT=(Zr={},Zr[te+"_"+Je]=function(r,t,e,i){return r[i+t]},Zr[te+"_"+vn]=function(r,t,e,i,n){i+=t;for(var a=n||[],o=r,s=0;s<o.length;s++){var l=o[s];a[s]=l?l[i]:null}return a},Zr[Le]=Hc,Zr[We]=function(r,t,e,i,n){for(var a=n||[],o=0;o<e.length;o++){var s=e[o].name,l=r[s];a[o]=l?l[i]:null}return a},Zr[me]=Hc,Zr);function Sm(r,t){var e=PT[Th(r,t)];return e}var Gc=function(r,t,e){return r.length},RT=(Xr={},Xr[te+"_"+Je]=function(r,t,e){return Math.max(0,r.length-t)},Xr[te+"_"+vn]=function(r,t,e){var i=r[0];return i?Math.max(0,i.length-t):0},Xr[Le]=Gc,Xr[We]=function(r,t,e){var i=e[0].name,n=r[i];return n?n.length:0},Xr[me]=Gc,Xr);function wm(r,t){var e=RT[Th(r,t)];return e}var $l=function(r,t,e){return r[t]},ET=(qr={},qr[te]=$l,qr[Le]=function(r,t,e){return r[e]},qr[We]=$l,qr[me]=function(r,t,e){var i=Aa(r);return i instanceof Array?i[t]:i},qr[Ar]=$l,qr);function xm(r){var t=ET[r];return t}function Th(r,t){return r===te?r+"_"+t:r}function an(r,t,e){if(!!r){var i=r.getRawDataItem(t);if(i!=null){var n=r.getStore(),a=n.getSource().sourceFormat;if(e!=null){var o=r.getDimensionIndex(e),s=n.getDimensionProperty(o);return xm(a)(i,o,s)}else{var l=i;return a===me&&(l=Aa(i)),l}}}}var kT=/\{@(.+?)\}/g,OT=function(){function r(){}return r.prototype.getDataParams=function(t,e){var i=this.getData(e),n=this.getRawValue(t,e),a=i.getRawIndex(t),o=i.getName(t),s=i.getRawDataItem(t),l=i.getItemVisual(t,"style"),u=l&&l[i.getItemVisual(t,"drawType")||"fill"],f=l&&l.stroke,h=this.mainType,c=h==="series",v=i.userOutput&&i.userOutput.get();return{componentType:h,componentSubType:this.subType,componentIndex:this.componentIndex,seriesType:c?this.subType:null,seriesIndex:this.seriesIndex,seriesId:c?this.id:null,seriesName:c?this.name:null,name:o,dataIndex:a,data:s,dataType:e,value:n,color:u,borderColor:f,dimensionNames:v?v.fullDimensions:null,encode:v?v.encode:null,$vars:["seriesName","name","value"]}},r.prototype.getFormattedLabel=function(t,e,i,n,a,o){e=e||"normal";var s=this.getData(i),l=this.getDataParams(t,i);if(o&&(l.value=o.interpolatedValue),n!=null&&V(l.value)&&(l.value=l.value[n]),!a){var u=s.getItemModel(t);a=u.get(e==="normal"?["label","formatter"]:[e,"label","formatter"])}if(K(a))return l.status=e,l.dimensionIndex=n,a(l);if(W(a)){var f=im(a,l);return f.replace(kT,function(h,c){var v=c.length,d=c;d.charAt(0)==="["&&d.charAt(v-1)==="]"&&(d=+d.slice(1,v-1));var p=an(s,t,d);if(o&&V(o.interpolatedValue)){var g=s.getDimensionIndex(d);g>=0&&(p=o.interpolatedValue[g])}return p!=null?p+"":""})}},r.prototype.getRawValue=function(t,e){return an(this.getData(e),t)},r.prototype.formatTooltip=function(t,e,i){},r}();function Wc(r){var t,e;return Y(r)?r.type&&(e=r):t=r,{text:t,frag:e}}function sa(r){return new BT(r)}var BT=function(){function r(t){t=t||{},this._reset=t.reset,this._plan=t.plan,this._count=t.count,this._onDirty=t.onDirty,this._dirty=!0}return r.prototype.perform=function(t){var e=this._upstream,i=t&&t.skip;if(this._dirty&&e){var n=this.context;n.data=n.outputData=e.context.outputData}this.__pipeline&&(this.__pipeline.currentTask=this);var a;this._plan&&!i&&(a=this._plan(this.context));var o=f(this._modBy),s=this._modDataCount||0,l=f(t&&t.modBy),u=t&&t.modDataCount||0;(o!==l||s!==u)&&(a="reset");function f(m){return!(m>=1)&&(m=1),m}var h;(this._dirty||a==="reset")&&(this._dirty=!1,h=this._doReset(i)),this._modBy=l,this._modDataCount=u;var c=t&&t.step;if(e?this._dueEnd=e._outputDueEnd:this._dueEnd=this._count?this._count(this.context):1/0,this._progress){var v=this._dueIndex,d=Math.min(c!=null?this._dueIndex+c:1/0,this._dueEnd);if(!i&&(h||v<d)){var p=this._progress;if(V(p))for(var g=0;g<p.length;g++)this._doProgress(p[g],v,d,l,u);else this._doProgress(p,v,d,l,u)}this._dueIndex=d;var y=this._settedOutputEnd!=null?this._settedOutputEnd:d;this._outputDueEnd=y}else this._dueIndex=this._outputDueEnd=this._settedOutputEnd!=null?this._settedOutputEnd:this._dueEnd;return this.unfinished()},r.prototype.dirty=function(){this._dirty=!0,this._onDirty&&this._onDirty(this.context)},r.prototype._doProgress=function(t,e,i,n,a){Uc.reset(e,i,n,a),this._callingProgress=t,this._callingProgress({start:e,end:i,count:i-e,next:Uc.next},this.context)},r.prototype._doReset=function(t){this._dueIndex=this._outputDueEnd=this._dueEnd=0,this._settedOutputEnd=null;var e,i;!t&&this._reset&&(e=this._reset(this.context),e&&e.progress&&(i=e.forceFirstProgress,e=e.progress),V(e)&&!e.length&&(e=null)),this._progress=e,this._modBy=this._modDataCount=null;var n=this._downstream;return n&&n.dirty(),i},r.prototype.unfinished=function(){return this._progress&&this._dueIndex<this._dueEnd},r.prototype.pipe=function(t){(this._downstream!==t||this._dirty)&&(this._downstream=t,t._upstream=this,t.dirty())},r.prototype.dispose=function(){this._disposed||(this._upstream&&(this._upstream._downstream=null),this._downstream&&(this._downstream._upstream=null),this._dirty=!1,this._disposed=!0)},r.prototype.getUpstream=function(){return this._upstream},r.prototype.getDownstream=function(){return this._downstream},r.prototype.setOutputEnd=function(t){this._outputDueEnd=this._settedOutputEnd=t},r}(),Uc=function(){var r,t,e,i,n,a={reset:function(l,u,f,h){t=l,r=u,e=f,i=h,n=Math.ceil(i/e),a.next=e>1&&i>0?s:o}};return a;function o(){return t<r?t++:null}function s(){var l=t%n*e+Math.ceil(t/n),u=t>=r?null:l<i?l:t;return t++,u}}();function No(r,t){var e=t&&t.type;return e==="ordinal"?r:(e==="time"&&!dt(r)&&r!=null&&r!=="-"&&(r=+er(r)),r==null||r===""?NaN:Number(r))}Z({number:function(r){return parseFloat(r)},time:function(r){return+er(r)},trim:function(r){return W(r)?Fe(r):r}});var NT=function(){function r(t,e){var i=t==="desc";this._resultLT=i?1:-1,e==null&&(e=i?"min":"max"),this._incomparable=e==="min"?-1/0:1/0}return r.prototype.evaluate=function(t,e){var i=dt(t)?t:Jo(t),n=dt(e)?e:Jo(e),a=isNaN(i),o=isNaN(n);if(a&&(i=this._incomparable),o&&(n=this._incomparable),a&&o){var s=W(t),l=W(e);s&&(i=l?t:0),l&&(n=s?e:0)}return i<n?this._resultLT:i>n?-this._resultLT:0},r}(),zT=function(){function r(){}return r.prototype.getRawData=function(){throw new Error("not supported")},r.prototype.getRawDataItem=function(t){throw new Error("not supported")},r.prototype.cloneRawData=function(){},r.prototype.getDimensionInfo=function(t){},r.prototype.cloneAllDimensionInfo=function(){},r.prototype.count=function(){},r.prototype.retrieveValue=function(t,e){},r.prototype.retrieveValueFromItem=function(t,e){},r.prototype.convertValue=function(t,e){return No(t,e)},r}();function FT(r,t){var e=new zT,i=r.data,n=e.sourceFormat=r.sourceFormat,a=r.startIndex,o="";r.seriesLayoutBy!==Je&&Xt(o);var s=[],l={},u=r.dimensionsDefine;if(u)A(u,function(p,g){var y=p.name,m={index:g,name:y,displayName:p.displayName};if(s.push(m),y!=null){var _="";Q(l,y)&&Xt(_),l[y]=m}});else for(var f=0;f<r.dimensionsDetectedCount;f++)s.push({index:f});var h=Sm(n,Je);t.__isBuiltIn&&(e.getRawDataItem=function(p){return h(i,a,s,p)},e.getRawData=$(VT,null,r)),e.cloneRawData=$(HT,null,r);var c=wm(n,Je);e.count=$(c,null,i,a,s);var v=xm(n);e.retrieveValue=function(p,g){var y=h(i,a,s,p);return d(y,g)};var d=e.retrieveValueFromItem=function(p,g){if(p!=null){var y=s[g];if(y)return v(p,g,y.name)}};return e.getDimensionInfo=$(GT,null,s,l),e.cloneAllDimensionInfo=$(WT,null,s),e}function VT(r){var t=r.sourceFormat;if(!Ch(t)){var e="";Xt(e)}return r.data}function HT(r){var t=r.sourceFormat,e=r.data;if(!Ch(t)){var i="";Xt(i)}if(t===te){for(var n=[],a=0,o=e.length;a<o;a++)n.push(e[a].slice());return n}else if(t===Le){for(var n=[],a=0,o=e.length;a<o;a++)n.push(O({},e[a]));return n}}function GT(r,t,e){if(e!=null){if(dt(e)||!isNaN(e)&&!Q(t,e))return r[e];if(Q(t,e))return t[e]}}function WT(r){return et(r)}var bm=Z();function UT(r){r=et(r);var t=r.type,e="";t||Xt(e);var i=t.split(":");i.length!==2&&Xt(e);var n=!1;i[0]==="echarts"&&(t=i[1],n=!0),r.__isBuiltIn=n,bm.set(t,r)}function YT(r,t,e){var i=At(r),n=i.length,a="";n||Xt(a);for(var o=0,s=n;o<s;o++){var l=i[o];t=$T(l,t),o!==s-1&&(t.length=Math.max(t.length,1))}return t}function $T(r,t,e,i){var n="";t.length||Xt(n),Y(r)||Xt(n);var a=r.type,o=bm.get(a);o||Xt(n);var s=G(t,function(u){return FT(u,o)}),l=At(o.transform({upstream:s[0],upstreamList:s,config:et(r.config)}));return G(l,function(u,f){var h="";Y(u)||Xt(h),u.data||Xt(h);var c=ym(u.data);Ch(c)||Xt(h);var v,d=t[0];if(d&&f===0&&!u.dimensions){var p=d.startIndex;p&&(u.data=d.data.slice(0,p).concat(u.data)),v={seriesLayoutBy:Je,sourceHeader:p,dimensions:d.metaRawOption.dimensions}}else v={seriesLayoutBy:Je,sourceHeader:0,dimensions:u.dimensions};return ff(u.data,v,null)})}function Ch(r){return r===te||r===Le}var Us="undefined",ZT=typeof Uint32Array===Us?Array:Uint32Array,XT=typeof Uint16Array===Us?Array:Uint16Array,Tm=typeof Int32Array===Us?Array:Int32Array,Yc=typeof Float64Array===Us?Array:Float64Array,Cm={float:Yc,int:Tm,ordinal:Array,number:Array,time:Yc},Zl;function ki(r){return r>65535?ZT:XT}function Oi(){return[1/0,-1/0]}function qT(r){var t=r.constructor;return t===Array?r.slice():new t(r)}function $c(r,t,e,i,n){var a=Cm[e||"float"];if(n){var o=r[t],s=o&&o.length;if(s!==i){for(var l=new a(i),u=0;u<s;u++)l[u]=o[u];r[t]=l}}else r[t]=new a(i)}var hf=function(){function r(){this._chunks=[],this._rawExtent=[],this._extent=[],this._count=0,this._rawCount=0,this._calcDimNameToIdx=Z()}return r.prototype.initData=function(t,e,i){this._provider=t,this._chunks=[],this._indices=null,this.getRawIndex=this._getRawIdxIdentity;var n=t.getSource(),a=this.defaultDimValueGetter=Zl[n.sourceFormat];this._dimValueGetter=i||a,this._rawExtent=[],mm(n),this._dimensions=G(e,function(o){return{type:o.type,property:o.property}}),this._initDataFromProvider(0,t.count())},r.prototype.getProvider=function(){return this._provider},r.prototype.getSource=function(){return this._provider.getSource()},r.prototype.ensureCalculationDimension=function(t,e){var i=this._calcDimNameToIdx,n=this._dimensions,a=i.get(t);if(a!=null){if(n[a].type===e)return a}else a=n.length;return n[a]={type:e},i.set(t,a),this._chunks[a]=new Cm[e||"float"](this._rawCount),this._rawExtent[a]=Oi(),a},r.prototype.collectOrdinalMeta=function(t,e){var i=this._chunks[t],n=this._dimensions[t],a=this._rawExtent,o=n.ordinalOffset||0,s=i.length;o===0&&(a[t]=Oi());for(var l=a[t],u=o;u<s;u++){var f=i[u]=e.parseAndCollect(i[u]);isNaN(f)||(l[0]=Math.min(f,l[0]),l[1]=Math.max(f,l[1]))}n.ordinalMeta=e,n.ordinalOffset=s,n.type="ordinal"},r.prototype.getOrdinalMeta=function(t){var e=this._dimensions[t],i=e.ordinalMeta;return i},r.prototype.getDimensionProperty=function(t){var e=this._dimensions[t];return e&&e.property},r.prototype.appendData=function(t){var e=this._provider,i=this.count();e.appendData(t);var n=e.count();return e.persistent||(n+=i),i<n&&this._initDataFromProvider(i,n,!0),[i,n]},r.prototype.appendValues=function(t,e){for(var i=this._chunks,n=this._dimensions,a=n.length,o=this._rawExtent,s=this.count(),l=s+Math.max(t.length,e||0),u=0;u<a;u++){var f=n[u];$c(i,u,f.type,l,!0)}for(var h=[],c=s;c<l;c++)for(var v=c-s,d=0;d<a;d++){var f=n[d],p=Zl.arrayRows.call(this,t[v]||h,f.property,v,d);i[d][c]=p;var g=o[d];p<g[0]&&(g[0]=p),p>g[1]&&(g[1]=p)}return this._rawCount=this._count=l,{start:s,end:l}},r.prototype._initDataFromProvider=function(t,e,i){for(var n=this._provider,a=this._chunks,o=this._dimensions,s=o.length,l=this._rawExtent,u=G(o,function(m){return m.property}),f=0;f<s;f++){var h=o[f];l[f]||(l[f]=Oi()),$c(a,f,h.type,e,i)}if(n.fillStorage)n.fillStorage(t,e,a,l);else for(var c=[],v=t;v<e;v++){c=n.getItem(v,c);for(var d=0;d<s;d++){var p=a[d],g=this._dimValueGetter(c,u[d],v,d);p[v]=g;var y=l[d];g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}!n.persistent&&n.clean&&n.clean(),this._rawCount=this._count=e,this._extent=[]},r.prototype.count=function(){return this._count},r.prototype.get=function(t,e){if(!(e>=0&&e<this._count))return NaN;var i=this._chunks[t];return i?i[this.getRawIndex(e)]:NaN},r.prototype.getValues=function(t,e){var i=[],n=[];if(e==null){e=t,t=[];for(var a=0;a<this._dimensions.length;a++)n.push(a)}else n=t;for(var a=0,o=n.length;a<o;a++)i.push(this.get(n[a],e));return i},r.prototype.getByRawIndex=function(t,e){if(!(e>=0&&e<this._rawCount))return NaN;var i=this._chunks[t];return i?i[e]:NaN},r.prototype.getSum=function(t){var e=this._chunks[t],i=0;if(e)for(var n=0,a=this.count();n<a;n++){var o=this.get(t,n);isNaN(o)||(i+=o)}return i},r.prototype.getMedian=function(t){var e=[];this.each([t],function(a){isNaN(a)||e.push(a)});var i=e.sort(function(a,o){return a-o}),n=this.count();return n===0?0:n%2===1?i[(n-1)/2]:(i[n/2]+i[n/2-1])/2},r.prototype.indexOfRawIndex=function(t){if(t>=this._rawCount||t<0)return-1;if(!this._indices)return t;var e=this._indices,i=e[t];if(i!=null&&i<this._count&&i===t)return t;for(var n=0,a=this._count-1;n<=a;){var o=(n+a)/2|0;if(e[o]<t)n=o+1;else if(e[o]>t)a=o-1;else return o}return-1},r.prototype.indicesOfNearest=function(t,e,i){var n=this._chunks,a=n[t],o=[];if(!a)return o;i==null&&(i=1/0);for(var s=1/0,l=-1,u=0,f=0,h=this.count();f<h;f++){var c=this.getRawIndex(f),v=e-a[c],d=Math.abs(v);d<=i&&((d<s||d===s&&v>=0&&l<0)&&(s=d,l=v,u=0),v===l&&(o[u++]=f))}return o.length=u,o},r.prototype.getIndices=function(){var t,e=this._indices;if(e){var i=e.constructor,n=this._count;if(i===Array){t=new i(n);for(var a=0;a<n;a++)t[a]=e[a]}else t=new i(e.buffer,0,n)}else{var i=ki(this._rawCount);t=new i(this.count());for(var a=0;a<t.length;a++)t[a]=a}return t},r.prototype.filter=function(t,e){if(!this._count)return this;for(var i=this.clone(),n=i.count(),a=ki(i._rawCount),o=new a(n),s=[],l=t.length,u=0,f=t[0],h=i._chunks,c=0;c<n;c++){var v=void 0,d=i.getRawIndex(c);if(l===0)v=e(c);else if(l===1){var p=h[f][d];v=e(p,c)}else{for(var g=0;g<l;g++)s[g]=h[t[g]][d];s[g]=c,v=e.apply(null,s)}v&&(o[u++]=d)}return u<n&&(i._indices=o),i._count=u,i._extent=[],i._updateGetRawIdx(),i},r.prototype.selectRange=function(t){var e=this.clone(),i=e._count;if(!i)return this;var n=vt(t),a=n.length;if(!a)return this;var o=e.count(),s=ki(e._rawCount),l=new s(o),u=0,f=n[0],h=t[f][0],c=t[f][1],v=e._chunks,d=!1;if(!e._indices){var p=0;if(a===1){for(var g=v[n[0]],y=0;y<i;y++){var m=g[y];(m>=h&&m<=c||isNaN(m))&&(l[u++]=p),p++}d=!0}else if(a===2){for(var g=v[n[0]],_=v[n[1]],S=t[n[1]][0],x=t[n[1]][1],y=0;y<i;y++){var m=g[y],w=_[y];(m>=h&&m<=c||isNaN(m))&&(w>=S&&w<=x||isNaN(w))&&(l[u++]=p),p++}d=!0}}if(!d)if(a===1)for(var y=0;y<o;y++){var b=e.getRawIndex(y),m=v[n[0]][b];(m>=h&&m<=c||isNaN(m))&&(l[u++]=b)}else for(var y=0;y<o;y++){for(var T=!0,b=e.getRawIndex(y),M=0;M<a;M++){var D=n[M],m=v[D][b];(m<t[D][0]||m>t[D][1])&&(T=!1)}T&&(l[u++]=e.getRawIndex(y))}return u<o&&(e._indices=l),e._count=u,e._extent=[],e._updateGetRawIdx(),e},r.prototype.map=function(t,e){var i=this.clone(t);return this._updateDims(i,t,e),i},r.prototype.modify=function(t,e){this._updateDims(this,t,e)},r.prototype._updateDims=function(t,e,i){for(var n=t._chunks,a=[],o=e.length,s=t.count(),l=[],u=t._rawExtent,f=0;f<e.length;f++)u[e[f]]=Oi();for(var h=0;h<s;h++){for(var c=t.getRawIndex(h),v=0;v<o;v++)l[v]=n[e[v]][c];l[o]=h;var d=i&&i.apply(null,l);if(d!=null){typeof d!="object"&&(a[0]=d,d=a);for(var f=0;f<d.length;f++){var p=e[f],g=d[f],y=u[p],m=n[p];m&&(m[c]=g),g<y[0]&&(y[0]=g),g>y[1]&&(y[1]=g)}}}},r.prototype.lttbDownSample=function(t,e){var i=this.clone([t],!0),n=i._chunks,a=n[t],o=this.count(),s=0,l=Math.floor(1/e),u=this.getRawIndex(0),f,h,c,v=new(ki(this._rawCount))(Math.min((Math.ceil(o/l)+2)*2,o));v[s++]=u;for(var d=1;d<o-1;d+=l){for(var p=Math.min(d+l,o-1),g=Math.min(d+l*2,o),y=(g+p)/2,m=0,_=p;_<g;_++){var S=this.getRawIndex(_),x=a[S];isNaN(x)||(m+=x)}m/=g-p;var w=d,b=Math.min(d+l,o),T=d-1,M=a[u];f=-1,c=w;for(var D=-1,C=0,_=w;_<b;_++){var S=this.getRawIndex(_),x=a[S];if(isNaN(x)){C++,D<0&&(D=S);continue}h=Math.abs((T-y)*(x-M)-(T-_)*(m-M)),h>f&&(f=h,c=S)}C>0&&C<b-w&&(v[s++]=Math.min(D,c),c=Math.max(D,c)),v[s++]=c,u=c}return v[s++]=this.getRawIndex(o-1),i._count=s,i._indices=v,i.getRawIndex=this._getRawIdx,i},r.prototype.minmaxDownSample=function(t,e){for(var i=this.clone([t],!0),n=i._chunks,a=Math.floor(1/e),o=n[t],s=this.count(),l=new(ki(this._rawCount))(Math.ceil(s/a)*2),u=0,f=0;f<s;f+=a){var h=f,c=o[this.getRawIndex(h)],v=f,d=o[this.getRawIndex(v)],p=a;f+a>s&&(p=s-f);for(var g=0;g<p;g++){var y=this.getRawIndex(f+g),m=o[y];m<c&&(c=m,h=f+g),m>d&&(d=m,v=f+g)}var _=this.getRawIndex(h),S=this.getRawIndex(v);h<v?(l[u++]=_,l[u++]=S):(l[u++]=S,l[u++]=_)}return i._count=u,i._indices=l,i._updateGetRawIdx(),i},r.prototype.downSample=function(t,e,i,n){for(var a=this.clone([t],!0),o=a._chunks,s=[],l=Math.floor(1/e),u=o[t],f=this.count(),h=a._rawExtent[t]=Oi(),c=new(ki(this._rawCount))(Math.ceil(f/l)),v=0,d=0;d<f;d+=l){l>f-d&&(l=f-d,s.length=l);for(var p=0;p<l;p++){var g=this.getRawIndex(d+p);s[p]=u[g]}var y=i(s),m=this.getRawIndex(Math.min(d+n(s,y)||0,f-1));u[m]=y,y<h[0]&&(h[0]=y),y>h[1]&&(h[1]=y),c[v++]=m}return a._count=v,a._indices=c,a._updateGetRawIdx(),a},r.prototype.each=function(t,e){if(!!this._count)for(var i=t.length,n=this._chunks,a=0,o=this.count();a<o;a++){var s=this.getRawIndex(a);switch(i){case 0:e(a);break;case 1:e(n[t[0]][s],a);break;case 2:e(n[t[0]][s],n[t[1]][s],a);break;default:for(var l=0,u=[];l<i;l++)u[l]=n[t[l]][s];u[l]=a,e.apply(null,u)}}},r.prototype.getDataExtent=function(t){var e=this._chunks[t],i=Oi();if(!e)return i;var n=this.count(),a=!this._indices,o;if(a)return this._rawExtent[t].slice();if(o=this._extent[t],o)return o.slice();o=i;for(var s=o[0],l=o[1],u=0;u<n;u++){var f=this.getRawIndex(u),h=e[f];h<s&&(s=h),h>l&&(l=h)}return o=[s,l],this._extent[t]=o,o},r.prototype.getRawDataItem=function(t){var e=this.getRawIndex(t);if(this._provider.persistent)return this._provider.getItem(e);for(var i=[],n=this._chunks,a=0;a<n.length;a++)i.push(n[a][e]);return i},r.prototype.clone=function(t,e){var i=new r,n=this._chunks,a=t&&je(t,function(s,l){return s[l]=!0,s},{});if(a)for(var o=0;o<n.length;o++)i._chunks[o]=a[o]?qT(n[o]):n[o];else i._chunks=n;return this._copyCommonProps(i),e||(i._indices=this._cloneIndices()),i._updateGetRawIdx(),i},r.prototype._copyCommonProps=function(t){t._count=this._count,t._rawCount=this._rawCount,t._provider=this._provider,t._dimensions=this._dimensions,t._extent=et(this._extent),t._rawExtent=et(this._rawExtent)},r.prototype._cloneIndices=function(){if(this._indices){var t=this._indices.constructor,e=void 0;if(t===Array){var i=this._indices.length;e=new t(i);for(var n=0;n<i;n++)e[n]=this._indices[n]}else e=new t(this._indices);return e}return null},r.prototype._getRawIdxIdentity=function(t){return t},r.prototype._getRawIdx=function(t){return t<this._count&&t>=0?this._indices[t]:-1},r.prototype._updateGetRawIdx=function(){this.getRawIndex=this._indices?this._getRawIdx:this._getRawIdxIdentity},r.internalField=function(){function t(e,i,n,a){return No(e[a],this._dimensions[a])}Zl={arrayRows:t,objectRows:function(e,i,n,a){return No(e[i],this._dimensions[a])},keyedColumns:t,original:function(e,i,n,a){var o=e&&(e.value==null?e:e.value);return No(o instanceof Array?o[a]:o,this._dimensions[a])},typedArray:function(e,i,n,a){return e[a]}}}(),r}(),KT=function(){function r(t){this._sourceList=[],this._storeList=[],this._upstreamSignList=[],this._versionSignBase=0,this._dirty=!0,this._sourceHost=t}return r.prototype.dirty=function(){this._setLocalSource([],[]),this._storeList=[],this._dirty=!0},r.prototype._setLocalSource=function(t,e){this._sourceList=t,this._upstreamSignList=e,this._versionSignBase++,this._versionSignBase>9e10&&(this._versionSignBase=0)},r.prototype._getVersionSign=function(){return this._sourceHost.uid+"_"+this._versionSignBase},r.prototype.prepareSource=function(){this._isDirty()&&(this._createSource(),this._dirty=!1)},r.prototype._createSource=function(){this._setLocalSource([],[]);var t=this._sourceHost,e=this._getUpstreamSourceManagers(),i=!!e.length,n,a;if(io(t)){var o=t,s=void 0,l=void 0,u=void 0;if(i){var f=e[0];f.prepareSource(),u=f.getSource(),s=u.data,l=u.sourceFormat,a=[f._getVersionSign()]}else s=o.get("data",!0),l=jt(s)?Ar:me,a=[];var h=this._getSourceMetaRawOption()||{},c=u&&u.metaRawOption||{},v=j(h.seriesLayoutBy,c.seriesLayoutBy)||null,d=j(h.sourceHeader,c.sourceHeader),p=j(h.dimensions,c.dimensions),g=v!==c.seriesLayoutBy||!!d!=!!c.sourceHeader||p;n=g?[ff(s,{seriesLayoutBy:v,sourceHeader:d,dimensions:p},l)]:[]}else{var y=t;if(i){var m=this._applyTransform(e);n=m.sourceList,a=m.upstreamSignList}else{var _=y.get("source",!0);n=[ff(_,this._getSourceMetaRawOption(),null)],a=[]}}this._setLocalSource(n,a)},r.prototype._applyTransform=function(t){var e=this._sourceHost,i=e.get("transform",!0),n=e.get("fromTransformResult",!0);if(n!=null){var a="";t.length!==1&&Zc(a)}var o,s=[],l=[];return A(t,function(u){u.prepareSource();var f=u.getSource(n||0),h="";n!=null&&!f&&Zc(h),s.push(f),l.push(u._getVersionSign())}),i?o=YT(i,s,{datasetIndex:e.componentIndex}):n!=null&&(o=[DT(s[0])]),{sourceList:o,upstreamSignList:l}},r.prototype._isDirty=function(){if(this._dirty)return!0;for(var t=this._getUpstreamSourceManagers(),e=0;e<t.length;e++){var i=t[e];if(i._isDirty()||this._upstreamSignList[e]!==i._getVersionSign())return!0}},r.prototype.getSource=function(t){t=t||0;var e=this._sourceList[t];if(!e){var i=this._getUpstreamSourceManagers();return i[0]&&i[0].getSource(t)}return e},r.prototype.getSharedDataStore=function(t){var e=t.makeStoreSchema();return this._innerGetDataStore(e.dimensions,t.source,e.hash)},r.prototype._innerGetDataStore=function(t,e,i){var n=0,a=this._storeList,o=a[n];o||(o=a[n]={});var s=o[i];if(!s){var l=this._getUpstreamSourceManagers()[0];io(this._sourceHost)&&l?s=l._innerGetDataStore(t,e,i):(s=new hf,s.initData(new _m(e,t.length),t)),o[i]=s}return s},r.prototype._getUpstreamSourceManagers=function(){var t=this._sourceHost;if(io(t)){var e=_h(t);return e?[e.getSourceManager()]:[]}else return G(tT(t),function(i){return i.getSourceManager()})},r.prototype._getSourceMetaRawOption=function(){var t=this._sourceHost,e,i,n;if(io(t))e=t.get("seriesLayoutBy",!0),i=t.get("sourceHeader",!0),n=t.get("dimensions",!0);else if(!this._getUpstreamSourceManagers().length){var a=t;e=a.get("seriesLayoutBy",!0),i=a.get("sourceHeader",!0),n=a.get("dimensions",!0)}return{seriesLayoutBy:e,sourceHeader:i,dimensions:n}},r}();function io(r){return r.mainType==="series"}function Zc(r){throw new Error(r)}var QT="line-height:1";function Mm(r){var t=r.lineHeight;return t==null?QT:"line-height:"+Zt(t+"")+"px"}function Am(r,t){var e=r.color||"#6e7079",i=r.fontSize||12,n=r.fontWeight||"400",a=r.color||"#464646",o=r.fontSize||14,s=r.fontWeight||"900";return t==="html"?{nameStyle:"font-size:"+Zt(i+"")+"px;color:"+Zt(e)+";font-weight:"+Zt(n+""),valueStyle:"font-size:"+Zt(o+"")+"px;color:"+Zt(a)+";font-weight:"+Zt(s+"")}:{nameStyle:{fontSize:i,fill:e,fontWeight:n},valueStyle:{fontSize:o,fill:a,fontWeight:s}}}var JT=[0,10,20,30],jT=["",`
`,`

`,`


`];function di(r,t){return t.type=r,t}function vf(r){return r.type==="section"}function Dm(r){return vf(r)?tC:eC}function Lm(r){if(vf(r)){var t=0,e=r.blocks.length,i=e>1||e>0&&!r.noHeader;return A(r.blocks,function(n){var a=Lm(n);a>=t&&(t=a+ +(i&&(!a||vf(n)&&!n.noHeader)))}),t}return 0}function tC(r,t,e,i){var n=t.noHeader,a=rC(Lm(t)),o=[],s=t.blocks||[];tr(!s||V(s)),s=s||[];var l=r.orderMode;if(t.sortBlocks&&l){s=s.slice();var u={valueAsc:"asc",valueDesc:"desc"};if(Q(u,l)){var f=new NT(u[l],null);s.sort(function(p,g){return f.evaluate(p.sortParam,g.sortParam)})}else l==="seriesDesc"&&s.reverse()}A(s,function(p,g){var y=t.valueFormatter,m=Dm(p)(y?O(O({},r),{valueFormatter:y}):r,p,g>0?a.html:0,i);m!=null&&o.push(m)});var h=r.renderMode==="richText"?o.join(a.richText):cf(i,o.join(""),n?e:a.html);if(n)return h;var c=uf(t.header,"ordinal",r.useUTC),v=Am(i,r.renderMode).nameStyle,d=Mm(i);return r.renderMode==="richText"?Im(r,c,v)+a.richText+h:cf(i,'<div style="'+v+";"+d+';">'+Zt(c)+"</div>"+h,e)}function eC(r,t,e,i){var n=r.renderMode,a=t.noName,o=t.noValue,s=!t.markerType,l=t.name,u=r.useUTC,f=t.valueFormatter||r.valueFormatter||function(S){return S=V(S)?S:[S],G(S,function(x,w){return uf(x,V(v)?v[w]:v,u)})};if(!(a&&o)){var h=s?"":r.markupStyleCreator.makeTooltipMarker(t.markerType,t.markerColor||"#333",n),c=a?"":uf(l,"ordinal",u),v=t.valueType,d=o?[]:f(t.value,t.dataIndex),p=!s||!a,g=!s&&a,y=Am(i,n),m=y.nameStyle,_=y.valueStyle;return n==="richText"?(s?"":h)+(a?"":Im(r,c,m))+(o?"":aC(r,d,p,g,_)):cf(i,(s?"":h)+(a?"":iC(c,!s,m))+(o?"":nC(d,p,g,_)),e)}}function Xc(r,t,e,i,n,a){if(!!r){var o=Dm(r),s={useUTC:n,renderMode:e,orderMode:i,markupStyleCreator:t,valueFormatter:r.valueFormatter};return o(s,r,0,a)}}function rC(r){return{html:JT[r],richText:jT[r]}}function cf(r,t,e){var i='<div style="clear:both"></div>',n="margin: "+e+"px 0 0",a=Mm(r);return'<div style="'+n+";"+a+';">'+t+i+"</div>"}function iC(r,t,e){var i=t?"margin-left:2px":"";return'<span style="'+e+";"+i+'">'+Zt(r)+"</span>"}function nC(r,t,e,i){var n=e?"10px":"20px",a=t?"float:right;margin-left:"+n:"";return r=V(r)?r:[r],'<span style="'+a+";"+i+'">'+G(r,function(o){return Zt(o)}).join("&nbsp;&nbsp;")+"</span>"}function Im(r,t,e){return r.markupStyleCreator.wrapRichTextStyle(t,e)}function aC(r,t,e,i,n){var a=[n],o=i?10:20;return e&&a.push({padding:[0,0,0,o],align:"right"}),r.markupStyleCreator.wrapRichTextStyle(V(t)?t.join("  "):t,a)}function Pm(r,t){var e=r.getData().getItemVisual(t,"style"),i=e[r.visualDrawType];return hi(i)}function Rm(r,t){var e=r.get("padding");return e!=null?e:t==="richText"?[8,10]:10}var Xl=function(){function r(){this.richTextStyles={},this._nextStyleNameId=Fg()}return r.prototype._generateStyleName=function(){return"__EC_aUTo_"+this._nextStyleNameId++},r.prototype.makeTooltipMarker=function(t,e,i){var n=i==="richText"?this._generateStyleName():null,a=$b({color:e,type:t,renderMode:i,markerId:n});return W(a)?a:(this.richTextStyles[n]=a.style,a.content)},r.prototype.wrapRichTextStyle=function(t,e){var i={};V(e)?A(e,function(a){return O(i,a)}):O(i,e);var n=this._generateStyleName();return this.richTextStyles[n]=i,"{"+n+"|"+t+"}"},r}();function oC(r){var t=r.series,e=r.dataIndex,i=r.multipleSeries,n=t.getData(),a=n.mapDimensionsAll("defaultedTooltip"),o=a.length,s=t.getRawValue(e),l=V(s),u=Pm(t,e),f,h,c,v;if(o>1||l&&!o){var d=sC(s,t,e,a,u);f=d.inlineValues,h=d.inlineValueTypes,c=d.blocks,v=d.inlineValues[0]}else if(o){var p=n.getDimensionInfo(a[0]);v=f=an(n,e,a[0]),h=p.type}else v=f=l?s[0]:s;var g=th(t),y=g&&t.name||"",m=n.getName(e),_=i?y:m;return di("section",{header:y,noHeader:i||!g,sortParam:v,blocks:[di("nameValue",{markerType:"item",markerColor:u,name:_,noName:!Fe(_),value:f,valueType:h,dataIndex:e})].concat(c||[])})}function sC(r,t,e,i,n){var a=t.getData(),o=je(r,function(h,c,v){var d=a.getDimensionInfo(v);return h=h||d&&d.tooltip!==!1&&d.displayName!=null},!1),s=[],l=[],u=[];i.length?A(i,function(h){f(an(a,e,h),h)}):A(r,f);function f(h,c){var v=a.getDimensionInfo(c);!v||v.otherDims.tooltip===!1||(o?u.push(di("nameValue",{markerType:"subItem",markerColor:n,name:v.displayName,value:h,valueType:v.type})):(s.push(h),l.push(v.type)))}return{inlineValues:s,inlineValueTypes:l,blocks:u}}var hr=gt();function no(r,t){return r.getName(t)||r.getId(t)}var lC="__universalTransitionEnabled",Ys=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e._selectedDataIndicesMap={},e}return t.prototype.init=function(e,i,n){this.seriesIndex=this.componentIndex,this.dataTask=sa({count:fC,reset:hC}),this.dataTask.context={model:this},this.mergeDefaultAndTheme(e,n);var a=hr(this).sourceManager=new KT(this);a.prepareSource();var o=this.getInitialData(e,n);Kc(o,this),this.dataTask.context.data=o,hr(this).dataBeforeProcessed=o,qc(this),this._initSelectedMapFromData(o)},t.prototype.mergeDefaultAndTheme=function(e,i){var n=_a(this),a=n?Pa(e):{},o=this.subType;pt.hasClass(o)&&(o+="Series"),nt(e,i.getTheme().get(this.subType)),nt(e,this.getDefaultOption()),Ku(e,"label",["show"]),this.fillDataTextStyle(e.data),n&&ci(e,a,n)},t.prototype.mergeOption=function(e,i){e=nt(this.option,e,!0),this.fillDataTextStyle(e.data);var n=_a(this);n&&ci(this.option,e,n);var a=hr(this).sourceManager;a.dirty(),a.prepareSource();var o=this.getInitialData(e,i);Kc(o,this),this.dataTask.dirty(),this.dataTask.context.data=o,hr(this).dataBeforeProcessed=o,qc(this),this._initSelectedMapFromData(o)},t.prototype.fillDataTextStyle=function(e){if(e&&!jt(e))for(var i=["show"],n=0;n<e.length;n++)e[n]&&e[n].label&&Ku(e[n],"label",i)},t.prototype.getInitialData=function(e,i){},t.prototype.appendData=function(e){var i=this.getRawData();i.appendData(e.data)},t.prototype.getData=function(e){var i=df(this);if(i){var n=i.context.data;return e==null||!n.getLinkedData?n:n.getLinkedData(e)}else return hr(this).data},t.prototype.getAllData=function(){var e=this.getData();return e&&e.getLinkedDataAll?e.getLinkedDataAll():[{data:e}]},t.prototype.setData=function(e){var i=df(this);if(i){var n=i.context;n.outputData=e,i!==this.dataTask&&(n.data=e)}hr(this).data=e},t.prototype.getEncode=function(){var e=this.get("encode",!0);if(e)return Z(e)},t.prototype.getSourceManager=function(){return hr(this).sourceManager},t.prototype.getSource=function(){return this.getSourceManager().getSource()},t.prototype.getRawData=function(){return hr(this).dataBeforeProcessed},t.prototype.getColorBy=function(){var e=this.get("colorBy");return e||"series"},t.prototype.isColorBySeries=function(){return this.getColorBy()==="series"},t.prototype.getBaseAxis=function(){var e=this.coordinateSystem;return e&&e.getBaseAxis&&e.getBaseAxis()},t.prototype.formatTooltip=function(e,i,n){return oC({series:this,dataIndex:e,multipleSeries:i})},t.prototype.isAnimationEnabled=function(){var e=this.ecModel;if(tt.node&&!(e&&e.ssr))return!1;var i=this.getShallow("animation");return i&&this.getData().count()>this.getShallow("animationThreshold")&&(i=!1),!!i},t.prototype.restoreData=function(){this.dataTask.dirty()},t.prototype.getColorFromPalette=function(e,i,n){var a=this.ecModel,o=Sh.prototype.getColorFromPalette.call(this,e,i,n);return o||(o=a.getColorFromPalette(e,i,n)),o},t.prototype.coordDimToDataDim=function(e){return this.getRawData().mapDimensionsAll(e)},t.prototype.getProgressive=function(){return this.get("progressive")},t.prototype.getProgressiveThreshold=function(){return this.get("progressiveThreshold")},t.prototype.select=function(e,i){this._innerSelect(this.getData(i),e)},t.prototype.unselect=function(e,i){var n=this.option.selectedMap;if(!!n){var a=this.option.selectedMode,o=this.getData(i);if(a==="series"||n==="all"){this.option.selectedMap={},this._selectedDataIndicesMap={};return}for(var s=0;s<e.length;s++){var l=e[s],u=no(o,l);n[u]=!1,this._selectedDataIndicesMap[u]=-1}}},t.prototype.toggleSelect=function(e,i){for(var n=[],a=0;a<e.length;a++)n[0]=e[a],this.isSelected(e[a],i)?this.unselect(n,i):this.select(n,i)},t.prototype.getSelectedDataIndices=function(){if(this.option.selectedMap==="all")return[].slice.call(this.getData().getIndices());for(var e=this._selectedDataIndicesMap,i=vt(e),n=[],a=0;a<i.length;a++){var o=e[i[a]];o>=0&&n.push(o)}return n},t.prototype.isSelected=function(e,i){var n=this.option.selectedMap;if(!n)return!1;var a=this.getData(i);return(n==="all"||n[no(a,e)])&&!a.getItemModel(e).get(["select","disabled"])},t.prototype.isUniversalTransitionEnabled=function(){if(this[lC])return!0;var e=this.option.universalTransition;return e?e===!0?!0:e&&e.enabled:!1},t.prototype._innerSelect=function(e,i){var n,a,o=this.option,s=o.selectedMode,l=i.length;if(!(!s||!l)){if(s==="series")o.selectedMap="all";else if(s==="multiple"){Y(o.selectedMap)||(o.selectedMap={});for(var u=o.selectedMap,f=0;f<l;f++){var h=i[f],c=no(e,h);u[c]=!0,this._selectedDataIndicesMap[c]=e.getRawIndex(h)}}else if(s==="single"||s===!0){var v=i[l-1],c=no(e,v);o.selectedMap=(n={},n[c]=!0,n),this._selectedDataIndicesMap=(a={},a[c]=e.getRawIndex(v),a)}}},t.prototype._initSelectedMapFromData=function(e){if(!this.option.selectedMap){var i=[];e.hasItemOption&&e.each(function(n){var a=e.getRawDataItem(n);a&&a.selected&&i.push(n)}),i.length>0&&this._innerSelect(e,i)}},t.registerClass=function(e){return pt.registerClass(e)},t.protoInitialize=function(){var e=t.prototype;e.type="series.__base__",e.seriesIndex=0,e.ignoreStyleOnData=!1,e.hasSymbolVisual=!1,e.defaultSymbol="circle",e.visualStyleAccessPath="itemStyle",e.visualDrawType="fill"}(),t}(pt);Me(Ys,OT);Me(Ys,Sh);$g(Ys,pt);function qc(r){var t=r.name;th(r)||(r.name=uC(r)||t)}function uC(r){var t=r.getRawData(),e=t.mapDimensionsAll("seriesName"),i=[];return A(e,function(n){var a=t.getDimensionInfo(n);a.displayName&&i.push(a.displayName)}),i.join(" ")}function fC(r){return r.model.getRawData().count()}function hC(r){var t=r.model;return t.setData(t.getRawData().cloneShallow()),vC}function vC(r,t){t.outputData&&r.end>t.outputData.count()&&t.model.getRawData().cloneShallow(t.outputData)}function Kc(r,t){A(g1(r.CHANGABLE_METHODS,r.DOWNSAMPLE_METHODS),function(e){r.wrapMethod(e,yt(cC,t))})}function cC(r,t){var e=df(r);return e&&e.setOutputEnd((t||this).count()),t}function df(r){var t=(r.ecModel||{}).scheduler,e=t&&t.getPipeline(r.uid);if(e){var i=e.currentTask;if(i){var n=i.agentStubMap;n&&(i=n.get(r.uid))}return i}}const rr=Ys;var Mh=function(){function r(){this.group=new xt,this.uid=Os("viewComponent")}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,i,n){},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,i,n){},r.prototype.updateLayout=function(t,e,i,n){},r.prototype.updateVisual=function(t,e,i,n){},r.prototype.toggleBlurSeries=function(t,e,i){},r.prototype.eachRendered=function(t){var e=this.group;e&&e.traverse(t)},r}();rh(Mh);Cs(Mh);const Ce=Mh;function Ah(){var r=gt();return function(t){var e=r(t),i=t.pipelineContext,n=!!e.large,a=!!e.progressiveRender,o=e.large=!!(i&&i.large),s=e.progressiveRender=!!(i&&i.progressiveRender);return(n!==o||a!==s)&&"reset"}}var Em=gt(),dC=Ah(),Dh=function(){function r(){this.group=new xt,this.uid=Os("viewChart"),this.renderTask=sa({plan:pC,reset:gC}),this.renderTask.context={view:this}}return r.prototype.init=function(t,e){},r.prototype.render=function(t,e,i,n){},r.prototype.highlight=function(t,e,i,n){var a=t.getData(n&&n.dataType);!a||Jc(a,n,"emphasis")},r.prototype.downplay=function(t,e,i,n){var a=t.getData(n&&n.dataType);!a||Jc(a,n,"normal")},r.prototype.remove=function(t,e){this.group.removeAll()},r.prototype.dispose=function(t,e){},r.prototype.updateView=function(t,e,i,n){this.render(t,e,i,n)},r.prototype.updateLayout=function(t,e,i,n){this.render(t,e,i,n)},r.prototype.updateVisual=function(t,e,i,n){this.render(t,e,i,n)},r.prototype.eachRendered=function(t){Rs(this.group,t)},r.markUpdateMethod=function(t,e){Em(t).updateMethod=e},r.protoInitialize=function(){var t=r.prototype;t.type="chart"}(),r}();function Qc(r,t,e){r&&nf(r)&&(t==="emphasis"?ts:es)(r,e)}function Jc(r,t,e){var i=li(r,t),n=t&&t.highlightKey!=null?Lx(t.highlightKey):null;i!=null?A(At(i),function(a){Qc(r.getItemGraphicEl(a),e,n)}):r.eachItemGraphicEl(function(a){Qc(a,e,n)})}rh(Dh);Cs(Dh);function pC(r){return dC(r.model)}function gC(r){var t=r.model,e=r.ecModel,i=r.api,n=r.payload,a=t.pipelineContext.progressiveRender,o=r.view,s=n&&Em(n).updateMethod,l=a?"incrementalPrepareRender":s&&o[s]?s:"render";return l!=="render"&&o[l](t,e,i,n),yC[l]}var yC={incrementalPrepareRender:{progress:function(r,t){t.view.incrementalRender(r,t.model,t.ecModel,t.api,t.payload)}},render:{forceFirstProgress:!0,progress:function(r,t){t.view.render(t.model,t.ecModel,t.api,t.payload)}}};const Te=Dh;var us="\0__throttleOriginMethod",jc="\0__throttleRate",td="\0__throttleType";function $s(r,t,e){var i,n=0,a=0,o=null,s,l,u,f;t=t||0;function h(){a=new Date().getTime(),o=null,r.apply(l,u||[])}var c=function(){for(var v=[],d=0;d<arguments.length;d++)v[d]=arguments[d];i=new Date().getTime(),l=this,u=v;var p=f||t,g=f||e;f=null,s=i-(g?n:a)-p,clearTimeout(o),g?o=setTimeout(h,p):s>=0?h():o=setTimeout(h,-s),n=i};return c.clear=function(){o&&(clearTimeout(o),o=null)},c.debounceNextCall=function(v){f=v},c}function Zs(r,t,e,i){var n=r[t];if(!!n){var a=n[us]||n,o=n[td],s=n[jc];if(s!==e||o!==i){if(e==null||!i)return r[t]=a;n=r[t]=$s(a,e,i==="debounce"),n[us]=a,n[td]=i,n[jc]=e}return n}}function fs(r,t){var e=r[t];e&&e[us]&&(e.clear&&e.clear(),r[t]=e[us])}var ed=gt(),rd={itemStyle:da(Uy,!0),lineStyle:da(Wy,!0)},mC={lineStyle:"stroke",itemStyle:"fill"};function km(r,t){var e=r.visualStyleMapper||rd[t];return e||(console.warn("Unknown style type '"+t+"'."),rd.itemStyle)}function Om(r,t){var e=r.visualDrawType||mC[t];return e||(console.warn("Unknown style type '"+t+"'."),"fill")}var _C={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData(),i=r.visualStyleAccessPath||"itemStyle",n=r.getModel(i),a=km(r,i),o=a(n),s=n.getShallow("decal");s&&(e.setVisual("decal",s),s.dirty=!0);var l=Om(r,i),u=o[l],f=K(u)?u:null,h=o.fill==="auto"||o.stroke==="auto";if(!o[l]||f||h){var c=r.getColorFromPalette(r.name,null,t.getSeriesCount());o[l]||(o[l]=c,e.setVisual("colorFromPalette",!0)),o.fill=o.fill==="auto"||K(o.fill)?c:o.fill,o.stroke=o.stroke==="auto"||K(o.stroke)?c:o.stroke}if(e.setVisual("style",o),e.setVisual("drawType",l),!t.isSeriesFiltered(r)&&f)return e.setVisual("colorFromPalette",!1),{dataEach:function(v,d){var p=r.getDataParams(d),g=O({},o);g[l]=f(p),v.setItemVisual(d,"style",g)}}}},Mn=new kt,SC={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!(r.ignoreStyleOnData||t.isSeriesFiltered(r))){var e=r.getData(),i=r.visualStyleAccessPath||"itemStyle",n=km(r,i),a=e.getVisual("drawType");return{dataEach:e.hasItemOption?function(o,s){var l=o.getRawDataItem(s);if(l&&l[i]){Mn.option=l[i];var u=n(Mn),f=o.ensureUniqueItemVisual(s,"style");O(f,u),Mn.option.decal&&(o.setItemVisual(s,"decal",Mn.option.decal),Mn.option.decal.dirty=!0),a in u&&o.setItemVisual(s,"colorFromPalette",!1)}}:null}}}},wC={performRawSeries:!0,overallReset:function(r){var t=Z();r.eachSeries(function(e){var i=e.getColorBy();if(!e.isColorBySeries()){var n=e.type+"-"+i,a=t.get(n);a||(a={},t.set(n,a)),ed(e).scope=a}}),r.eachSeries(function(e){if(!(e.isColorBySeries()||r.isSeriesFiltered(e))){var i=e.getRawData(),n={},a=e.getData(),o=ed(e).scope,s=e.visualStyleAccessPath||"itemStyle",l=Om(e,s);a.each(function(u){var f=a.getRawIndex(u);n[f]=u}),i.each(function(u){var f=n[u],h=a.getItemVisual(f,"colorFromPalette");if(h){var c=a.ensureUniqueItemVisual(f,"style"),v=i.getName(u)||u+"",d=i.count();c[l]=e.getColorFromPalette(v,o,d)}})}})}},ao=Math.PI;function xC(r,t){t=t||{},rt(t,{text:"loading",textColor:"#000",fontSize:12,fontWeight:"normal",fontStyle:"normal",fontFamily:"sans-serif",maskColor:"rgba(255, 255, 255, 0.8)",showSpinner:!0,color:"#5470c6",spinnerRadius:10,lineWidth:5,zlevel:0});var e=new xt,i=new _t({style:{fill:t.maskColor},zlevel:t.zlevel,z:1e4});e.add(i);var n=new Dt({style:{text:t.text,fill:t.textColor,fontSize:t.fontSize,fontWeight:t.fontWeight,fontStyle:t.fontStyle,fontFamily:t.fontFamily},zlevel:t.zlevel,z:10001}),a=new _t({style:{fill:"none"},textContent:n,textConfig:{position:"right",distance:10},zlevel:t.zlevel,z:10001});e.add(a);var o;return t.showSpinner&&(o=new lh({shape:{startAngle:-ao/2,endAngle:-ao/2+.1,r:t.spinnerRadius},style:{stroke:t.color,lineCap:"round",lineWidth:t.lineWidth},zlevel:t.zlevel,z:10001}),o.animateShape(!0).when(1e3,{endAngle:ao*3/2}).start("circularInOut"),o.animateShape(!0).when(1e3,{startAngle:ao*3/2}).delay(300).start("circularInOut"),e.add(o)),e.resize=function(){var s=n.getBoundingRect().width,l=t.showSpinner?t.spinnerRadius:0,u=(r.getWidth()-l*2-(t.showSpinner&&s?10:0)-s)/2-(t.showSpinner&&s?0:5+s/2)+(t.showSpinner?0:s/2)+(s?0:l),f=r.getHeight()/2;t.showSpinner&&o.setShape({cx:u,cy:f}),a.setShape({x:u-l,y:f-l,width:l*2,height:l*2}),i.setShape({x:0,y:0,width:r.getWidth(),height:r.getHeight()})},e.resize(),e}var bC=function(){function r(t,e,i,n){this._stageTaskMap=Z(),this.ecInstance=t,this.api=e,i=this._dataProcessorHandlers=i.slice(),n=this._visualHandlers=n.slice(),this._allHandlers=i.concat(n)}return r.prototype.restoreData=function(t,e){t.restoreData(e),this._stageTaskMap.each(function(i){var n=i.overallTask;n&&n.dirty()})},r.prototype.getPerformArgs=function(t,e){if(!!t.__pipeline){var i=this._pipelineMap.get(t.__pipeline.id),n=i.context,a=!e&&i.progressiveEnabled&&(!n||n.progressiveRender)&&t.__idxInPipeline>i.blockIndex,o=a?i.step:null,s=n&&n.modDataCount,l=s!=null?Math.ceil(s/o):null;return{step:o,modBy:l,modDataCount:s}}},r.prototype.getPipeline=function(t){return this._pipelineMap.get(t)},r.prototype.updateStreamModes=function(t,e){var i=this._pipelineMap.get(t.uid),n=t.getData(),a=n.count(),o=i.progressiveEnabled&&e.incrementalPrepareRender&&a>=i.threshold,s=t.get("large")&&a>=t.get("largeThreshold"),l=t.get("progressiveChunkMode")==="mod"?a:null;t.pipelineContext=i.context={progressiveRender:o,modDataCount:l,large:s}},r.prototype.restorePipelines=function(t){var e=this,i=e._pipelineMap=Z();t.eachSeries(function(n){var a=n.getProgressive(),o=n.uid;i.set(o,{id:o,head:null,tail:null,threshold:n.getProgressiveThreshold(),progressiveEnabled:a&&!(n.preventIncremental&&n.preventIncremental()),blockIndex:-1,step:Math.round(a||700),count:0}),e._pipe(n,n.dataTask)})},r.prototype.prepareStageTasks=function(){var t=this._stageTaskMap,e=this.api.getModel(),i=this.api;A(this._allHandlers,function(n){var a=t.get(n.uid)||t.set(n.uid,{}),o="";tr(!(n.reset&&n.overallReset),o),n.reset&&this._createSeriesStageTask(n,a,e,i),n.overallReset&&this._createOverallStageTask(n,a,e,i)},this)},r.prototype.prepareView=function(t,e,i,n){var a=t.renderTask,o=a.context;o.model=e,o.ecModel=i,o.api=n,a.__block=!t.incrementalPrepareRender,this._pipe(e,a)},r.prototype.performDataProcessorTasks=function(t,e){this._performStageTasks(this._dataProcessorHandlers,t,e,{block:!0})},r.prototype.performVisualTasks=function(t,e,i){this._performStageTasks(this._visualHandlers,t,e,i)},r.prototype._performStageTasks=function(t,e,i,n){n=n||{};var a=!1,o=this;A(t,function(l,u){if(!(n.visualType&&n.visualType!==l.visualType)){var f=o._stageTaskMap.get(l.uid),h=f.seriesTaskMap,c=f.overallTask;if(c){var v,d=c.agentStubMap;d.each(function(g){s(n,g)&&(g.dirty(),v=!0)}),v&&c.dirty(),o.updatePayload(c,i);var p=o.getPerformArgs(c,n.block);d.each(function(g){g.perform(p)}),c.perform(p)&&(a=!0)}else h&&h.each(function(g,y){s(n,g)&&g.dirty();var m=o.getPerformArgs(g,n.block);m.skip=!l.performRawSeries&&e.isSeriesFiltered(g.context.model),o.updatePayload(g,i),g.perform(m)&&(a=!0)})}});function s(l,u){return l.setDirty&&(!l.dirtyMap||l.dirtyMap.get(u.__pipeline.id))}this.unfinished=a||this.unfinished},r.prototype.performSeriesTasks=function(t){var e;t.eachSeries(function(i){e=i.dataTask.perform()||e}),this.unfinished=e||this.unfinished},r.prototype.plan=function(){this._pipelineMap.each(function(t){var e=t.tail;do{if(e.__block){t.blockIndex=e.__idxInPipeline;break}e=e.getUpstream()}while(e)})},r.prototype.updatePayload=function(t,e){e!=="remain"&&(t.context.payload=e)},r.prototype._createSeriesStageTask=function(t,e,i,n){var a=this,o=e.seriesTaskMap,s=e.seriesTaskMap=Z(),l=t.seriesType,u=t.getTargetSeries;t.createOnAllSeries?i.eachRawSeries(f):l?i.eachRawSeriesByType(l,f):u&&u(i,n).each(f);function f(h){var c=h.uid,v=s.set(c,o&&o.get(c)||sa({plan:DC,reset:LC,count:PC}));v.context={model:h,ecModel:i,api:n,useClearVisual:t.isVisual&&!t.isLayout,plan:t.plan,reset:t.reset,scheduler:a},a._pipe(h,v)}},r.prototype._createOverallStageTask=function(t,e,i,n){var a=this,o=e.overallTask=e.overallTask||sa({reset:TC});o.context={ecModel:i,api:n,overallReset:t.overallReset,scheduler:a};var s=o.agentStubMap,l=o.agentStubMap=Z(),u=t.seriesType,f=t.getTargetSeries,h=!0,c=!1,v="";tr(!t.createOnAllSeries,v),u?i.eachRawSeriesByType(u,d):f?f(i,n).each(d):(h=!1,A(i.getSeries(),d));function d(p){var g=p.uid,y=l.set(g,s&&s.get(g)||(c=!0,sa({reset:CC,onDirty:AC})));y.context={model:p,overallProgress:h},y.agent=o,y.__block=h,a._pipe(p,y)}c&&o.dirty()},r.prototype._pipe=function(t,e){var i=t.uid,n=this._pipelineMap.get(i);!n.head&&(n.head=e),n.tail&&n.tail.pipe(e),n.tail=e,e.__idxInPipeline=n.count++,e.__pipeline=n},r.wrapStageHandler=function(t,e){return K(t)&&(t={overallReset:t,seriesType:RC(t)}),t.uid=Os("stageHandler"),e&&(t.visualType=e),t},r}();function TC(r){r.overallReset(r.ecModel,r.api,r.payload)}function CC(r){return r.overallProgress&&MC}function MC(){this.agent.dirty(),this.getDownstream().dirty()}function AC(){this.agent&&this.agent.dirty()}function DC(r){return r.plan?r.plan(r.model,r.ecModel,r.api,r.payload):null}function LC(r){r.useClearVisual&&r.data.clearAllVisual();var t=r.resetDefines=At(r.reset(r.model,r.ecModel,r.api,r.payload));return t.length>1?G(t,function(e,i){return Bm(i)}):IC}var IC=Bm(0);function Bm(r){return function(t,e){var i=e.data,n=e.resetDefines[r];if(n&&n.dataEach)for(var a=t.start;a<t.end;a++)n.dataEach(i,a);else n&&n.progress&&n.progress(t,i)}}function PC(r){return r.data.count()}function RC(r){hs=null;try{r(wa,Nm)}catch{}return hs}var wa={},Nm={},hs;zm(wa,cm);zm(Nm,dm);wa.eachSeriesByType=wa.eachRawSeriesByType=function(r){hs=r};wa.eachComponent=function(r){r.mainType==="series"&&r.subType&&(hs=r.subType)};function zm(r,t){for(var e in t.prototype)r[e]=Gt}const Fm=bC;var id=["#37A2DA","#32C5E9","#67E0E3","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#E062AE","#E690D1","#e7bcf3","#9d96f5","#8378EA","#96BFFF"];const EC={color:id,colorLayer:[["#37A2DA","#ffd85c","#fd7b5f"],["#37A2DA","#67E0E3","#FFDB5C","#ff9f7f","#E062AE","#9d96f5"],["#37A2DA","#32C5E9","#9FE6B8","#FFDB5C","#ff9f7f","#fb7293","#e7bcf3","#8378EA","#96BFFF"],id]};var Nt="#B9B8CE",nd="#100C2A",oo=function(){return{axisLine:{lineStyle:{color:Nt}},splitLine:{lineStyle:{color:"#484753"}},splitArea:{areaStyle:{color:["rgba(255,255,255,0.02)","rgba(255,255,255,0.05)"]}},minorSplitLine:{lineStyle:{color:"#20203B"}}}},ad=["#4992ff","#7cffb2","#fddd60","#ff6e76","#58d9f9","#05c091","#ff8a45","#8d48e3","#dd79ff"],Vm={darkMode:!0,color:ad,backgroundColor:nd,axisPointer:{lineStyle:{color:"#817f91"},crossStyle:{color:"#817f91"},label:{color:"#fff"}},legend:{textStyle:{color:Nt},pageTextStyle:{color:Nt}},textStyle:{color:Nt},title:{textStyle:{color:"#EEF1FA"},subtextStyle:{color:"#B9B8CE"}},toolbox:{iconStyle:{borderColor:Nt}},dataZoom:{borderColor:"#71708A",textStyle:{color:Nt},brushStyle:{color:"rgba(135,163,206,0.3)"},handleStyle:{color:"#353450",borderColor:"#C5CBE3"},moveHandleStyle:{color:"#B0B6C3",opacity:.3},fillerColor:"rgba(135,163,206,0.2)",emphasis:{handleStyle:{borderColor:"#91B7F2",color:"#4D587D"},moveHandleStyle:{color:"#636D9A",opacity:.7}},dataBackground:{lineStyle:{color:"#71708A",width:1},areaStyle:{color:"#71708A"}},selectedDataBackground:{lineStyle:{color:"#87A3CE"},areaStyle:{color:"#87A3CE"}}},visualMap:{textStyle:{color:Nt}},timeline:{lineStyle:{color:Nt},label:{color:Nt},controlStyle:{color:Nt,borderColor:Nt}},calendar:{itemStyle:{color:nd},dayLabel:{color:Nt},monthLabel:{color:Nt},yearLabel:{color:Nt}},timeAxis:oo(),logAxis:oo(),valueAxis:oo(),categoryAxis:oo(),line:{symbol:"circle"},graph:{color:ad},gauge:{title:{color:Nt},axisLine:{lineStyle:{color:[[1,"rgba(207,212,219,0.2)"]]}},axisLabel:{color:Nt},detail:{color:"#EEF1FA"}},candlestick:{itemStyle:{color:"#f64e56",color0:"#54ea92",borderColor:"#f64e56",borderColor0:"#54ea92"}}};Vm.categoryAxis.splitLine.show=!1;const kC=Vm;var OC=function(){function r(){}return r.prototype.normalizeQuery=function(t){var e={},i={},n={};if(W(t)){var a=Ve(t);e.mainType=a.main||null,e.subType=a.sub||null}else{var o=["Index","Name","Id"],s={name:1,dataIndex:1,dataType:1};A(t,function(l,u){for(var f=!1,h=0;h<o.length;h++){var c=o[h],v=u.lastIndexOf(c);if(v>0&&v===u.length-c.length){var d=u.slice(0,v);d!=="data"&&(e.mainType=d,e[c.toLowerCase()]=l,f=!0)}}s.hasOwnProperty(u)&&(i[u]=l,f=!0),f||(n[u]=l)})}return{cptQuery:e,dataQuery:i,otherQuery:n}},r.prototype.filter=function(t,e){var i=this.eventInfo;if(!i)return!0;var n=i.targetEl,a=i.packedEvent,o=i.model,s=i.view;if(!o||!s)return!0;var l=e.cptQuery,u=e.dataQuery;return f(l,o,"mainType")&&f(l,o,"subType")&&f(l,o,"index","componentIndex")&&f(l,o,"name")&&f(l,o,"id")&&f(u,a,"name")&&f(u,a,"dataIndex")&&f(u,a,"dataType")&&(!s.filterForExposedEvent||s.filterForExposedEvent(t,e.otherQuery,n,a));function f(h,c,v,d){return h[v]==null||c[d||v]===h[v]}},r.prototype.afterTrigger=function(){this.eventInfo=null},r}(),pf=["symbol","symbolSize","symbolRotate","symbolOffset"],od=pf.concat(["symbolKeepAspect"]),BC={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){var e=r.getData();if(r.legendIcon&&e.setVisual("legendIcon",r.legendIcon),!r.hasSymbolVisual)return;for(var i={},n={},a=!1,o=0;o<pf.length;o++){var s=pf[o],l=r.get(s);K(l)?(a=!0,n[s]=l):i[s]=l}if(i.symbol=i.symbol||r.defaultSymbol,e.setVisual(O({legendIcon:r.legendIcon||i.symbol,symbolKeepAspect:r.get("symbolKeepAspect")},i)),t.isSeriesFiltered(r))return;var u=vt(n);function f(h,c){for(var v=r.getRawValue(c),d=r.getDataParams(c),p=0;p<u.length;p++){var g=u[p];h.setItemVisual(c,g,n[g](v,d))}}return{dataEach:a?f:null}}},NC={createOnAllSeries:!0,performRawSeries:!0,reset:function(r,t){if(!r.hasSymbolVisual||t.isSeriesFiltered(r))return;var e=r.getData();function i(n,a){for(var o=n.getItemModel(a),s=0;s<od.length;s++){var l=od[s],u=o.getShallow(l,!0);u!=null&&n.setItemVisual(a,l,u)}}return{dataEach:e.hasItemOption?i:null}}};function zC(r,t,e){switch(e){case"color":var i=r.getItemVisual(t,"style");return i[r.getVisual("drawType")];case"opacity":return r.getItemVisual(t,"style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getItemVisual(t,e)}}function FC(r,t){switch(t){case"color":var e=r.getVisual("style");return e[r.getVisual("drawType")];case"opacity":return r.getVisual("style").opacity;case"symbol":case"symbolSize":case"liftZ":return r.getVisual(t)}}function VC(r,t){function e(i,n){var a=[];return i.eachComponent({mainType:"series",subType:r,query:n},function(o){a.push(o.seriesIndex)}),a}A([[r+"ToggleSelect","toggleSelect"],[r+"Select","select"],[r+"UnSelect","unselect"]],function(i){t(i[0],function(n,a,o){n=O({},n),o.dispatchAction(O(n,{type:i[1],seriesIndex:e(a,n)}))})})}function Bi(r,t,e,i,n){var a=r+t;e.isSilent(a)||i.eachComponent({mainType:"series",subType:"pie"},function(o){for(var s=o.seriesIndex,l=o.option.selectedMap,u=n.selected,f=0;f<u.length;f++)if(u[f].seriesIndex===s){var h=o.getData(),c=li(h,n.fromActionPayload);e.trigger(a,{type:a,seriesId:o.id,name:V(c)?h.getName(c[0]):h.getName(c),selected:W(l)?l:O({},l)})}})}function HC(r,t,e){r.on("selectchanged",function(i){var n=e.getModel();i.isFromClick?(Bi("map","selectchanged",t,n,i),Bi("pie","selectchanged",t,n,i)):i.fromAction==="select"?(Bi("map","selected",t,n,i),Bi("pie","selected",t,n,i)):i.fromAction==="unselect"&&(Bi("map","unselected",t,n,i),Bi("pie","unselected",t,n,i))})}function Xn(r,t,e){for(var i;r&&!(t(r)&&(i=r,e));)r=r.__hostTarget||r.parent;return i}var GC=Math.round(Math.random()*9),WC=typeof Object.defineProperty=="function",UC=function(){function r(){this._id="__ec_inner_"+GC++}return r.prototype.get=function(t){return this._guard(t)[this._id]},r.prototype.set=function(t,e){var i=this._guard(t);return WC?Object.defineProperty(i,this._id,{value:e,enumerable:!1,configurable:!0}):i[this._id]=e,this},r.prototype.delete=function(t){return this.has(t)?(delete this._guard(t)[this._id],!0):!1},r.prototype.has=function(t){return!!this._guard(t)[this._id]},r.prototype._guard=function(t){if(t!==Object(t))throw TypeError("Value of WeakMap is not a non-null object.");return t},r}();const YC=UC;var $C=ct.extend({type:"triangle",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,i=t.cy,n=t.width/2,a=t.height/2;r.moveTo(e,i-a),r.lineTo(e+n,i+a),r.lineTo(e-n,i+a),r.closePath()}}),ZC=ct.extend({type:"diamond",shape:{cx:0,cy:0,width:0,height:0},buildPath:function(r,t){var e=t.cx,i=t.cy,n=t.width/2,a=t.height/2;r.moveTo(e,i-a),r.lineTo(e+n,i),r.lineTo(e,i+a),r.lineTo(e-n,i),r.closePath()}}),XC=ct.extend({type:"pin",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.x,i=t.y,n=t.width/5*3,a=Math.max(n,t.height),o=n/2,s=o*o/(a-o),l=i-a+o+s,u=Math.asin(s/o),f=Math.cos(u)*o,h=Math.sin(u),c=Math.cos(u),v=o*.6,d=o*.7;r.moveTo(e-f,l+s),r.arc(e,l,o,Math.PI-u,Math.PI*2+u),r.bezierCurveTo(e+f-h*v,l+s+c*v,e,i-d,e,i),r.bezierCurveTo(e,i-d,e-f+h*v,l+s+c*v,e-f,l+s),r.closePath()}}),qC=ct.extend({type:"arrow",shape:{x:0,y:0,width:0,height:0},buildPath:function(r,t){var e=t.height,i=t.width,n=t.x,a=t.y,o=i/3*2;r.moveTo(n,a),r.lineTo(n+o,a+e),r.lineTo(n,a+e/4*3),r.lineTo(n-o,a+e),r.lineTo(n,a),r.closePath()}}),KC={line:ui,rect:_t,roundRect:_t,square:_t,circle:Ps,diamond:ZC,pin:XC,arrow:qC,triangle:$C},QC={line:function(r,t,e,i,n){n.x1=r,n.y1=t+i/2,n.x2=r+e,n.y2=t+i/2},rect:function(r,t,e,i,n){n.x=r,n.y=t,n.width=e,n.height=i},roundRect:function(r,t,e,i,n){n.x=r,n.y=t,n.width=e,n.height=i,n.r=Math.min(e,i)/4},square:function(r,t,e,i,n){var a=Math.min(e,i);n.x=r,n.y=t,n.width=a,n.height=a},circle:function(r,t,e,i,n){n.cx=r+e/2,n.cy=t+i/2,n.r=Math.min(e,i)/2},diamond:function(r,t,e,i,n){n.cx=r+e/2,n.cy=t+i/2,n.width=e,n.height=i},pin:function(r,t,e,i,n){n.x=r+e/2,n.y=t+i/2,n.width=e,n.height=i},arrow:function(r,t,e,i,n){n.x=r+e/2,n.y=t+i/2,n.width=e,n.height=i},triangle:function(r,t,e,i,n){n.cx=r+e/2,n.cy=t+i/2,n.width=e,n.height=i}},vs={};A(KC,function(r,t){vs[t]=new r});var JC=ct.extend({type:"symbol",shape:{symbolType:"",x:0,y:0,width:0,height:0},calculateTextPosition:function(r,t,e){var i=Ko(r,t,e),n=this.shape;return n&&n.symbolType==="pin"&&t.position==="inside"&&(i.y=e.y+e.height*.4),i},buildPath:function(r,t,e){var i=t.symbolType;if(i!=="none"){var n=vs[i];n||(i="rect",n=vs[i]),QC[i](t.x,t.y,t.width,t.height,n.shape),n.buildPath(r,n.shape,e)}}});function jC(r,t){if(this.type!=="image"){var e=this.style;this.__isEmptyBrush?(e.stroke=r,e.fill=t||"#fff",e.lineWidth=2):this.shape.symbolType==="line"?e.stroke=r:e.fill=r,this.markRedraw()}}function ir(r,t,e,i,n,a,o){var s=r.indexOf("empty")===0;s&&(r=r.substr(5,1).toLowerCase()+r.substr(6));var l;return r.indexOf("image://")===0?l=Oy(r.slice(8),new ut(t,e,i,n),o?"center":"cover"):r.indexOf("path://")===0?l=hh(r.slice(7),{},new ut(t,e,i,n),o?"center":"cover"):l=new JC({shape:{symbolType:r,x:t,y:e,width:i,height:n}}),l.__isEmptyBrush=s,l.setColor=jC,a&&l.setColor(a),l}function Hm(r){return V(r)||(r=[+r,+r]),[r[0]||0,r[1]||0]}function Gm(r,t){if(r!=null)return V(r)||(r=[r,r]),[st(r[0],t[0])||0,st(j(r[1],r[0]),t[1])||0]}function ti(r){return isFinite(r)}function tM(r,t,e){var i=t.x==null?0:t.x,n=t.x2==null?1:t.x2,a=t.y==null?0:t.y,o=t.y2==null?0:t.y2;t.global||(i=i*e.width+e.x,n=n*e.width+e.x,a=a*e.height+e.y,o=o*e.height+e.y),i=ti(i)?i:0,n=ti(n)?n:1,a=ti(a)?a:0,o=ti(o)?o:0;var s=r.createLinearGradient(i,a,n,o);return s}function eM(r,t,e){var i=e.width,n=e.height,a=Math.min(i,n),o=t.x==null?.5:t.x,s=t.y==null?.5:t.y,l=t.r==null?.5:t.r;t.global||(o=o*i+e.x,s=s*n+e.y,l=l*a),o=ti(o)?o:.5,s=ti(s)?s:.5,l=l>=0&&ti(l)?l:.5;var u=r.createRadialGradient(o,s,0,o,s,l);return u}function gf(r,t,e){for(var i=t.type==="radial"?eM(r,t,e):tM(r,t,e),n=t.colorStops,a=0;a<n.length;a++)i.addColorStop(n[a].offset,n[a].color);return i}function rM(r,t){if(r===t||!r&&!t)return!1;if(!r||!t||r.length!==t.length)return!0;for(var e=0;e<r.length;e++)if(r[e]!==t[e])return!0;return!1}function so(r){return parseInt(r,10)}function lo(r,t,e){var i=["width","height"][t],n=["clientWidth","clientHeight"][t],a=["paddingLeft","paddingTop"][t],o=["paddingRight","paddingBottom"][t];if(e[i]!=null&&e[i]!=="auto")return parseFloat(e[i]);var s=document.defaultView.getComputedStyle(r);return(r[n]||so(s[i])||so(r.style[i]))-(so(s[a])||0)-(so(s[o])||0)|0}function iM(r,t){return!r||r==="solid"||!(t>0)?null:r==="dashed"?[4*t,2*t]:r==="dotted"?[t]:dt(r)?[r]:V(r)?r:null}function Wm(r){var t=r.style,e=t.lineDash&&t.lineWidth>0&&iM(t.lineDash,t.lineWidth),i=t.lineDashOffset;if(e){var n=t.strokeNoScale&&r.getLineScale?r.getLineScale():1;n&&n!==1&&(e=G(e,function(a){return a/n}),i/=n)}return[e,i]}var nM=new Lr(!0);function cs(r){var t=r.stroke;return!(t==null||t==="none"||!(r.lineWidth>0))}function sd(r){return typeof r=="string"&&r!=="none"}function ds(r){var t=r.fill;return t!=null&&t!=="none"}function ld(r,t){if(t.fillOpacity!=null&&t.fillOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.fillOpacity*t.opacity,r.fill(),r.globalAlpha=e}else r.fill()}function ud(r,t){if(t.strokeOpacity!=null&&t.strokeOpacity!==1){var e=r.globalAlpha;r.globalAlpha=t.strokeOpacity*t.opacity,r.stroke(),r.globalAlpha=e}else r.stroke()}function yf(r,t,e){var i=Zg(t.image,t.__image,e);if(Ms(i)){var n=r.createPattern(i,t.repeat||"repeat");if(typeof DOMMatrix=="function"&&n&&n.setTransform){var a=new DOMMatrix;a.translateSelf(t.x||0,t.y||0),a.rotateSelf(0,0,(t.rotation||0)*y1),a.scaleSelf(t.scaleX||1,t.scaleY||1),n.setTransform(a)}return n}}function aM(r,t,e,i){var n,a=cs(e),o=ds(e),s=e.strokePercent,l=s<1,u=!t.path;(!t.silent||l)&&u&&t.createPathProxy();var f=t.path||nM,h=t.__dirty;if(!i){var c=e.fill,v=e.stroke,d=o&&!!c.colorStops,p=a&&!!v.colorStops,g=o&&!!c.image,y=a&&!!v.image,m=void 0,_=void 0,S=void 0,x=void 0,w=void 0;(d||p)&&(w=t.getBoundingRect()),d&&(m=h?gf(r,c,w):t.__canvasFillGradient,t.__canvasFillGradient=m),p&&(_=h?gf(r,v,w):t.__canvasStrokeGradient,t.__canvasStrokeGradient=_),g&&(S=h||!t.__canvasFillPattern?yf(r,c,t):t.__canvasFillPattern,t.__canvasFillPattern=S),y&&(x=h||!t.__canvasStrokePattern?yf(r,v,t):t.__canvasStrokePattern,t.__canvasStrokePattern=S),d?r.fillStyle=m:g&&(S?r.fillStyle=S:o=!1),p?r.strokeStyle=_:y&&(x?r.strokeStyle=x:a=!1)}var b=t.getGlobalScale();f.setScale(b[0],b[1],t.segmentIgnoreThreshold);var T,M;r.setLineDash&&e.lineDash&&(n=Wm(t),T=n[0],M=n[1]);var D=!0;(u||h&Hi)&&(f.setDPR(r.dpr),l?f.setContext(null):(f.setContext(r),D=!1),f.reset(),t.buildPath(f,t.shape,i),f.toStatic(),t.pathUpdated()),D&&f.rebuildPath(r,l?s:1),T&&(r.setLineDash(T),r.lineDashOffset=M),i||(e.strokeFirst?(a&&ud(r,e),o&&ld(r,e)):(o&&ld(r,e),a&&ud(r,e))),T&&r.setLineDash([])}function oM(r,t,e){var i=t.__image=Zg(e.image,t.__image,t,t.onload);if(!(!i||!Ms(i))){var n=e.x||0,a=e.y||0,o=t.getWidth(),s=t.getHeight(),l=i.width/i.height;if(o==null&&s!=null?o=s*l:s==null&&o!=null?s=o/l:o==null&&s==null&&(o=i.width,s=i.height),e.sWidth&&e.sHeight){var u=e.sx||0,f=e.sy||0;r.drawImage(i,u,f,e.sWidth,e.sHeight,n,a,o,s)}else if(e.sx&&e.sy){var u=e.sx,f=e.sy,h=o-u,c=s-f;r.drawImage(i,u,f,h,c,n,a,o,s)}else r.drawImage(i,n,a,o,s)}}function sM(r,t,e){var i,n=e.text;if(n!=null&&(n+=""),n){r.font=e.font||si,r.textAlign=e.textAlign,r.textBaseline=e.textBaseline;var a=void 0,o=void 0;r.setLineDash&&e.lineDash&&(i=Wm(t),a=i[0],o=i[1]),a&&(r.setLineDash(a),r.lineDashOffset=o),e.strokeFirst?(cs(e)&&r.strokeText(n,e.x,e.y),ds(e)&&r.fillText(n,e.x,e.y)):(ds(e)&&r.fillText(n,e.x,e.y),cs(e)&&r.strokeText(n,e.x,e.y)),a&&r.setLineDash([])}}var fd=["shadowBlur","shadowOffsetX","shadowOffsetY"],hd=[["lineCap","butt"],["lineJoin","miter"],["miterLimit",10]];function Um(r,t,e,i,n){var a=!1;if(!i&&(e=e||{},t===e))return!1;if(i||t.opacity!==e.opacity){qt(r,n),a=!0;var o=Math.max(Math.min(t.opacity,1),0);r.globalAlpha=isNaN(o)?ri.opacity:o}(i||t.blend!==e.blend)&&(a||(qt(r,n),a=!0),r.globalCompositeOperation=t.blend||ri.blend);for(var s=0;s<fd.length;s++){var l=fd[s];(i||t[l]!==e[l])&&(a||(qt(r,n),a=!0),r[l]=r.dpr*(t[l]||0))}return(i||t.shadowColor!==e.shadowColor)&&(a||(qt(r,n),a=!0),r.shadowColor=t.shadowColor||ri.shadowColor),a}function vd(r,t,e,i,n){var a=xa(t,n.inHover),o=i?null:e&&xa(e,n.inHover)||{};if(a===o)return!1;var s=Um(r,a,o,i,n);if((i||a.fill!==o.fill)&&(s||(qt(r,n),s=!0),sd(a.fill)&&(r.fillStyle=a.fill)),(i||a.stroke!==o.stroke)&&(s||(qt(r,n),s=!0),sd(a.stroke)&&(r.strokeStyle=a.stroke)),(i||a.opacity!==o.opacity)&&(s||(qt(r,n),s=!0),r.globalAlpha=a.opacity==null?1:a.opacity),t.hasStroke()){var l=a.lineWidth,u=l/(a.strokeNoScale&&t.getLineScale?t.getLineScale():1);r.lineWidth!==u&&(s||(qt(r,n),s=!0),r.lineWidth=u)}for(var f=0;f<hd.length;f++){var h=hd[f],c=h[0];(i||a[c]!==o[c])&&(s||(qt(r,n),s=!0),r[c]=a[c]||h[1])}return s}function lM(r,t,e,i,n){return Um(r,xa(t,n.inHover),e&&xa(e,n.inHover),i,n)}function Ym(r,t){var e=t.transform,i=r.dpr||1;e?r.setTransform(i*e[0],i*e[1],i*e[2],i*e[3],i*e[4],i*e[5]):r.setTransform(i,0,0,i,0,0)}function uM(r,t,e){for(var i=!1,n=0;n<r.length;n++){var a=r[n];i=i||a.isZeroArea(),Ym(t,a),t.beginPath(),a.buildPath(t,a.shape),t.clip()}e.allClipped=i}function fM(r,t){return r&&t?r[0]!==t[0]||r[1]!==t[1]||r[2]!==t[2]||r[3]!==t[3]||r[4]!==t[4]||r[5]!==t[5]:!(!r&&!t)}var cd=1,dd=2,pd=3,gd=4;function hM(r){var t=ds(r),e=cs(r);return!(r.lineDash||!(+t^+e)||t&&typeof r.fill!="string"||e&&typeof r.stroke!="string"||r.strokePercent<1||r.strokeOpacity<1||r.fillOpacity<1)}function qt(r,t){t.batchFill&&r.fill(),t.batchStroke&&r.stroke(),t.batchFill="",t.batchStroke=""}function xa(r,t){return t&&r.__hoverStyle||r.style}function $m(r,t){ei(r,t,{inHover:!1,viewWidth:0,viewHeight:0},!0)}function ei(r,t,e,i){var n=t.transform;if(!t.shouldBePainted(e.viewWidth,e.viewHeight,!1,!1)){t.__dirty&=~re,t.__isRendered=!1;return}var a=t.__clipPaths,o=e.prevElClipPaths,s=!1,l=!1;if((!o||rM(a,o))&&(o&&o.length&&(qt(r,e),r.restore(),l=s=!0,e.prevElClipPaths=null,e.allClipped=!1,e.prevEl=null),a&&a.length&&(qt(r,e),r.save(),uM(a,r,e),s=!0),e.prevElClipPaths=a),e.allClipped){t.__isRendered=!1;return}t.beforeBrush&&t.beforeBrush(),t.innerBeforeBrush();var u=e.prevEl;u||(l=s=!0);var f=t instanceof ct&&t.autoBatch&&hM(t.style);s||fM(n,u.transform)?(qt(r,e),Ym(r,t)):f||qt(r,e);var h=xa(t,e.inHover);t instanceof ct?(e.lastDrawType!==cd&&(l=!0,e.lastDrawType=cd),vd(r,t,u,l,e),(!f||!e.batchFill&&!e.batchStroke)&&r.beginPath(),aM(r,t,h,f),f&&(e.batchFill=h.fill||"",e.batchStroke=h.stroke||"")):t instanceof tf?(e.lastDrawType!==pd&&(l=!0,e.lastDrawType=pd),vd(r,t,u,l,e),sM(r,t,h)):t instanceof nr?(e.lastDrawType!==dd&&(l=!0,e.lastDrawType=dd),lM(r,t,u,l,e),oM(r,t,h)):t.getTemporalDisplayables&&(e.lastDrawType!==gd&&(l=!0,e.lastDrawType=gd),vM(r,t,e)),f&&i&&qt(r,e),t.innerAfterBrush(),t.afterBrush&&t.afterBrush(),e.prevEl=t,t.__dirty=0,t.__isRendered=!0}function vM(r,t,e){var i=t.getDisplayables(),n=t.getTemporalDisplayables();r.save();var a={prevElClipPaths:null,prevEl:null,allClipped:!1,viewWidth:e.viewWidth,viewHeight:e.viewHeight,inHover:e.inHover},o,s;for(o=t.getCursor(),s=i.length;o<s;o++){var l=i[o];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),ei(r,l,a,o===s-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}for(var u=0,f=n.length;u<f;u++){var l=n[u];l.beforeBrush&&l.beforeBrush(),l.innerBeforeBrush(),ei(r,l,a,u===f-1),l.innerAfterBrush(),l.afterBrush&&l.afterBrush(),a.prevEl=l}t.clearTemporalDisplayables(),t.notClear=!0,r.restore()}var ql=new YC,yd=new Ma(100),md=["symbol","symbolSize","symbolKeepAspect","color","backgroundColor","dashArrayX","dashArrayY","maxTileWidth","maxTileHeight"];function mf(r,t){if(r==="none")return null;var e=t.getDevicePixelRatio(),i=t.getZr(),n=i.painter.type==="svg";r.dirty&&ql.delete(r);var a=ql.get(r);if(a)return a;var o=rt(r,{symbol:"rect",symbolSize:1,symbolKeepAspect:!0,color:"rgba(0, 0, 0, 0.2)",backgroundColor:null,dashArrayX:5,dashArrayY:5,rotation:0,maxTileWidth:512,maxTileHeight:512});o.backgroundColor==="none"&&(o.backgroundColor=null);var s={repeat:"repeat"};return l(s),s.rotation=o.rotation,s.scaleX=s.scaleY=n?1:1/e,ql.set(r,s),r.dirty=!1,s;function l(u){for(var f=[e],h=!0,c=0;c<md.length;++c){var v=o[md[c]];if(v!=null&&!V(v)&&!W(v)&&!dt(v)&&typeof v!="boolean"){h=!1;break}f.push(v)}var d;if(h){d=f.join(",")+(n?"-svg":"");var p=yd.get(d);p&&(n?u.svgElement=p:u.image=p)}var g=Xm(o.dashArrayX),y=cM(o.dashArrayY),m=Zm(o.symbol),_=dM(g),S=qm(y),x=!n&&gi.createCanvas(),w=n&&{tag:"g",attrs:{},key:"dcl",children:[]},b=M(),T;x&&(x.width=b.width*e,x.height=b.height*e,T=x.getContext("2d")),D(),h&&yd.put(d,x||w),u.image=x,u.svgElement=w,u.svgWidth=b.width,u.svgHeight=b.height;function M(){for(var C=1,L=0,I=_.length;L<I;++L)C=Ev(C,_[L]);for(var P=1,L=0,I=m.length;L<I;++L)P=Ev(P,m[L].length);C*=P;var R=S*_.length*m.length;return{width:Math.max(1,Math.min(C,o.maxTileWidth)),height:Math.max(1,Math.min(R,o.maxTileHeight))}}function D(){T&&(T.clearRect(0,0,x.width,x.height),o.backgroundColor&&(T.fillStyle=o.backgroundColor,T.fillRect(0,0,x.width,x.height)));for(var C=0,L=0;L<y.length;++L)C+=y[L];if(C<=0)return;for(var I=-S,P=0,R=0,E=0;I<b.height;){if(P%2===0){for(var z=R/2%m.length,k=0,B=0,F=0;k<b.width*2;){for(var H=0,L=0;L<g[E].length;++L)H+=g[E][L];if(H<=0)break;if(B%2===0){var U=(1-o.symbolSize)*.5,J=k+g[E][B]*U,ot=I+y[P]*U,ft=g[E][B]*o.symbolSize,Ut=y[P]*o.symbolSize,ne=F/2%m[z].length;ee(J,ot,ft,Ut,m[z][ne])}k+=g[E][B],++F,++B,B===g[E].length&&(B=0)}++E,E===g.length&&(E=0)}I+=y[P],++R,++P,P===y.length&&(P=0)}function ee(It,St,X,it,Ie){var Mt=n?1:e,sr=ir(Ie,It*Mt,St*Mt,X*Mt,it*Mt,o.color,o.symbolKeepAspect);if(n){var Ue=i.painter.renderOneToVNode(sr);Ue&&w.children.push(Ue)}else $m(T,sr)}}}}function Zm(r){if(!r||r.length===0)return[["rect"]];if(W(r))return[[r]];for(var t=!0,e=0;e<r.length;++e)if(!W(r[e])){t=!1;break}if(t)return Zm([r]);for(var i=[],e=0;e<r.length;++e)W(r[e])?i.push([r[e]]):i.push(r[e]);return i}function Xm(r){if(!r||r.length===0)return[[0,0]];if(dt(r)){var t=Math.ceil(r);return[[t,t]]}for(var e=!0,i=0;i<r.length;++i)if(!dt(r[i])){e=!1;break}if(e)return Xm([r]);for(var n=[],i=0;i<r.length;++i)if(dt(r[i])){var t=Math.ceil(r[i]);n.push([t,t])}else{var t=G(r[i],function(s){return Math.ceil(s)});t.length%2===1?n.push(t.concat(t)):n.push(t)}return n}function cM(r){if(!r||typeof r=="object"&&r.length===0)return[0,0];if(dt(r)){var t=Math.ceil(r);return[t,t]}var e=G(r,function(i){return Math.ceil(i)});return r.length%2?e.concat(e):e}function dM(r){return G(r,function(t){return qm(t)})}function qm(r){for(var t=0,e=0;e<r.length;++e)t+=r[e];return r.length%2===1?t*2:t}function pM(r,t){r.eachRawSeries(function(e){if(!r.isSeriesFiltered(e)){var i=e.getData();i.hasItemVisual()&&i.each(function(o){var s=i.getItemVisual(o,"decal");if(s){var l=i.ensureUniqueItemVisual(o,"style");l.decal=mf(s,t)}});var n=i.getVisual("decal");if(n){var a=i.getVisual("style");a.decal=mf(n,t)}}})}var gM=new Ae;const be=gM;var Km={};function yM(r,t){Km[r]=t}function mM(r){return Km[r]}var _M=1,SM=800,wM=900,xM=1e3,bM=2e3,TM=5e3,Qm=1e3,CM=1100,Lh=2e3,Jm=3e3,MM=4e3,Xs=4500,AM=4600,DM=5e3,LM=6e3,jm=7e3,IM={PROCESSOR:{FILTER:xM,SERIES_FILTER:SM,STATISTIC:TM},VISUAL:{LAYOUT:Qm,PROGRESSIVE_LAYOUT:CM,GLOBAL:Lh,CHART:Jm,POST_CHART_LAYOUT:AM,COMPONENT:MM,BRUSH:DM,CHART_ITEM:Xs,ARIA:LM,DECAL:jm}},Bt="__flagInMainProcess",$t="__pendingUpdate",Kl="__needsUpdateStatus",_d=/^[a-zA-Z0-9_]+$/,Ql="__connectUpdateStatus",Sd=0,PM=1,RM=2;function t0(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];if(this.isDisposed()){this.id;return}return r0(this,r,t)}}function e0(r){return function(){for(var t=[],e=0;e<arguments.length;e++)t[e]=arguments[e];return r0(this,r,t)}}function r0(r,t,e){return e[0]=e[0]&&e[0].toLowerCase(),Ae.prototype[t].apply(r,e)}var i0=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t}(Ae),n0=i0.prototype;n0.on=e0("on");n0.off=e0("off");var Ni,Jl,uo,vr,jl,tu,eu,An,Dn,wd,xd,ru,bd,fo,Td,a0,ae,Cd,o0=function(r){N(t,r);function t(e,i,n){var a=r.call(this,new OC)||this;a._chartsViews=[],a._chartsMap={},a._componentsViews=[],a._componentsMap={},a._pendingActions=[],n=n||{},W(i)&&(i=s0[i]),a._dom=e;var o="canvas",s="auto",l=!1;n.ssr;var u=a._zr=Pv(e,{renderer:n.renderer||o,devicePixelRatio:n.devicePixelRatio,width:n.width,height:n.height,ssr:n.ssr,useDirtyRect:j(n.useDirtyRect,l),useCoarsePointer:j(n.useCoarsePointer,s),pointerSize:n.pointerSize});a._ssr=n.ssr,a._throttledZrFlush=$s($(u.flush,u),17),i=et(i),i&&gm(i,!0),a._theme=i,a._locale=Fb(n.locale||Yy),a._coordSysMgr=new wh;var f=a._api=Td(a);function h(c,v){return c.__prio-v.__prio}return Ao(gs,h),Ao(_f,h),a._scheduler=new Fm(a,f,_f,gs),a._messageCenter=new i0,a._initEvents(),a.resize=$(a.resize,a),u.animation.on("frame",a._onframe,a),wd(u,a),xd(u,a),Ru(a),a}return t.prototype._onframe=function(){if(!this._disposed){Cd(this);var e=this._scheduler;if(this[$t]){var i=this[$t].silent;this[Bt]=!0;try{Ni(this),vr.update.call(this,null,this[$t].updateParams)}catch(l){throw this[Bt]=!1,this[$t]=null,l}this._zr.flush(),this[Bt]=!1,this[$t]=null,An.call(this,i),Dn.call(this,i)}else if(e.unfinished){var n=_M,a=this._model,o=this._api;e.unfinished=!1;do{var s=+new Date;e.performSeriesTasks(a),e.performDataProcessorTasks(a),tu(this,a),e.performVisualTasks(a),fo(this,this._model,o,"remain",{}),n-=+new Date-s}while(n>0&&e.unfinished);e.unfinished||this._zr.flush()}}},t.prototype.getDom=function(){return this._dom},t.prototype.getId=function(){return this.id},t.prototype.getZr=function(){return this._zr},t.prototype.isSSR=function(){return this._ssr},t.prototype.setOption=function(e,i,n){if(!this[Bt]){if(this._disposed){this.id;return}var a,o,s;if(Y(i)&&(n=i.lazyUpdate,a=i.silent,o=i.replaceMerge,s=i.transition,i=i.notMerge),this[Bt]=!0,!this._model||i){var l=new mT(this._api),u=this._theme,f=this._model=new cm;f.scheduler=this._scheduler,f.ssr=this._ssr,f.init(null,null,null,u,this._locale,l)}this._model.setOption(e,{replaceMerge:o},Sf);var h={seriesTransition:s,optionChanged:!0};if(n)this[$t]={silent:a,updateParams:h},this[Bt]=!1,this.getZr().wakeUp();else{try{Ni(this),vr.update.call(this,null,h)}catch(c){throw this[$t]=null,this[Bt]=!1,c}this._ssr||this._zr.flush(),this[$t]=null,this[Bt]=!1,An.call(this,a),Dn.call(this,a)}}},t.prototype.setTheme=function(){},t.prototype.getModel=function(){return this._model},t.prototype.getOption=function(){return this._model&&this._model.getOption()},t.prototype.getWidth=function(){return this._zr.getWidth()},t.prototype.getHeight=function(){return this._zr.getHeight()},t.prototype.getDevicePixelRatio=function(){return this._zr.painter.dpr||tt.hasGlobalWindow&&window.devicePixelRatio||1},t.prototype.getRenderedCanvas=function(e){return this.renderToCanvas(e)},t.prototype.renderToCanvas=function(e){e=e||{};var i=this._zr.painter;return i.getRenderedCanvas({backgroundColor:e.backgroundColor||this._model.get("backgroundColor"),pixelRatio:e.pixelRatio||this.getDevicePixelRatio()})},t.prototype.renderToSVGString=function(e){e=e||{};var i=this._zr.painter;return i.renderToString({useViewBox:e.useViewBox})},t.prototype.getSvgDataURL=function(){if(!!tt.svgSupported){var e=this._zr,i=e.storage.getDisplayList();return A(i,function(n){n.stopAnimation(null,!0)}),e.painter.toDataURL()}},t.prototype.getDataURL=function(e){if(this._disposed){this.id;return}e=e||{};var i=e.excludeComponents,n=this._model,a=[],o=this;A(i,function(l){n.eachComponent({mainType:l},function(u){var f=o._componentsMap[u.__viewId];f.group.ignore||(a.push(f),f.group.ignore=!0)})});var s=this._zr.painter.getType()==="svg"?this.getSvgDataURL():this.renderToCanvas(e).toDataURL("image/"+(e&&e.type||"png"));return A(a,function(l){l.group.ignore=!1}),s},t.prototype.getConnectedDataURL=function(e){if(this._disposed){this.id;return}var i=e.type==="svg",n=this.group,a=Math.min,o=Math.max,s=1/0;if(Md[n]){var l=s,u=s,f=-s,h=-s,c=[],v=e&&e.pixelRatio||this.getDevicePixelRatio();A(ua,function(_,S){if(_.group===n){var x=i?_.getZr().painter.getSvgDom().innerHTML:_.renderToCanvas(et(e)),w=_.getDom().getBoundingClientRect();l=a(w.left,l),u=a(w.top,u),f=o(w.right,f),h=o(w.bottom,h),c.push({dom:x,left:w.left,top:w.top})}}),l*=v,u*=v,f*=v,h*=v;var d=f-l,p=h-u,g=gi.createCanvas(),y=Pv(g,{renderer:i?"svg":"canvas"});if(y.resize({width:d,height:p}),i){var m="";return A(c,function(_){var S=_.left-l,x=_.top-u;m+='<g transform="translate('+S+","+x+')">'+_.dom+"</g>"}),y.painter.getSvgRoot().innerHTML=m,e.connectedBackgroundColor&&y.painter.setBackgroundColor(e.connectedBackgroundColor),y.refreshImmediately(),y.painter.toDataURL()}else return e.connectedBackgroundColor&&y.add(new _t({shape:{x:0,y:0,width:d,height:p},style:{fill:e.connectedBackgroundColor}})),A(c,function(_){var S=new nr({style:{x:_.left*v-l,y:_.top*v-u,image:_.dom}});y.add(S)}),y.refreshImmediately(),g.toDataURL("image/"+(e&&e.type||"png"))}else return this.getDataURL(e)},t.prototype.convertToPixel=function(e,i){return jl(this,"convertToPixel",e,i)},t.prototype.convertFromPixel=function(e,i){return jl(this,"convertFromPixel",e,i)},t.prototype.containPixel=function(e,i){if(this._disposed){this.id;return}var n=this._model,a,o=xl(n,e);return A(o,function(s,l){l.indexOf("Models")>=0&&A(s,function(u){var f=u.coordinateSystem;if(f&&f.containPoint)a=a||!!f.containPoint(i);else if(l==="seriesModels"){var h=this._chartsMap[u.__viewId];h&&h.containPoint&&(a=a||h.containPoint(i,u))}},this)},this),!!a},t.prototype.getVisual=function(e,i){var n=this._model,a=xl(n,e,{defaultMainType:"series"}),o=a.seriesModel,s=o.getData(),l=a.hasOwnProperty("dataIndexInside")?a.dataIndexInside:a.hasOwnProperty("dataIndex")?s.indexOfRawIndex(a.dataIndex):null;return l!=null?zC(s,l,i):FC(s,i)},t.prototype.getViewOfComponentModel=function(e){return this._componentsMap[e.__viewId]},t.prototype.getViewOfSeriesModel=function(e){return this._chartsMap[e.__viewId]},t.prototype._initEvents=function(){var e=this;A(EM,function(i){var n=function(a){var o=e.getModel(),s=a.target,l,u=i==="globalout";if(u?l={}:s&&Xn(s,function(d){var p=lt(d);if(p&&p.dataIndex!=null){var g=p.dataModel||o.getSeriesByIndex(p.seriesIndex);return l=g&&g.getDataParams(p.dataIndex,p.dataType,s)||{},!0}else if(p.eventData)return l=O({},p.eventData),!0},!0),l){var f=l.componentType,h=l.componentIndex;(f==="markLine"||f==="markPoint"||f==="markArea")&&(f="series",h=l.seriesIndex);var c=f&&h!=null&&o.getComponent(f,h),v=c&&e[c.mainType==="series"?"_chartsMap":"_componentsMap"][c.__viewId];l.event=a,l.type=i,e._$eventProcessor.eventInfo={targetEl:s,packedEvent:l,model:c,view:v},e.trigger(i,l)}};n.zrEventfulCallAtLast=!0,e._zr.on(i,n,e)}),A(la,function(i,n){e._messageCenter.on(n,function(a){this.trigger(n,a)},e)}),A(["selectchanged"],function(i){e._messageCenter.on(i,function(n){this.trigger(i,n)},e)}),HC(this._messageCenter,this,this._api)},t.prototype.isDisposed=function(){return this._disposed},t.prototype.clear=function(){if(this._disposed){this.id;return}this.setOption({series:[]},!0)},t.prototype.dispose=function(){if(this._disposed){this.id;return}this._disposed=!0;var e=this.getDom();e&&Ug(this.getDom(),Ph,"");var i=this,n=i._api,a=i._model;A(i._componentsViews,function(o){o.dispose(a,n)}),A(i._chartsViews,function(o){o.dispose(a,n)}),i._zr.dispose(),i._dom=i._model=i._chartsMap=i._componentsMap=i._chartsViews=i._componentsViews=i._scheduler=i._api=i._zr=i._throttledZrFlush=i._theme=i._coordSysMgr=i._messageCenter=null,delete ua[i.id]},t.prototype.resize=function(e){if(!this[Bt]){if(this._disposed){this.id;return}this._zr.resize(e);var i=this._model;if(this._loadingFX&&this._loadingFX.resize(),!!i){var n=i.resetOption("media"),a=e&&e.silent;this[$t]&&(a==null&&(a=this[$t].silent),n=!0,this[$t]=null),this[Bt]=!0;try{n&&Ni(this),vr.update.call(this,{type:"resize",animation:O({duration:0},e&&e.animation)})}catch(o){throw this[Bt]=!1,o}this[Bt]=!1,An.call(this,a),Dn.call(this,a)}}},t.prototype.showLoading=function(e,i){if(this._disposed){this.id;return}if(Y(e)&&(i=e,e=""),e=e||"default",this.hideLoading(),!!wf[e]){var n=wf[e](this._api,i),a=this._zr;this._loadingFX=n,a.add(n)}},t.prototype.hideLoading=function(){if(this._disposed){this.id;return}this._loadingFX&&this._zr.remove(this._loadingFX),this._loadingFX=null},t.prototype.makeActionFromEvent=function(e){var i=O({},e);return i.type=la[e.type],i},t.prototype.dispatchAction=function(e,i){if(this._disposed){this.id;return}if(Y(i)||(i={silent:!!i}),!!ps[e.type]&&!!this._model){if(this[Bt]){this._pendingActions.push(e);return}var n=i.silent;eu.call(this,e,n);var a=i.flush;a?this._zr.flush():a!==!1&&tt.browser.weChat&&this._throttledZrFlush(),An.call(this,n),Dn.call(this,n)}},t.prototype.updateLabelLayout=function(){be.trigger("series:layoutlabels",this._model,this._api,{updatedSeries:[]})},t.prototype.appendData=function(e){if(this._disposed){this.id;return}var i=e.seriesIndex,n=this.getModel(),a=n.getSeriesByIndex(i);a.appendData(e),this._scheduler.unfinished=!0,this.getZr().wakeUp()},t.internalField=function(){Ni=function(h){var c=h._scheduler;c.restorePipelines(h._model),c.prepareStageTasks(),Jl(h,!0),Jl(h,!1),c.plan()},Jl=function(h,c){for(var v=h._model,d=h._scheduler,p=c?h._componentsViews:h._chartsViews,g=c?h._componentsMap:h._chartsMap,y=h._zr,m=h._api,_=0;_<p.length;_++)p[_].__alive=!1;c?v.eachComponent(function(w,b){w!=="series"&&S(b)}):v.eachSeries(S);function S(w){var b=w.__requireNewView;w.__requireNewView=!1;var T="_ec_"+w.id+"_"+w.type,M=!b&&g[T];if(!M){var D=Ve(w.type),C=c?Ce.getClass(D.main,D.sub):Te.getClass(D.sub);M=new C,M.init(v,m),g[T]=M,p.push(M),y.add(M.group)}w.__viewId=M.__id=T,M.__alive=!0,M.__model=w,M.group.__ecComponentInfo={mainType:w.mainType,index:w.componentIndex},!c&&d.prepareView(M,w,v,m)}for(var _=0;_<p.length;){var x=p[_];x.__alive?_++:(!c&&x.renderTask.dispose(),y.remove(x.group),x.dispose(v,m),p.splice(_,1),g[x.__id]===x&&delete g[x.__id],x.__id=x.group.__ecComponentInfo=null)}},uo=function(h,c,v,d,p){var g=h._model;if(g.setUpdatePayload(v),!d){A([].concat(h._componentsViews).concat(h._chartsViews),x);return}var y={};y[d+"Id"]=v[d+"Id"],y[d+"Index"]=v[d+"Index"],y[d+"Name"]=v[d+"Name"];var m={mainType:d,query:y};p&&(m.subType=p);var _=v.excludeSeriesId,S;_!=null&&(S=Z(),A(At(_),function(w){var b=Kt(w,null);b!=null&&S.set(b,!0)})),g&&g.eachComponent(m,function(w){var b=S&&S.get(w.id)!=null;if(!b)if(oc(v))if(w instanceof rr)v.type===ii&&!v.notBlur&&!w.get(["emphasis","disabled"])&&Sx(w,v,h._api);else{var T=oh(w.mainType,w.componentIndex,v.name,h._api),M=T.focusSelf,D=T.dispatchers;v.type===ii&&M&&!v.notBlur&&rf(w.mainType,w.componentIndex,h._api),D&&A(D,function(C){v.type===ii?ts(C):es(C)})}else af(v)&&w instanceof rr&&(Tx(w,v,h._api),nc(w),ae(h))},h),g&&g.eachComponent(m,function(w){var b=S&&S.get(w.id)!=null;b||x(h[d==="series"?"_chartsMap":"_componentsMap"][w.__viewId])},h);function x(w){w&&w.__alive&&w[c]&&w[c](w.__model,g,h._api,v)}},vr={prepareAndUpdate:function(h){Ni(this),vr.update.call(this,h,{optionChanged:h.newOption!=null})},update:function(h,c){var v=this._model,d=this._api,p=this._zr,g=this._coordSysMgr,y=this._scheduler;if(!!v){v.setUpdatePayload(h),y.restoreData(v,h),y.performSeriesTasks(v),g.create(v,d),y.performDataProcessorTasks(v,h),tu(this,v),g.update(v,d),e(v),y.performVisualTasks(v,h),ru(this,v,d,h,c);var m=v.get("backgroundColor")||"transparent",_=v.get("darkMode");p.setBackgroundColor(m),_!=null&&_!=="auto"&&p.setDarkMode(_),be.trigger("afterupdate",v,d)}},updateTransform:function(h){var c=this,v=this._model,d=this._api;if(!!v){v.setUpdatePayload(h);var p=[];v.eachComponent(function(y,m){if(y!=="series"){var _=c.getViewOfComponentModel(m);if(_&&_.__alive)if(_.updateTransform){var S=_.updateTransform(m,v,d,h);S&&S.update&&p.push(_)}else p.push(_)}});var g=Z();v.eachSeries(function(y){var m=c._chartsMap[y.__viewId];if(m.updateTransform){var _=m.updateTransform(y,v,d,h);_&&_.update&&g.set(y.uid,1)}else g.set(y.uid,1)}),e(v),this._scheduler.performVisualTasks(v,h,{setDirty:!0,dirtyMap:g}),fo(this,v,d,h,{},g),be.trigger("afterupdate",v,d)}},updateView:function(h){var c=this._model;!c||(c.setUpdatePayload(h),Te.markUpdateMethod(h,"updateView"),e(c),this._scheduler.performVisualTasks(c,h,{setDirty:!0}),ru(this,c,this._api,h,{}),be.trigger("afterupdate",c,this._api))},updateVisual:function(h){var c=this,v=this._model;!v||(v.setUpdatePayload(h),v.eachSeries(function(d){d.getData().clearAllVisual()}),Te.markUpdateMethod(h,"updateVisual"),e(v),this._scheduler.performVisualTasks(v,h,{visualType:"visual",setDirty:!0}),v.eachComponent(function(d,p){if(d!=="series"){var g=c.getViewOfComponentModel(p);g&&g.__alive&&g.updateVisual(p,v,c._api,h)}}),v.eachSeries(function(d){var p=c._chartsMap[d.__viewId];p.updateVisual(d,v,c._api,h)}),be.trigger("afterupdate",v,this._api))},updateLayout:function(h){vr.update.call(this,h)}},jl=function(h,c,v,d){if(h._disposed){h.id;return}for(var p=h._model,g=h._coordSysMgr.getCoordinateSystems(),y,m=xl(p,v),_=0;_<g.length;_++){var S=g[_];if(S[c]&&(y=S[c](p,m,d))!=null)return y}},tu=function(h,c){var v=h._chartsMap,d=h._scheduler;c.eachSeries(function(p){d.updateStreamModes(p,v[p.__viewId])})},eu=function(h,c){var v=this,d=this.getModel(),p=h.type,g=h.escapeConnect,y=ps[p],m=y.actionInfo,_=(m.update||"update").split(":"),S=_.pop(),x=_[0]!=null&&Ve(_[0]);this[Bt]=!0;var w=[h],b=!1;h.batch&&(b=!0,w=G(h.batch,function(P){return P=rt(O({},P),h),P.batch=null,P}));var T=[],M,D=af(h),C=oc(h);if(C&&dy(this._api),A(w,function(P){if(M=y.action(P,v._model,v._api),M=M||O({},P),M.type=m.event||M.type,T.push(M),C){var R=eh(h),E=R.queryOptionMap,z=R.mainTypeSpecified,k=z?E.keys()[0]:"series";uo(v,S,P,k),ae(v)}else D?(uo(v,S,P,"series"),ae(v)):x&&uo(v,S,P,x.main,x.sub)}),S!=="none"&&!C&&!D&&!x)try{this[$t]?(Ni(this),vr.update.call(this,h),this[$t]=null):vr[S].call(this,h)}catch(P){throw this[Bt]=!1,P}if(b?M={type:m.event||p,escapeConnect:g,batch:T}:M=T[0],this[Bt]=!1,!c){var L=this._messageCenter;if(L.trigger(M.type,M),D){var I={type:"selectchanged",escapeConnect:g,selected:Cx(d),isFromClick:h.isFromClick||!1,fromAction:h.type,fromActionPayload:h};L.trigger(I.type,I)}}},An=function(h){for(var c=this._pendingActions;c.length;){var v=c.shift();eu.call(this,v,h)}},Dn=function(h){!h&&this.trigger("updated")},wd=function(h,c){h.on("rendered",function(v){c.trigger("rendered",v),h.animation.isFinished()&&!c[$t]&&!c._scheduler.unfinished&&!c._pendingActions.length&&c.trigger("finished")})},xd=function(h,c){h.on("mouseover",function(v){var d=v.target,p=Xn(d,nf);p&&(xx(p,v,c._api),ae(c))}).on("mouseout",function(v){var d=v.target,p=Xn(d,nf);p&&(bx(p,v,c._api),ae(c))}).on("click",function(v){var d=v.target,p=Xn(d,function(m){return lt(m).dataIndex!=null},!0);if(p){var g=p.selected?"unselect":"select",y=lt(p);c._api.dispatchAction({type:g,dataType:y.dataType,dataIndexInside:y.dataIndex,seriesIndex:y.seriesIndex,isFromClick:!0})}})};function e(h){h.clearColorPalette(),h.eachSeries(function(c){c.clearColorPalette()})}function i(h){var c=[],v=[],d=!1;if(h.eachComponent(function(m,_){var S=_.get("zlevel")||0,x=_.get("z")||0,w=_.getZLevelKey();d=d||!!w,(m==="series"?v:c).push({zlevel:S,z:x,idx:_.componentIndex,type:m,key:w})}),d){var p=c.concat(v),g,y;Ao(p,function(m,_){return m.zlevel===_.zlevel?m.z-_.z:m.zlevel-_.zlevel}),A(p,function(m){var _=h.getComponent(m.type,m.idx),S=m.zlevel,x=m.key;g!=null&&(S=Math.max(g,S)),x?(S===g&&x!==y&&S++,y=x):y&&(S===g&&S++,y=""),g=S,_.setZLevel(S)})}}ru=function(h,c,v,d,p){i(c),bd(h,c,v,d,p),A(h._chartsViews,function(g){g.__alive=!1}),fo(h,c,v,d,p),A(h._chartsViews,function(g){g.__alive||g.remove(c,v)})},bd=function(h,c,v,d,p,g){A(g||h._componentsViews,function(y){var m=y.__model;u(m,y),y.render(m,c,v,d),s(m,y),f(m,y)})},fo=function(h,c,v,d,p,g){var y=h._scheduler;p=O(p||{},{updatedSeries:c.getSeries()}),be.trigger("series:beforeupdate",c,v,p);var m=!1;c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];S.__alive=!0;var x=S.renderTask;y.updatePayload(x,d),u(_,S),g&&g.get(_.uid)&&x.dirty(),x.perform(y.getPerformArgs(x))&&(m=!0),S.group.silent=!!_.get("silent"),o(_,S),nc(_)}),y.unfinished=m||y.unfinished,be.trigger("series:layoutlabels",c,v,p),be.trigger("series:transition",c,v,p),c.eachSeries(function(_){var S=h._chartsMap[_.__viewId];s(_,S),f(_,S)}),a(h,c),be.trigger("series:afterupdate",c,v,p)},ae=function(h){h[Kl]=!0,h.getZr().wakeUp()},Cd=function(h){!h[Kl]||(h.getZr().storage.traverse(function(c){na(c)||n(c)}),h[Kl]=!1)};function n(h){for(var c=[],v=h.currentStates,d=0;d<v.length;d++){var p=v[d];p==="emphasis"||p==="blur"||p==="select"||c.push(p)}h.selected&&h.states.select&&c.push("select"),h.hoverState===Ls&&h.states.emphasis?c.push("emphasis"):h.hoverState===Ds&&h.states.blur&&c.push("blur"),h.useStates(c)}function a(h,c){var v=h._zr,d=v.storage,p=0;d.traverse(function(g){g.isGroup||p++}),p>c.get("hoverLayerThreshold")&&!tt.node&&!tt.worker&&c.eachSeries(function(g){if(!g.preventUsingHoverLayer){var y=h._chartsMap[g.__viewId];y.__alive&&y.eachRendered(function(m){m.states.emphasis&&(m.states.emphasis.hoverLayer=!0)})}})}function o(h,c){var v=h.get("blendMode")||null;c.eachRendered(function(d){d.isGroup||(d.style.blend=v)})}function s(h,c){if(!h.preventAutoZ){var v=h.get("z")||0,d=h.get("zlevel")||0;c.eachRendered(function(p){return l(p,v,d,-1/0),!0})}}function l(h,c,v,d){var p=h.getTextContent(),g=h.getTextGuideLine(),y=h.isGroup;if(y)for(var m=h.childrenRef(),_=0;_<m.length;_++)d=Math.max(l(m[_],c,v,d),d);else h.z=c,h.zlevel=v,d=Math.max(h.z2,d);if(p&&(p.z=c,p.zlevel=v,isFinite(d)&&(p.z2=d+2)),g){var S=h.textGuideLineConfig;g.z=c,g.zlevel=v,isFinite(d)&&(g.z2=d+(S&&S.showAbove?1:-1))}return d}function u(h,c){c.eachRendered(function(v){if(!na(v)){var d=v.getTextContent(),p=v.getTextGuideLine();v.stateTransition&&(v.stateTransition=null),d&&d.stateTransition&&(d.stateTransition=null),p&&p.stateTransition&&(p.stateTransition=null),v.hasState()?(v.prevStates=v.currentStates,v.clearStates()):v.prevStates&&(v.prevStates=null)}})}function f(h,c){var v=h.getModel("stateAnimation"),d=h.isAnimationEnabled(),p=v.get("duration"),g=p>0?{duration:p,delay:v.get("delay"),easing:v.get("easing")}:null;c.eachRendered(function(y){if(y.states&&y.states.emphasis){if(na(y))return;if(y instanceof ct&&Ix(y),y.__dirty){var m=y.prevStates;m&&y.useStates(m)}if(d){y.stateTransition=g;var _=y.getTextContent(),S=y.getTextGuideLine();_&&(_.stateTransition=g),S&&(S.stateTransition=g)}y.__dirty&&n(y)}})}Td=function(h){return new(function(c){N(v,c);function v(){return c!==null&&c.apply(this,arguments)||this}return v.prototype.getCoordinateSystems=function(){return h._coordSysMgr.getCoordinateSystems()},v.prototype.getComponentByElement=function(d){for(;d;){var p=d.__ecComponentInfo;if(p!=null)return h._model.getComponent(p.mainType,p.index);d=d.parent}},v.prototype.enterEmphasis=function(d,p){ts(d,p),ae(h)},v.prototype.leaveEmphasis=function(d,p){es(d,p),ae(h)},v.prototype.enterBlur=function(d){_x(d),ae(h)},v.prototype.leaveBlur=function(d){fy(d),ae(h)},v.prototype.enterSelect=function(d){hy(d),ae(h)},v.prototype.leaveSelect=function(d){vy(d),ae(h)},v.prototype.getModel=function(){return h.getModel()},v.prototype.getViewOfComponentModel=function(d){return h.getViewOfComponentModel(d)},v.prototype.getViewOfSeriesModel=function(d){return h.getViewOfSeriesModel(d)},v}(dm))(h)},a0=function(h){function c(v,d){for(var p=0;p<v.length;p++){var g=v[p];g[Ql]=d}}A(la,function(v,d){h._messageCenter.on(d,function(p){if(Md[h.group]&&h[Ql]!==Sd){if(p&&p.escapeConnect)return;var g=h.makeActionFromEvent(p),y=[];A(ua,function(m){m!==h&&m.group===h.group&&y.push(m)}),c(y,Sd),A(y,function(m){m[Ql]!==PM&&m.dispatchAction(g)}),c(y,RM)}})})}}(),t}(Ae),Ih=o0.prototype;Ih.on=t0("on");Ih.off=t0("off");Ih.one=function(r,t,e){var i=this;function n(){for(var a=[],o=0;o<arguments.length;o++)a[o]=arguments[o];t&&t.apply&&t.apply(this,a),i.off(r,n)}this.on.call(this,r,n,e)};var EM=["click","dblclick","mouseover","mouseout","mousemove","mousedown","mouseup","globalout","contextmenu"];var ps={},la={},_f=[],Sf=[],gs=[],s0={},wf={},ua={},Md={},kM=+new Date-0,Ph="_echarts_instance_";function OM(r,t,e){var i=!(e&&e.ssr);if(i){var n=BM(r);if(n)return n}var a=new o0(r,t,e);return a.id="ec_"+kM++,ua[a.id]=a,i&&Ug(r,Ph,a.id),a0(a),be.trigger("afterinit",a),a}function BM(r){return ua[ow(r,Ph)]}function l0(r,t){s0[r]=t}function u0(r){at(Sf,r)<0&&Sf.push(r)}function f0(r,t){Eh(_f,r,t,bM)}function NM(r){Rh("afterinit",r)}function zM(r){Rh("afterupdate",r)}function Rh(r,t){be.on(r,t)}function wi(r,t,e){K(t)&&(e=t,t="");var i=Y(r)?r.type:[r,r={event:t}][0];r.event=(r.event||i).toLowerCase(),t=r.event,!la[t]&&(tr(_d.test(i)&&_d.test(t)),ps[i]||(ps[i]={action:e,actionInfo:r}),la[t]=i)}function FM(r,t){wh.register(r,t)}function VM(r,t){Eh(gs,r,t,Qm,"layout")}function xi(r,t){Eh(gs,r,t,Jm,"visual")}var Ad=[];function Eh(r,t,e,i,n){if((K(t)||Y(t))&&(e=t,t=i),!(at(Ad,e)>=0)){Ad.push(e);var a=Fm.wrapStageHandler(e,n);a.__prio=t,a.__raw=e,r.push(a)}}function h0(r,t){wf[r]=t}function HM(r,t,e){var i=mM("registerMap");i&&i(r,t,e)}var GM=UT;xi(Lh,_C);xi(Xs,SC);xi(Xs,wC);xi(Lh,BC);xi(Xs,NC);xi(jm,pM);u0(gm);f0(wM,MT);h0("default",xC);wi({type:ii,event:ii,update:ii},Gt);wi({type:Eo,event:Eo,update:Eo},Gt);wi({type:ea,event:ea,update:ea},Gt);wi({type:ko,event:ko,update:ko},Gt);wi({type:ra,event:ra,update:ra},Gt);l0("light",EC);l0("dark",kC);function Ln(r){return r==null?0:r.length||1}function Dd(r){return r}var WM=function(){function r(t,e,i,n,a,o){this._old=t,this._new=e,this._oldKeyGetter=i||Dd,this._newKeyGetter=n||Dd,this.context=a,this._diffModeMultiple=o==="multiple"}return r.prototype.add=function(t){return this._add=t,this},r.prototype.update=function(t){return this._update=t,this},r.prototype.updateManyToOne=function(t){return this._updateManyToOne=t,this},r.prototype.updateOneToMany=function(t){return this._updateOneToMany=t,this},r.prototype.updateManyToMany=function(t){return this._updateManyToMany=t,this},r.prototype.remove=function(t){return this._remove=t,this},r.prototype.execute=function(){this[this._diffModeMultiple?"_executeMultiple":"_executeOneToOne"]()},r.prototype._executeOneToOne=function(){var t=this._old,e=this._new,i={},n=new Array(t.length),a=new Array(e.length);this._initIndexMap(t,null,n,"_oldKeyGetter"),this._initIndexMap(e,i,a,"_newKeyGetter");for(var o=0;o<t.length;o++){var s=n[o],l=i[s],u=Ln(l);if(u>1){var f=l.shift();l.length===1&&(i[s]=l[0]),this._update&&this._update(f,o)}else u===1?(i[s]=null,this._update&&this._update(l,o)):this._remove&&this._remove(o)}this._performRestAdd(a,i)},r.prototype._executeMultiple=function(){var t=this._old,e=this._new,i={},n={},a=[],o=[];this._initIndexMap(t,i,a,"_oldKeyGetter"),this._initIndexMap(e,n,o,"_newKeyGetter");for(var s=0;s<a.length;s++){var l=a[s],u=i[l],f=n[l],h=Ln(u),c=Ln(f);if(h>1&&c===1)this._updateManyToOne&&this._updateManyToOne(f,u),n[l]=null;else if(h===1&&c>1)this._updateOneToMany&&this._updateOneToMany(f,u),n[l]=null;else if(h===1&&c===1)this._update&&this._update(f,u),n[l]=null;else if(h>1&&c>1)this._updateManyToMany&&this._updateManyToMany(f,u),n[l]=null;else if(h>1)for(var v=0;v<h;v++)this._remove&&this._remove(u[v]);else this._remove&&this._remove(u)}this._performRestAdd(o,n)},r.prototype._performRestAdd=function(t,e){for(var i=0;i<t.length;i++){var n=t[i],a=e[n],o=Ln(a);if(o>1)for(var s=0;s<o;s++)this._add&&this._add(a[s]);else o===1&&this._add&&this._add(a);e[n]=null}},r.prototype._initIndexMap=function(t,e,i,n){for(var a=this._diffModeMultiple,o=0;o<t.length;o++){var s="_ec_"+this[n](t[o],o);if(a||(i[o]=s),!!e){var l=e[s],u=Ln(l);u===0?(e[s]=o,a&&i.push(s)):u===1?e[s]=[l,o]:l.push(o)}}},r}();const UM=WM;var YM=function(){function r(t,e){this._encode=t,this._schema=e}return r.prototype.get=function(){return{fullDimensions:this._getFullDimensionNames(),encode:this._encode}},r.prototype._getFullDimensionNames=function(){return this._cachedDimNames||(this._cachedDimNames=this._schema?this._schema.makeOutputDimensionNames():[]),this._cachedDimNames},r}();function $M(r,t){var e={},i=e.encode={},n=Z(),a=[],o=[],s={};A(r.dimensions,function(c){var v=r.getDimensionInfo(c),d=v.coordDim;if(d){var p=v.coordDimIndex;iu(i,d)[p]=c,v.isExtraCoord||(n.set(d,1),XM(v.type)&&(a[0]=c),iu(s,d)[p]=r.getDimensionIndex(v.name)),v.defaultTooltip&&o.push(c)}sm.each(function(g,y){var m=iu(i,y),_=v.otherDims[y];_!=null&&_!==!1&&(m[_]=v.name)})});var l=[],u={};n.each(function(c,v){var d=i[v];u[v]=d[0],l=l.concat(d)}),e.dataDimsOnCoord=l,e.dataDimIndicesOnCoord=G(l,function(c){return r.getDimensionInfo(c).storeDimIndex}),e.encodeFirstDimNotExtra=u;var f=i.label;f&&f.length&&(a=f.slice());var h=i.tooltip;return h&&h.length?o=h.slice():o.length||(o=a.slice()),i.defaultedLabel=a,i.defaultedTooltip=o,e.userOutput=new YM(s,t),e}function iu(r,t){return r.hasOwnProperty(t)||(r[t]=[]),r[t]}function ZM(r){return r==="category"?"ordinal":r==="time"?"time":"float"}function XM(r){return!(r==="ordinal"||r==="time")}var qM=function(){function r(t){this.otherDims={},t!=null&&O(this,t)}return r}();const zo=qM;var KM=gt(),QM={float:"f",int:"i",ordinal:"o",number:"n",time:"t"},v0=function(){function r(t){this.dimensions=t.dimensions,this._dimOmitted=t.dimensionOmitted,this.source=t.source,this._fullDimCount=t.fullDimensionCount,this._updateDimOmitted(t.dimensionOmitted)}return r.prototype.isDimensionOmitted=function(){return this._dimOmitted},r.prototype._updateDimOmitted=function(t){this._dimOmitted=t,t&&(this._dimNameMap||(this._dimNameMap=p0(this.source)))},r.prototype.getSourceDimensionIndex=function(t){return j(this._dimNameMap.get(t),-1)},r.prototype.getSourceDimension=function(t){var e=this.source.dimensionsDefine;if(e)return e[t]},r.prototype.makeStoreSchema=function(){for(var t=this._fullDimCount,e=mm(this.source),i=!g0(t),n="",a=[],o=0,s=0;o<t;o++){var l=void 0,u=void 0,f=void 0,h=this.dimensions[s];if(h&&h.storeDimIndex===o)l=e?h.name:null,u=h.type,f=h.ordinalMeta,s++;else{var c=this.getSourceDimension(o);c&&(l=e?c.name:null,u=c.type)}a.push({property:l,type:u,ordinalMeta:f}),e&&l!=null&&(!h||!h.isCalculationCoord)&&(n+=i?l.replace(/\`/g,"`1").replace(/\$/g,"`2"):l),n+="$",n+=QM[u]||"f",f&&(n+=f.uid),n+="$"}var v=this.source,d=[v.seriesLayoutBy,v.startIndex,n].join("$$");return{dimensions:a,hash:d}},r.prototype.makeOutputDimensionNames=function(){for(var t=[],e=0,i=0;e<this._fullDimCount;e++){var n=void 0,a=this.dimensions[i];if(a&&a.storeDimIndex===e)a.isCalculationCoord||(n=a.name),i++;else{var o=this.getSourceDimension(e);o&&(n=o.name)}t.push(n)}return t},r.prototype.appendCalculationDimension=function(t){this.dimensions.push(t),t.isCalculationCoord=!0,this._fullDimCount++,this._updateDimOmitted(!0)},r}();function c0(r){return r instanceof v0}function d0(r){for(var t=Z(),e=0;e<(r||[]).length;e++){var i=r[e],n=Y(i)?i.name:i;n!=null&&t.get(n)==null&&t.set(n,e)}return t}function p0(r){var t=KM(r);return t.dimNameMap||(t.dimNameMap=d0(r.dimensionsDefine))}function g0(r){return r>30}var In=Y,cr=G,JM=typeof Int32Array>"u"?Array:Int32Array,jM="e\0\0",Ld=-1,tA=["hasItemOption","_nameList","_idList","_invertedIndicesMap","_dimSummary","userOutput","_rawData","_dimValueGetter","_nameDimIdx","_idDimIdx","_nameRepeatCount"],eA=["_approximateExtent"],Id,ho,Pn,Rn,nu,En,au,rA=function(){function r(t,e){this.type="list",this._dimOmitted=!1,this._nameList=[],this._idList=[],this._visual={},this._layout={},this._itemVisuals=[],this._itemLayouts=[],this._graphicEls=[],this._approximateExtent={},this._calculationInfo={},this.hasItemOption=!1,this.TRANSFERABLE_METHODS=["cloneShallow","downSample","minmaxDownSample","lttbDownSample","map"],this.CHANGABLE_METHODS=["filterSelf","selectRange"],this.DOWNSAMPLE_METHODS=["downSample","minmaxDownSample","lttbDownSample"];var i,n=!1;c0(t)?(i=t.dimensions,this._dimOmitted=t.isDimensionOmitted(),this._schema=t):(n=!0,i=t),i=i||["x","y"];for(var a={},o=[],s={},l=!1,u={},f=0;f<i.length;f++){var h=i[f],c=W(h)?new zo({name:h}):h instanceof zo?h:new zo(h),v=c.name;c.type=c.type||"float",c.coordDim||(c.coordDim=v,c.coordDimIndex=0);var d=c.otherDims=c.otherDims||{};o.push(v),a[v]=c,u[v]!=null&&(l=!0),c.createInvertedIndices&&(s[v]=[]),d.itemName===0&&(this._nameDimIdx=f),d.itemId===0&&(this._idDimIdx=f),n&&(c.storeDimIndex=f)}if(this.dimensions=o,this._dimInfos=a,this._initGetDimensionInfo(l),this.hostModel=e,this._invertedIndicesMap=s,this._dimOmitted){var p=this._dimIdxToName=Z();A(o,function(g){p.set(a[g].storeDimIndex,g)})}}return r.prototype.getDimension=function(t){var e=this._recognizeDimIndex(t);if(e==null)return t;if(e=t,!this._dimOmitted)return this.dimensions[e];var i=this._dimIdxToName.get(e);if(i!=null)return i;var n=this._schema.getSourceDimension(e);if(n)return n.name},r.prototype.getDimensionIndex=function(t){var e=this._recognizeDimIndex(t);if(e!=null)return e;if(t==null)return-1;var i=this._getDimInfo(t);return i?i.storeDimIndex:this._dimOmitted?this._schema.getSourceDimensionIndex(t):-1},r.prototype._recognizeDimIndex=function(t){if(dt(t)||t!=null&&!isNaN(t)&&!this._getDimInfo(t)&&(!this._dimOmitted||this._schema.getSourceDimensionIndex(t)<0))return+t},r.prototype._getStoreDimIndex=function(t){var e=this.getDimensionIndex(t);return e},r.prototype.getDimensionInfo=function(t){return this._getDimInfo(this.getDimension(t))},r.prototype._initGetDimensionInfo=function(t){var e=this._dimInfos;this._getDimInfo=t?function(i){return e.hasOwnProperty(i)?e[i]:void 0}:function(i){return e[i]}},r.prototype.getDimensionsOnCoord=function(){return this._dimSummary.dataDimsOnCoord.slice()},r.prototype.mapDimension=function(t,e){var i=this._dimSummary;if(e==null)return i.encodeFirstDimNotExtra[t];var n=i.encode[t];return n?n[e]:null},r.prototype.mapDimensionsAll=function(t){var e=this._dimSummary,i=e.encode[t];return(i||[]).slice()},r.prototype.getStore=function(){return this._store},r.prototype.initData=function(t,e,i){var n=this,a;if(t instanceof hf&&(a=t),!a){var o=this.dimensions,s=xh(t)||Wt(t)?new _m(t,o.length):t;a=new hf;var l=cr(o,function(u){return{type:n._dimInfos[u].type,property:u}});a.initData(s,l,i)}this._store=a,this._nameList=(e||[]).slice(),this._idList=[],this._nameRepeatCount={},this._doInit(0,a.count()),this._dimSummary=$M(this,this._schema),this.userOutput=this._dimSummary.userOutput},r.prototype.appendData=function(t){var e=this._store.appendData(t);this._doInit(e[0],e[1])},r.prototype.appendValues=function(t,e){var i=this._store.appendValues(t,e&&e.length),n=i.start,a=i.end,o=this._shouldMakeIdFromName();if(this._updateOrdinalMeta(),e)for(var s=n;s<a;s++){var l=s-n;this._nameList[s]=e[l],o&&au(this,s)}},r.prototype._updateOrdinalMeta=function(){for(var t=this._store,e=this.dimensions,i=0;i<e.length;i++){var n=this._dimInfos[e[i]];n.ordinalMeta&&t.collectOrdinalMeta(n.storeDimIndex,n.ordinalMeta)}},r.prototype._shouldMakeIdFromName=function(){var t=this._store.getProvider();return this._idDimIdx==null&&t.getSource().sourceFormat!==Ar&&!t.fillStorage},r.prototype._doInit=function(t,e){if(!(t>=e)){var i=this._store,n=i.getProvider();this._updateOrdinalMeta();var a=this._nameList,o=this._idList,s=n.getSource().sourceFormat,l=s===me;if(l&&!n.pure)for(var u=[],f=t;f<e;f++){var h=n.getItem(f,u);if(!this.hasItemOption&&qS(h)&&(this.hasItemOption=!0),h){var c=h.name;a[f]==null&&c!=null&&(a[f]=Kt(c,null));var v=h.id;o[f]==null&&v!=null&&(o[f]=Kt(v,null))}}if(this._shouldMakeIdFromName())for(var f=t;f<e;f++)au(this,f);Id(this)}},r.prototype.getApproximateExtent=function(t){return this._approximateExtent[t]||this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.setApproximateExtent=function(t,e){e=this.getDimension(e),this._approximateExtent[e]=t.slice()},r.prototype.getCalculationInfo=function(t){return this._calculationInfo[t]},r.prototype.setCalculationInfo=function(t,e){In(t)?O(this._calculationInfo,t):this._calculationInfo[t]=e},r.prototype.getName=function(t){var e=this.getRawIndex(t),i=this._nameList[e];return i==null&&this._nameDimIdx!=null&&(i=Pn(this,this._nameDimIdx,e)),i==null&&(i=""),i},r.prototype._getCategory=function(t,e){var i=this._store.get(t,e),n=this._store.getOrdinalMeta(t);return n?n.categories[i]:i},r.prototype.getId=function(t){return ho(this,this.getRawIndex(t))},r.prototype.count=function(){return this._store.count()},r.prototype.get=function(t,e){var i=this._store,n=this._dimInfos[t];if(n)return i.get(n.storeDimIndex,e)},r.prototype.getByRawIndex=function(t,e){var i=this._store,n=this._dimInfos[t];if(n)return i.getByRawIndex(n.storeDimIndex,e)},r.prototype.getIndices=function(){return this._store.getIndices()},r.prototype.getDataExtent=function(t){return this._store.getDataExtent(this._getStoreDimIndex(t))},r.prototype.getSum=function(t){return this._store.getSum(this._getStoreDimIndex(t))},r.prototype.getMedian=function(t){return this._store.getMedian(this._getStoreDimIndex(t))},r.prototype.getValues=function(t,e){var i=this,n=this._store;return V(t)?n.getValues(cr(t,function(a){return i._getStoreDimIndex(a)}),e):n.getValues(t)},r.prototype.hasValue=function(t){for(var e=this._dimSummary.dataDimIndicesOnCoord,i=0,n=e.length;i<n;i++)if(isNaN(this._store.get(e[i],t)))return!1;return!0},r.prototype.indexOfName=function(t){for(var e=0,i=this._store.count();e<i;e++)if(this.getName(e)===t)return e;return-1},r.prototype.getRawIndex=function(t){return this._store.getRawIndex(t)},r.prototype.indexOfRawIndex=function(t){return this._store.indexOfRawIndex(t)},r.prototype.rawIndexOf=function(t,e){var i=t&&this._invertedIndicesMap[t],n=i&&i[e];return n==null||isNaN(n)?Ld:n},r.prototype.indicesOfNearest=function(t,e,i){return this._store.indicesOfNearest(this._getStoreDimIndex(t),e,i)},r.prototype.each=function(t,e,i){K(t)&&(i=e,e=t,t=[]);var n=i||this,a=cr(Rn(t),this._getStoreDimIndex,this);this._store.each(a,n?$(e,n):e)},r.prototype.filterSelf=function(t,e,i){K(t)&&(i=e,e=t,t=[]);var n=i||this,a=cr(Rn(t),this._getStoreDimIndex,this);return this._store=this._store.filter(a,n?$(e,n):e),this},r.prototype.selectRange=function(t){var e=this,i={},n=vt(t);return A(n,function(a){var o=e._getStoreDimIndex(a);i[o]=t[a]}),this._store=this._store.selectRange(i),this},r.prototype.mapArray=function(t,e,i){K(t)&&(i=e,e=t,t=[]),i=i||this;var n=[];return this.each(t,function(){n.push(e&&e.apply(this,arguments))},i),n},r.prototype.map=function(t,e,i,n){var a=i||n||this,o=cr(Rn(t),this._getStoreDimIndex,this),s=En(this);return s._store=this._store.map(o,a?$(e,a):e),s},r.prototype.modify=function(t,e,i,n){var a=i||n||this,o=cr(Rn(t),this._getStoreDimIndex,this);this._store.modify(o,a?$(e,a):e)},r.prototype.downSample=function(t,e,i,n){var a=En(this);return a._store=this._store.downSample(this._getStoreDimIndex(t),e,i,n),a},r.prototype.minmaxDownSample=function(t,e){var i=En(this);return i._store=this._store.minmaxDownSample(this._getStoreDimIndex(t),e),i},r.prototype.lttbDownSample=function(t,e){var i=En(this);return i._store=this._store.lttbDownSample(this._getStoreDimIndex(t),e),i},r.prototype.getRawDataItem=function(t){return this._store.getRawDataItem(t)},r.prototype.getItemModel=function(t){var e=this.hostModel,i=this.getRawDataItem(t);return new kt(i,e,e&&e.ecModel)},r.prototype.diff=function(t){var e=this;return new UM(t?t.getStore().getIndices():[],this.getStore().getIndices(),function(i){return ho(t,i)},function(i){return ho(e,i)})},r.prototype.getVisual=function(t){var e=this._visual;return e&&e[t]},r.prototype.setVisual=function(t,e){this._visual=this._visual||{},In(t)?O(this._visual,t):this._visual[t]=e},r.prototype.getItemVisual=function(t,e){var i=this._itemVisuals[t],n=i&&i[e];return n==null?this.getVisual(e):n},r.prototype.hasItemVisual=function(){return this._itemVisuals.length>0},r.prototype.ensureUniqueItemVisual=function(t,e){var i=this._itemVisuals,n=i[t];n||(n=i[t]={});var a=n[e];return a==null&&(a=this.getVisual(e),V(a)?a=a.slice():In(a)&&(a=O({},a)),n[e]=a),a},r.prototype.setItemVisual=function(t,e,i){var n=this._itemVisuals[t]||{};this._itemVisuals[t]=n,In(e)?O(n,e):n[e]=i},r.prototype.clearAllVisual=function(){this._visual={},this._itemVisuals=[]},r.prototype.setLayout=function(t,e){In(t)?O(this._layout,t):this._layout[t]=e},r.prototype.getLayout=function(t){return this._layout[t]},r.prototype.getItemLayout=function(t){return this._itemLayouts[t]},r.prototype.setItemLayout=function(t,e,i){this._itemLayouts[t]=i?O(this._itemLayouts[t]||{},e):e},r.prototype.clearItemLayouts=function(){this._itemLayouts.length=0},r.prototype.setItemGraphicEl=function(t,e){var i=this.hostModel&&this.hostModel.seriesIndex;ux(i,this.dataType,t,e),this._graphicEls[t]=e},r.prototype.getItemGraphicEl=function(t){return this._graphicEls[t]},r.prototype.eachItemGraphicEl=function(t,e){A(this._graphicEls,function(i,n){i&&t&&t.call(e,i,n)})},r.prototype.cloneShallow=function(t){return t||(t=new r(this._schema?this._schema:cr(this.dimensions,this._getDimInfo,this),this.hostModel)),nu(t,this),t._store=this._store,t},r.prototype.wrapMethod=function(t,e){var i=this[t];!K(i)||(this.__wrappedMethods=this.__wrappedMethods||[],this.__wrappedMethods.push(t),this[t]=function(){var n=i.apply(this,arguments);return e.apply(this,[n].concat(Wf(arguments)))})},r.internalField=function(){Id=function(t){var e=t._invertedIndicesMap;A(e,function(i,n){var a=t._dimInfos[n],o=a.ordinalMeta,s=t._store;if(o){i=e[n]=new JM(o.categories.length);for(var l=0;l<i.length;l++)i[l]=Ld;for(var l=0;l<s.count();l++)i[s.get(a.storeDimIndex,l)]=l}})},Pn=function(t,e,i){return Kt(t._getCategory(e,i),null)},ho=function(t,e){var i=t._idList[e];return i==null&&t._idDimIdx!=null&&(i=Pn(t,t._idDimIdx,e)),i==null&&(i=jM+e),i},Rn=function(t){return V(t)||(t=t!=null?[t]:[]),t},En=function(t){var e=new r(t._schema?t._schema:cr(t.dimensions,t._getDimInfo,t),t.hostModel);return nu(e,t),e},nu=function(t,e){A(tA.concat(e.__wrappedMethods||[]),function(i){e.hasOwnProperty(i)&&(t[i]=e[i])}),t.__wrappedMethods=e.__wrappedMethods,A(eA,function(i){t[i]=et(e[i])}),t._calculationInfo=O({},e._calculationInfo)},au=function(t,e){var i=t._nameList,n=t._idList,a=t._nameDimIdx,o=t._idDimIdx,s=i[e],l=n[e];if(s==null&&a!=null&&(i[e]=s=Pn(t,a,e)),l==null&&o!=null&&(n[e]=l=Pn(t,o,e)),l==null&&s!=null){var u=t._nameRepeatCount,f=u[s]=(u[s]||0)+1;l=s,f>1&&(l+="__ec__"+f),n[e]=l}}}(),r}();const y0=rA;function m0(r,t){xh(r)||(r=bh(r)),t=t||{};var e=t.coordDimensions||[],i=t.dimensionsDefine||r.dimensionsDefine||[],n=Z(),a=[],o=nA(r,e,i,t.dimensionsCount),s=t.canOmitUnusedDimensions&&g0(o),l=i===r.dimensionsDefine,u=l?p0(r):d0(i),f=t.encodeDefine;!f&&t.encodeDefaulter&&(f=t.encodeDefaulter(r,o));for(var h=Z(f),c=new Tm(o),v=0;v<c.length;v++)c[v]=-1;function d(M){var D=c[M];if(D<0){var C=i[M],L=Y(C)?C:{name:C},I=new zo,P=L.name;P!=null&&u.get(P)!=null&&(I.name=I.displayName=P),L.type!=null&&(I.type=L.type),L.displayName!=null&&(I.displayName=L.displayName);var R=a.length;return c[M]=R,I.storeDimIndex=M,a.push(I),I}return a[D]}if(!s)for(var v=0;v<o;v++)d(v);h.each(function(M,D){var C=At(M).slice();if(C.length===1&&!W(C[0])&&C[0]<0){h.set(D,!1);return}var L=h.set(D,[]);A(C,function(I,P){var R=W(I)?u.get(I):I;R!=null&&R<o&&(L[P]=R,g(d(R),D,P))})});var p=0;A(e,function(M){var D,C,L,I;if(W(M))D=M,I={};else{I=M,D=I.name;var P=I.ordinalMeta;I.ordinalMeta=null,I=O({},I),I.ordinalMeta=P,C=I.dimsDef,L=I.otherDims,I.name=I.coordDim=I.coordDimIndex=I.dimsDef=I.otherDims=null}var R=h.get(D);if(R!==!1){if(R=At(R),!R.length)for(var E=0;E<(C&&C.length||1);E++){for(;p<o&&d(p).coordDim!=null;)p++;p<o&&R.push(p++)}A(R,function(z,k){var B=d(z);if(l&&I.type!=null&&(B.type=I.type),g(rt(B,I),D,k),B.name==null&&C){var F=C[k];!Y(F)&&(F={name:F}),B.name=B.displayName=F.name,B.defaultTooltip=F.defaultTooltip}L&&rt(B.otherDims,L)})}});function g(M,D,C){sm.get(D)!=null?M.otherDims[D]=C:(M.coordDim=D,M.coordDimIndex=C,n.set(D,!0))}var y=t.generateCoord,m=t.generateCoordCount,_=m!=null;m=y?m||1:0;var S=y||"value";function x(M){M.name==null&&(M.name=M.coordDim)}if(s)A(a,function(M){x(M)}),a.sort(function(M,D){return M.storeDimIndex-D.storeDimIndex});else for(var w=0;w<o;w++){var b=d(w),T=b.coordDim;T==null&&(b.coordDim=aA(S,n,_),b.coordDimIndex=0,(!y||m<=0)&&(b.isExtraCoord=!0),m--),x(b),b.type==null&&(fm(r,w)===Pt.Must||b.isExtraCoord&&(b.otherDims.itemName!=null||b.otherDims.seriesName!=null))&&(b.type="ordinal")}return iA(a),new v0({source:r,dimensions:a,fullDimensionCount:o,dimensionOmitted:s})}function iA(r){for(var t=Z(),e=0;e<r.length;e++){var i=r[e],n=i.name,a=t.get(n)||0;a>0&&(i.name=n+(a-1)),a++,t.set(n,a)}}function nA(r,t,e,i){var n=Math.max(r.dimensionsDetectedCount||1,t.length,e.length,i||0);return A(t,function(a){var o;Y(a)&&(o=a.dimsDef)&&(n=Math.max(n,o.length))}),n}function aA(r,t,e){if(e||t.hasKey(r)){for(var i=0;t.hasKey(r+i);)i++;r+=i}return t.set(r,!0),r}var oA=function(){function r(t){this.coordSysDims=[],this.axisMap=Z(),this.categoryAxisMap=Z(),this.coordSysName=t}return r}();function sA(r){var t=r.get("coordinateSystem"),e=new oA(t),i=lA[t];if(i)return i(r,e,e.axisMap,e.categoryAxisMap),e}var lA={cartesian2d:function(r,t,e,i){var n=r.getReferringComponents("xAxis",Qt).models[0],a=r.getReferringComponents("yAxis",Qt).models[0];t.coordSysDims=["x","y"],e.set("x",n),e.set("y",a),zi(n)&&(i.set("x",n),t.firstCategoryDimIndex=0),zi(a)&&(i.set("y",a),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},singleAxis:function(r,t,e,i){var n=r.getReferringComponents("singleAxis",Qt).models[0];t.coordSysDims=["single"],e.set("single",n),zi(n)&&(i.set("single",n),t.firstCategoryDimIndex=0)},polar:function(r,t,e,i){var n=r.getReferringComponents("polar",Qt).models[0],a=n.findAxisModel("radiusAxis"),o=n.findAxisModel("angleAxis");t.coordSysDims=["radius","angle"],e.set("radius",a),e.set("angle",o),zi(a)&&(i.set("radius",a),t.firstCategoryDimIndex=0),zi(o)&&(i.set("angle",o),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=1))},geo:function(r,t,e,i){t.coordSysDims=["lng","lat"]},parallel:function(r,t,e,i){var n=r.ecModel,a=n.getComponent("parallel",r.get("parallelIndex")),o=t.coordSysDims=a.dimensions.slice();A(a.parallelAxisIndex,function(s,l){var u=n.getComponent("parallelAxis",s),f=o[l];e.set(f,u),zi(u)&&(i.set(f,u),t.firstCategoryDimIndex==null&&(t.firstCategoryDimIndex=l))})}};function zi(r){return r.get("type")==="category"}function uA(r,t,e){e=e||{};var i=e.byIndex,n=e.stackedCoordDimension,a,o,s;fA(t)?a=t:(o=t.schema,a=o.dimensions,s=t.store);var l=!!(r&&r.get("stack")),u,f,h,c;if(A(a,function(m,_){W(m)&&(a[_]=m={name:m}),l&&!m.isExtraCoord&&(!i&&!u&&m.ordinalMeta&&(u=m),!f&&m.type!=="ordinal"&&m.type!=="time"&&(!n||n===m.coordDim)&&(f=m))}),f&&!i&&!u&&(i=!0),f){h="__\0ecstackresult_"+r.id,c="__\0ecstackedover_"+r.id,u&&(u.createInvertedIndices=!0);var v=f.coordDim,d=f.type,p=0;A(a,function(m){m.coordDim===v&&p++});var g={name:h,coordDim:v,coordDimIndex:p,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length},y={name:c,coordDim:c,coordDimIndex:p+1,type:d,isExtraCoord:!0,isCalculationCoord:!0,storeDimIndex:a.length+1};o?(s&&(g.storeDimIndex=s.ensureCalculationDimension(c,d),y.storeDimIndex=s.ensureCalculationDimension(h,d)),o.appendCalculationDimension(g),o.appendCalculationDimension(y)):(a.push(g),a.push(y))}return{stackedDimension:f&&f.name,stackedByDimension:u&&u.name,isStackedByIndex:i,stackedOverDimension:c,stackResultDimension:h}}function fA(r){return!c0(r.schema)}function on(r,t){return!!t&&t===r.getCalculationInfo("stackedDimension")}function hA(r,t){return on(r,t)?r.getCalculationInfo("stackResultDimension"):t}function vA(r,t){var e=r.get("coordinateSystem"),i=wh.get(e),n;return t&&t.coordSysDims&&(n=G(t.coordSysDims,function(a){var o={name:a},s=t.axisMap.get(a);if(s){var l=s.get("type");o.type=ZM(l)}return o})),n||(n=i&&(i.getDimensionsInfo?i.getDimensionsInfo():i.dimensions.slice())||["x","y"]),n}function cA(r,t,e){var i,n;return e&&A(r,function(a,o){var s=a.coordDim,l=e.categoryAxisMap.get(s);l&&(i==null&&(i=o),a.ordinalMeta=l.getOrdinalMeta(),t&&(a.createInvertedIndices=!0)),a.otherDims.itemName!=null&&(n=!0)}),!n&&i!=null&&(r[i].otherDims.itemName=0),i}function kh(r,t,e){e=e||{};var i=t.getSourceManager(),n,a=!1;r?(a=!0,n=bh(r)):(n=i.getSource(),a=n.sourceFormat===me);var o=sA(t),s=vA(t,o),l=e.useEncodeDefaulter,u=K(l)?l:l?yt(Jb,s,t):null,f={coordDimensions:s,generateCoord:e.generateCoord,encodeDefine:t.getEncode(),encodeDefaulter:u,canOmitUnusedDimensions:!a},h=m0(n,f),c=cA(h.dimensions,e.createInvertedIndices,o),v=a?null:i.getSharedDataStore(h),d=uA(t,{schema:h,store:v}),p=new y0(h,t);p.setCalculationInfo(d);var g=c!=null&&dA(n)?function(y,m,_,S){return S===c?_:this.defaultDimValueGetter(y,m,_,S)}:null;return p.hasItemOption=!1,p.initData(a?n:v,null,g),p}function dA(r){if(r.sourceFormat===me){var t=pA(r.data||[]);return!V(Aa(t))}}function pA(r){for(var t=0;t<r.length&&r[t]==null;)t++;return r[t]}var _0=function(){function r(t){this._setting=t||{},this._extent=[1/0,-1/0]}return r.prototype.getSetting=function(t){return this._setting[t]},r.prototype.unionExtent=function(t){var e=this._extent;t[0]<e[0]&&(e[0]=t[0]),t[1]>e[1]&&(e[1]=t[1])},r.prototype.unionExtentFromData=function(t,e){this.unionExtent(t.getApproximateExtent(e))},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.setExtent=function(t,e){var i=this._extent;isNaN(t)||(i[0]=t),isNaN(e)||(i[1]=e)},r.prototype.isInExtentRange=function(t){return this._extent[0]<=t&&this._extent[1]>=t},r.prototype.isBlank=function(){return this._isBlank},r.prototype.setBlank=function(t){this._isBlank=t},r}();Cs(_0);const or=_0;var gA=0,yA=function(){function r(t){this.categories=t.categories||[],this._needCollect=t.needCollect,this._deduplication=t.deduplication,this.uid=++gA}return r.createByAxisModel=function(t){var e=t.option,i=e.data,n=i&&G(i,mA);return new r({categories:n,needCollect:!n,deduplication:e.dedplication!==!1})},r.prototype.getOrdinal=function(t){return this._getOrCreateMap().get(t)},r.prototype.parseAndCollect=function(t){var e,i=this._needCollect;if(!W(t)&&!i)return t;if(i&&!this._deduplication)return e=this.categories.length,this.categories[e]=t,e;var n=this._getOrCreateMap();return e=n.get(t),e==null&&(i?(e=this.categories.length,this.categories[e]=t,n.set(t,e)):e=NaN),e},r.prototype._getOrCreateMap=function(){return this._map||(this._map=Z(this.categories))},r}();function mA(r){return Y(r)&&r.value!=null?r.value:r+""}const xf=yA;function bf(r){return r.type==="interval"||r.type==="log"}function _A(r,t,e,i){var n={},a=r[1]-r[0],o=n.interval=zg(a/t,!0);e!=null&&o<e&&(o=n.interval=e),i!=null&&o>i&&(o=n.interval=i);var s=n.intervalPrecision=S0(o),l=n.niceTickExtent=[bt(Math.ceil(r[0]/o)*o,s),bt(Math.floor(r[1]/o)*o,s)];return SA(l,r),n}function ou(r){var t=Math.pow(10,jf(r)),e=r/t;return e?e===2?e=3:e===3?e=5:e*=2:e=1,bt(e*t)}function S0(r){return Xe(r)+2}function Pd(r,t,e){r[t]=Math.max(Math.min(r[t],e[1]),e[0])}function SA(r,t){!isFinite(r[0])&&(r[0]=t[0]),!isFinite(r[1])&&(r[1]=t[1]),Pd(r,0,t),Pd(r,1,t),r[0]>r[1]&&(r[0]=r[1])}function qs(r,t){return r>=t[0]&&r<=t[1]}function Ks(r,t){return t[1]===t[0]?.5:(r-t[0])/(t[1]-t[0])}function Qs(r,t){return r*(t[1]-t[0])+t[0]}var w0=function(r){N(t,r);function t(e){var i=r.call(this,e)||this;i.type="ordinal";var n=i.getSetting("ordinalMeta");return n||(n=new xf({})),V(n)&&(n=new xf({categories:G(n,function(a){return Y(a)?a.value:a})})),i._ordinalMeta=n,i._extent=i.getSetting("extent")||[0,n.categories.length-1],i}return t.prototype.parse=function(e){return e==null?NaN:W(e)?this._ordinalMeta.getOrdinal(e):Math.round(e)},t.prototype.contain=function(e){return e=this.parse(e),qs(e,this._extent)&&this._ordinalMeta.categories[e]!=null},t.prototype.normalize=function(e){return e=this._getTickNumber(this.parse(e)),Ks(e,this._extent)},t.prototype.scale=function(e){return e=Math.round(Qs(e,this._extent)),this.getRawOrdinalNumber(e)},t.prototype.getTicks=function(){for(var e=[],i=this._extent,n=i[0];n<=i[1];)e.push({value:n}),n++;return e},t.prototype.getMinorTicks=function(e){},t.prototype.setSortInfo=function(e){if(e==null){this._ordinalNumbersByTick=this._ticksByOrdinalNumber=null;return}for(var i=e.ordinalNumbers,n=this._ordinalNumbersByTick=[],a=this._ticksByOrdinalNumber=[],o=0,s=this._ordinalMeta.categories.length,l=Math.min(s,i.length);o<l;++o){var u=i[o];n[o]=u,a[u]=o}for(var f=0;o<s;++o){for(;a[f]!=null;)f++;n.push(f),a[f]=o}},t.prototype._getTickNumber=function(e){var i=this._ticksByOrdinalNumber;return i&&e>=0&&e<i.length?i[e]:e},t.prototype.getRawOrdinalNumber=function(e){var i=this._ordinalNumbersByTick;return i&&e>=0&&e<i.length?i[e]:e},t.prototype.getLabel=function(e){if(!this.isBlank()){var i=this.getRawOrdinalNumber(e.value),n=this._ordinalMeta.categories[i];return n==null?"":n+""}},t.prototype.count=function(){return this._extent[1]-this._extent[0]+1},t.prototype.unionExtentFromData=function(e,i){this.unionExtent(e.getApproximateExtent(i))},t.prototype.isInExtentRange=function(e){return e=this._getTickNumber(e),this._extent[0]<=e&&this._extent[1]>=e},t.prototype.getOrdinalMeta=function(){return this._ordinalMeta},t.prototype.calcNiceTicks=function(){},t.prototype.calcNiceExtent=function(){},t.type="ordinal",t}(or);or.registerClass(w0);const x0=w0;var Kr=bt,b0=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="interval",e._interval=0,e._intervalPrecision=2,e}return t.prototype.parse=function(e){return e},t.prototype.contain=function(e){return qs(e,this._extent)},t.prototype.normalize=function(e){return Ks(e,this._extent)},t.prototype.scale=function(e){return Qs(e,this._extent)},t.prototype.setExtent=function(e,i){var n=this._extent;isNaN(e)||(n[0]=parseFloat(e)),isNaN(i)||(n[1]=parseFloat(i))},t.prototype.unionExtent=function(e){var i=this._extent;e[0]<i[0]&&(i[0]=e[0]),e[1]>i[1]&&(i[1]=e[1]),this.setExtent(i[0],i[1])},t.prototype.getInterval=function(){return this._interval},t.prototype.setInterval=function(e){this._interval=e,this._niceExtent=this._extent.slice(),this._intervalPrecision=S0(e)},t.prototype.getTicks=function(e){var i=this._interval,n=this._extent,a=this._niceExtent,o=this._intervalPrecision,s=[];if(!i)return s;var l=1e4;n[0]<a[0]&&(e?s.push({value:Kr(a[0]-i,o)}):s.push({value:n[0]}));for(var u=a[0];u<=a[1]&&(s.push({value:u}),u=Kr(u+i,o),u!==s[s.length-1].value);)if(s.length>l)return[];var f=s.length?s[s.length-1].value:a[1];return n[1]>f&&(e?s.push({value:Kr(f+i,o)}):s.push({value:n[1]})),s},t.prototype.getMinorTicks=function(e){for(var i=this.getTicks(!0),n=[],a=this.getExtent(),o=1;o<i.length;o++){for(var s=i[o],l=i[o-1],u=0,f=[],h=s.value-l.value,c=h/e;u<e-1;){var v=Kr(l.value+(u+1)*c);v>a[0]&&v<a[1]&&f.push(v),u++}n.push(f)}return n},t.prototype.getLabel=function(e,i){if(e==null)return"";var n=i&&i.precision;n==null?n=Xe(e.value)||0:n==="auto"&&(n=this._intervalPrecision);var a=Kr(e.value,n,!0);return em(a)},t.prototype.calcNiceTicks=function(e,i,n){e=e||5;var a=this._extent,o=a[1]-a[0];if(!!isFinite(o)){o<0&&(o=-o,a.reverse());var s=_A(a,e,i,n);this._intervalPrecision=s.intervalPrecision,this._interval=s.interval,this._niceExtent=s.niceTickExtent}},t.prototype.calcNiceExtent=function(e){var i=this._extent;if(i[0]===i[1])if(i[0]!==0){var n=Math.abs(i[0]);e.fixMax||(i[1]+=n/2),i[0]-=n/2}else i[1]=1;var a=i[1]-i[0];isFinite(a)||(i[0]=0,i[1]=1),this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval);var o=this._interval;e.fixMin||(i[0]=Kr(Math.floor(i[0]/o)*o)),e.fixMax||(i[1]=Kr(Math.ceil(i[1]/o)*o))},t.prototype.setNiceExtent=function(e,i){this._niceExtent=[e,i]},t.type="interval",t}(or);or.registerClass(b0);const pi=b0;var T0=typeof Float32Array<"u",wA=T0?Float32Array:Array;function qe(r){return V(r)?T0?new Float32Array(r):r:new wA(r)}var xA="__ec_stack_";function Oh(r){return r.get("stack")||xA+r.seriesIndex}function Bh(r){return r.dim+r.index}function C0(r,t){var e=[];return t.eachSeriesByType(r,function(i){A0(i)&&e.push(i)}),e}function bA(r){var t={};A(r,function(l){var u=l.coordinateSystem,f=u.getBaseAxis();if(!(f.type!=="time"&&f.type!=="value"))for(var h=l.getData(),c=f.dim+"_"+f.index,v=h.getDimensionIndex(h.mapDimension(f.dim)),d=h.getStore(),p=0,g=d.count();p<g;++p){var y=d.get(v,p);t[c]?t[c].push(y):t[c]=[y]}});var e={};for(var i in t)if(t.hasOwnProperty(i)){var n=t[i];if(n){n.sort(function(l,u){return l-u});for(var a=null,o=1;o<n.length;++o){var s=n[o]-n[o-1];s>0&&(a=a===null?s:Math.min(a,s))}e[i]=a}}return e}function M0(r){var t=bA(r),e=[];return A(r,function(i){var n=i.coordinateSystem,a=n.getBaseAxis(),o=a.getExtent(),s;if(a.type==="category")s=a.getBandWidth();else if(a.type==="value"||a.type==="time"){var l=a.dim+"_"+a.index,u=t[l],f=Math.abs(o[1]-o[0]),h=a.scale.getExtent(),c=Math.abs(h[1]-h[0]);s=u?f/c*u:f}else{var v=i.getData();s=Math.abs(o[1]-o[0])/v.count()}var d=st(i.get("barWidth"),s),p=st(i.get("barMaxWidth"),s),g=st(i.get("barMinWidth")||(D0(i)?.5:1),s),y=i.get("barGap"),m=i.get("barCategoryGap");e.push({bandWidth:s,barWidth:d,barMaxWidth:p,barMinWidth:g,barGap:y,barCategoryGap:m,axisKey:Bh(a),stackId:Oh(i)})}),TA(e)}function TA(r){var t={};A(r,function(i,n){var a=i.axisKey,o=i.bandWidth,s=t[a]||{bandWidth:o,remainedWidth:o,autoWidthCount:0,categoryGap:null,gap:"20%",stacks:{}},l=s.stacks;t[a]=s;var u=i.stackId;l[u]||s.autoWidthCount++,l[u]=l[u]||{width:0,maxWidth:0};var f=i.barWidth;f&&!l[u].width&&(l[u].width=f,f=Math.min(s.remainedWidth,f),s.remainedWidth-=f);var h=i.barMaxWidth;h&&(l[u].maxWidth=h);var c=i.barMinWidth;c&&(l[u].minWidth=c);var v=i.barGap;v!=null&&(s.gap=v);var d=i.barCategoryGap;d!=null&&(s.categoryGap=d)});var e={};return A(t,function(i,n){e[n]={};var a=i.stacks,o=i.bandWidth,s=i.categoryGap;if(s==null){var l=vt(a).length;s=Math.max(35-l*4,15)+"%"}var u=st(s,o),f=st(i.gap,1),h=i.remainedWidth,c=i.autoWidthCount,v=(h-u)/(c+(c-1)*f);v=Math.max(v,0),A(a,function(y){var m=y.maxWidth,_=y.minWidth;if(y.width){var S=y.width;m&&(S=Math.min(S,m)),_&&(S=Math.max(S,_)),y.width=S,h-=S+f*S,c--}else{var S=v;m&&m<S&&(S=Math.min(m,h)),_&&_>S&&(S=_),S!==v&&(y.width=S,h-=S+f*S,c--)}}),v=(h-u)/(c+(c-1)*f),v=Math.max(v,0);var d=0,p;A(a,function(y,m){y.width||(y.width=v),p=y,d+=y.width*(1+f)}),p&&(d-=p.width*f);var g=-d/2;A(a,function(y,m){e[n][m]=e[n][m]||{bandWidth:o,offset:g,width:y.width},g+=y.width*(1+f)})}),e}function CA(r,t,e){if(r&&t){var i=r[Bh(t)];return i!=null&&e!=null?i[Oh(e)]:i}}function MA(r,t){var e=C0(r,t),i=M0(e);A(e,function(n){var a=n.getData(),o=n.coordinateSystem,s=o.getBaseAxis(),l=Oh(n),u=i[Bh(s)][l],f=u.offset,h=u.width;a.setLayout({bandWidth:u.bandWidth,offset:f,size:h})})}function AA(r){return{seriesType:r,plan:Ah(),reset:function(t){if(!!A0(t)){var e=t.getData(),i=t.coordinateSystem,n=i.getBaseAxis(),a=i.getOtherAxis(n),o=e.getDimensionIndex(e.mapDimension(a.dim)),s=e.getDimensionIndex(e.mapDimension(n.dim)),l=t.get("showBackground",!0),u=e.mapDimension(a.dim),f=e.getCalculationInfo("stackResultDimension"),h=on(e,u)&&!!e.getCalculationInfo("stackedOnSeries"),c=a.isHorizontal(),v=DA(n,a),d=D0(t),p=t.get("barMinHeight")||0,g=f&&e.getDimensionIndex(f),y=e.getLayout("size"),m=e.getLayout("offset");return{progress:function(_,S){for(var x=_.count,w=d&&qe(x*3),b=d&&l&&qe(x*3),T=d&&qe(x),M=i.master.getRect(),D=c?M.width:M.height,C,L=S.getStore(),I=0;(C=_.next())!=null;){var P=L.get(h?g:o,C),R=L.get(s,C),E=v,z=void 0;h&&(z=+P-L.get(o,C));var k=void 0,B=void 0,F=void 0,H=void 0;if(c){var U=i.dataToPoint([P,R]);if(h){var J=i.dataToPoint([z,R]);E=J[0]}k=E,B=U[1]+m,F=U[0]-E,H=y,Math.abs(F)<p&&(F=(F<0?-1:1)*p)}else{var U=i.dataToPoint([R,P]);if(h){var J=i.dataToPoint([R,z]);E=J[1]}k=U[0]+m,B=E,F=y,H=U[1]-E,Math.abs(H)<p&&(H=(H<=0?-1:1)*p)}d?(w[I]=k,w[I+1]=B,w[I+2]=c?F:H,b&&(b[I]=c?M.x:k,b[I+1]=c?B:M.y,b[I+2]=D),T[C]=C):S.setItemLayout(C,{x:k,y:B,width:F,height:H}),I+=3}d&&S.setLayout({largePoints:w,largeDataIndices:T,largeBackgroundPoints:b,valueAxisHorizontal:c})}}}}}}function A0(r){return r.coordinateSystem&&r.coordinateSystem.type==="cartesian2d"}function D0(r){return r.pipelineContext&&r.pipelineContext.large}function DA(r,t){var e=t.model.get("startValue");return e||(e=0),t.toGlobalCoord(t.dataToCoord(t.type==="log"?e>0?e:1:e))}var LA=function(r,t,e,i){for(;e<i;){var n=e+i>>>1;r[n][1]<t?e=n+1:i=n}return e},L0=function(r){N(t,r);function t(e){var i=r.call(this,e)||this;return i.type="time",i}return t.prototype.getLabel=function(e){var i=this.getSetting("useUTC");return Ns(e.value,bc[Wb(ji(this._minLevelUnit))]||bc.second,i,this.getSetting("locale"))},t.prototype.getFormattedLabel=function(e,i,n){var a=this.getSetting("useUTC"),o=this.getSetting("locale");return Ub(e,i,n,o,a)},t.prototype.getTicks=function(){var e=this._interval,i=this._extent,n=[];if(!e)return n;n.push({value:i[0],level:0});var a=this.getSetting("useUTC"),o=BA(this._minLevelUnit,this._approxInterval,a,i);return n=n.concat(o),n.push({value:i[1],level:0}),n},t.prototype.calcNiceExtent=function(e){var i=this._extent;if(i[0]===i[1]&&(i[0]-=pe,i[1]+=pe),i[1]===-1/0&&i[0]===1/0){var n=new Date;i[1]=+new Date(n.getFullYear(),n.getMonth(),n.getDate()),i[0]=i[1]-pe}this.calcNiceTicks(e.splitNumber,e.minInterval,e.maxInterval)},t.prototype.calcNiceTicks=function(e,i,n){e=e||10;var a=this._extent,o=a[1]-a[0];this._approxInterval=o/e,i!=null&&this._approxInterval<i&&(this._approxInterval=i),n!=null&&this._approxInterval>n&&(this._approxInterval=n);var s=vo.length,l=Math.min(LA(vo,this._approxInterval,0,s),s-1);this._interval=vo[l][1],this._minLevelUnit=vo[Math.max(l-1,0)][0]},t.prototype.parse=function(e){return dt(e)?e:+er(e)},t.prototype.contain=function(e){return qs(this.parse(e),this._extent)},t.prototype.normalize=function(e){return Ks(this.parse(e),this._extent)},t.prototype.scale=function(e){return Qs(e,this._extent)},t.type="time",t}(pi),vo=[["second",ph],["minute",gh],["hour",aa],["quarter-day",aa*6],["half-day",aa*12],["day",pe*1.2],["half-week",pe*3.5],["week",pe*7],["month",pe*31],["quarter",pe*95],["half-year",xc/2],["year",xc]];function IA(r,t,e,i){var n=er(t),a=er(e),o=function(d){return Tc(n,d,i)===Tc(a,d,i)},s=function(){return o("year")},l=function(){return s()&&o("month")},u=function(){return l()&&o("day")},f=function(){return u()&&o("hour")},h=function(){return f()&&o("minute")},c=function(){return h()&&o("second")},v=function(){return c()&&o("millisecond")};switch(r){case"year":return s();case"month":return l();case"day":return u();case"hour":return f();case"minute":return h();case"second":return c();case"millisecond":return v()}}function PA(r,t){return r/=pe,r>16?16:r>7.5?7:r>3.5?4:r>1.5?2:1}function RA(r){var t=30*pe;return r/=t,r>6?6:r>3?3:r>2?2:1}function EA(r){return r/=aa,r>12?12:r>6?6:r>3.5?4:r>2?2:1}function Rd(r,t){return r/=t?gh:ph,r>30?30:r>20?20:r>15?15:r>10?10:r>5?5:r>2?2:1}function kA(r){return zg(r,!0)}function OA(r,t,e){var i=new Date(r);switch(ji(t)){case"year":case"month":i[qy(e)](0);case"day":i[Ky(e)](1);case"hour":i[Qy(e)](0);case"minute":i[Jy(e)](0);case"second":i[jy(e)](0),i[tm(e)](0)}return i.getTime()}function BA(r,t,e,i){var n=1e4,a=Zy,o=0;function s(D,C,L,I,P,R,E){for(var z=new Date(C),k=C,B=z[I]();k<L&&k<=i[1];)E.push({value:k}),B+=D,z[P](B),k=z.getTime();E.push({value:k,notAdd:!0})}function l(D,C,L){var I=[],P=!C.length;if(!IA(ji(D),i[0],i[1],e)){P&&(C=[{value:OA(new Date(i[0]),D,e)},{value:i[1]}]);for(var R=0;R<C.length-1;R++){var E=C[R].value,z=C[R+1].value;if(E!==z){var k=void 0,B=void 0,F=void 0,H=!1;switch(D){case"year":k=Math.max(1,Math.round(t/pe/365)),B=yh(e),F=Yb(e);break;case"half-year":case"quarter":case"month":k=RA(t),B=tn(e),F=qy(e);break;case"week":case"half-week":case"day":k=PA(t),B=zs(e),F=Ky(e),H=!0;break;case"half-day":case"quarter-day":case"hour":k=EA(t),B=ma(e),F=Qy(e);break;case"minute":k=Rd(t,!0),B=Fs(e),F=Jy(e);break;case"second":k=Rd(t,!1),B=Vs(e),F=jy(e);break;case"millisecond":k=kA(t),B=Hs(e),F=tm(e);break}s(k,E,z,B,F,H,I),D==="year"&&L.length>1&&R===0&&L.unshift({value:L[0].value-k})}}for(var R=0;R<I.length;R++)L.push(I[R]);return I}}for(var u=[],f=[],h=0,c=0,v=0;v<a.length&&o++<n;++v){var d=ji(a[v]);if(!!Gb(a[v])){l(a[v],u[u.length-1]||[],f);var p=a[v+1]?ji(a[v+1]):null;if(d!==p){if(f.length){c=h,f.sort(function(D,C){return D.value-C.value});for(var g=[],y=0;y<f.length;++y){var m=f[y].value;(y===0||f[y-1].value!==m)&&(g.push(f[y]),m>=i[0]&&m<=i[1]&&h++)}var _=(i[1]-i[0])/t;if(h>_*1.5&&c>_/1.5||(u.push(g),h>_||r===a[v]))break}f=[]}}}for(var S=Ct(G(u,function(D){return Ct(D,function(C){return C.value>=i[0]&&C.value<=i[1]&&!C.notAdd})}),function(D){return D.length>0}),x=[],w=S.length-1,v=0;v<S.length;++v)for(var b=S[v],T=0;T<b.length;++T)x.push({value:b[T].value,level:w-v});x.sort(function(D,C){return D.value-C.value});for(var M=[],v=0;v<x.length;++v)(v===0||x[v].value!==x[v-1].value)&&M.push(x[v]);return M}or.registerClass(L0);const NA=L0;var Ed=or.prototype,fa=pi.prototype,zA=bt,FA=Math.floor,VA=Math.ceil,co=Math.pow,Se=Math.log,Nh=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="log",e.base=10,e._originalScale=new pi,e._interval=0,e}return t.prototype.getTicks=function(e){var i=this._originalScale,n=this._extent,a=i.getExtent(),o=fa.getTicks.call(this,e);return G(o,function(s){var l=s.value,u=bt(co(this.base,l));return u=l===n[0]&&this._fixMin?po(u,a[0]):u,u=l===n[1]&&this._fixMax?po(u,a[1]):u,{value:u}},this)},t.prototype.setExtent=function(e,i){var n=Se(this.base);e=Se(Math.max(0,e))/n,i=Se(Math.max(0,i))/n,fa.setExtent.call(this,e,i)},t.prototype.getExtent=function(){var e=this.base,i=Ed.getExtent.call(this);i[0]=co(e,i[0]),i[1]=co(e,i[1]);var n=this._originalScale,a=n.getExtent();return this._fixMin&&(i[0]=po(i[0],a[0])),this._fixMax&&(i[1]=po(i[1],a[1])),i},t.prototype.unionExtent=function(e){this._originalScale.unionExtent(e);var i=this.base;e[0]=Se(e[0])/Se(i),e[1]=Se(e[1])/Se(i),Ed.unionExtent.call(this,e)},t.prototype.unionExtentFromData=function(e,i){this.unionExtent(e.getApproximateExtent(i))},t.prototype.calcNiceTicks=function(e){e=e||10;var i=this._extent,n=i[1]-i[0];if(!(n===1/0||n<=0)){var a=$S(n),o=e/n*a;for(o<=.5&&(a*=10);!isNaN(a)&&Math.abs(a)<1&&Math.abs(a)>0;)a*=10;var s=[bt(VA(i[0]/a)*a),bt(FA(i[1]/a)*a)];this._interval=a,this._niceExtent=s}},t.prototype.calcNiceExtent=function(e){fa.calcNiceExtent.call(this,e),this._fixMin=e.fixMin,this._fixMax=e.fixMax},t.prototype.parse=function(e){return e},t.prototype.contain=function(e){return e=Se(e)/Se(this.base),qs(e,this._extent)},t.prototype.normalize=function(e){return e=Se(e)/Se(this.base),Ks(e,this._extent)},t.prototype.scale=function(e){return e=Qs(e,this._extent),co(this.base,e)},t.type="log",t}(or),I0=Nh.prototype;I0.getMinorTicks=fa.getMinorTicks;I0.getLabel=fa.getLabel;function po(r,t){return zA(r,Xe(t))}or.registerClass(Nh);const HA=Nh;var GA=function(){function r(t,e,i){this._prepareParams(t,e,i)}return r.prototype._prepareParams=function(t,e,i){i[1]<i[0]&&(i=[NaN,NaN]),this._dataMin=i[0],this._dataMax=i[1];var n=this._isOrdinal=t.type==="ordinal";this._needCrossZero=t.type==="interval"&&e.getNeedCrossZero&&e.getNeedCrossZero();var a=e.get("min",!0);a==null&&(a=e.get("startValue",!0));var o=this._modelMinRaw=a;K(o)?this._modelMinNum=go(t,o({min:i[0],max:i[1]})):o!=="dataMin"&&(this._modelMinNum=go(t,o));var s=this._modelMaxRaw=e.get("max",!0);if(K(s)?this._modelMaxNum=go(t,s({min:i[0],max:i[1]})):s!=="dataMax"&&(this._modelMaxNum=go(t,s)),n)this._axisDataLen=e.getCategories().length;else{var l=e.get("boundaryGap"),u=V(l)?l:[l||0,l||0];typeof u[0]=="boolean"||typeof u[1]=="boolean"?this._boundaryGapInner=[0,0]:this._boundaryGapInner=[Dr(u[0],1),Dr(u[1],1)]}},r.prototype.calculate=function(){var t=this._isOrdinal,e=this._dataMin,i=this._dataMax,n=this._axisDataLen,a=this._boundaryGapInner,o=t?null:i-e||Math.abs(e),s=this._modelMinRaw==="dataMin"?e:this._modelMinNum,l=this._modelMaxRaw==="dataMax"?i:this._modelMaxNum,u=s!=null,f=l!=null;s==null&&(s=t?n?0:NaN:e-a[0]*o),l==null&&(l=t?n?n-1:NaN:i+a[1]*o),(s==null||!isFinite(s))&&(s=NaN),(l==null||!isFinite(l))&&(l=NaN);var h=Wo(s)||Wo(l)||t&&!n;this._needCrossZero&&(s>0&&l>0&&!u&&(s=0),s<0&&l<0&&!f&&(l=0));var c=this._determinedMin,v=this._determinedMax;return c!=null&&(s=c,u=!0),v!=null&&(l=v,f=!0),{min:s,max:l,minFixed:u,maxFixed:f,isBlank:h}},r.prototype.modifyDataMinMax=function(t,e){this[UA[t]]=e},r.prototype.setDeterminedMinMax=function(t,e){var i=WA[t];this[i]=e},r.prototype.freeze=function(){this.frozen=!0},r}(),WA={min:"_determinedMin",max:"_determinedMax"},UA={min:"_dataMin",max:"_dataMax"};function P0(r,t,e){var i=r.rawExtentInfo;return i||(i=new GA(r,t,e),r.rawExtentInfo=i,i)}function go(r,t){return t==null?null:Wo(t)?NaN:r.parse(t)}function R0(r,t){var e=r.type,i=P0(r,t,r.getExtent()).calculate();r.setBlank(i.isBlank);var n=i.min,a=i.max,o=t.ecModel;if(o&&e==="time"){var s=C0("bar",o),l=!1;if(A(s,function(h){l=l||h.getBaseAxis()===t.axis}),l){var u=M0(s),f=YA(n,a,t,u);n=f.min,a=f.max}}return{extent:[n,a],fixMin:i.minFixed,fixMax:i.maxFixed}}function YA(r,t,e,i){var n=e.axis.getExtent(),a=Math.abs(n[1]-n[0]),o=CA(i,e.axis);if(o===void 0)return{min:r,max:t};var s=1/0;A(o,function(v){s=Math.min(v.offset,s)});var l=-1/0;A(o,function(v){l=Math.max(v.offset+v.width,l)}),s=Math.abs(s),l=Math.abs(l);var u=s+l,f=t-r,h=1-(s+l)/a,c=f/h-f;return t+=c*(l/u),r-=c*(s/u),{min:r,max:t}}function kd(r,t){var e=t,i=R0(r,e),n=i.extent,a=e.get("splitNumber");r instanceof HA&&(r.base=e.get("logBase"));var o=r.type,s=e.get("interval"),l=o==="interval"||o==="time";r.setExtent(n[0],n[1]),r.calcNiceExtent({splitNumber:a,fixMin:i.fixMin,fixMax:i.fixMax,minInterval:l?e.get("minInterval"):null,maxInterval:l?e.get("maxInterval"):null}),s!=null&&r.setInterval&&r.setInterval(s)}function $A(r,t){if(t=t||r.get("type"),t)switch(t){case"category":return new x0({ordinalMeta:r.getOrdinalMeta?r.getOrdinalMeta():r.getCategories(),extent:[1/0,-1/0]});case"time":return new NA({locale:r.ecModel.getLocaleModel(),useUTC:r.ecModel.get("useUTC")});default:return new(or.getClass(t)||pi)}}function ZA(r){var t=r.scale.getExtent(),e=t[0],i=t[1];return!(e>0&&i>0||e<0&&i<0)}function cn(r){var t=r.getLabelModel().get("formatter"),e=r.type==="category"?r.scale.getExtent()[0]:null;return r.scale.type==="time"?function(i){return function(n,a){return r.scale.getFormattedLabel(n,a,i)}}(t):W(t)?function(i){return function(n){var a=r.scale.getLabel(n),o=i.replace("{value}",a!=null?a:"");return o}}(t):K(t)?function(i){return function(n,a){return e!=null&&(a=n.value-e),i(zh(r,n),a,n.level!=null?{level:n.level}:null)}}(t):function(i){return r.scale.getLabel(i)}}function zh(r,t){return r.type==="category"?r.scale.getLabel(t):t.value}function XA(r){var t=r.model,e=r.scale;if(!(!t.get(["axisLabel","show"])||e.isBlank())){var i,n,a=e.getExtent();e instanceof x0?n=e.count():(i=e.getTicks(),n=i.length);var o=r.getLabelModel(),s=cn(r),l,u=1;n>40&&(u=Math.ceil(n/40));for(var f=0;f<n;f+=u){var h=i?i[f]:{value:a[0]+f},c=s(h,f),v=o.getTextRect(c),d=qA(v,o.get("rotate")||0);l?l.union(d):l=d}return l}}function qA(r,t){var e=t*Math.PI/180,i=r.width,n=r.height,a=i*Math.abs(Math.cos(e))+Math.abs(n*Math.sin(e)),o=i*Math.abs(Math.sin(e))+Math.abs(n*Math.cos(e)),s=new ut(r.x,r.y,a,o);return s}function Fh(r){var t=r.get("interval");return t==null?"auto":t}function E0(r){return r.type==="category"&&Fh(r.getLabelModel())===0}function k0(r,t){var e={};return A(r.mapDimensionsAll(t),function(i){e[hA(r,i)]=!0}),vt(e)}function KA(r,t,e){t&&A(k0(t,e),function(i){var n=t.getApproximateExtent(i);n[0]<r[0]&&(r[0]=n[0]),n[1]>r[1]&&(r[1]=n[1])})}var O0=function(){function r(){}return r.prototype.getNeedCrossZero=function(){var t=this.option;return!t.scale},r.prototype.getCoordSysModel=function(){},r}(),Od=[],QA={registerPreprocessor:u0,registerProcessor:f0,registerPostInit:NM,registerPostUpdate:zM,registerUpdateLifecycle:Rh,registerAction:wi,registerCoordinateSystem:FM,registerLayout:VM,registerVisual:xi,registerTransform:GM,registerLoading:h0,registerMap:HM,registerImpl:yM,PRIORITY:IM,ComponentModel:pt,ComponentView:Ce,SeriesModel:rr,ChartView:Te,registerComponentModel:function(r){pt.registerClass(r)},registerComponentView:function(r){Ce.registerClass(r)},registerSeriesModel:function(r){rr.registerClass(r)},registerChartView:function(r){Te.registerClass(r)},registerSubTypeDefaulter:function(r,t){pt.registerSubTypeDefaulter(r,t)},registerPainter:function(r,t){VS(r,t)}};function Ge(r){if(V(r)){A(r,function(t){Ge(t)});return}at(Od,r)>=0||(Od.push(r),K(r)&&(r={install:r}),r.install(QA))}var ba=gt();function B0(r,t){var e=G(t,function(i){return r.scale.parse(i)});return r.type==="time"&&e.length>0&&(e.sort(),e.unshift(e[0]),e.push(e[e.length-1])),e}function JA(r){var t=r.getLabelModel().get("customValues");if(t){var e=cn(r),i=r.scale.getExtent(),n=B0(r,t),a=Ct(n,function(o){return o>=i[0]&&o<=i[1]});return{labels:G(a,function(o){var s={value:o};return{formattedLabel:e(s),rawLabel:r.scale.getLabel(s),tickValue:o}})}}return r.type==="category"?tD(r):rD(r)}function jA(r,t){var e=r.getTickModel().get("customValues");if(e){var i=r.scale.getExtent(),n=B0(r,e);return{ticks:Ct(n,function(a){return a>=i[0]&&a<=i[1]})}}return r.type==="category"?eD(r,t):{ticks:G(r.scale.getTicks(),function(a){return a.value})}}function tD(r){var t=r.getLabelModel(),e=N0(r,t);return!t.get("show")||r.scale.isBlank()?{labels:[],labelCategoryInterval:e.labelCategoryInterval}:e}function N0(r,t){var e=z0(r,"labels"),i=Fh(t),n=F0(e,i);if(n)return n;var a,o;return K(i)?a=G0(r,i):(o=i==="auto"?iD(r):i,a=H0(r,o)),V0(e,i,{labels:a,labelCategoryInterval:o})}function eD(r,t){var e=z0(r,"ticks"),i=Fh(t),n=F0(e,i);if(n)return n;var a,o;if((!t.get("show")||r.scale.isBlank())&&(a=[]),K(i))a=G0(r,i,!0);else if(i==="auto"){var s=N0(r,r.getLabelModel());o=s.labelCategoryInterval,a=G(s.labels,function(l){return l.tickValue})}else o=i,a=H0(r,o,!0);return V0(e,i,{ticks:a,tickCategoryInterval:o})}function rD(r){var t=r.scale.getTicks(),e=cn(r);return{labels:G(t,function(i,n){return{level:i.level,formattedLabel:e(i,n),rawLabel:r.scale.getLabel(i),tickValue:i.value}})}}function z0(r,t){return ba(r)[t]||(ba(r)[t]=[])}function F0(r,t){for(var e=0;e<r.length;e++)if(r[e].key===t)return r[e].value}function V0(r,t,e){return r.push({key:t,value:e}),e}function iD(r){var t=ba(r).autoInterval;return t!=null?t:ba(r).autoInterval=r.calculateCategoryInterval()}function nD(r){var t=aD(r),e=cn(r),i=(t.axisRotate-t.labelRotate)/180*Math.PI,n=r.scale,a=n.getExtent(),o=n.count();if(a[1]-a[0]<1)return 0;var s=1;o>40&&(s=Math.max(1,Math.floor(o/40)));for(var l=a[0],u=r.dataToCoord(l+1)-r.dataToCoord(l),f=Math.abs(u*Math.cos(i)),h=Math.abs(u*Math.sin(i)),c=0,v=0;l<=a[1];l+=s){var d=0,p=0,g=Kf(e({value:l}),t.font,"center","top");d=g.width*1.3,p=g.height*1.3,c=Math.max(c,d,7),v=Math.max(v,p,7)}var y=c/f,m=v/h;isNaN(y)&&(y=1/0),isNaN(m)&&(m=1/0);var _=Math.max(0,Math.floor(Math.min(y,m))),S=ba(r.model),x=r.getExtent(),w=S.lastAutoInterval,b=S.lastTickCount;return w!=null&&b!=null&&Math.abs(w-_)<=1&&Math.abs(b-o)<=1&&w>_&&S.axisExtent0===x[0]&&S.axisExtent1===x[1]?_=w:(S.lastTickCount=o,S.lastAutoInterval=_,S.axisExtent0=x[0],S.axisExtent1=x[1]),_}function aD(r){var t=r.getLabelModel();return{axisRotate:r.getRotate?r.getRotate():r.isHorizontal&&!r.isHorizontal()?90:0,labelRotate:t.get("rotate")||0,font:t.getFont()}}function H0(r,t,e){var i=cn(r),n=r.scale,a=n.getExtent(),o=r.getLabelModel(),s=[],l=Math.max((t||0)+1,1),u=a[0],f=n.count();u!==0&&l>1&&f/l>2&&(u=Math.round(Math.ceil(u/l)*l));var h=E0(r),c=o.get("showMinLabel")||h,v=o.get("showMaxLabel")||h;c&&u!==a[0]&&p(a[0]);for(var d=u;d<=a[1];d+=l)p(d);v&&d-l!==a[1]&&p(a[1]);function p(g){var y={value:g};s.push(e?g:{formattedLabel:i(y),rawLabel:n.getLabel(y),tickValue:g})}return s}function G0(r,t,e){var i=r.scale,n=cn(r),a=[];return A(i.getTicks(),function(o){var s=i.getLabel(o),l=o.value;t(o.value,s)&&a.push(e?l:{formattedLabel:n(o),rawLabel:s,tickValue:l})}),a}var Bd=[0,1],oD=function(){function r(t,e,i){this.onBand=!1,this.inverse=!1,this.dim=t,this.scale=e,this._extent=i||[0,0]}return r.prototype.contain=function(t){var e=this._extent,i=Math.min(e[0],e[1]),n=Math.max(e[0],e[1]);return t>=i&&t<=n},r.prototype.containData=function(t){return this.scale.contain(t)},r.prototype.getExtent=function(){return this._extent.slice()},r.prototype.getPixelPrecision=function(t){return Bg(t||this.scale.getExtent(),this._extent)},r.prototype.setExtent=function(t,e){var i=this._extent;i[0]=t,i[1]=e},r.prototype.dataToCoord=function(t,e){var i=this._extent,n=this.scale;return t=n.normalize(t),this.onBand&&n.type==="ordinal"&&(i=i.slice(),Nd(i,n.count())),Rt(t,Bd,i,e)},r.prototype.coordToData=function(t,e){var i=this._extent,n=this.scale;this.onBand&&n.type==="ordinal"&&(i=i.slice(),Nd(i,n.count()));var a=Rt(t,i,Bd,e);return this.scale.scale(a)},r.prototype.pointToData=function(t,e){},r.prototype.getTicksCoords=function(t){t=t||{};var e=t.tickModel||this.getTickModel(),i=jA(this,e),n=i.ticks,a=G(n,function(s){return{coord:this.dataToCoord(this.scale.type==="ordinal"?this.scale.getRawOrdinalNumber(s):s),tickValue:s}},this),o=e.get("alignWithLabel");return sD(this,a,o,t.clamp),a},r.prototype.getMinorTicksCoords=function(){if(this.scale.type==="ordinal")return[];var t=this.model.getModel("minorTick"),e=t.get("splitNumber");e>0&&e<100||(e=5);var i=this.scale.getMinorTicks(e),n=G(i,function(a){return G(a,function(o){return{coord:this.dataToCoord(o),tickValue:o}},this)},this);return n},r.prototype.getViewLabels=function(){return JA(this).labels},r.prototype.getLabelModel=function(){return this.model.getModel("axisLabel")},r.prototype.getTickModel=function(){return this.model.getModel("axisTick")},r.prototype.getBandWidth=function(){var t=this._extent,e=this.scale.getExtent(),i=e[1]-e[0]+(this.onBand?1:0);i===0&&(i=1);var n=Math.abs(t[1]-t[0]);return Math.abs(n)/i},r.prototype.calculateCategoryInterval=function(){return nD(this)},r}();function Nd(r,t){var e=r[1]-r[0],i=t,n=e/i/2;r[0]+=n,r[1]-=n}function sD(r,t,e,i){var n=t.length;if(!r.onBand||e||!n)return;var a=r.getExtent(),o,s;if(n===1)t[0].coord=a[0],o=t[1]={coord:a[1],tickValue:t[0].tickValue};else{var l=t[n-1].tickValue-t[0].tickValue,u=(t[n-1].coord-t[0].coord)/l;A(t,function(v){v.coord-=u/2});var f=r.scale.getExtent();s=1+f[1]-t[n-1].tickValue,o={coord:t[n-1].coord+u*s,tickValue:f[1]+1},t.push(o)}var h=a[0]>a[1];c(t[0].coord,a[0])&&(i?t[0].coord=a[0]:t.shift()),i&&c(a[0],t[0].coord)&&t.unshift({coord:a[0]}),c(a[1],o.coord)&&(i?o.coord=a[1]:t.pop()),i&&c(o.coord,a[1])&&t.push({coord:a[1]});function c(v,d){return v=bt(v),d=bt(d),h?v>d:v<d}}const W0=oD;Lr.CMD;function U0(r,t,e,i,n,a,o,s){var l=n-r,u=a-t,f=e-r,h=i-t,c=Math.sqrt(f*f+h*h);f/=c,h/=c;var v=l*f+u*h,d=v/c;s&&(d=Math.min(Math.max(d,0),1)),d*=c;var p=o[0]=r+d*f,g=o[1]=t+d*h;return Math.sqrt((p-n)*(p-n)+(g-a)*(g-a))}var wr=new q,mt=new q,Et=new q,xr=new q,ze=new q,ys=[],Ht=new q;function lD(r,t){if(t<=180&&t>0){t=t/180*Math.PI,wr.fromArray(r[0]),mt.fromArray(r[1]),Et.fromArray(r[2]),q.sub(xr,wr,mt),q.sub(ze,Et,mt);var e=xr.len(),i=ze.len();if(!(e<.001||i<.001)){xr.scale(1/e),ze.scale(1/i);var n=xr.dot(ze),a=Math.cos(t);if(a<n){var o=U0(mt.x,mt.y,Et.x,Et.y,wr.x,wr.y,ys,!1);Ht.fromArray(ys),Ht.scaleAndAdd(ze,o/Math.tan(Math.PI-t));var s=Et.x!==mt.x?(Ht.x-mt.x)/(Et.x-mt.x):(Ht.y-mt.y)/(Et.y-mt.y);if(isNaN(s))return;s<0?q.copy(Ht,mt):s>1&&q.copy(Ht,Et),Ht.toArray(r[1])}}}}function uD(r,t,e){if(e<=180&&e>0){e=e/180*Math.PI,wr.fromArray(r[0]),mt.fromArray(r[1]),Et.fromArray(r[2]),q.sub(xr,mt,wr),q.sub(ze,Et,mt);var i=xr.len(),n=ze.len();if(!(i<.001||n<.001)){xr.scale(1/i),ze.scale(1/n);var a=xr.dot(t),o=Math.cos(e);if(a<o){var s=U0(mt.x,mt.y,Et.x,Et.y,wr.x,wr.y,ys,!1);Ht.fromArray(ys);var l=Math.PI/2,u=Math.acos(ze.dot(t)),f=l+u-e;if(f>=l)q.copy(Ht,Et);else{Ht.scaleAndAdd(ze,s/Math.tan(Math.PI/2-f));var h=Et.x!==mt.x?(Ht.x-mt.x)/(Et.x-mt.x):(Ht.y-mt.y)/(Et.y-mt.y);if(isNaN(h))return;h<0?q.copy(Ht,mt):h>1&&q.copy(Ht,Et)}Ht.toArray(r[1])}}}}function su(r,t,e,i){var n=e==="normal",a=n?r:r.ensureState(e);a.ignore=t;var o=i.get("smooth");o&&o===!0&&(o=.3),a.shape=a.shape||{},o>0&&(a.shape.smooth=o);var s=i.getModel("lineStyle").getLineStyle();n?r.useStyle(s):a.style=s}function fD(r,t){var e=t.smooth,i=t.points;if(!!i)if(r.moveTo(i[0][0],i[0][1]),e>0&&i.length>=3){var n=ku(i[0],i[1]),a=ku(i[1],i[2]);if(!n||!a){r.lineTo(i[1][0],i[1][1]),r.lineTo(i[2][0],i[2][1]);return}var o=Math.min(n,a)*e,s=el([],i[1],i[0],o/n),l=el([],i[1],i[2],o/a),u=el([],s,l,.5);r.bezierCurveTo(s[0],s[1],s[0],s[1],u[0],u[1]),r.bezierCurveTo(l[0],l[1],l[0],l[1],i[2][0],i[2][1])}else for(var f=1;f<i.length;f++)r.lineTo(i[f][0],i[f][1])}function hD(r,t,e){var i=r.getTextGuideLine(),n=r.getTextContent();if(!n){i&&r.removeTextGuideLine();return}for(var a=t.normal,o=a.get("show"),s=n.ignore,l=0;l<jo.length;l++){var u=jo[l],f=t[u],h=u==="normal";if(f){var c=f.get("show"),v=h?s:j(n.states[u]&&n.states[u].ignore,s);if(v||!j(c,o)){var d=h?i:i&&i.states[u];d&&(d.ignore=!0),i&&su(i,!0,u,f);continue}i||(i=new _i,r.setTextGuideLine(i),!h&&(s||!o)&&su(i,!0,"normal",t.normal),r.stateProxy&&(i.stateProxy=r.stateProxy)),su(i,!1,u,f)}}if(i){rt(i.style,e),i.style.fill=null;var p=a.get("showAbove"),g=r.textGuideLineConfig=r.textGuideLineConfig||{};g.showAbove=p||!1,i.buildPath=fD}}function vD(r,t){t=t||"labelLine";for(var e={normal:r.getModel(t)},i=0;i<ye.length;i++){var n=ye[i];e[n]=r.getModel([n,t])}return e}function cD(r){for(var t=[],e=0;e<r.length;e++){var i=r[e];if(!i.defaultAttr.ignore){var n=i.label,a=n.getComputedTransform(),o=n.getBoundingRect(),s=!a||a[1]<1e-5&&a[2]<1e-5,l=n.style.margin||0,u=o.clone();u.applyTransform(a),u.x-=l/2,u.y-=l/2,u.width+=l,u.height+=l;var f=s?new is(o,a):null;t.push({label:n,labelLine:i.labelLine,rect:u,localRect:o,obb:f,priority:i.priority,defaultAttr:i.defaultAttr,layoutOption:i.computedLayoutOption,axisAligned:s,transform:a})}}return t}function dD(r,t,e,i,n,a){var o=r.length;if(o<2)return;r.sort(function(T,M){return T.rect[t]-M.rect[t]});for(var s=0,l,u=!1,f=0,h=0;h<o;h++){var c=r[h],v=c.rect;l=v[t]-s,l<0&&(v[t]-=l,c.label[t]-=l,u=!0);var d=Math.max(-l,0);f+=d,s=v[t]+v[e]}f>0&&a&&x(-f/o,0,o);var p=r[0],g=r[o-1],y,m;_(),y<0&&w(-y,.8),m<0&&w(m,.8),_(),S(y,m,1),S(m,y,-1),_(),y<0&&b(-y),m<0&&b(m);function _(){y=p.rect[t]-i,m=n-g.rect[t]-g.rect[e]}function S(T,M,D){if(T<0){var C=Math.min(M,-T);if(C>0){x(C*D,0,o);var L=C+T;L<0&&w(-L*D,1)}else w(-T*D,1)}}function x(T,M,D){T!==0&&(u=!0);for(var C=M;C<D;C++){var L=r[C],I=L.rect;I[t]+=T,L.label[t]+=T}}function w(T,M){for(var D=[],C=0,L=1;L<o;L++){var I=r[L-1].rect,P=Math.max(r[L].rect[t]-I[t]-I[e],0);D.push(P),C+=P}if(!!C){var R=Math.min(Math.abs(T)/C,M);if(T>0)for(var L=0;L<o-1;L++){var E=D[L]*R;x(E,0,L+1)}else for(var L=o-1;L>0;L--){var E=D[L-1]*R;x(-E,L,o)}}}function b(T){var M=T<0?-1:1;T=Math.abs(T);for(var D=Math.ceil(T/(o-1)),C=0;C<o-1;C++)if(M>0?x(D,0,C+1):x(-D,o-C-1,o),T-=D,T<=0)return}return u}function pD(r,t,e,i){return dD(r,"y","height",t,e,i)}function gD(r){var t=[];r.sort(function(p,g){return g.priority-p.priority});var e=new ut(0,0,0,0);function i(p){if(!p.ignore){var g=p.ensureState("emphasis");g.ignore==null&&(g.ignore=!1)}p.ignore=!0}for(var n=0;n<r.length;n++){var a=r[n],o=a.axisAligned,s=a.localRect,l=a.transform,u=a.label,f=a.labelLine;e.copy(a.rect),e.width-=.1,e.height-=.1,e.x+=.05,e.y+=.05;for(var h=a.obb,c=!1,v=0;v<t.length;v++){var d=t[v];if(!!e.intersect(d.rect)){if(o&&d.axisAligned){c=!0;break}if(d.obb||(d.obb=new is(d.localRect,d.transform)),h||(h=new is(s,l)),h.intersect(d.obb)){c=!0;break}}}c?(i(u),f&&i(f)):(u.attr("ignore",a.defaultAttr.ignore),f&&f.attr("ignore",a.defaultAttr.labelGuideIgnore),t.push(a))}}function zd(r,t,e){var i=gi.createCanvas(),n=t.getWidth(),a=t.getHeight(),o=i.style;return o&&(o.position="absolute",o.left="0",o.top="0",o.width=n+"px",o.height=a+"px",i.setAttribute("data-zr-dom-id",r)),i.width=n*e,i.height=a*e,i}var yD=function(r){N(t,r);function t(e,i,n){var a=r.call(this)||this;a.motionBlur=!1,a.lastFrameAlpha=.7,a.dpr=1,a.virtual=!1,a.config={},a.incremental=!1,a.zlevel=0,a.maxRepaintRectCount=5,a.__dirty=!0,a.__firstTimePaint=!0,a.__used=!1,a.__drawIndex=0,a.__startIndex=0,a.__endIndex=0,a.__prevStartIndex=null,a.__prevEndIndex=null;var o;n=n||qo,typeof e=="string"?o=zd(e,i,n):Y(e)&&(o=e,e=o.id),a.id=e,a.dom=o;var s=o.style;return s&&(cg(o),o.onselectstart=function(){return!1},s.padding="0",s.margin="0",s.borderWidth="0"),a.painter=i,a.dpr=n,a}return t.prototype.getElementCount=function(){return this.__endIndex-this.__startIndex},t.prototype.afterBrush=function(){this.__prevStartIndex=this.__startIndex,this.__prevEndIndex=this.__endIndex},t.prototype.initContext=function(){this.ctx=this.dom.getContext("2d"),this.ctx.dpr=this.dpr},t.prototype.setUnpainted=function(){this.__firstTimePaint=!0},t.prototype.createBackBuffer=function(){var e=this.dpr;this.domBack=zd("back-"+this.id,this.painter,e),this.ctxBack=this.domBack.getContext("2d"),e!==1&&this.ctxBack.scale(e,e)},t.prototype.createRepaintRects=function(e,i,n,a){if(this.__firstTimePaint)return this.__firstTimePaint=!1,null;var o=[],s=this.maxRepaintRectCount,l=!1,u=new ut(0,0,0,0);function f(m){if(!(!m.isFinite()||m.isZero()))if(o.length===0){var _=new ut(0,0,0,0);_.copy(m),o.push(_)}else{for(var S=!1,x=1/0,w=0,b=0;b<o.length;++b){var T=o[b];if(T.intersect(m)){var M=new ut(0,0,0,0);M.copy(T),M.union(m),o[b]=M,S=!0;break}else if(l){u.copy(m),u.union(T);var D=m.width*m.height,C=T.width*T.height,L=u.width*u.height,I=L-D-C;I<x&&(x=I,w=b)}}if(l&&(o[w].union(m),S=!0),!S){var _=new ut(0,0,0,0);_.copy(m),o.push(_)}l||(l=o.length>=s)}}for(var h=this.__startIndex;h<this.__endIndex;++h){var c=e[h];if(c){var v=c.shouldBePainted(n,a,!0,!0),d=c.__isRendered&&(c.__dirty&re||!v)?c.getPrevPaintRect():null;d&&f(d);var p=v&&(c.__dirty&re||!c.__isRendered)?c.getPaintRect():null;p&&f(p)}}for(var h=this.__prevStartIndex;h<this.__prevEndIndex;++h){var c=i[h],v=c&&c.shouldBePainted(n,a,!0,!0);if(c&&(!v||!c.__zr)&&c.__isRendered){var d=c.getPrevPaintRect();d&&f(d)}}var g;do{g=!1;for(var h=0;h<o.length;){if(o[h].isZero()){o.splice(h,1);continue}for(var y=h+1;y<o.length;)o[h].intersect(o[y])?(g=!0,o[h].union(o[y]),o.splice(y,1)):y++;h++}}while(g);return this._paintRects=o,o},t.prototype.debugGetPaintRects=function(){return(this._paintRects||[]).slice()},t.prototype.resize=function(e,i){var n=this.dpr,a=this.dom,o=a.style,s=this.domBack;o&&(o.width=e+"px",o.height=i+"px"),a.width=e*n,a.height=i*n,s&&(s.width=e*n,s.height=i*n,n!==1&&this.ctxBack.scale(n,n))},t.prototype.clear=function(e,i,n){var a=this.dom,o=this.ctx,s=a.width,l=a.height;i=i||this.clearColor;var u=this.motionBlur&&!e,f=this.lastFrameAlpha,h=this.dpr,c=this;u&&(this.domBack||this.createBackBuffer(),this.ctxBack.globalCompositeOperation="copy",this.ctxBack.drawImage(a,0,0,s/h,l/h));var v=this.domBack;function d(p,g,y,m){if(o.clearRect(p,g,y,m),i&&i!=="transparent"){var _=void 0;if(xs(i)){var S=i.global||i.__width===y&&i.__height===m;_=S&&i.__canvasGradient||gf(o,i,{x:0,y:0,width:y,height:m}),i.__canvasGradient=_,i.__width=y,i.__height=m}else v1(i)&&(i.scaleX=i.scaleX||h,i.scaleY=i.scaleY||h,_=yf(o,i,{dirty:function(){c.setUnpainted(),c.painter.refresh()}}));o.save(),o.fillStyle=_||i,o.fillRect(p,g,y,m),o.restore()}u&&(o.save(),o.globalAlpha=f,o.drawImage(v,p,g,y,m),o.restore())}!n||u?d(0,0,s,l):n.length&&A(n,function(p){d(p.x*h,p.y*h,p.width*h,p.height*h)})},t}(Ae);const lu=yD;var Fd=1e5,Qr=314159,yo=.01,mD=.001;function _D(r){return r?r.__builtin__?!0:!(typeof r.resize!="function"||typeof r.refresh!="function"):!1}function SD(r,t){var e=document.createElement("div");return e.style.cssText=["position:relative","width:"+r+"px","height:"+t+"px","padding:0","margin:0","border-width:0"].join(";")+";",e}var wD=function(){function r(t,e,i,n){this.type="canvas",this._zlevelList=[],this._prevDisplayList=[],this._layers={},this._layerConfig={},this._needsManuallyCompositing=!1,this.type="canvas";var a=!t.nodeName||t.nodeName.toUpperCase()==="CANVAS";this._opts=i=O({},i||{}),this.dpr=i.devicePixelRatio||qo,this._singleCanvas=a,this.root=t;var o=t.style;o&&(cg(t),t.innerHTML=""),this.storage=e;var s=this._zlevelList;this._prevDisplayList=[];var l=this._layers;if(a){var f=t,h=f.width,c=f.height;i.width!=null&&(h=i.width),i.height!=null&&(c=i.height),this.dpr=i.devicePixelRatio||1,f.width=h*this.dpr,f.height=c*this.dpr,this._width=h,this._height=c;var v=new lu(f,this,this.dpr);v.__builtin__=!0,v.initContext(),l[Qr]=v,v.zlevel=Qr,s.push(Qr),this._domRoot=t}else{this._width=lo(t,0,i),this._height=lo(t,1,i);var u=this._domRoot=SD(this._width,this._height);t.appendChild(u)}}return r.prototype.getType=function(){return"canvas"},r.prototype.isSingleCanvas=function(){return this._singleCanvas},r.prototype.getViewportRoot=function(){return this._domRoot},r.prototype.getViewportRootOffset=function(){var t=this.getViewportRoot();if(t)return{offsetLeft:t.offsetLeft||0,offsetTop:t.offsetTop||0}},r.prototype.refresh=function(t){var e=this.storage.getDisplayList(!0),i=this._prevDisplayList,n=this._zlevelList;this._redrawId=Math.random(),this._paintList(e,i,t,this._redrawId);for(var a=0;a<n.length;a++){var o=n[a],s=this._layers[o];if(!s.__builtin__&&s.refresh){var l=a===0?this._backgroundColor:null;s.refresh(l)}}return this._opts.useDirtyRect&&(this._prevDisplayList=e.slice()),this},r.prototype.refreshHover=function(){this._paintHoverList(this.storage.getDisplayList(!1))},r.prototype._paintHoverList=function(t){var e=t.length,i=this._hoverlayer;if(i&&i.clear(),!!e){for(var n={inHover:!0,viewWidth:this._width,viewHeight:this._height},a,o=0;o<e;o++){var s=t[o];s.__inHover&&(i||(i=this._hoverlayer=this.getLayer(Fd)),a||(a=i.ctx,a.save()),ei(a,s,n,o===e-1))}a&&a.restore()}},r.prototype.getHoverLayer=function(){return this.getLayer(Fd)},r.prototype.paintOne=function(t,e){$m(t,e)},r.prototype._paintList=function(t,e,i,n){if(this._redrawId===n){i=i||!1,this._updateLayerStatus(t);var a=this._doPaintList(t,e,i),o=a.finished,s=a.needsRefreshHover;if(this._needsManuallyCompositing&&this._compositeManually(),s&&this._paintHoverList(t),o)this.eachLayer(function(u){u.afterBrush&&u.afterBrush()});else{var l=this;Fu(function(){l._paintList(t,e,i,n)})}}},r.prototype._compositeManually=function(){var t=this.getLayer(Qr).ctx,e=this._domRoot.width,i=this._domRoot.height;t.clearRect(0,0,e,i),this.eachBuiltinLayer(function(n){n.virtual&&t.drawImage(n.dom,0,0,e,i)})},r.prototype._doPaintList=function(t,e,i){for(var n=this,a=[],o=this._opts.useDirtyRect,s=0;s<this._zlevelList.length;s++){var l=this._zlevelList[s],u=this._layers[l];u.__builtin__&&u!==this._hoverlayer&&(u.__dirty||i)&&a.push(u)}for(var f=!0,h=!1,c=function(p){var g=a[p],y=g.ctx,m=o&&g.createRepaintRects(t,e,v._width,v._height),_=i?g.__startIndex:g.__drawIndex,S=!i&&g.incremental&&Date.now,x=S&&Date.now(),w=g.zlevel===v._zlevelList[0]?v._backgroundColor:null;if(g.__startIndex===g.__endIndex)g.clear(!1,w,m);else if(_===g.__startIndex){var b=t[_];(!b.incremental||!b.notClear||i)&&g.clear(!1,w,m)}_===-1&&(console.error("For some unknown reason. drawIndex is -1"),_=g.__startIndex);var T,M=function(I){var P={inHover:!1,allClipped:!1,prevEl:null,viewWidth:n._width,viewHeight:n._height};for(T=_;T<g.__endIndex;T++){var R=t[T];if(R.__inHover&&(h=!0),n._doPaintEl(R,g,o,I,P,T===g.__endIndex-1),S){var E=Date.now()-x;if(E>15)break}}P.prevElClipPaths&&y.restore()};if(m)if(m.length===0)T=g.__endIndex;else for(var D=v.dpr,C=0;C<m.length;++C){var L=m[C];y.save(),y.beginPath(),y.rect(L.x*D,L.y*D,L.width*D,L.height*D),y.clip(),M(L),y.restore()}else y.save(),M(),y.restore();g.__drawIndex=T,g.__drawIndex<g.__endIndex&&(f=!1)},v=this,d=0;d<a.length;d++)c(d);return tt.wxa&&A(this._layers,function(p){p&&p.ctx&&p.ctx.draw&&p.ctx.draw()}),{finished:f,needsRefreshHover:h}},r.prototype._doPaintEl=function(t,e,i,n,a,o){var s=e.ctx;if(i){var l=t.getPaintRect();(!n||l&&l.intersect(n))&&(ei(s,t,a,o),t.setPrevPaintRect(l))}else ei(s,t,a,o)},r.prototype.getLayer=function(t,e){this._singleCanvas&&!this._needsManuallyCompositing&&(t=Qr);var i=this._layers[t];return i||(i=new lu("zr_"+t,this,this.dpr),i.zlevel=t,i.__builtin__=!0,this._layerConfig[t]?nt(i,this._layerConfig[t],!0):this._layerConfig[t-yo]&&nt(i,this._layerConfig[t-yo],!0),e&&(i.virtual=e),this.insertLayer(t,i),i.initContext()),i},r.prototype.insertLayer=function(t,e){var i=this._layers,n=this._zlevelList,a=n.length,o=this._domRoot,s=null,l=-1;if(!i[t]&&!!_D(e)){if(a>0&&t>n[0]){for(l=0;l<a-1&&!(n[l]<t&&n[l+1]>t);l++);s=i[n[l]]}if(n.splice(l+1,0,t),i[t]=e,!e.virtual)if(s){var u=s.dom;u.nextSibling?o.insertBefore(e.dom,u.nextSibling):o.appendChild(e.dom)}else o.firstChild?o.insertBefore(e.dom,o.firstChild):o.appendChild(e.dom);e.painter||(e.painter=this)}},r.prototype.eachLayer=function(t,e){for(var i=this._zlevelList,n=0;n<i.length;n++){var a=i[n];t.call(e,this._layers[a],a)}},r.prototype.eachBuiltinLayer=function(t,e){for(var i=this._zlevelList,n=0;n<i.length;n++){var a=i[n],o=this._layers[a];o.__builtin__&&t.call(e,o,a)}},r.prototype.eachOtherLayer=function(t,e){for(var i=this._zlevelList,n=0;n<i.length;n++){var a=i[n],o=this._layers[a];o.__builtin__||t.call(e,o,a)}},r.prototype.getLayers=function(){return this._layers},r.prototype._updateLayerStatus=function(t){this.eachBuiltinLayer(function(h,c){h.__dirty=h.__used=!1});function e(h){a&&(a.__endIndex!==h&&(a.__dirty=!0),a.__endIndex=h)}if(this._singleCanvas)for(var i=1;i<t.length;i++){var n=t[i];if(n.zlevel!==t[i-1].zlevel||n.incremental){this._needsManuallyCompositing=!0;break}}var a=null,o=0,s,l;for(l=0;l<t.length;l++){var n=t[l],u=n.zlevel,f=void 0;s!==u&&(s=u,o=0),n.incremental?(f=this.getLayer(u+mD,this._needsManuallyCompositing),f.incremental=!0,o=1):f=this.getLayer(u+(o>0?yo:0),this._needsManuallyCompositing),f.__builtin__||Gf("ZLevel "+u+" has been used by unkown layer "+f.id),f!==a&&(f.__used=!0,f.__startIndex!==l&&(f.__dirty=!0),f.__startIndex=l,f.incremental?f.__drawIndex=-1:f.__drawIndex=l,e(l),a=f),n.__dirty&re&&!n.__inHover&&(f.__dirty=!0,f.incremental&&f.__drawIndex<0&&(f.__drawIndex=l))}e(l),this.eachBuiltinLayer(function(h,c){!h.__used&&h.getElementCount()>0&&(h.__dirty=!0,h.__startIndex=h.__endIndex=h.__drawIndex=0),h.__dirty&&h.__drawIndex<0&&(h.__drawIndex=h.__startIndex)})},r.prototype.clear=function(){return this.eachBuiltinLayer(this._clearLayer),this},r.prototype._clearLayer=function(t){t.clear()},r.prototype.setBackgroundColor=function(t){this._backgroundColor=t,A(this._layers,function(e){e.setUnpainted()})},r.prototype.configLayer=function(t,e){if(e){var i=this._layerConfig;i[t]?nt(i[t],e,!0):i[t]=e;for(var n=0;n<this._zlevelList.length;n++){var a=this._zlevelList[n];if(a===t||a===t+yo){var o=this._layers[a];nt(o,i[t],!0)}}}},r.prototype.delLayer=function(t){var e=this._layers,i=this._zlevelList,n=e[t];!n||(n.dom.parentNode.removeChild(n.dom),delete e[t],i.splice(at(i,t),1))},r.prototype.resize=function(t,e){if(this._domRoot.style){var i=this._domRoot;i.style.display="none";var n=this._opts,a=this.root;if(t!=null&&(n.width=t),e!=null&&(n.height=e),t=lo(a,0,n),e=lo(a,1,n),i.style.display="",this._width!==t||e!==this._height){i.style.width=t+"px",i.style.height=e+"px";for(var o in this._layers)this._layers.hasOwnProperty(o)&&this._layers[o].resize(t,e);this.refresh(!0)}this._width=t,this._height=e}else{if(t==null||e==null)return;this._width=t,this._height=e,this.getLayer(Qr).resize(t,e)}return this},r.prototype.clearLayer=function(t){var e=this._layers[t];e&&e.clear()},r.prototype.dispose=function(){this.root.innerHTML="",this.root=this.storage=this._domRoot=this._layers=null},r.prototype.getRenderedCanvas=function(t){if(t=t||{},this._singleCanvas&&!this._compositeManually)return this._layers[Qr].dom;var e=new lu("image",this,t.pixelRatio||this.dpr);e.initContext(),e.clear(!1,t.backgroundColor||this._backgroundColor);var i=e.ctx;if(t.pixelRatio<=this.dpr){this.refresh();var n=e.dom.width,a=e.dom.height;this.eachLayer(function(h){h.__builtin__?i.drawImage(h.dom,0,0,n,a):h.renderToCanvas&&(i.save(),h.renderToCanvas(i),i.restore())})}else for(var o={inHover:!1,viewWidth:this._width,viewHeight:this._height},s=this.storage.getDisplayList(!0),l=0,u=s.length;l<u;l++){var f=s[l];ei(i,f,o,l===u-1)}return e.dom},r.prototype.getWidth=function(){return this._width},r.prototype.getHeight=function(){return this._height},r}();const xD=wD;function iR(r){r.registerPainter("canvas",xD)}var bD=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.getInitialData=function(e){return kh(null,this,{useEncodeDefaulter:!0})},t.prototype.getLegendIcon=function(e){var i=new xt,n=ir("line",0,e.itemHeight/2,e.itemWidth,0,e.lineStyle.stroke,!1);i.add(n),n.setStyle(e.lineStyle);var a=this.getData().getVisual("symbol"),o=this.getData().getVisual("symbolRotate"),s=a==="none"?"circle":a,l=e.itemHeight*.8,u=ir(s,(e.itemWidth-l)/2,(e.itemHeight-l)/2,l,l,e.itemStyle.fill);i.add(u),u.setStyle(e.itemStyle);var f=e.iconRotate==="inherit"?o:e.iconRotate||0;return u.rotation=f*Math.PI/180,u.setOrigin([e.itemWidth/2,e.itemHeight/2]),s.indexOf("empty")>-1&&(u.style.stroke=u.style.fill,u.style.fill="#fff",u.style.lineWidth=2),i},t.type="series.line",t.dependencies=["grid","polar"],t.defaultOption={z:3,coordinateSystem:"cartesian2d",legendHoverLink:!0,clip:!0,label:{position:"top"},endLabel:{show:!1,valueAnimation:!0,distance:8},lineStyle:{width:2,type:"solid"},emphasis:{scale:!0},step:!1,smooth:!1,smoothMonotone:null,symbol:"emptyCircle",symbolSize:4,symbolRotate:null,showSymbol:!0,showAllSymbol:"auto",connectNulls:!1,sampling:"none",animationEasing:"linear",progressive:0,hoverLayerThreshold:1/0,universalTransition:{divideShape:"clone"},triggerLineEvent:!1},t}(rr);const TD=bD;function Vh(r,t){var e=r.mapDimensionsAll("defaultedLabel"),i=e.length;if(i===1){var n=an(r,t,e[0]);return n!=null?n+"":null}else if(i){for(var a=[],o=0;o<e.length;o++)a.push(an(r,t,e[o]));return a.join(" ")}}function Y0(r,t){var e=r.mapDimensionsAll("defaultedLabel");if(!V(t))return t+"";for(var i=[],n=0;n<e.length;n++){var a=r.getDimensionIndex(e[n]);a>=0&&i.push(t[a])}return i.join(" ")}var CD=function(r){N(t,r);function t(e,i,n,a){var o=r.call(this)||this;return o.updateData(e,i,n,a),o}return t.prototype._createSymbol=function(e,i,n,a,o){this.removeAll();var s=ir(e,-1,-1,2,2,null,o);s.attr({z2:100,culling:!0,scaleX:a[0]/2,scaleY:a[1]/2}),s.drift=MD,this._symbolType=e,this.add(s)},t.prototype.stopSymbolAnimation=function(e){this.childAt(0).stopAnimation(null,e)},t.prototype.getSymbolType=function(){return this._symbolType},t.prototype.getSymbolPath=function(){return this.childAt(0)},t.prototype.highlight=function(){ts(this.childAt(0))},t.prototype.downplay=function(){es(this.childAt(0))},t.prototype.setZ=function(e,i){var n=this.childAt(0);n.zlevel=e,n.z=i},t.prototype.setDraggable=function(e,i){var n=this.childAt(0);n.draggable=e,n.cursor=!i&&e?"move":n.cursor},t.prototype.updateData=function(e,i,n,a){this.silent=!1;var o=e.getItemVisual(i,"symbol")||"circle",s=e.hostModel,l=t.getSymbolSize(e,i),u=o!==this._symbolType,f=a&&a.disableAnimation;if(u){var h=e.getItemVisual(i,"symbolKeepAspect");this._createSymbol(o,e,i,l,h)}else{var c=this.childAt(0);c.silent=!1;var v={scaleX:l[0]/2,scaleY:l[1]/2};f?c.attr(v):Lt(c,v,s,i),pa(c)}if(this._updateCommon(e,i,l,n,a),u){var c=this.childAt(0);if(!f){var v={scaleX:this._sizeX,scaleY:this._sizeY,style:{opacity:c.style.opacity}};c.scaleX=c.scaleY=0,c.style.opacity=0,Jt(c,v,s,i)}}f&&this.childAt(0).stopAnimation("leave")},t.prototype._updateCommon=function(e,i,n,a,o){var s=this.childAt(0),l=e.hostModel,u,f,h,c,v,d,p,g,y;if(a&&(u=a.emphasisItemStyle,f=a.blurItemStyle,h=a.selectItemStyle,c=a.focus,v=a.blurScope,p=a.labelStatesModels,g=a.hoverScale,y=a.cursorStyle,d=a.emphasisDisabled),!a||e.hasItemOption){var m=a&&a.itemModel?a.itemModel:e.getItemModel(i),_=m.getModel("emphasis");u=_.getModel("itemStyle").getItemStyle(),h=m.getModel(["select","itemStyle"]).getItemStyle(),f=m.getModel(["blur","itemStyle"]).getItemStyle(),c=_.get("focus"),v=_.get("blurScope"),d=_.get("disabled"),p=fn(m),g=_.getShallow("scale"),y=m.getShallow("cursor")}var S=e.getItemVisual(i,"symbolRotate");s.attr("rotation",(S||0)*Math.PI/180||0);var x=Gm(e.getItemVisual(i,"symbolOffset"),n);x&&(s.x=x[0],s.y=x[1]),y&&s.attr("cursor",y);var w=e.getItemVisual(i,"style"),b=w.fill;if(s instanceof nr){var T=s.style;s.useStyle(O({image:T.image,x:T.x,y:T.y,width:T.width,height:T.height},w))}else s.__isEmptyBrush?s.useStyle(O({},w)):s.useStyle(w),s.style.decal=null,s.setColor(b,o&&o.symbolInnerColor),s.style.strokeNoScale=!0;var M=e.getItemVisual(i,"liftZ"),D=this._z2;M!=null?D==null&&(this._z2=s.z2,s.z2+=M):D!=null&&(s.z2=D,this._z2=null);var C=o&&o.useNameLabel;un(s,p,{labelFetcher:l,labelDataIndex:i,defaultText:L,inheritColor:b,defaultOpacity:w.opacity});function L(R){return C?e.getName(R):Vh(e,R)}this._sizeX=n[0]/2,this._sizeY=n[1]/2;var I=s.ensureState("emphasis");I.style=u,s.ensureState("select").style=h,s.ensureState("blur").style=f;var P=g==null||g===!0?Math.max(1.1,3/this._sizeY):isFinite(g)&&g>0?+g:1;I.scaleX=this._sizeX*P,I.scaleY=this._sizeY*P,this.setSymbolScale(1),rn(this,c,v,d)},t.prototype.setSymbolScale=function(e){this.scaleX=this.scaleY=e},t.prototype.fadeOut=function(e,i,n){var a=this.childAt(0),o=lt(this).dataIndex,s=n&&n.animation;if(this.silent=a.silent=!0,n&&n.fadeLabel){var l=a.getTextContent();l&&ns(l,{style:{opacity:0}},i,{dataIndex:o,removeOpt:s,cb:function(){a.removeTextContent()}})}else a.removeTextContent();ns(a,{style:{opacity:0},scaleX:0,scaleY:0},i,{dataIndex:o,cb:e,removeOpt:s})},t.getSymbolSize=function(e,i){return Hm(e.getItemVisual(i,"symbolSize"))},t}(xt);function MD(r,t){this.parent.drift(r,t)}const Hh=CD;function uu(r,t,e,i){return t&&!isNaN(t[0])&&!isNaN(t[1])&&!(i.isIgnore&&i.isIgnore(e))&&!(i.clipShape&&!i.clipShape.contain(t[0],t[1]))&&r.getItemVisual(e,"symbol")!=="none"}function Vd(r){return r!=null&&!Y(r)&&(r={isIgnore:r}),r||{}}function Hd(r){var t=r.hostModel,e=t.getModel("emphasis");return{emphasisItemStyle:e.getModel("itemStyle").getItemStyle(),blurItemStyle:t.getModel(["blur","itemStyle"]).getItemStyle(),selectItemStyle:t.getModel(["select","itemStyle"]).getItemStyle(),focus:e.get("focus"),blurScope:e.get("blurScope"),emphasisDisabled:e.get("disabled"),hoverScale:e.get("scale"),labelStatesModels:fn(t),cursorStyle:t.get("cursor")}}var AD=function(){function r(t){this.group=new xt,this._SymbolCtor=t||Hh}return r.prototype.updateData=function(t,e){this._progressiveEls=null,e=Vd(e);var i=this.group,n=t.hostModel,a=this._data,o=this._SymbolCtor,s=e.disableAnimation,l=Hd(t),u={disableAnimation:s},f=e.getSymbolPoint||function(h){return t.getItemLayout(h)};a||i.removeAll(),t.diff(a).add(function(h){var c=f(h);if(uu(t,c,h,e)){var v=new o(t,h,l,u);v.setPosition(c),t.setItemGraphicEl(h,v),i.add(v)}}).update(function(h,c){var v=a.getItemGraphicEl(c),d=f(h);if(!uu(t,d,h,e)){i.remove(v);return}var p=t.getItemVisual(h,"symbol")||"circle",g=v&&v.getSymbolType&&v.getSymbolType();if(!v||g&&g!==p)i.remove(v),v=new o(t,h,l,u),v.setPosition(d);else{v.updateData(t,h,l,u);var y={x:d[0],y:d[1]};s?v.attr(y):Lt(v,y,n)}i.add(v),t.setItemGraphicEl(h,v)}).remove(function(h){var c=a.getItemGraphicEl(h);c&&c.fadeOut(function(){i.remove(c)},n)}).execute(),this._getSymbolPoint=f,this._data=t},r.prototype.updateLayout=function(){var t=this,e=this._data;e&&e.eachItemGraphicEl(function(i,n){var a=t._getSymbolPoint(n);i.setPosition(a),i.markRedraw()})},r.prototype.incrementalPrepareUpdate=function(t){this._seriesScope=Hd(t),this._data=null,this.group.removeAll()},r.prototype.incrementalUpdate=function(t,e,i){this._progressiveEls=[],i=Vd(i);function n(l){l.isGroup||(l.incremental=!0,l.ensureState("emphasis").hoverLayer=!0)}for(var a=t.start;a<t.end;a++){var o=e.getItemLayout(a);if(uu(e,o,a,i)){var s=new this._SymbolCtor(e,a,this._seriesScope);s.traverse(n),s.setPosition(o),this.group.add(s),e.setItemGraphicEl(a,s),this._progressiveEls.push(s)}}},r.prototype.eachRendered=function(t){Rs(this._progressiveEls||this.group,t)},r.prototype.remove=function(t){var e=this.group,i=this._data;i&&t?i.eachItemGraphicEl(function(n){n.fadeOut(function(){e.remove(n)},i.hostModel)}):e.removeAll()},r}();const DD=AD;function $0(r,t,e){var i=r.getBaseAxis(),n=r.getOtherAxis(i),a=LD(n,e),o=i.dim,s=n.dim,l=t.mapDimension(s),u=t.mapDimension(o),f=s==="x"||s==="radius"?1:0,h=G(r.dimensions,function(d){return t.mapDimension(d)}),c=!1,v=t.getCalculationInfo("stackResultDimension");return on(t,h[0])&&(c=!0,h[0]=v),on(t,h[1])&&(c=!0,h[1]=v),{dataDimsForPoint:h,valueStart:a,valueAxisDim:s,baseAxisDim:o,stacked:!!c,valueDim:l,baseDim:u,baseDataOffset:f,stackedOverDimension:t.getCalculationInfo("stackedOverDimension")}}function LD(r,t){var e=0,i=r.scale.getExtent();return t==="start"?e=i[0]:t==="end"?e=i[1]:dt(t)&&!isNaN(t)?e=t:i[0]>0?e=i[0]:i[1]<0&&(e=i[1]),e}function Z0(r,t,e,i){var n=NaN;r.stacked&&(n=e.get(e.getCalculationInfo("stackedOverDimension"),i)),isNaN(n)&&(n=r.valueStart);var a=r.baseDataOffset,o=[];return o[a]=e.get(r.baseDim,i),o[1-a]=n,t.dataToPoint(o)}function ID(r,t){var e=[];return t.diff(r).add(function(i){e.push({cmd:"+",idx:i})}).update(function(i,n){e.push({cmd:"=",idx:n,idx1:i})}).remove(function(i){e.push({cmd:"-",idx:i})}).execute(),e}function PD(r,t,e,i,n,a,o,s){for(var l=ID(r,t),u=[],f=[],h=[],c=[],v=[],d=[],p=[],g=$0(n,t,o),y=r.getLayout("points")||[],m=t.getLayout("points")||[],_=0;_<l.length;_++){var S=l[_],x=!0,w=void 0,b=void 0;switch(S.cmd){case"=":w=S.idx*2,b=S.idx1*2;var T=y[w],M=y[w+1],D=m[b],C=m[b+1];(isNaN(T)||isNaN(M))&&(T=D,M=C),u.push(T,M),f.push(D,C),h.push(e[w],e[w+1]),c.push(i[b],i[b+1]),p.push(t.getRawIndex(S.idx1));break;case"+":var L=S.idx,I=g.dataDimsForPoint,P=n.dataToPoint([t.get(I[0],L),t.get(I[1],L)]);b=L*2,u.push(P[0],P[1]),f.push(m[b],m[b+1]);var R=Z0(g,n,t,L);h.push(R[0],R[1]),c.push(i[b],i[b+1]),p.push(t.getRawIndex(L));break;case"-":x=!1}x&&(v.push(S),d.push(d.length))}d.sort(function(ft,Ut){return p[ft]-p[Ut]});for(var E=u.length,z=qe(E),k=qe(E),B=qe(E),F=qe(E),H=[],_=0;_<d.length;_++){var U=d[_],J=_*2,ot=U*2;z[J]=u[ot],z[J+1]=u[ot+1],k[J]=f[ot],k[J+1]=f[ot+1],B[J]=h[ot],B[J+1]=h[ot+1],F[J]=c[ot],F[J+1]=c[ot+1],H[_]=v[U]}return{current:z,next:k,stackedOnCurrent:B,stackedOnNext:F,status:H}}var dr=Math.min,pr=Math.max;function ni(r,t){return isNaN(r)||isNaN(t)}function Tf(r,t,e,i,n,a,o,s,l){for(var u,f,h,c,v,d,p=e,g=0;g<i;g++){var y=t[p*2],m=t[p*2+1];if(p>=n||p<0)break;if(ni(y,m)){if(l){p+=a;continue}break}if(p===e)r[a>0?"moveTo":"lineTo"](y,m),h=y,c=m;else{var _=y-u,S=m-f;if(_*_+S*S<.5){p+=a;continue}if(o>0){for(var x=p+a,w=t[x*2],b=t[x*2+1];w===y&&b===m&&g<i;)g++,x+=a,p+=a,w=t[x*2],b=t[x*2+1],y=t[p*2],m=t[p*2+1],_=y-u,S=m-f;var T=g+1;if(l)for(;ni(w,b)&&T<i;)T++,x+=a,w=t[x*2],b=t[x*2+1];var M=.5,D=0,C=0,L=void 0,I=void 0;if(T>=i||ni(w,b))v=y,d=m;else{D=w-u,C=b-f;var P=y-u,R=w-y,E=m-f,z=b-m,k=void 0,B=void 0;if(s==="x"){k=Math.abs(P),B=Math.abs(R);var F=D>0?1:-1;v=y-F*k*o,d=m,L=y+F*B*o,I=m}else if(s==="y"){k=Math.abs(E),B=Math.abs(z);var H=C>0?1:-1;v=y,d=m-H*k*o,L=y,I=m+H*B*o}else k=Math.sqrt(P*P+E*E),B=Math.sqrt(R*R+z*z),M=B/(B+k),v=y-D*o*(1-M),d=m-C*o*(1-M),L=y+D*o*M,I=m+C*o*M,L=dr(L,pr(w,y)),I=dr(I,pr(b,m)),L=pr(L,dr(w,y)),I=pr(I,dr(b,m)),D=L-y,C=I-m,v=y-D*k/B,d=m-C*k/B,v=dr(v,pr(u,y)),d=dr(d,pr(f,m)),v=pr(v,dr(u,y)),d=pr(d,dr(f,m)),D=y-v,C=m-d,L=y+D*B/k,I=m+C*B/k}r.bezierCurveTo(h,c,v,d,y,m),h=L,c=I}else r.lineTo(y,m)}u=y,f=m,p+=a}return g}var X0=function(){function r(){this.smooth=0,this.smoothConstraint=!0}return r}(),RD=function(r){N(t,r);function t(e){var i=r.call(this,e)||this;return i.type="ec-polyline",i}return t.prototype.getDefaultStyle=function(){return{stroke:"#000",fill:null}},t.prototype.getDefaultShape=function(){return new X0},t.prototype.buildPath=function(e,i){var n=i.points,a=0,o=n.length/2;if(i.connectNulls){for(;o>0&&ni(n[o*2-2],n[o*2-1]);o--);for(;a<o&&ni(n[a*2],n[a*2+1]);a++);}for(;a<o;)a+=Tf(e,n,a,o,o,1,i.smooth,i.smoothMonotone,i.connectNulls)+1},t.prototype.getPointOn=function(e,i){this.path||(this.createPathProxy(),this.buildPath(this.path,this.shape));for(var n=this.path,a=n.data,o=Lr.CMD,s,l,u=i==="x",f=[],h=0;h<a.length;){var c=a[h++],v=void 0,d=void 0,p=void 0,g=void 0,y=void 0,m=void 0,_=void 0;switch(c){case o.M:s=a[h++],l=a[h++];break;case o.L:if(v=a[h++],d=a[h++],_=u?(e-s)/(v-s):(e-l)/(d-l),_<=1&&_>=0){var S=u?(d-l)*_+l:(v-s)*_+s;return u?[e,S]:[S,e]}s=v,l=d;break;case o.C:v=a[h++],d=a[h++],p=a[h++],g=a[h++],y=a[h++],m=a[h++];var x=u?Yo(s,v,p,y,e,f):Yo(l,d,g,m,e,f);if(x>0)for(var w=0;w<x;w++){var b=f[w];if(b<=1&&b>=0){var S=u?Tt(l,d,g,m,b):Tt(s,v,p,y,b);return u?[e,S]:[S,e]}}s=y,l=m;break}}},t}(ct),ED=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t}(X0),kD=function(r){N(t,r);function t(e){var i=r.call(this,e)||this;return i.type="ec-polygon",i}return t.prototype.getDefaultShape=function(){return new ED},t.prototype.buildPath=function(e,i){var n=i.points,a=i.stackedOnPoints,o=0,s=n.length/2,l=i.smoothMonotone;if(i.connectNulls){for(;s>0&&ni(n[s*2-2],n[s*2-1]);s--);for(;o<s&&ni(n[o*2],n[o*2+1]);o++);}for(;o<s;){var u=Tf(e,n,o,s,s,1,i.smooth,l,i.connectNulls);Tf(e,a,o+u-1,u,s,-1,i.stackedOnSmooth,l,i.connectNulls),o+=u+1,e.closePath()}},t}(ct);function q0(r,t,e,i,n){var a=r.getArea(),o=a.x,s=a.y,l=a.width,u=a.height,f=e.get(["lineStyle","width"])||0;o-=f/2,s-=f/2,l+=f,u+=f,l=Math.ceil(l),o!==Math.floor(o)&&(o=Math.floor(o),l++);var h=new _t({shape:{x:o,y:s,width:l,height:u}});if(t){var c=r.getBaseAxis(),v=c.isHorizontal(),d=c.inverse;v?(d&&(h.shape.x+=l),h.shape.width=0):(d||(h.shape.y+=u),h.shape.height=0);var p=K(n)?function(g){n(g,h)}:null;Jt(h,{shape:{width:l,height:u,x:o,y:s}},e,null,i,p)}return h}function K0(r,t,e){var i=r.getArea(),n=bt(i.r0,1),a=bt(i.r,1),o=new mi({shape:{cx:bt(r.cx,1),cy:bt(r.cy,1),r0:n,r:a,startAngle:i.startAngle,endAngle:i.endAngle,clockwise:i.clockwise}});if(t){var s=r.getBaseAxis().dim==="angle";s?o.shape.endAngle=i.startAngle:o.shape.r=n,Jt(o,{shape:{endAngle:i.endAngle,r:a}},e)}return o}function OD(r,t,e,i,n){if(r){if(r.type==="polar")return K0(r,t,e);if(r.type==="cartesian2d")return q0(r,t,e,i,n)}else return null;return null}function Gh(r,t){return r.type===t}function Gd(r,t){if(r.length===t.length){for(var e=0;e<r.length;e++)if(r[e]!==t[e])return;return!0}}function Wd(r){for(var t=1/0,e=1/0,i=-1/0,n=-1/0,a=0;a<r.length;){var o=r[a++],s=r[a++];isNaN(o)||(t=Math.min(o,t),i=Math.max(o,i)),isNaN(s)||(e=Math.min(s,e),n=Math.max(s,n))}return[[t,e],[i,n]]}function Ud(r,t){var e=Wd(r),i=e[0],n=e[1],a=Wd(t),o=a[0],s=a[1];return Math.max(Math.abs(i[0]-o[0]),Math.abs(i[1]-o[1]),Math.abs(n[0]-s[0]),Math.abs(n[1]-s[1]))}function Yd(r){return dt(r)?r:r?.5:0}function BD(r,t,e){if(!e.valueDim)return[];for(var i=t.count(),n=qe(i*2),a=0;a<i;a++){var o=Z0(e,r,t,a);n[a*2]=o[0],n[a*2+1]=o[1]}return n}function gr(r,t,e,i,n){var a=e.getBaseAxis(),o=a.dim==="x"||a.dim==="radius"?0:1,s=[],l=0,u=[],f=[],h=[],c=[];if(n){for(l=0;l<r.length;l+=2){var v=t||r;!isNaN(v[l])&&!isNaN(v[l+1])&&c.push(r[l],r[l+1])}r=c}for(l=0;l<r.length-2;l+=2)switch(h[0]=r[l+2],h[1]=r[l+3],f[0]=r[l],f[1]=r[l+1],s.push(f[0],f[1]),i){case"end":u[o]=h[o],u[1-o]=f[1-o],s.push(u[0],u[1]);break;case"middle":var d=(f[o]+h[o])/2,p=[];u[o]=p[o]=d,u[1-o]=f[1-o],p[1-o]=h[1-o],s.push(u[0],u[1]),s.push(p[0],p[1]);break;default:u[o]=f[o],u[1-o]=h[1-o],s.push(u[0],u[1])}return s.push(r[l++],r[l++]),s}function ND(r,t){var e=[],i=r.length,n,a;function o(f,h,c){var v=f.coord,d=(c-v)/(h.coord-v),p=hS(d,[f.color,h.color]);return{coord:c,color:p}}for(var s=0;s<i;s++){var l=r[s],u=l.coord;if(u<0)n=l;else if(u>t){a?e.push(o(a,l,t)):n&&e.push(o(n,l,0),o(n,l,t));break}else n&&(e.push(o(n,l,0)),n=null),e.push(l),a=l}return e}function zD(r,t,e){var i=r.getVisual("visualMeta");if(!(!i||!i.length||!r.count())&&t.type==="cartesian2d"){for(var n,a,o=i.length-1;o>=0;o--){var s=r.getDimensionInfo(i[o].dimension);if(n=s&&s.coordDim,n==="x"||n==="y"){a=i[o];break}}if(!!a){var l=t.getAxis(n),u=G(a.stops,function(_){return{coord:l.toGlobalCoord(l.dataToCoord(_.value)),color:_.color}}),f=u.length,h=a.outerColors.slice();f&&u[0].coord>u[f-1].coord&&(u.reverse(),h.reverse());var c=ND(u,n==="x"?e.getWidth():e.getHeight()),v=c.length;if(!v&&f)return u[0].coord<0?h[1]?h[1]:u[f-1].color:h[0]?h[0]:u[0].color;var d=10,p=c[0].coord-d,g=c[v-1].coord+d,y=g-p;if(y<.001)return"transparent";A(c,function(_){_.offset=(_.coord-p)/y}),c.push({offset:v?c[v-1].offset:.5,color:h[1]||"transparent"}),c.unshift({offset:v?c[0].offset:.5,color:h[0]||"transparent"});var m=new Ey(0,0,0,0,c,!0);return m[n]=p,m[n+"2"]=g,m}}}function FD(r,t,e){var i=r.get("showAllSymbol"),n=i==="auto";if(!(i&&!n)){var a=e.getAxesByScale("ordinal")[0];if(!!a&&!(n&&VD(a,t))){var o=t.mapDimension(a.dim),s={};return A(a.getViewLabels(),function(l){var u=a.scale.getRawOrdinalNumber(l.tickValue);s[u]=1}),function(l){return!s.hasOwnProperty(t.get(o,l))}}}}function VD(r,t){var e=r.getExtent(),i=Math.abs(e[1]-e[0])/r.scale.count();isNaN(i)&&(i=0);for(var n=t.count(),a=Math.max(1,Math.round(n/5)),o=0;o<n;o+=a)if(Hh.getSymbolSize(t,o)[r.isHorizontal()?1:0]*1.5>i)return!1;return!0}function HD(r,t){return isNaN(r)||isNaN(t)}function GD(r){for(var t=r.length/2;t>0&&HD(r[t*2-2],r[t*2-1]);t--);return t-1}function $d(r,t){return[r[t*2],r[t*2+1]]}function WD(r,t,e){for(var i=r.length/2,n=e==="x"?0:1,a,o,s=0,l=-1,u=0;u<i;u++)if(o=r[u*2+n],!(isNaN(o)||isNaN(r[u*2+1-n]))){if(u===0){a=o;continue}if(a<=t&&o>=t||a>=t&&o<=t){l=u;break}s=u,a=o}return{range:[s,l],t:(t-a)/(o-a)}}function Q0(r){if(r.get(["endLabel","show"]))return!0;for(var t=0;t<ye.length;t++)if(r.get([ye[t],"endLabel","show"]))return!0;return!1}function fu(r,t,e,i){if(Gh(t,"cartesian2d")){var n=i.getModel("endLabel"),a=n.get("valueAnimation"),o=i.getData(),s={lastFrameIndex:0},l=Q0(i)?function(v,d){r._endLabelOnDuring(v,d,o,s,a,n,t)}:null,u=t.getBaseAxis().isHorizontal(),f=q0(t,e,i,function(){var v=r._endLabel;v&&e&&s.originalX!=null&&v.attr({x:s.originalX,y:s.originalY})},l);if(!i.get("clip",!0)){var h=f.shape,c=Math.max(h.width,h.height);u?(h.y-=c,h.height+=c*2):(h.x-=c,h.width+=c*2)}return l&&l(1,f),f}else return K0(t,e,i)}function UD(r,t){var e=t.getBaseAxis(),i=e.isHorizontal(),n=e.inverse,a=i?n?"right":"left":"center",o=i?"middle":n?"top":"bottom";return{normal:{align:r.get("align")||a,verticalAlign:r.get("verticalAlign")||o}}}var YD=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(){var e=new xt,i=new DD;this.group.add(i.group),this._symbolDraw=i,this._lineGroup=e,this._changePolyState=$(this._changePolyState,this)},t.prototype.render=function(e,i,n){var a=e.coordinateSystem,o=this.group,s=e.getData(),l=e.getModel("lineStyle"),u=e.getModel("areaStyle"),f=s.getLayout("points")||[],h=a.type==="polar",c=this._coordSys,v=this._symbolDraw,d=this._polyline,p=this._polygon,g=this._lineGroup,y=!i.ssr&&e.get("animation"),m=!u.isEmpty(),_=u.get("origin"),S=$0(a,s,_),x=m&&BD(a,s,S),w=e.get("showSymbol"),b=e.get("connectNulls"),T=w&&!h&&FD(e,s,a),M=this._data;M&&M.eachItemGraphicEl(function(ft,Ut){ft.__temp&&(o.remove(ft),M.setItemGraphicEl(Ut,null))}),w||v.remove(),o.add(g);var D=h?!1:e.get("step"),C;a&&a.getArea&&e.get("clip",!0)&&(C=a.getArea(),C.width!=null?(C.x-=.1,C.y-=.1,C.width+=.2,C.height+=.2):C.r0&&(C.r0-=.5,C.r+=.5)),this._clipShapeForSymbol=C;var L=zD(s,a,n)||s.getVisual("style")[s.getVisual("drawType")];if(!(d&&c.type===a.type&&D===this._step))w&&v.updateData(s,{isIgnore:T,clipShape:C,disableAnimation:!0,getSymbolPoint:function(ft){return[f[ft*2],f[ft*2+1]]}}),y&&this._initSymbolLabelAnimation(s,a,C),D&&(x&&(x=gr(x,f,a,D,b)),f=gr(f,null,a,D,b)),d=this._newPolyline(f),m?p=this._newPolygon(f,x):p&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(e,a,hi(L)),g.setClipPath(fu(this,a,!0,e));else{m&&!p?p=this._newPolygon(f,x):p&&!m&&(g.remove(p),p=this._polygon=null),h||this._initOrUpdateEndLabel(e,a,hi(L));var I=g.getClipPath();if(I){var P=fu(this,a,!1,e);Jt(I,{shape:P.shape},e)}else g.setClipPath(fu(this,a,!0,e));w&&v.updateData(s,{isIgnore:T,clipShape:C,disableAnimation:!0,getSymbolPoint:function(ft){return[f[ft*2],f[ft*2+1]]}}),(!Gd(this._stackedOnPoints,x)||!Gd(this._points,f))&&(y?this._doUpdateAnimation(s,x,a,n,D,_,b):(D&&(x&&(x=gr(x,f,a,D,b)),f=gr(f,null,a,D,b)),d.setShape({points:f}),p&&p.setShape({points:f,stackedOnPoints:x})))}var R=e.getModel("emphasis"),E=R.get("focus"),z=R.get("blurScope"),k=R.get("disabled");if(d.useStyle(rt(l.getLineStyle(),{fill:"none",stroke:L,lineJoin:"bevel"})),nn(d,e,"lineStyle"),d.style.lineWidth>0&&e.get(["emphasis","lineStyle","width"])==="bolder"){var B=d.getState("emphasis").style;B.lineWidth=+d.style.lineWidth+1}lt(d).seriesIndex=e.seriesIndex,rn(d,E,z,k);var F=Yd(e.get("smooth")),H=e.get("smoothMonotone");if(d.setShape({smooth:F,smoothMonotone:H,connectNulls:b}),p){var U=s.getCalculationInfo("stackedOnSeries"),J=0;p.useStyle(rt(u.getAreaStyle(),{fill:L,opacity:.7,lineJoin:"bevel",decal:s.getVisual("style").decal})),U&&(J=Yd(U.get("smooth"))),p.setShape({smooth:F,stackedOnSmooth:J,smoothMonotone:H,connectNulls:b}),nn(p,e,"areaStyle"),lt(p).seriesIndex=e.seriesIndex,rn(p,E,z,k)}var ot=this._changePolyState;s.eachItemGraphicEl(function(ft){ft&&(ft.onHoverStateChange=ot)}),this._polyline.onHoverStateChange=ot,this._data=s,this._coordSys=a,this._stackedOnPoints=x,this._points=f,this._step=D,this._valueOrigin=_,e.get("triggerLineEvent")&&(this.packEventData(e,d),p&&this.packEventData(e,p))},t.prototype.packEventData=function(e,i){lt(i).eventData={componentType:"series",componentSubType:"line",componentIndex:e.componentIndex,seriesIndex:e.seriesIndex,seriesName:e.name,seriesType:"line"}},t.prototype.highlight=function(e,i,n,a){var o=e.getData(),s=li(o,a);if(this._changePolyState("emphasis"),!(s instanceof Array)&&s!=null&&s>=0){var l=o.getLayout("points"),u=o.getItemGraphicEl(s);if(!u){var f=l[s*2],h=l[s*2+1];if(isNaN(f)||isNaN(h)||this._clipShapeForSymbol&&!this._clipShapeForSymbol.contain(f,h))return;var c=e.get("zlevel")||0,v=e.get("z")||0;u=new Hh(o,s),u.x=f,u.y=h,u.setZ(c,v);var d=u.getSymbolPath().getTextContent();d&&(d.zlevel=c,d.z=v,d.z2=this._polyline.z2+1),u.__temp=!0,o.setItemGraphicEl(s,u),u.stopSymbolAnimation(!0),this.group.add(u)}u.highlight()}else Te.prototype.highlight.call(this,e,i,n,a)},t.prototype.downplay=function(e,i,n,a){var o=e.getData(),s=li(o,a);if(this._changePolyState("normal"),s!=null&&s>=0){var l=o.getItemGraphicEl(s);l&&(l.__temp?(o.setItemGraphicEl(s,null),this.group.remove(l)):l.downplay())}else Te.prototype.downplay.call(this,e,i,n,a)},t.prototype._changePolyState=function(e){var i=this._polygon;ec(this._polyline,e),i&&ec(i,e)},t.prototype._newPolyline=function(e){var i=this._polyline;return i&&this._lineGroup.remove(i),i=new RD({shape:{points:e},segmentIgnoreThreshold:2,z2:10}),this._lineGroup.add(i),this._polyline=i,i},t.prototype._newPolygon=function(e,i){var n=this._polygon;return n&&this._lineGroup.remove(n),n=new kD({shape:{points:e,stackedOnPoints:i},segmentIgnoreThreshold:2}),this._lineGroup.add(n),this._polygon=n,n},t.prototype._initSymbolLabelAnimation=function(e,i,n){var a,o,s=i.getBaseAxis(),l=s.inverse;i.type==="cartesian2d"?(a=s.isHorizontal(),o=!1):i.type==="polar"&&(a=s.dim==="angle",o=!0);var u=e.hostModel,f=u.get("animationDuration");K(f)&&(f=f(null));var h=u.get("animationDelay")||0,c=K(h)?h(null):h;e.eachItemGraphicEl(function(v,d){var p=v;if(p){var g=[v.x,v.y],y=void 0,m=void 0,_=void 0;if(n)if(o){var S=n,x=i.pointToCoord(g);a?(y=S.startAngle,m=S.endAngle,_=-x[1]/180*Math.PI):(y=S.r0,m=S.r,_=x[0])}else{var w=n;a?(y=w.x,m=w.x+w.width,_=v.x):(y=w.y+w.height,m=w.y,_=v.y)}var b=m===y?0:(_-y)/(m-y);l&&(b=1-b);var T=K(h)?h(d):f*b+c,M=p.getSymbolPath(),D=M.getTextContent();p.attr({scaleX:0,scaleY:0}),p.animateTo({scaleX:1,scaleY:1},{duration:200,setToFinal:!0,delay:T}),D&&D.animateFrom({style:{opacity:0}},{duration:300,delay:T}),M.disableLabelAnimation=!0}})},t.prototype._initOrUpdateEndLabel=function(e,i,n){var a=e.getModel("endLabel");if(Q0(e)){var o=e.getData(),s=this._polyline,l=o.getLayout("points");if(!l){s.removeTextContent(),this._endLabel=null;return}var u=this._endLabel;u||(u=this._endLabel=new Dt({z2:200}),u.ignoreClip=!0,s.setTextContent(this._endLabel),s.disableLabelAnimation=!0);var f=GD(l);f>=0&&(un(s,fn(e,"endLabel"),{inheritColor:n,labelFetcher:e,labelDataIndex:f,defaultText:function(h,c,v){return v!=null?Y0(o,v):Vh(o,h)},enableTextSetter:!0},UD(a,i)),s.textConfig.position=null)}else this._endLabel&&(this._polyline.removeTextContent(),this._endLabel=null)},t.prototype._endLabelOnDuring=function(e,i,n,a,o,s,l){var u=this._endLabel,f=this._polyline;if(u){e<1&&a.originalX==null&&(a.originalX=u.x,a.originalY=u.y);var h=n.getLayout("points"),c=n.hostModel,v=c.get("connectNulls"),d=s.get("precision"),p=s.get("distance")||0,g=l.getBaseAxis(),y=g.isHorizontal(),m=g.inverse,_=i.shape,S=m?y?_.x:_.y+_.height:y?_.x+_.width:_.y,x=(y?p:0)*(m?-1:1),w=(y?0:-p)*(m?-1:1),b=y?"x":"y",T=WD(h,S,b),M=T.range,D=M[1]-M[0],C=void 0;if(D>=1){if(D>1&&!v){var L=$d(h,M[0]);u.attr({x:L[0]+x,y:L[1]+w}),o&&(C=c.getRawValue(M[0]))}else{var L=f.getPointOn(S,b);L&&u.attr({x:L[0]+x,y:L[1]+w});var I=c.getRawValue(M[0]),P=c.getRawValue(M[1]);o&&(C=lw(n,d,I,P,T.t))}a.lastFrameIndex=M[0]}else{var R=e===1||a.lastFrameIndex>0?M[0]:0,L=$d(h,R);o&&(C=c.getRawValue(R)),u.attr({x:L[0]+x,y:L[1]+w})}if(o){var E=ks(u);typeof E.setLabelText=="function"&&E.setLabelText(C)}}},t.prototype._doUpdateAnimation=function(e,i,n,a,o,s,l){var u=this._polyline,f=this._polygon,h=e.hostModel,c=PD(this._data,e,this._stackedOnPoints,i,this._coordSys,n,this._valueOrigin),v=c.current,d=c.stackedOnCurrent,p=c.next,g=c.stackedOnNext;if(o&&(d=gr(c.stackedOnCurrent,c.current,n,o,l),v=gr(c.current,null,n,o,l),g=gr(c.stackedOnNext,c.next,n,o,l),p=gr(c.next,null,n,o,l)),Ud(v,p)>3e3||f&&Ud(d,g)>3e3){u.stopAnimation(),u.setShape({points:p}),f&&(f.stopAnimation(),f.setShape({points:p,stackedOnPoints:g}));return}u.shape.__points=c.current,u.shape.points=v;var y={shape:{points:p}};c.current!==v&&(y.shape.__points=c.next),u.stopAnimation(),Lt(u,y,h),f&&(f.setShape({points:v,stackedOnPoints:d}),f.stopAnimation(),Lt(f,{shape:{stackedOnPoints:g}},h),u.shape.points!==f.shape.points&&(f.shape.points=u.shape.points));for(var m=[],_=c.status,S=0;S<_.length;S++){var x=_[S].cmd;if(x==="="){var w=e.getItemGraphicEl(_[S].idx1);w&&m.push({el:w,ptIdx:S})}}u.animators&&u.animators.length&&u.animators[0].during(function(){f&&f.dirtyShape();for(var b=u.shape.__points,T=0;T<m.length;T++){var M=m[T].el,D=m[T].ptIdx*2;M.x=b[D],M.y=b[D+1],M.markRedraw()}})},t.prototype.remove=function(e){var i=this.group,n=this._data;this._lineGroup.removeAll(),this._symbolDraw.remove(!0),n&&n.eachItemGraphicEl(function(a,o){a.__temp&&(i.remove(a),n.setItemGraphicEl(o,null))}),this._polyline=this._polygon=this._coordSys=this._points=this._stackedOnPoints=this._endLabel=this._data=null},t.type="line",t}(Te);const $D=YD;function ZD(r,t){return{seriesType:r,plan:Ah(),reset:function(e){var i=e.getData(),n=e.coordinateSystem,a=e.pipelineContext,o=t||a.large;if(!!n){var s=G(n.dimensions,function(v){return i.mapDimension(v)}).slice(0,2),l=s.length,u=i.getCalculationInfo("stackResultDimension");on(i,s[0])&&(s[0]=u),on(i,s[1])&&(s[1]=u);var f=i.getStore(),h=i.getDimensionIndex(s[0]),c=i.getDimensionIndex(s[1]);return l&&{progress:function(v,d){for(var p=v.end-v.start,g=o&&qe(p*l),y=[],m=[],_=v.start,S=0;_<v.end;_++){var x=void 0;if(l===1){var w=f.get(h,_);x=n.dataToPoint(w,null,m)}else y[0]=f.get(h,_),y[1]=f.get(c,_),x=n.dataToPoint(y,null,m);o?(g[S++]=x[0],g[S++]=x[1]):d.setItemLayout(_,x.slice())}o&&d.setLayout("points",g)}}}}}}var XD={average:function(r){for(var t=0,e=0,i=0;i<r.length;i++)isNaN(r[i])||(t+=r[i],e++);return e===0?NaN:t/e},sum:function(r){for(var t=0,e=0;e<r.length;e++)t+=r[e]||0;return t},max:function(r){for(var t=-1/0,e=0;e<r.length;e++)r[e]>t&&(t=r[e]);return isFinite(t)?t:NaN},min:function(r){for(var t=1/0,e=0;e<r.length;e++)r[e]<t&&(t=r[e]);return isFinite(t)?t:NaN},nearest:function(r){return r[0]}},qD=function(r){return Math.round(r.length/2)};function J0(r){return{seriesType:r,reset:function(t,e,i){var n=t.getData(),a=t.get("sampling"),o=t.coordinateSystem,s=n.count();if(s>10&&o.type==="cartesian2d"&&a){var l=o.getBaseAxis(),u=o.getOtherAxis(l),f=l.getExtent(),h=i.getDevicePixelRatio(),c=Math.abs(f[1]-f[0])*(h||1),v=Math.round(s/c);if(isFinite(v)&&v>1){a==="lttb"?t.setData(n.lttbDownSample(n.mapDimension(u.dim),1/v)):a==="minmax"&&t.setData(n.minmaxDownSample(n.mapDimension(u.dim),1/v));var d=void 0;W(a)?d=XD[a]:K(a)&&(d=a),d&&t.setData(n.downSample(n.mapDimension(u.dim),1/v,d,qD))}}}}}function nR(r){r.registerChartView($D),r.registerSeriesModel(TD),r.registerLayout(ZD("line",!0)),r.registerVisual({seriesType:"line",reset:function(t){var e=t.getData(),i=t.getModel("lineStyle").getLineStyle();i&&!i.stroke&&(i.stroke=e.getVisual("style").fill),e.setVisual("legendLineStyle",i)}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,J0("line"))}var j0=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(e,i){return kh(null,this,{useEncodeDefaulter:!0})},t.prototype.getMarkerPosition=function(e,i,n){var a=this.coordinateSystem;if(a&&a.clampData){var o=a.clampData(e),s=a.dataToPoint(o);if(n)A(a.getAxes(),function(c,v){if(c.type==="category"&&i!=null){var d=c.getTicksCoords(),p=c.getTickModel().get("alignWithLabel"),g=o[v],y=i[v]==="x1"||i[v]==="y1";if(y&&!p&&(g+=1),d.length<2)return;if(d.length===2){s[v]=c.toGlobalCoord(c.getExtent()[y?1:0]);return}for(var m=void 0,_=void 0,S=1,x=0;x<d.length;x++){var w=d[x].coord,b=x===d.length-1?d[x-1].tickValue+S:d[x].tickValue;if(b===g){_=w;break}else if(b<g)m=w;else if(m!=null&&b>g){_=(w+m)/2;break}x===1&&(S=b-d[0].tickValue)}_==null&&(m?m&&(_=d[d.length-1].coord):_=d[0].coord),s[v]=c.toGlobalCoord(_)}});else{var l=this.getData(),u=l.getLayout("offset"),f=l.getLayout("size"),h=a.getBaseAxis().isHorizontal()?0:1;s[h]+=u+f/2}return s}return[NaN,NaN]},t.type="series.__base_bar__",t.defaultOption={z:2,coordinateSystem:"cartesian2d",legendHoverLink:!0,barMinHeight:0,barMinAngle:0,large:!1,largeThreshold:400,progressive:3e3,progressiveChunkMode:"mod"},t}(rr);rr.registerClass(j0);const Zd=j0;var KD=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.getInitialData=function(){return kh(null,this,{useEncodeDefaulter:!0,createInvertedIndices:!!this.get("realtimeSort",!0)||null})},t.prototype.getProgressive=function(){return this.get("large")?this.get("progressive"):!1},t.prototype.getProgressiveThreshold=function(){var e=this.get("progressiveThreshold"),i=this.get("largeThreshold");return i>e&&(e=i),e},t.prototype.brushSelector=function(e,i,n){return n.rect(i.getItemLayout(e))},t.type="series.bar",t.dependencies=["grid","polar"],t.defaultOption=Bs(Zd.defaultOption,{clip:!0,roundCap:!1,showBackground:!1,backgroundStyle:{color:"rgba(180, 180, 180, 0.2)",borderColor:null,borderWidth:0,borderType:"solid",borderRadius:0,shadowBlur:0,shadowColor:null,shadowOffsetX:0,shadowOffsetY:0,opacity:1},select:{itemStyle:{borderColor:"#212121"}},realtimeSort:!1}),t}(Zd);const QD=KD;var JD=function(){function r(){this.cx=0,this.cy=0,this.r0=0,this.r=0,this.startAngle=0,this.endAngle=Math.PI*2,this.clockwise=!0}return r}(),jD=function(r){N(t,r);function t(e){var i=r.call(this,e)||this;return i.type="sausage",i}return t.prototype.getDefaultShape=function(){return new JD},t.prototype.buildPath=function(e,i){var n=i.cx,a=i.cy,o=Math.max(i.r0||0,0),s=Math.max(i.r,0),l=(s-o)*.5,u=o+l,f=i.startAngle,h=i.endAngle,c=i.clockwise,v=Math.PI*2,d=c?h-f<v:f-h<v;d||(f=h-(c?v:-v));var p=Math.cos(f),g=Math.sin(f),y=Math.cos(h),m=Math.sin(h);d?(e.moveTo(p*o+n,g*o+a),e.arc(p*u+n,g*u+a,l,-Math.PI+f,f,!c)):e.moveTo(p*s+n,g*s+a),e.arc(n,a,s,f,h,!c),e.arc(y*u+n,m*u+a,l,h-Math.PI*2,h-Math.PI,!c),o!==0&&e.arc(n,a,o,h,f,c)},t}(ct);const Xd=jD;function tL(r,t){t=t||{};var e=t.isRoundCap;return function(i,n,a){var o=n.position;if(!o||o instanceof Array)return Ko(i,n,a);var s=r(o),l=n.distance!=null?n.distance:5,u=this.shape,f=u.cx,h=u.cy,c=u.r,v=u.r0,d=(c+v)/2,p=u.startAngle,g=u.endAngle,y=(p+g)/2,m=e?Math.abs(c-v)/2:0,_=Math.cos,S=Math.sin,x=f+c*_(p),w=h+c*S(p),b="left",T="top";switch(s){case"startArc":x=f+(v-l)*_(y),w=h+(v-l)*S(y),b="center",T="top";break;case"insideStartArc":x=f+(v+l)*_(y),w=h+(v+l)*S(y),b="center",T="bottom";break;case"startAngle":x=f+d*_(p)+mo(p,l+m,!1),w=h+d*S(p)+_o(p,l+m,!1),b="right",T="middle";break;case"insideStartAngle":x=f+d*_(p)+mo(p,-l+m,!1),w=h+d*S(p)+_o(p,-l+m,!1),b="left",T="middle";break;case"middle":x=f+d*_(y),w=h+d*S(y),b="center",T="middle";break;case"endArc":x=f+(c+l)*_(y),w=h+(c+l)*S(y),b="center",T="bottom";break;case"insideEndArc":x=f+(c-l)*_(y),w=h+(c-l)*S(y),b="center",T="top";break;case"endAngle":x=f+d*_(g)+mo(g,l+m,!0),w=h+d*S(g)+_o(g,l+m,!0),b="left",T="middle";break;case"insideEndAngle":x=f+d*_(g)+mo(g,-l+m,!0),w=h+d*S(g)+_o(g,-l+m,!0),b="right",T="middle";break;default:return Ko(i,n,a)}return i=i||{},i.x=x,i.y=w,i.align=b,i.verticalAlign=T,i}}function eL(r,t,e,i){if(dt(i)){r.setTextConfig({rotation:i});return}else if(V(t)){r.setTextConfig({rotation:0});return}var n=r.shape,a=n.clockwise?n.startAngle:n.endAngle,o=n.clockwise?n.endAngle:n.startAngle,s=(a+o)/2,l,u=e(t);switch(u){case"startArc":case"insideStartArc":case"middle":case"insideEndArc":case"endArc":l=s;break;case"startAngle":case"insideStartAngle":l=a;break;case"endAngle":case"insideEndAngle":l=o;break;default:r.setTextConfig({rotation:0});return}var f=Math.PI*1.5-l;u==="middle"&&f>Math.PI/2&&f<Math.PI*1.5&&(f-=Math.PI),r.setTextConfig({rotation:f})}function mo(r,t,e){return t*Math.sin(r)*(e?-1:1)}function _o(r,t,e){return t*Math.cos(r)*(e?1:-1)}function qn(r,t,e){var i=r.get("borderRadius");if(i==null)return e?{cornerRadius:0}:null;V(i)||(i=[i,i,i,i]);var n=Math.abs(t.r||0-t.r0||0);return{cornerRadius:G(i,function(a){return Dr(a,n)})}}var hu=Math.max,vu=Math.min;function rL(r,t){var e=r.getArea&&r.getArea();if(Gh(r,"cartesian2d")){var i=r.getBaseAxis();if(i.type!=="category"||!i.onBand){var n=t.getLayout("bandWidth");i.isHorizontal()?(e.x-=n,e.width+=n*2):(e.y-=n,e.height+=n*2)}}return e}var iL=function(r){N(t,r);function t(){var e=r.call(this)||this;return e.type=t.type,e._isFirstFrame=!0,e}return t.prototype.render=function(e,i,n,a){this._model=e,this._removeOnRenderedListener(n),this._updateDrawMode(e);var o=e.get("coordinateSystem");(o==="cartesian2d"||o==="polar")&&(this._progressiveEls=null,this._isLargeDraw?this._renderLarge(e,i,n):this._renderNormal(e,i,n,a))},t.prototype.incrementalPrepareRender=function(e){this._clear(),this._updateDrawMode(e),this._updateLargeClip(e)},t.prototype.incrementalRender=function(e,i){this._progressiveEls=[],this._incrementalRenderLarge(e,i)},t.prototype.eachRendered=function(e){Rs(this._progressiveEls||this.group,e)},t.prototype._updateDrawMode=function(e){var i=e.pipelineContext.large;(this._isLargeDraw==null||i!==this._isLargeDraw)&&(this._isLargeDraw=i,this._clear())},t.prototype._renderNormal=function(e,i,n,a){var o=this.group,s=e.getData(),l=this._data,u=e.coordinateSystem,f=u.getBaseAxis(),h;u.type==="cartesian2d"?h=f.isHorizontal():u.type==="polar"&&(h=f.dim==="angle");var c=e.isAnimationEnabled()?e:null,v=nL(e,u);v&&this._enableRealtimeSort(v,s,n);var d=e.get("clip",!0)||v,p=rL(u,s);o.removeClipPath();var g=e.get("roundCap",!0),y=e.get("showBackground",!0),m=e.getModel("backgroundStyle"),_=m.get("borderRadius")||0,S=[],x=this._backgroundEls,w=a&&a.isInitSort,b=a&&a.type==="changeAxisOrder";function T(C){var L=So[u.type](s,C),I=hL(u,h,L);return I.useStyle(m.getItemStyle()),u.type==="cartesian2d"?I.setShape("r",_):I.setShape("cornerRadius",_),S[C]=I,I}s.diff(l).add(function(C){var L=s.getItemModel(C),I=So[u.type](s,C,L);if(y&&T(C),!(!s.hasValue(C)||!jd[u.type](I))){var P=!1;d&&(P=qd[u.type](p,I));var R=Kd[u.type](e,s,C,I,h,c,f.model,!1,g);v&&(R.forceLabelAnimation=!0),tp(R,s,C,L,I,e,h,u.type==="polar"),w?R.attr({shape:I}):v?Qd(v,c,R,I,C,h,!1,!1):Jt(R,{shape:I},e,C),s.setItemGraphicEl(C,R),o.add(R),R.ignore=P}}).update(function(C,L){var I=s.getItemModel(C),P=So[u.type](s,C,I);if(y){var R=void 0;x.length===0?R=T(L):(R=x[L],R.useStyle(m.getItemStyle()),u.type==="cartesian2d"?R.setShape("r",_):R.setShape("cornerRadius",_),S[C]=R);var E=So[u.type](s,C),z=e_(h,E,u);Lt(R,{shape:z},c,C)}var k=l.getItemGraphicEl(L);if(!s.hasValue(C)||!jd[u.type](P)){o.remove(k);return}var B=!1;if(d&&(B=qd[u.type](p,P),B&&o.remove(k)),k?pa(k):k=Kd[u.type](e,s,C,P,h,c,f.model,!!k,g),v&&(k.forceLabelAnimation=!0),b){var F=k.getTextContent();if(F){var H=ks(F);H.prevValue!=null&&(H.prevValue=H.value)}}else tp(k,s,C,I,P,e,h,u.type==="polar");w?k.attr({shape:P}):v?Qd(v,c,k,P,C,h,!0,b):Lt(k,{shape:P},e,C,null),s.setItemGraphicEl(C,k),k.ignore=B,o.add(k)}).remove(function(C){var L=l.getItemGraphicEl(C);L&&as(L,e,C)}).execute();var M=this._backgroundGroup||(this._backgroundGroup=new xt);M.removeAll();for(var D=0;D<S.length;++D)M.add(S[D]);o.add(M),this._backgroundEls=S,this._data=s},t.prototype._renderLarge=function(e,i,n){this._clear(),rp(e,this.group),this._updateLargeClip(e)},t.prototype._incrementalRenderLarge=function(e,i){this._removeBackground(),rp(i,this.group,this._progressiveEls,!0)},t.prototype._updateLargeClip=function(e){var i=e.get("clip",!0)&&OD(e.coordinateSystem,!1,e),n=this.group;i?n.setClipPath(i):n.removeClipPath()},t.prototype._enableRealtimeSort=function(e,i,n){var a=this;if(!!i.count()){var o=e.baseAxis;if(this._isFirstFrame)this._dispatchInitSort(i,e,n),this._isFirstFrame=!1;else{var s=function(l){var u=i.getItemGraphicEl(l),f=u&&u.shape;return f&&Math.abs(o.isHorizontal()?f.height:f.width)||0};this._onRendered=function(){a._updateSortWithinSameData(i,s,o,n)},n.getZr().on("rendered",this._onRendered)}}},t.prototype._dataSort=function(e,i,n){var a=[];return e.each(e.mapDimension(i.dim),function(o,s){var l=n(s);l=l==null?NaN:l,a.push({dataIndex:s,mappedValue:l,ordinalNumber:o})}),a.sort(function(o,s){return s.mappedValue-o.mappedValue}),{ordinalNumbers:G(a,function(o){return o.ordinalNumber})}},t.prototype._isOrderChangedWithinSameData=function(e,i,n){for(var a=n.scale,o=e.mapDimension(n.dim),s=Number.MAX_VALUE,l=0,u=a.getOrdinalMeta().categories.length;l<u;++l){var f=e.rawIndexOf(o,a.getRawOrdinalNumber(l)),h=f<0?Number.MIN_VALUE:i(e.indexOfRawIndex(f));if(h>s)return!0;s=h}return!1},t.prototype._isOrderDifferentInView=function(e,i){for(var n=i.scale,a=n.getExtent(),o=Math.max(0,a[0]),s=Math.min(a[1],n.getOrdinalMeta().categories.length-1);o<=s;++o)if(e.ordinalNumbers[o]!==n.getRawOrdinalNumber(o))return!0},t.prototype._updateSortWithinSameData=function(e,i,n,a){if(!!this._isOrderChangedWithinSameData(e,i,n)){var o=this._dataSort(e,n,i);this._isOrderDifferentInView(o,n)&&(this._removeOnRenderedListener(a),a.dispatchAction({type:"changeAxisOrder",componentType:n.dim+"Axis",axisId:n.index,sortInfo:o}))}},t.prototype._dispatchInitSort=function(e,i,n){var a=i.baseAxis,o=this._dataSort(e,a,function(s){return e.get(e.mapDimension(i.otherAxis.dim),s)});n.dispatchAction({type:"changeAxisOrder",componentType:a.dim+"Axis",isInitSort:!0,axisId:a.index,sortInfo:o})},t.prototype.remove=function(e,i){this._clear(this._model),this._removeOnRenderedListener(i)},t.prototype.dispose=function(e,i){this._removeOnRenderedListener(i)},t.prototype._removeOnRenderedListener=function(e){this._onRendered&&(e.getZr().off("rendered",this._onRendered),this._onRendered=null)},t.prototype._clear=function(e){var i=this.group,n=this._data;e&&e.isAnimationEnabled()&&n&&!this._isLargeDraw?(this._removeBackground(),this._backgroundEls=[],n.eachItemGraphicEl(function(a){as(a,e,lt(a).dataIndex)})):i.removeAll(),this._data=null,this._isFirstFrame=!0},t.prototype._removeBackground=function(){this.group.remove(this._backgroundGroup),this._backgroundGroup=null},t.type="bar",t}(Te),qd={cartesian2d:function(r,t){var e=t.width<0?-1:1,i=t.height<0?-1:1;e<0&&(t.x+=t.width,t.width=-t.width),i<0&&(t.y+=t.height,t.height=-t.height);var n=r.x+r.width,a=r.y+r.height,o=hu(t.x,r.x),s=vu(t.x+t.width,n),l=hu(t.y,r.y),u=vu(t.y+t.height,a),f=s<o,h=u<l;return t.x=f&&o>n?s:o,t.y=h&&l>a?u:l,t.width=f?0:s-o,t.height=h?0:u-l,e<0&&(t.x+=t.width,t.width=-t.width),i<0&&(t.y+=t.height,t.height=-t.height),f||h},polar:function(r,t){var e=t.r0<=t.r?1:-1;if(e<0){var i=t.r;t.r=t.r0,t.r0=i}var n=vu(t.r,r.r),a=hu(t.r0,r.r0);t.r=n,t.r0=a;var o=n-a<0;if(e<0){var i=t.r;t.r=t.r0,t.r0=i}return o}},Kd={cartesian2d:function(r,t,e,i,n,a,o,s,l){var u=new _t({shape:O({},i),z2:1});if(u.__dataIndex=e,u.name="item",a){var f=u.shape,h=n?"height":"width";f[h]=0}return u},polar:function(r,t,e,i,n,a,o,s,l){var u=!n&&l?Xd:mi,f=new u({shape:i,z2:1});f.name="item";var h=t_(n);if(f.calculateTextPosition=tL(h,{isRoundCap:u===Xd}),a){var c=f.shape,v=n?"r":"endAngle",d={};c[v]=n?i.r0:i.startAngle,d[v]=i[v],(s?Lt:Jt)(f,{shape:d},a)}return f}};function nL(r,t){var e=r.get("realtimeSort",!0),i=t.getBaseAxis();if(e&&i.type==="category"&&t.type==="cartesian2d")return{baseAxis:i,otherAxis:t.getOtherAxis(i)}}function Qd(r,t,e,i,n,a,o,s){var l,u;a?(u={x:i.x,width:i.width},l={y:i.y,height:i.height}):(u={y:i.y,height:i.height},l={x:i.x,width:i.width}),s||(o?Lt:Jt)(e,{shape:l},t,n,null);var f=t?r.baseAxis.model:null;(o?Lt:Jt)(e,{shape:u},f,n)}function Jd(r,t){for(var e=0;e<t.length;e++)if(!isFinite(r[t[e]]))return!0;return!1}var aL=["x","y","width","height"],oL=["cx","cy","r","startAngle","endAngle"],jd={cartesian2d:function(r){return!Jd(r,aL)},polar:function(r){return!Jd(r,oL)}},So={cartesian2d:function(r,t,e){var i=r.getItemLayout(t),n=e?lL(e,i):0,a=i.width>0?1:-1,o=i.height>0?1:-1;return{x:i.x+a*n/2,y:i.y+o*n/2,width:i.width-a*n,height:i.height-o*n}},polar:function(r,t,e){var i=r.getItemLayout(t);return{cx:i.cx,cy:i.cy,r0:i.r0,r:i.r,startAngle:i.startAngle,endAngle:i.endAngle,clockwise:i.clockwise}}};function sL(r){return r.startAngle!=null&&r.endAngle!=null&&r.startAngle===r.endAngle}function t_(r){return function(t){var e=t?"Arc":"Angle";return function(i){switch(i){case"start":case"insideStart":case"end":case"insideEnd":return i+e;default:return i}}}(r)}function tp(r,t,e,i,n,a,o,s){var l=t.getItemVisual(e,"style");if(s){if(!a.get("roundCap")){var f=r.shape,h=qn(i.getModel("itemStyle"),f,!0);O(f,h),r.setShape(f)}}else{var u=i.get(["itemStyle","borderRadius"])||0;r.setShape("r",u)}r.useStyle(l);var c=i.getShallow("cursor");c&&r.attr("cursor",c);var v=s?o?n.r>=n.r0?"endArc":"startArc":n.endAngle>=n.startAngle?"endAngle":"startAngle":o?n.height>=0?"bottom":"top":n.width>=0?"right":"left",d=fn(i);un(r,d,{labelFetcher:a,labelDataIndex:e,defaultText:Vh(a.getData(),e),inheritColor:l.fill,defaultOpacity:l.opacity,defaultOutsidePosition:v});var p=r.getTextContent();if(s&&p){var g=i.get(["label","position"]);r.textConfig.inside=g==="middle"?!0:null,eL(r,g==="outside"?v:g,t_(o),i.get(["label","rotate"]))}Mb(p,d,a.getRawValue(e),function(m){return Y0(t,m)});var y=i.getModel(["emphasis"]);rn(r,y.get("focus"),y.get("blurScope"),y.get("disabled")),nn(r,i),sL(n)&&(r.style.fill="none",r.style.stroke="none",A(r.states,function(m){m.style&&(m.style.fill=m.style.stroke="none")}))}function lL(r,t){var e=r.get(["itemStyle","borderColor"]);if(!e||e==="none")return 0;var i=r.get(["itemStyle","borderWidth"])||0,n=isNaN(t.width)?Number.MAX_VALUE:Math.abs(t.width),a=isNaN(t.height)?Number.MAX_VALUE:Math.abs(t.height);return Math.min(i,n,a)}var uL=function(){function r(){}return r}(),ep=function(r){N(t,r);function t(e){var i=r.call(this,e)||this;return i.type="largeBar",i}return t.prototype.getDefaultShape=function(){return new uL},t.prototype.buildPath=function(e,i){for(var n=i.points,a=this.baseDimIdx,o=1-this.baseDimIdx,s=[],l=[],u=this.barWidth,f=0;f<n.length;f+=3)l[a]=u,l[o]=n[f+2],s[a]=n[f+a],s[o]=n[f+o],e.rect(s[0],s[1],l[0],l[1])},t}(ct);function rp(r,t,e,i){var n=r.getData(),a=n.getLayout("valueAxisHorizontal")?1:0,o=n.getLayout("largeDataIndices"),s=n.getLayout("size"),l=r.getModel("backgroundStyle"),u=n.getLayout("largeBackgroundPoints");if(u){var f=new ep({shape:{points:u},incremental:!!i,silent:!0,z2:0});f.baseDimIdx=a,f.largeDataIndices=o,f.barWidth=s,f.useStyle(l.getItemStyle()),t.add(f),e&&e.push(f)}var h=new ep({shape:{points:n.getLayout("largePoints")},incremental:!!i,ignoreCoarsePointer:!0,z2:1});h.baseDimIdx=a,h.largeDataIndices=o,h.barWidth=s,t.add(h),h.useStyle(n.getVisual("style")),h.style.stroke=null,lt(h).seriesIndex=r.seriesIndex,r.get("silent")||(h.on("mousedown",ip),h.on("mousemove",ip)),e&&e.push(h)}var ip=$s(function(r){var t=this,e=fL(t,r.offsetX,r.offsetY);lt(t).dataIndex=e>=0?e:null},30,!1);function fL(r,t,e){for(var i=r.baseDimIdx,n=1-i,a=r.shape.points,o=r.largeDataIndices,s=[],l=[],u=r.barWidth,f=0,h=a.length/3;f<h;f++){var c=f*3;if(l[i]=u,l[n]=a[c+2],s[i]=a[c+i],s[n]=a[c+n],l[n]<0&&(s[n]+=l[n],l[n]=-l[n]),t>=s[0]&&t<=s[0]+l[0]&&e>=s[1]&&e<=s[1]+l[1])return o[f]}return-1}function e_(r,t,e){if(Gh(e,"cartesian2d")){var i=t,n=e.getArea();return{x:r?i.x:n.x,y:r?n.y:i.y,width:r?i.width:n.width,height:r?n.height:i.height}}else{var n=e.getArea(),a=t;return{cx:n.cx,cy:n.cy,r0:r?n.r0:a.r0,r:r?n.r:a.r,startAngle:r?a.startAngle:0,endAngle:r?a.endAngle:Math.PI*2}}}function hL(r,t,e){var i=r.type==="polar"?mi:_t;return new i({shape:e_(t,e,r),silent:!0,z2:0})}const vL=iL;function aR(r){r.registerChartView(vL),r.registerSeriesModel(QD),r.registerLayout(r.PRIORITY.VISUAL.LAYOUT,yt(MA,"bar")),r.registerLayout(r.PRIORITY.VISUAL.PROGRESSIVE_LAYOUT,AA("bar")),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,J0("bar")),r.registerAction({type:"changeAxisOrder",event:"changeAxisOrder",update:"update"},function(t,e){var i=t.componentType||"series";e.eachComponent({mainType:i,query:t},function(n){t.sortInfo&&n.axis.setCategorySortInfo(t.sortInfo)})})}var np=Math.PI*2,wo=Math.PI/180;function r_(r,t){return vi(r.getBoxLayoutParams(),{width:t.getWidth(),height:t.getHeight()})}function i_(r,t){var e=r_(r,t),i=r.get("center"),n=r.get("radius");V(n)||(n=[0,n]);var a=st(e.width,t.getWidth()),o=st(e.height,t.getHeight()),s=Math.min(a,o),l=st(n[0],s/2),u=st(n[1],s/2),f,h,c=r.coordinateSystem;if(c){var v=c.dataToPoint(i);f=v[0]||0,h=v[1]||0}else V(i)||(i=[i,i]),f=st(i[0],a)+e.x,h=st(i[1],o)+e.y;return{cx:f,cy:h,r0:l,r:u}}function cL(r,t,e){t.eachSeriesByType(r,function(i){var n=i.getData(),a=n.mapDimension("value"),o=r_(i,e),s=i_(i,e),l=s.cx,u=s.cy,f=s.r,h=s.r0,c=-i.get("startAngle")*wo,v=i.get("endAngle"),d=i.get("padAngle")*wo;v=v==="auto"?c-np:-v*wo;var p=i.get("minAngle")*wo,g=p+d,y=0;n.each(a,function(z){!isNaN(z)&&y++});var m=n.getSum(a),_=Math.PI/(m||y)*2,S=i.get("clockwise"),x=i.get("roseType"),w=i.get("stillShowZeroSum"),b=n.getDataExtent(a);b[0]=0;var T=S?1:-1,M=[c,v],D=T*d/2;Qg(M,!S),c=M[0],v=M[1];var C=n_(i);C.startAngle=c,C.endAngle=v,C.clockwise=S;var L=Math.abs(v-c),I=L,P=0,R=c;if(n.setLayout({viewRect:o,r:f}),n.each(a,function(z,k){var B;if(isNaN(z)){n.setItemLayout(k,{angle:NaN,startAngle:NaN,endAngle:NaN,clockwise:S,cx:l,cy:u,r0:h,r:x?NaN:f});return}x!=="area"?B=m===0&&w?_:z*_:B=L/y,B<g?(B=g,I-=g):P+=z;var F=R+T*B,H=0,U=0;d>B?(H=R+T*B/2,U=H):(H=R+D,U=F-D),n.setItemLayout(k,{angle:B,startAngle:H,endAngle:U,clockwise:S,cx:l,cy:u,r0:h,r:x?Rt(z,b,[h,f]):f}),R=F}),I<np&&y)if(I<=.001){var E=L/y;n.each(a,function(z,k){if(!isNaN(z)){var B=n.getItemLayout(k);B.angle=E;var F=0,H=0;E<d?(F=c+T*(k+1/2)*E,H=F):(F=c+T*k*E+D,H=c+T*(k+1)*E-D),B.startAngle=F,B.endAngle=H}})}else _=I/P,R=c,n.each(a,function(z,k){if(!isNaN(z)){var B=n.getItemLayout(k),F=B.angle===g?g:z*_,H=0,U=0;F<d?(H=R+T*F/2,U=H):(H=R+D,U=R+T*F-D),B.startAngle=H,B.endAngle=U,R+=T*F}})})}var n_=gt();function a_(r){return{seriesType:r,reset:function(t,e){var i=e.findComponents({mainType:"legend"});if(!(!i||!i.length)){var n=t.getData();n.filterSelf(function(a){for(var o=n.getName(a),s=0;s<i.length;s++)if(!i[s].isSelected(o))return!1;return!0})}}}}var dL=Math.PI/180;function ap(r,t,e,i,n,a,o,s,l,u){if(r.length<2)return;function f(p){for(var g=p.rB,y=g*g,m=0;m<p.list.length;m++){var _=p.list[m],S=Math.abs(_.label.y-e),x=i+_.len,w=x*x,b=Math.sqrt(Math.abs((1-S*S/y)*w)),T=t+(b+_.len2)*n,M=T-_.label.x,D=_.targetTextWidth-M*n;o_(_,D,!0),_.label.x=T}}function h(p){for(var g={list:[],maxY:0},y={list:[],maxY:0},m=0;m<p.length;m++)if(p[m].labelAlignTo==="none"){var _=p[m],S=_.label.y>e?y:g,x=Math.abs(_.label.y-e);if(x>=S.maxY){var w=_.label.x-t-_.len2*n,b=i+_.len,T=Math.abs(w)<b?Math.sqrt(x*x/(1-w*w/b/b)):b;S.rB=T,S.maxY=x}S.list.push(_)}f(g),f(y)}for(var c=r.length,v=0;v<c;v++)if(r[v].position==="outer"&&r[v].labelAlignTo==="labelLine"){var d=r[v].label.x-u;r[v].linePoints[1][0]+=d,r[v].label.x=u}pD(r,l,l+o)&&h(r)}function pL(r,t,e,i,n,a,o,s){for(var l=[],u=[],f=Number.MAX_VALUE,h=-Number.MAX_VALUE,c=0;c<r.length;c++){var v=r[c].label;cu(r[c])||(v.x<t?(f=Math.min(f,v.x),l.push(r[c])):(h=Math.max(h,v.x),u.push(r[c])))}for(var c=0;c<r.length;c++){var d=r[c];if(!cu(d)&&d.linePoints){if(d.labelStyleWidth!=null)continue;var v=d.label,p=d.linePoints,g=void 0;d.labelAlignTo==="edge"?v.x<t?g=p[2][0]-d.labelDistance-o-d.edgeDistance:g=o+n-d.edgeDistance-p[2][0]-d.labelDistance:d.labelAlignTo==="labelLine"?v.x<t?g=f-o-d.bleedMargin:g=o+n-h-d.bleedMargin:v.x<t?g=v.x-o-d.bleedMargin:g=o+n-v.x-d.bleedMargin,d.targetTextWidth=g,o_(d,g)}}ap(u,t,e,i,1,n,a,o,s,h),ap(l,t,e,i,-1,n,a,o,s,f);for(var c=0;c<r.length;c++){var d=r[c];if(!cu(d)&&d.linePoints){var v=d.label,p=d.linePoints,y=d.labelAlignTo==="edge",m=v.style.padding,_=m?m[1]+m[3]:0,S=v.style.backgroundColor?0:_,x=d.rect.width+S,w=p[1][0]-p[2][0];y?v.x<t?p[2][0]=o+d.edgeDistance+x+d.labelDistance:p[2][0]=o+n-d.edgeDistance-x-d.labelDistance:(v.x<t?p[2][0]=v.x+d.labelDistance:p[2][0]=v.x-d.labelDistance,p[1][0]=p[2][0]+w),p[1][1]=p[2][1]=v.y}}}function o_(r,t,e){if(e===void 0&&(e=!1),r.labelStyleWidth==null){var i=r.label,n=i.style,a=r.rect,o=n.backgroundColor,s=n.padding,l=s?s[1]+s[3]:0,u=n.overflow,f=a.width+(o?0:l);if(t<f||e){var h=a.height;if(u&&u.match("break")){i.setStyle("backgroundColor",null),i.setStyle("width",t-l);var c=i.getBoundingRect();i.setStyle("width",Math.ceil(c.width)),i.setStyle("backgroundColor",o)}else{var v=t-l,d=t<f?v:e?v>r.unconstrainedWidth?null:v:null;i.setStyle("width",d)}var p=i.getBoundingRect();a.width=p.width;var g=(i.style.margin||0)+2.1;a.height=p.height+g,a.y-=(a.height-h)/2}}}function cu(r){return r.position==="center"}function gL(r){var t=r.getData(),e=[],i,n,a=!1,o=(r.get("minShowLabelAngle")||0)*dL,s=t.getLayout("viewRect"),l=t.getLayout("r"),u=s.width,f=s.x,h=s.y,c=s.height;function v(w){w.ignore=!0}function d(w){if(!w.ignore)return!0;for(var b in w.states)if(w.states[b].ignore===!1)return!0;return!1}t.each(function(w){var b=t.getItemGraphicEl(w),T=b.shape,M=b.getTextContent(),D=b.getTextGuideLine(),C=t.getItemModel(w),L=C.getModel("label"),I=L.get("position")||C.get(["emphasis","label","position"]),P=L.get("distanceToLabelLine"),R=L.get("alignTo"),E=st(L.get("edgeDistance"),u),z=L.get("bleedMargin"),k=C.getModel("labelLine"),B=k.get("length");B=st(B,u);var F=k.get("length2");if(F=st(F,u),Math.abs(T.endAngle-T.startAngle)<o){A(M.states,v),M.ignore=!0,D&&(A(D.states,v),D.ignore=!0);return}if(!!d(M)){var H=(T.startAngle+T.endAngle)/2,U=Math.cos(H),J=Math.sin(H),ot,ft,Ut,ne;i=T.cx,n=T.cy;var ee=I==="inside"||I==="inner";if(I==="center")ot=T.cx,ft=T.cy,ne="center";else{var It=(ee?(T.r+T.r0)/2*U:T.r*U)+i,St=(ee?(T.r+T.r0)/2*J:T.r*J)+n;if(ot=It+U*3,ft=St+J*3,!ee){var X=It+U*(B+l-T.r),it=St+J*(B+l-T.r),Ie=X+(U<0?-1:1)*F,Mt=it;R==="edge"?ot=U<0?f+E:f+u-E:ot=Ie+(U<0?-P:P),ft=Mt,Ut=[[It,St],[X,it],[Ie,Mt]]}ne=ee?"center":R==="edge"?U>0?"right":"left":U>0?"left":"right"}var sr=Math.PI,Ue=0,dn=L.get("rotate");if(dt(dn))Ue=dn*(sr/180);else if(I==="center")Ue=0;else if(dn==="radial"||dn===!0){var V_=U<0?-H+sr:-H;Ue=V_}else if(dn==="tangential"&&I!=="outside"&&I!=="outer"){var bi=Math.atan2(U,J);bi<0&&(bi=sr*2+bi);var H_=J>0;H_&&(bi=sr+bi),Ue=bi-sr}if(a=!!Ue,M.x=ot,M.y=ft,M.rotation=Ue,M.setStyle({verticalAlign:"middle"}),ee){M.setStyle({align:ne});var js=M.states.select;js&&(js.x+=M.x,js.y+=M.y)}else{var pn=M.getBoundingRect().clone();pn.applyTransform(M.getComputedTransform());var Qh=(M.style.margin||0)+2.1;pn.y-=Qh/2,pn.height+=Qh,e.push({label:M,labelLine:D,position:I,len:B,len2:F,minTurnAngle:k.get("minTurnAngle"),maxSurfaceAngle:k.get("maxSurfaceAngle"),surfaceNormal:new q(U,J),linePoints:Ut,textAlign:ne,labelDistance:P,labelAlignTo:R,edgeDistance:E,bleedMargin:z,rect:pn,unconstrainedWidth:pn.width,labelStyleWidth:M.style.width})}b.setTextConfig({inside:ee})}}),!a&&r.get("avoidLabelOverlap")&&pL(e,i,n,l,u,c,f,h);for(var p=0;p<e.length;p++){var g=e[p],y=g.label,m=g.labelLine,_=isNaN(y.x)||isNaN(y.y);if(y){y.setStyle({align:g.textAlign}),_&&(A(y.states,v),y.ignore=!0);var S=y.states.select;S&&(S.x+=y.x,S.y+=y.y)}if(m){var x=g.linePoints;_||!x?(A(m.states,v),m.ignore=!0):(lD(x,g.minTurnAngle),uD(x,g.surfaceNormal,g.maxSurfaceAngle),m.setShape({points:x}),y.__hostTarget.textGuideLineConfig={anchor:new q(x[0][0],x[0][1])})}}}var yL=function(r){N(t,r);function t(e,i,n){var a=r.call(this)||this;a.z2=2;var o=new Dt;return a.setTextContent(o),a.updateData(e,i,n,!0),a}return t.prototype.updateData=function(e,i,n,a){var o=this,s=e.hostModel,l=e.getItemModel(i),u=l.getModel("emphasis"),f=e.getItemLayout(i),h=O(qn(l.getModel("itemStyle"),f,!0),f);if(isNaN(h.startAngle)){o.setShape(h);return}if(a){o.setShape(h);var c=s.getShallow("animationType");s.ecModel.ssr?(Jt(o,{scaleX:0,scaleY:0},s,{dataIndex:i,isFrom:!0}),o.originX=h.cx,o.originY=h.cy):c==="scale"?(o.shape.r=f.r0,Jt(o,{shape:{r:f.r}},s,i)):n!=null?(o.setShape({startAngle:n,endAngle:n}),Jt(o,{shape:{startAngle:f.startAngle,endAngle:f.endAngle}},s,i)):(o.shape.endAngle=f.startAngle,Lt(o,{shape:{endAngle:f.endAngle}},s,i))}else pa(o),Lt(o,{shape:h},s,i);o.useStyle(e.getItemVisual(i,"style")),nn(o,l);var v=(f.startAngle+f.endAngle)/2,d=s.get("selectedOffset"),p=Math.cos(v)*d,g=Math.sin(v)*d,y=l.getShallow("cursor");y&&o.attr("cursor",y),this._updateLabel(s,e,i),o.ensureState("emphasis").shape=O({r:f.r+(u.get("scale")&&u.get("scaleSize")||0)},qn(u.getModel("itemStyle"),f)),O(o.ensureState("select"),{x:p,y:g,shape:qn(l.getModel(["select","itemStyle"]),f)}),O(o.ensureState("blur"),{shape:qn(l.getModel(["blur","itemStyle"]),f)});var m=o.getTextGuideLine(),_=o.getTextContent();m&&O(m.ensureState("select"),{x:p,y:g}),O(_.ensureState("select"),{x:p,y:g}),rn(this,u.get("focus"),u.get("blurScope"),u.get("disabled"))},t.prototype._updateLabel=function(e,i,n){var a=this,o=i.getItemModel(n),s=o.getModel("labelLine"),l=i.getItemVisual(n,"style"),u=l&&l.fill,f=l&&l.opacity;un(a,fn(o),{labelFetcher:i.hostModel,labelDataIndex:n,inheritColor:u,defaultOpacity:f,defaultText:e.getFormattedLabel(n,"normal")||i.getName(n)});var h=a.getTextContent();a.setTextConfig({position:null,rotation:null}),h.attr({z2:10});var c=e.get(["label","position"]);if(c!=="outside"&&c!=="outer")a.removeTextGuideLine();else{var v=this.getTextGuideLine();v||(v=new _i,this.setTextGuideLine(v)),hD(this,vD(o),{stroke:u,opacity:Kn(s.get(["lineStyle","opacity"]),f,1)})}},t}(mi),mL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.ignoreLabelLineUpdate=!0,e}return t.prototype.render=function(e,i,n,a){var o=e.getData(),s=this._data,l=this.group,u;if(!s&&o.count()>0){for(var f=o.getItemLayout(0),h=1;isNaN(f&&f.startAngle)&&h<o.count();++h)f=o.getItemLayout(h);f&&(u=f.startAngle)}if(this._emptyCircleSector&&l.remove(this._emptyCircleSector),o.count()===0&&e.get("showEmptyCircle")){var c=n_(e),v=new mi({shape:O(i_(e,n),c)});v.useStyle(e.getModel("emptyCircleStyle").getItemStyle()),this._emptyCircleSector=v,l.add(v)}o.diff(s).add(function(d){var p=new yL(o,d,u);o.setItemGraphicEl(d,p),l.add(p)}).update(function(d,p){var g=s.getItemGraphicEl(p);g.updateData(o,d,u),g.off("click"),l.add(g),o.setItemGraphicEl(d,g)}).remove(function(d){var p=s.getItemGraphicEl(d);as(p,e,d)}).execute(),gL(e),e.get("animationTypeUpdate")!=="expansion"&&(this._data=o)},t.prototype.dispose=function(){},t.prototype.containPoint=function(e,i){var n=i.getData(),a=n.getItemLayout(0);if(a){var o=e[0]-a.cx,s=e[1]-a.cy,l=Math.sqrt(o*o+s*s);return l<=a.r&&l>=a.r0}},t.type="pie",t}(Te);const _L=mL;function s_(r,t,e){t=V(t)&&{coordDimensions:t}||O({encodeDefine:r.getEncode()},t);var i=r.getSource(),n=m0(i,t).dimensions,a=new y0(n,r);return a.initData(i,e),a}var SL=function(){function r(t,e){this._getDataWithEncodedVisual=t,this._getRawData=e}return r.prototype.getAllNames=function(){var t=this._getRawData();return t.mapArray(t.getName)},r.prototype.containName=function(t){var e=this._getRawData();return e.indexOfName(t)>=0},r.prototype.indexOfName=function(t){var e=this._getDataWithEncodedVisual();return e.indexOfName(t)},r.prototype.getItemVisual=function(t,e){var i=this._getDataWithEncodedVisual();return i.getItemVisual(t,e)},r}();const l_=SL;var wL=gt(),xL=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new l_($(this.getData,this),$(this.getRawData,this)),this._defaultLabelLine(e)},t.prototype.mergeOption=function(){r.prototype.mergeOption.apply(this,arguments)},t.prototype.getInitialData=function(){return s_(this,{coordDimensions:["value"],encodeDefaulter:yt(jb,this)})},t.prototype.getDataParams=function(e){var i=this.getData(),n=wL(i),a=n.seats;if(!a){var o=[];i.each(i.mapDimension("value"),function(l){o.push(l)}),a=n.seats=WS(o,i.hostModel.get("percentPrecision"))}var s=r.prototype.getDataParams.call(this,e);return s.percent=a[e]||0,s.$vars.push("percent"),s},t.prototype._defaultLabelLine=function(e){Ku(e,"labelLine",["show"]);var i=e.labelLine,n=e.emphasis.labelLine;i.show=i.show&&e.label.show,n.show=n.show&&e.emphasis.label.show},t.type="series.pie",t.defaultOption={z:2,legendHoverLink:!0,colorBy:"data",center:["50%","50%"],radius:[0,"75%"],clockwise:!0,startAngle:90,endAngle:"auto",padAngle:0,minAngle:0,minShowLabelAngle:0,selectedOffset:10,percentPrecision:2,stillShowZeroSum:!0,left:0,top:0,right:0,bottom:0,width:null,height:null,label:{rotate:0,show:!0,overflow:"truncate",position:"outer",alignTo:"none",edgeDistance:"25%",bleedMargin:10,distanceToLabelLine:5},labelLine:{show:!0,length:15,length2:15,smooth:!1,minTurnAngle:90,maxSurfaceAngle:90,lineStyle:{width:1,type:"solid"}},itemStyle:{borderWidth:1,borderJoin:"round"},showEmptyCircle:!0,emptyCircleStyle:{color:"lightgray",opacity:1},labelLayout:{hideOverlap:!0},emphasis:{scale:!0,scaleSize:5},avoidLabelOverlap:!0,animationType:"expansion",animationDuration:1e3,animationTypeUpdate:"transition",animationEasingUpdate:"cubicInOut",animationDurationUpdate:500,animationEasing:"cubicInOut"},t}(rr);const bL=xL;function TL(r){return{seriesType:r,reset:function(t,e){var i=t.getData();i.filterSelf(function(n){var a=i.mapDimension("value"),o=i.get(a,n);return!(dt(o)&&!isNaN(o)&&o<0)})}}}function oR(r){r.registerChartView(_L),r.registerSeriesModel(bL),VC("pie",r.registerAction),r.registerLayout(yt(cL,"pie")),r.registerProcessor(a_("pie")),r.registerProcessor(TL("pie"))}var CL=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.type="grid",t.dependencies=["xAxis","yAxis"],t.layoutMode="box",t.defaultOption={show:!1,z:0,left:"10%",top:60,right:"10%",bottom:70,containLabel:!1,backgroundColor:"rgba(0,0,0,0)",borderWidth:1,borderColor:"#ccc"},t}(pt);const ML=CL;var Cf=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.getCoordSysModel=function(){return this.getReferringComponents("grid",Qt).models[0]},t.type="cartesian2dAxis",t}(pt);Me(Cf,O0);var u_={show:!0,z:0,inverse:!1,name:"",nameLocation:"end",nameRotate:null,nameTruncate:{maxWidth:null,ellipsis:"...",placeholder:"."},nameTextStyle:{},nameGap:15,silent:!1,triggerEvent:!1,tooltip:{show:!1},axisPointer:{},axisLine:{show:!0,onZero:!0,onZeroAxisIndex:null,lineStyle:{color:"#6E7079",width:1,type:"solid"},symbol:["none","none"],symbolSize:[10,15]},axisTick:{show:!0,inside:!1,length:5,lineStyle:{width:1}},axisLabel:{show:!0,inside:!1,rotate:0,showMinLabel:null,showMaxLabel:null,margin:8,fontSize:12},splitLine:{show:!0,showMinLine:!0,showMaxLine:!0,lineStyle:{color:["#E0E6F1"],width:1,type:"solid"}},splitArea:{show:!1,areaStyle:{color:["rgba(250,250,250,0.2)","rgba(210,219,238,0.2)"]}}},AL=nt({boundaryGap:!0,deduplication:null,splitLine:{show:!1},axisTick:{alignWithLabel:!1,interval:"auto"},axisLabel:{interval:"auto"}},u_),Wh=nt({boundaryGap:[0,0],axisLine:{show:"auto"},axisTick:{show:"auto"},splitNumber:5,minorTick:{show:!1,splitNumber:5,length:3,lineStyle:{}},minorSplitLine:{show:!1,lineStyle:{color:"#F4F7FD",width:1}}},u_),DL=nt({splitNumber:6,axisLabel:{showMinLabel:!1,showMaxLabel:!1,rich:{primary:{fontWeight:"bold"}}},splitLine:{show:!1}},Wh),LL=rt({logBase:10},Wh);const f_={category:AL,value:Wh,time:DL,log:LL};var IL={value:1,category:1,time:1,log:1};function op(r,t,e,i){A(IL,function(n,a){var o=nt(nt({},f_[a],!0),i,!0),s=function(l){N(u,l);function u(){var f=l!==null&&l.apply(this,arguments)||this;return f.type=t+"Axis."+a,f}return u.prototype.mergeDefaultAndTheme=function(f,h){var c=_a(this),v=c?Pa(f):{},d=h.getTheme();nt(f,d.get(a+"Axis")),nt(f,this.getDefaultOption()),f.type=sp(f),c&&ci(f,v,c)},u.prototype.optionUpdated=function(){var f=this.option;f.type==="category"&&(this.__ordinalMeta=xf.createByAxisModel(this))},u.prototype.getCategories=function(f){var h=this.option;if(h.type==="category")return f?h.data:this.__ordinalMeta.categories},u.prototype.getOrdinalMeta=function(){return this.__ordinalMeta},u.type=t+"Axis."+a,u.defaultOption=o,u}(e);r.registerComponentModel(s)}),r.registerSubTypeDefaulter(t+"Axis",sp)}function sp(r){return r.type||(r.data?"category":"value")}var PL=function(){function r(t){this.type="cartesian",this._dimList=[],this._axes={},this.name=t||""}return r.prototype.getAxis=function(t){return this._axes[t]},r.prototype.getAxes=function(){return G(this._dimList,function(t){return this._axes[t]},this)},r.prototype.getAxesByScale=function(t){return t=t.toLowerCase(),Ct(this.getAxes(),function(e){return e.scale.type===t})},r.prototype.addAxis=function(t){var e=t.dim;this._axes[e]=t,this._dimList.push(e)},r}();const RL=PL;var Mf=["x","y"];function lp(r){return r.type==="interval"||r.type==="time"}var EL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="cartesian2d",e.dimensions=Mf,e}return t.prototype.calcAffineTransform=function(){this._transform=this._invTransform=null;var e=this.getAxis("x").scale,i=this.getAxis("y").scale;if(!(!lp(e)||!lp(i))){var n=e.getExtent(),a=i.getExtent(),o=this.dataToPoint([n[0],a[0]]),s=this.dataToPoint([n[1],a[1]]),l=n[1]-n[0],u=a[1]-a[0];if(!(!l||!u)){var f=(s[0]-o[0])/l,h=(s[1]-o[1])/u,c=o[0]-n[0]*f,v=o[1]-a[0]*h,d=this._transform=[f,0,0,h,c,v];this._invTransform=Zf([],d)}}},t.prototype.getBaseAxis=function(){return this.getAxesByScale("ordinal")[0]||this.getAxesByScale("time")[0]||this.getAxis("x")},t.prototype.containPoint=function(e){var i=this.getAxis("x"),n=this.getAxis("y");return i.contain(i.toLocalCoord(e[0]))&&n.contain(n.toLocalCoord(e[1]))},t.prototype.containData=function(e){return this.getAxis("x").containData(e[0])&&this.getAxis("y").containData(e[1])},t.prototype.containZone=function(e,i){var n=this.dataToPoint(e),a=this.dataToPoint(i),o=this.getArea(),s=new ut(n[0],n[1],a[0]-n[0],a[1]-n[1]);return o.intersect(s)},t.prototype.dataToPoint=function(e,i,n){n=n||[];var a=e[0],o=e[1];if(this._transform&&a!=null&&isFinite(a)&&o!=null&&isFinite(o))return ge(n,e,this._transform);var s=this.getAxis("x"),l=this.getAxis("y");return n[0]=s.toGlobalCoord(s.dataToCoord(a,i)),n[1]=l.toGlobalCoord(l.dataToCoord(o,i)),n},t.prototype.clampData=function(e,i){var n=this.getAxis("x").scale,a=this.getAxis("y").scale,o=n.getExtent(),s=a.getExtent(),l=n.parse(e[0]),u=a.parse(e[1]);return i=i||[],i[0]=Math.min(Math.max(Math.min(o[0],o[1]),l),Math.max(o[0],o[1])),i[1]=Math.min(Math.max(Math.min(s[0],s[1]),u),Math.max(s[0],s[1])),i},t.prototype.pointToData=function(e,i){var n=[];if(this._invTransform)return ge(n,e,this._invTransform);var a=this.getAxis("x"),o=this.getAxis("y");return n[0]=a.coordToData(a.toLocalCoord(e[0]),i),n[1]=o.coordToData(o.toLocalCoord(e[1]),i),n},t.prototype.getOtherAxis=function(e){return this.getAxis(e.dim==="x"?"y":"x")},t.prototype.getArea=function(e){e=e||0;var i=this.getAxis("x").getGlobalExtent(),n=this.getAxis("y").getGlobalExtent(),a=Math.min(i[0],i[1])-e,o=Math.min(n[0],n[1])-e,s=Math.max(i[0],i[1])-a+e,l=Math.max(n[0],n[1])-o+e;return new ut(a,o,s,l)},t}(RL),kL=function(r){N(t,r);function t(e,i,n,a,o){var s=r.call(this,e,i,n)||this;return s.index=0,s.type=a||"value",s.position=o||"bottom",s}return t.prototype.isHorizontal=function(){var e=this.position;return e==="top"||e==="bottom"},t.prototype.getGlobalExtent=function(e){var i=this.getExtent();return i[0]=this.toGlobalCoord(i[0]),i[1]=this.toGlobalCoord(i[1]),e&&i[0]>i[1]&&i.reverse(),i},t.prototype.pointToData=function(e,i){return this.coordToData(this.toLocalCoord(e[this.dim==="x"?0:1]),i)},t.prototype.setCategorySortInfo=function(e){if(this.type!=="category")return!1;this.model.option.categorySortInfo=e,this.scale.setSortInfo(e)},t}(W0);const OL=kL;function Af(r,t,e){e=e||{};var i=r.coordinateSystem,n=t.axis,a={},o=n.getAxesOnZeroOf()[0],s=n.position,l=o?"onZero":s,u=n.dim,f=i.getRect(),h=[f.x,f.x+f.width,f.y,f.y+f.height],c={left:0,right:1,top:0,bottom:1,onZero:2},v=t.get("offset")||0,d=u==="x"?[h[2]-v,h[3]+v]:[h[0]-v,h[1]+v];if(o){var p=o.toGlobalCoord(o.dataToCoord(0));d[c.onZero]=Math.max(Math.min(p,d[1]),d[0])}a.position=[u==="y"?d[c[l]]:h[0],u==="x"?d[c[l]]:h[3]],a.rotation=Math.PI/2*(u==="x"?0:1);var g={top:-1,bottom:1,left:-1,right:1};a.labelDirection=a.tickDirection=a.nameDirection=g[s],a.labelOffset=o?d[c[s]]-d[c.onZero]:0,t.get(["axisTick","inside"])&&(a.tickDirection=-a.tickDirection),va(e.labelInside,t.get(["axisLabel","inside"]))&&(a.labelDirection=-a.labelDirection);var y=t.get(["axisLabel","rotate"]);return a.labelRotate=l==="top"?-y:y,a.z2=1,a}function up(r){return r.get("coordinateSystem")==="cartesian2d"}function fp(r){var t={xAxisModel:null,yAxisModel:null};return A(t,function(e,i){var n=i.replace(/Model$/,""),a=r.getReferringComponents(n,Qt).models[0];t[i]=a}),t}var du=Math.log;function h_(r,t,e){var i=pi.prototype,n=i.getTicks.call(e),a=i.getTicks.call(e,!0),o=n.length-1,s=i.getInterval.call(e),l=R0(r,t),u=l.extent,f=l.fixMin,h=l.fixMax;if(r.type==="log"){var c=du(r.base);u=[du(u[0])/c,du(u[1])/c]}r.setExtent(u[0],u[1]),r.calcNiceExtent({splitNumber:o,fixMin:f,fixMax:h});var v=i.getExtent.call(r);f&&(u[0]=v[0]),h&&(u[1]=v[1]);var d=i.getInterval.call(r),p=u[0],g=u[1];if(f&&h)d=(g-p)/o;else if(f)for(g=u[0]+d*o;g<u[1]&&isFinite(g)&&isFinite(u[1]);)d=ou(d),g=u[0]+d*o;else if(h)for(p=u[1]-d*o;p>u[0]&&isFinite(p)&&isFinite(u[0]);)d=ou(d),p=u[1]-d*o;else{var y=r.getTicks().length-1;y>o&&(d=ou(d));var m=d*o;g=Math.ceil(u[1]/d)*d,p=bt(g-m),p<0&&u[0]>=0?(p=0,g=bt(m)):g>0&&u[1]<=0&&(g=0,p=-bt(m))}var _=(n[0].value-a[0].value)/s,S=(n[o].value-a[o].value)/s;i.setExtent.call(r,p+d*_,g+d*S),i.setInterval.call(r,d),(_||S)&&i.setNiceExtent.call(r,p+d,g-d)}var BL=function(){function r(t,e,i){this.type="grid",this._coordsMap={},this._coordsList=[],this._axesMap={},this._axesList=[],this.axisPointerEnabled=!0,this.dimensions=Mf,this._initCartesian(t,e,i),this.model=t}return r.prototype.getRect=function(){return this._rect},r.prototype.update=function(t,e){var i=this._axesMap;this._updateScale(t,this.model);function n(o){var s,l=vt(o),u=l.length;if(!!u){for(var f=[],h=u-1;h>=0;h--){var c=+l[h],v=o[c],d=v.model,p=v.scale;bf(p)&&d.get("alignTicks")&&d.get("interval")==null?f.push(v):(kd(p,d),bf(p)&&(s=v))}f.length&&(s||(s=f.pop(),kd(s.scale,s.model)),A(f,function(g){h_(g.scale,g.model,s.scale)}))}}n(i.x),n(i.y);var a={};A(i.x,function(o){hp(i,"y",o,a)}),A(i.y,function(o){hp(i,"x",o,a)}),this.resize(this.model,e)},r.prototype.resize=function(t,e,i){var n=t.getBoxLayoutParams(),a=!i&&t.get("containLabel"),o=vi(n,{width:e.getWidth(),height:e.getHeight()});this._rect=o;var s=this._axesList;l(),a&&(A(s,function(u){if(!u.model.get(["axisLabel","inside"])){var f=XA(u);if(f){var h=u.isHorizontal()?"height":"width",c=u.model.get(["axisLabel","margin"]);o[h]-=f[h]+c,u.position==="top"?o.y+=f.height+c:u.position==="left"&&(o.x+=f.width+c)}}}),l()),A(this._coordsList,function(u){u.calcAffineTransform()});function l(){A(s,function(u){var f=u.isHorizontal(),h=f?[0,o.width]:[0,o.height],c=u.inverse?1:0;u.setExtent(h[c],h[1-c]),NL(u,f?o.x:o.y)})}},r.prototype.getAxis=function(t,e){var i=this._axesMap[t];if(i!=null)return i[e||0]},r.prototype.getAxes=function(){return this._axesList.slice()},r.prototype.getCartesian=function(t,e){if(t!=null&&e!=null){var i="x"+t+"y"+e;return this._coordsMap[i]}Y(t)&&(e=t.yAxisIndex,t=t.xAxisIndex);for(var n=0,a=this._coordsList;n<a.length;n++)if(a[n].getAxis("x").index===t||a[n].getAxis("y").index===e)return a[n]},r.prototype.getCartesians=function(){return this._coordsList.slice()},r.prototype.convertToPixel=function(t,e,i){var n=this._findConvertTarget(e);return n.cartesian?n.cartesian.dataToPoint(i):n.axis?n.axis.toGlobalCoord(n.axis.dataToCoord(i)):null},r.prototype.convertFromPixel=function(t,e,i){var n=this._findConvertTarget(e);return n.cartesian?n.cartesian.pointToData(i):n.axis?n.axis.coordToData(n.axis.toLocalCoord(i)):null},r.prototype._findConvertTarget=function(t){var e=t.seriesModel,i=t.xAxisModel||e&&e.getReferringComponents("xAxis",Qt).models[0],n=t.yAxisModel||e&&e.getReferringComponents("yAxis",Qt).models[0],a=t.gridModel,o=this._coordsList,s,l;if(e)s=e.coordinateSystem,at(o,s)<0&&(s=null);else if(i&&n)s=this.getCartesian(i.componentIndex,n.componentIndex);else if(i)l=this.getAxis("x",i.componentIndex);else if(n)l=this.getAxis("y",n.componentIndex);else if(a){var u=a.coordinateSystem;u===this&&(s=this._coordsList[0])}return{cartesian:s,axis:l}},r.prototype.containPoint=function(t){var e=this._coordsList[0];if(e)return e.containPoint(t)},r.prototype._initCartesian=function(t,e,i){var n=this,a=this,o={left:!1,right:!1,top:!1,bottom:!1},s={x:{},y:{}},l={x:0,y:0};if(e.eachComponent("xAxis",u("x"),this),e.eachComponent("yAxis",u("y"),this),!l.x||!l.y){this._axesMap={},this._axesList=[];return}this._axesMap=s,A(s.x,function(f,h){A(s.y,function(c,v){var d="x"+h+"y"+v,p=new EL(d);p.master=n,p.model=t,n._coordsMap[d]=p,n._coordsList.push(p),p.addAxis(f),p.addAxis(c)})});function u(f){return function(h,c){if(!!pu(h,t)){var v=h.get("position");f==="x"?v!=="top"&&v!=="bottom"&&(v=o.bottom?"top":"bottom"):v!=="left"&&v!=="right"&&(v=o.left?"right":"left"),o[v]=!0;var d=new OL(f,$A(h),[0,0],h.get("type"),v),p=d.type==="category";d.onBand=p&&h.get("boundaryGap"),d.inverse=h.get("inverse"),h.axis=d,d.model=h,d.grid=a,d.index=c,a._axesList.push(d),s[f][c]=d,l[f]++}}}},r.prototype._updateScale=function(t,e){A(this._axesList,function(n){if(n.scale.setExtent(1/0,-1/0),n.type==="category"){var a=n.model.get("categorySortInfo");n.scale.setSortInfo(a)}}),t.eachSeries(function(n){if(up(n)){var a=fp(n),o=a.xAxisModel,s=a.yAxisModel;if(!pu(o,e)||!pu(s,e))return;var l=this.getCartesian(o.componentIndex,s.componentIndex),u=n.getData(),f=l.getAxis("x"),h=l.getAxis("y");i(u,f),i(u,h)}},this);function i(n,a){A(k0(n,a.dim),function(o){a.scale.unionExtentFromData(n,o)})}},r.prototype.getTooltipAxes=function(t){var e=[],i=[];return A(this.getCartesians(),function(n){var a=t!=null&&t!=="auto"?n.getAxis(t):n.getBaseAxis(),o=n.getOtherAxis(a);at(e,a)<0&&e.push(a),at(i,o)<0&&i.push(o)}),{baseAxes:e,otherAxes:i}},r.create=function(t,e){var i=[];return t.eachComponent("grid",function(n,a){var o=new r(n,t,e);o.name="grid_"+a,o.resize(n,e,!0),n.coordinateSystem=o,i.push(o)}),t.eachSeries(function(n){if(!!up(n)){var a=fp(n),o=a.xAxisModel,s=a.yAxisModel,l=o.getCoordSysModel(),u=l.coordinateSystem;n.coordinateSystem=u.getCartesian(o.componentIndex,s.componentIndex)}}),i},r.dimensions=Mf,r}();function pu(r,t){return r.getCoordSysModel()===t}function hp(r,t,e,i){e.getAxesOnZeroOf=function(){return a?[a]:[]};var n=r[t],a,o=e.model,s=o.get(["axisLine","onZero"]),l=o.get(["axisLine","onZeroAxisIndex"]);if(!s)return;if(l!=null)vp(n[l])&&(a=n[l]);else for(var u in n)if(n.hasOwnProperty(u)&&vp(n[u])&&!i[f(n[u])]){a=n[u];break}a&&(i[f(a)]=!0);function f(h){return h.dim+"_"+h.index}}function vp(r){return r&&r.type!=="category"&&r.type!=="time"&&ZA(r)}function NL(r,t){var e=r.getExtent(),i=e[0]+e[1];r.toGlobalCoord=r.dim==="x"?function(n){return n+t}:function(n){return i-n+t},r.toLocalCoord=r.dim==="x"?function(n){return n-t}:function(n){return i-n+t}}const zL=BL;var br=Math.PI,ai=function(){function r(t,e){this.group=new xt,this.opt=e,this.axisModel=t,rt(e,{labelOffset:0,nameDirection:1,tickDirection:1,labelDirection:1,silent:!0,handleAutoShown:function(){return!0}});var i=new xt({x:e.position[0],y:e.position[1],rotation:e.rotation});i.updateTransform(),this._transformGroup=i}return r.prototype.hasBuilder=function(t){return!!cp[t]},r.prototype.add=function(t){cp[t](this.opt,this.axisModel,this.group,this._transformGroup)},r.prototype.getGroup=function(){return this.group},r.innerTextLayout=function(t,e,i){var n=Ng(e-t),a,o;return Qo(n)?(o=i>0?"top":"bottom",a="center"):Qo(n-br)?(o=i>0?"bottom":"top",a="center"):(o="middle",n>0&&n<br?a=i>0?"right":"left":a=i>0?"left":"right"),{rotation:n,textAlign:a,textVerticalAlign:o}},r.makeAxisEventDataBase=function(t){var e={componentType:t.mainType,componentIndex:t.componentIndex};return e[t.mainType+"Index"]=t.componentIndex,e},r.isLabelSilent=function(t){var e=t.get("tooltip");return t.get("silent")||!(t.get("triggerEvent")||e&&e.show)},r}(),cp={axisLine:function(r,t,e,i){var n=t.get(["axisLine","show"]);if(n==="auto"&&r.handleAutoShown&&(n=r.handleAutoShown("axisLine")),!!n){var a=t.axis.getExtent(),o=i.transform,s=[a[0],0],l=[a[1],0],u=s[0]>l[0];o&&(ge(s,s,o),ge(l,l,o));var f=O({lineCap:"round"},t.getModel(["axisLine","lineStyle"]).getLineStyle()),h=new ui({shape:{x1:s[0],y1:s[1],x2:l[0],y2:l[1]},style:f,strokeContainThreshold:r.strokeContainThreshold||5,silent:!0,z2:1});ga(h.shape,h.style.lineWidth),h.anid="line",e.add(h);var c=t.get(["axisLine","symbol"]);if(c!=null){var v=t.get(["axisLine","symbolSize"]);W(c)&&(c=[c,c]),(W(v)||dt(v))&&(v=[v,v]);var d=Gm(t.get(["axisLine","symbolOffset"])||0,v),p=v[0],g=v[1];A([{rotate:r.rotation+Math.PI/2,offset:d[0],r:0},{rotate:r.rotation-Math.PI/2,offset:d[1],r:Math.sqrt((s[0]-l[0])*(s[0]-l[0])+(s[1]-l[1])*(s[1]-l[1]))}],function(y,m){if(c[m]!=="none"&&c[m]!=null){var _=ir(c[m],-p/2,-g/2,p,g,f.stroke,!0),S=y.r+y.offset,x=u?l:s;_.attr({rotation:y.rotate,x:x[0]+S*Math.cos(r.rotation),y:x[1]-S*Math.sin(r.rotation),silent:!0,z2:11}),e.add(_)}})}}},axisTickLabel:function(r,t,e,i){var n=HL(e,i,t,r),a=WL(e,i,t,r);if(VL(t,a,n),GL(e,i,t,r.tickDirection),t.get(["axisLabel","hideOverlap"])){var o=cD(G(a,function(s){return{label:s,priority:s.z2,defaultAttr:{ignore:s.ignore}}}));gD(o)}},axisName:function(r,t,e,i){var n=va(r.axisName,t.get("name"));if(!!n){var a=t.get("nameLocation"),o=r.nameDirection,s=t.getModel("nameTextStyle"),l=t.get("nameGap")||0,u=t.axis.getExtent(),f=u[0]>u[1]?-1:1,h=[a==="start"?u[0]-f*l:a==="end"?u[1]+f*l:(u[0]+u[1])/2,pp(a)?r.labelOffset+o*l:0],c,v=t.get("nameRotate");v!=null&&(v=v*br/180);var d;pp(a)?c=ai.innerTextLayout(r.rotation,v!=null?v:r.rotation,o):(c=FL(r.rotation,a,v||0,u),d=r.axisNameAvailableWidth,d!=null&&(d=Math.abs(d/Math.sin(c.rotation)),!isFinite(d)&&(d=null)));var p=s.getFont(),g=t.get("nameTruncate",!0)||{},y=g.ellipsis,m=va(r.nameTruncateMaxWidth,g.maxWidth,d),_=new Dt({x:h[0],y:h[1],rotation:c.rotation,silent:ai.isLabelSilent(t),style:fi(s,{text:n,font:p,overflow:"truncate",width:m,ellipsis:y,fill:s.getTextColor()||t.get(["axisLine","lineStyle","color"]),align:s.get("align")||c.textAlign,verticalAlign:s.get("verticalAlign")||c.textVerticalAlign}),z2:1});if(Ia({el:_,componentModel:t,itemName:n}),_.__fullText=n,_.anid="name",t.get("triggerEvent")){var S=ai.makeAxisEventDataBase(t);S.targetType="axisName",S.name=n,lt(_).eventData=S}i.add(_),_.updateTransform(),e.add(_),_.decomposeTransform()}}};function FL(r,t,e,i){var n=Ng(e-r),a,o,s=i[0]>i[1],l=t==="start"&&!s||t!=="start"&&s;return Qo(n-br/2)?(o=l?"bottom":"top",a="center"):Qo(n-br*1.5)?(o=l?"top":"bottom",a="center"):(o="middle",n<br*1.5&&n>br/2?a=l?"left":"right":a=l?"right":"left"),{rotation:n,textAlign:a,textVerticalAlign:o}}function VL(r,t,e){if(!E0(r.axis)){var i=r.get(["axisLabel","showMinLabel"]),n=r.get(["axisLabel","showMaxLabel"]);t=t||[],e=e||[];var a=t[0],o=t[1],s=t[t.length-1],l=t[t.length-2],u=e[0],f=e[1],h=e[e.length-1],c=e[e.length-2];i===!1?(oe(a),oe(u)):dp(a,o)&&(i?(oe(o),oe(f)):(oe(a),oe(u))),n===!1?(oe(s),oe(h)):dp(l,s)&&(n?(oe(l),oe(c)):(oe(s),oe(h)))}}function oe(r){r&&(r.ignore=!0)}function dp(r,t){var e=r&&r.getBoundingRect().clone(),i=t&&t.getBoundingRect().clone();if(!(!e||!i)){var n=Yf([]);return $f(n,n,-r.rotation),e.applyTransform(Ki([],n,r.getLocalTransform())),i.applyTransform(Ki([],n,t.getLocalTransform())),e.intersect(i)}}function pp(r){return r==="middle"||r==="center"}function v_(r,t,e,i,n){for(var a=[],o=[],s=[],l=0;l<r.length;l++){var u=r[l].coord;o[0]=u,o[1]=0,s[0]=u,s[1]=e,t&&(ge(o,o,t),ge(s,s,t));var f=new ui({shape:{x1:o[0],y1:o[1],x2:s[0],y2:s[1]},style:i,z2:2,autoBatch:!0,silent:!0});ga(f.shape,f.style.lineWidth),f.anid=n+"_"+r[l].tickValue,a.push(f)}return a}function HL(r,t,e,i){var n=e.axis,a=e.getModel("axisTick"),o=a.get("show");if(o==="auto"&&i.handleAutoShown&&(o=i.handleAutoShown("axisTick")),!(!o||n.scale.isBlank())){for(var s=a.getModel("lineStyle"),l=i.tickDirection*a.get("length"),u=n.getTicksCoords(),f=v_(u,t.transform,l,rt(s.getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])}),"ticks"),h=0;h<f.length;h++)r.add(f[h]);return f}}function GL(r,t,e,i){var n=e.axis,a=e.getModel("minorTick");if(!(!a.get("show")||n.scale.isBlank())){var o=n.getMinorTicksCoords();if(!!o.length)for(var s=a.getModel("lineStyle"),l=i*a.get("length"),u=rt(s.getLineStyle(),rt(e.getModel("axisTick").getLineStyle(),{stroke:e.get(["axisLine","lineStyle","color"])})),f=0;f<o.length;f++)for(var h=v_(o[f],t.transform,l,u,"minorticks_"+f),c=0;c<h.length;c++)r.add(h[c])}}function WL(r,t,e,i){var n=e.axis,a=va(i.axisLabelShow,e.get(["axisLabel","show"]));if(!(!a||n.scale.isBlank())){var o=e.getModel("axisLabel"),s=o.get("margin"),l=n.getViewLabels(),u=(va(i.labelRotate,o.get("rotate"))||0)*br/180,f=ai.innerTextLayout(i.rotation,u,i.labelDirection),h=e.getCategories&&e.getCategories(!0),c=[],v=ai.isLabelSilent(e),d=e.get("triggerEvent");return A(l,function(p,g){var y=n.scale.type==="ordinal"?n.scale.getRawOrdinalNumber(p.tickValue):p.tickValue,m=p.formattedLabel,_=p.rawLabel,S=o;if(h&&h[y]){var x=h[y];Y(x)&&x.textStyle&&(S=new kt(x.textStyle,o,e.ecModel))}var w=S.getTextColor()||e.get(["axisLine","lineStyle","color"]),b=n.dataToCoord(y),T=S.getShallow("align",!0)||f.textAlign,M=j(S.getShallow("alignMinLabel",!0),T),D=j(S.getShallow("alignMaxLabel",!0),T),C=S.getShallow("verticalAlign",!0)||S.getShallow("baseline",!0)||f.textVerticalAlign,L=j(S.getShallow("verticalAlignMinLabel",!0),C),I=j(S.getShallow("verticalAlignMaxLabel",!0),C),P=new Dt({x:b,y:i.labelOffset+i.labelDirection*s,rotation:f.rotation,silent:v,z2:10+(p.level||0),style:fi(S,{text:m,align:g===0?M:g===l.length-1?D:T,verticalAlign:g===0?L:g===l.length-1?I:C,fill:K(w)?w(n.type==="category"?_:n.type==="value"?y+"":y,g):w})});if(P.anid="label_"+y,Ia({el:P,componentModel:e,itemName:m,formatterParamsExtra:{isTruncated:function(){return P.isTruncated},value:_,tickIndex:g}}),d){var R=ai.makeAxisEventDataBase(e);R.targetType="axisLabel",R.value=_,R.tickIndex=g,n.type==="category"&&(R.dataIndex=y),lt(P).eventData=R}t.add(P),P.updateTransform(),c.push(P),r.add(P),P.decomposeTransform()}),c}}const Uh=ai;function UL(r,t){var e={axesInfo:{},seriesInvolved:!1,coordSysAxesInfo:{},coordSysMap:{}};return YL(e,r,t),e.seriesInvolved&&ZL(e,r),e}function YL(r,t,e){var i=t.getComponent("tooltip"),n=t.getComponent("axisPointer"),a=n.get("link",!0)||[],o=[];A(e.getCoordinateSystems(),function(s){if(!s.axisPointerEnabled)return;var l=Ta(s.model),u=r.coordSysAxesInfo[l]={};r.coordSysMap[l]=s;var f=s.model,h=f.getModel("tooltip",i);if(A(s.getAxes(),yt(p,!1,null)),s.getTooltipAxes&&i&&h.get("show")){var c=h.get("trigger")==="axis",v=h.get(["axisPointer","type"])==="cross",d=s.getTooltipAxes(h.get(["axisPointer","axis"]));(c||v)&&A(d.baseAxes,yt(p,v?"cross":!0,c)),v&&A(d.otherAxes,yt(p,"cross",!1))}function p(g,y,m){var _=m.model.getModel("axisPointer",n),S=_.get("show");if(!(!S||S==="auto"&&!g&&!Df(_))){y==null&&(y=_.get("triggerTooltip")),_=g?$L(m,h,n,t,g,y):_;var x=_.get("snap"),w=_.get("triggerEmphasis"),b=Ta(m.model),T=y||x||m.type==="category",M=r.axesInfo[b]={key:b,axis:m,coordSys:s,axisPointerModel:_,triggerTooltip:y,triggerEmphasis:w,involveSeries:T,snap:x,useHandle:Df(_),seriesModels:[],linkGroup:null};u[b]=M,r.seriesInvolved=r.seriesInvolved||T;var D=XL(a,m);if(D!=null){var C=o[D]||(o[D]={axesInfo:{}});C.axesInfo[b]=M,C.mapper=a[D].mapper,M.linkGroup=C}}}})}function $L(r,t,e,i,n,a){var o=t.getModel("axisPointer"),s=["type","snap","lineStyle","shadowStyle","label","animation","animationDurationUpdate","animationEasingUpdate","z"],l={};A(s,function(c){l[c]=et(o.get(c))}),l.snap=r.type!=="category"&&!!a,o.get("type")==="cross"&&(l.type="line");var u=l.label||(l.label={});if(u.show==null&&(u.show=!1),n==="cross"){var f=o.get(["label","show"]);if(u.show=f!=null?f:!0,!a){var h=l.lineStyle=o.get("crossStyle");h&&rt(u,h.textStyle)}}return r.model.getModel("axisPointer",new kt(l,e,i))}function ZL(r,t){t.eachSeries(function(e){var i=e.coordinateSystem,n=e.get(["tooltip","trigger"],!0),a=e.get(["tooltip","show"],!0);!i||n==="none"||n===!1||n==="item"||a===!1||e.get(["axisPointer","show"],!0)===!1||A(r.coordSysAxesInfo[Ta(i.model)],function(o){var s=o.axis;i.getAxis(s.dim)===s&&(o.seriesModels.push(e),o.seriesDataCount==null&&(o.seriesDataCount=0),o.seriesDataCount+=e.getData().count())})})}function XL(r,t){for(var e=t.model,i=t.dim,n=0;n<r.length;n++){var a=r[n]||{};if(gu(a[i+"AxisId"],e.id)||gu(a[i+"AxisIndex"],e.componentIndex)||gu(a[i+"AxisName"],e.name))return n}}function gu(r,t){return r==="all"||V(r)&&at(r,t)>=0||r===t}function qL(r){var t=Yh(r);if(!!t){var e=t.axisPointerModel,i=t.axis.scale,n=e.option,a=e.get("status"),o=e.get("value");o!=null&&(o=i.parse(o));var s=Df(e);a==null&&(n.status=s?"show":"hide");var l=i.getExtent().slice();l[0]>l[1]&&l.reverse(),(o==null||o>l[1])&&(o=l[1]),o<l[0]&&(o=l[0]),n.value=o,s&&(n.status=t.axis.scale.isBlank()?"hide":"show")}}function Yh(r){var t=(r.ecModel.getComponent("axisPointer")||{}).coordSysAxesInfo;return t&&t.axesInfo[Ta(r)]}function KL(r){var t=Yh(r);return t&&t.axisPointerModel}function Df(r){return!!r.get(["handle","show"])}function Ta(r){return r.type+"||"+r.id}var gp={},QL=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,i,n,a){this.axisPointerClass&&qL(e),r.prototype.render.apply(this,arguments),this._doUpdateAxisPointerClass(e,n,!0)},t.prototype.updateAxisPointer=function(e,i,n,a){this._doUpdateAxisPointerClass(e,n,!1)},t.prototype.remove=function(e,i){var n=this._axisPointer;n&&n.remove(i)},t.prototype.dispose=function(e,i){this._disposeAxisPointer(i),r.prototype.dispose.apply(this,arguments)},t.prototype._doUpdateAxisPointerClass=function(e,i,n){var a=t.getAxisPointerClass(this.axisPointerClass);if(!!a){var o=KL(e);o?(this._axisPointer||(this._axisPointer=new a)).render(e,o,i,n):this._disposeAxisPointer(i)}},t.prototype._disposeAxisPointer=function(e){this._axisPointer&&this._axisPointer.dispose(e),this._axisPointer=null},t.registerAxisPointerClass=function(e,i){gp[e]=i},t.getAxisPointerClass=function(e){return e&&gp[e]},t.type="axis",t}(Ce);const c_=QL;var Lf=gt();function JL(r,t,e,i){var n=e.axis;if(!n.scale.isBlank()){var a=e.getModel("splitArea"),o=a.getModel("areaStyle"),s=o.get("color"),l=i.coordinateSystem.getRect(),u=n.getTicksCoords({tickModel:a,clamp:!0});if(!!u.length){var f=s.length,h=Lf(r).splitAreaColors,c=Z(),v=0;if(h)for(var d=0;d<u.length;d++){var p=h.get(u[d].tickValue);if(p!=null){v=(p+(f-1)*d)%f;break}}var g=n.toGlobalCoord(u[0].coord),y=o.getAreaStyle();s=V(s)?s:[s];for(var d=1;d<u.length;d++){var m=n.toGlobalCoord(u[d].coord),_=void 0,S=void 0,x=void 0,w=void 0;n.isHorizontal()?(_=g,S=l.y,x=m-_,w=l.height,g=_+x):(_=l.x,S=g,x=l.width,w=m-S,g=S+w);var b=u[d-1].tickValue;b!=null&&c.set(b,v),t.add(new _t({anid:b!=null?"area_"+b:null,shape:{x:_,y:S,width:x,height:w},style:rt({fill:s[v]},y),autoBatch:!0,silent:!0})),v=(v+1)%f}Lf(r).splitAreaColors=c}}}function jL(r){Lf(r).splitAreaColors=null}var tI=["axisLine","axisTickLabel","axisName"],eI=["splitArea","splitLine","minorSplitLine"],d_=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.axisPointerClass="CartesianAxisPointer",e}return t.prototype.render=function(e,i,n,a){this.group.removeAll();var o=this._axisGroup;if(this._axisGroup=new xt,this.group.add(this._axisGroup),!!e.get("show")){var s=e.getCoordSysModel(),l=Af(s,e),u=new Uh(e,O({handleAutoShown:function(h){for(var c=s.coordinateSystem.getCartesians(),v=0;v<c.length;v++)if(bf(c[v].getOtherAxis(e.axis).scale))return!0;return!1}},l));A(tI,u.add,u),this._axisGroup.add(u.getGroup()),A(eI,function(h){e.get([h,"show"])&&rI[h](this,this._axisGroup,e,s)},this);var f=a&&a.type==="changeAxisOrder"&&a.isInitSort;f||Vy(o,this._axisGroup,e),r.prototype.render.call(this,e,i,n,a)}},t.prototype.remove=function(){jL(this)},t.type="cartesianAxis",t}(c_),rI={splitLine:function(r,t,e,i){var n=e.axis;if(!n.scale.isBlank()){var a=e.getModel("splitLine"),o=a.getModel("lineStyle"),s=o.get("color"),l=a.get("showMinLine")!==!1,u=a.get("showMaxLine")!==!1;s=V(s)?s:[s];for(var f=i.coordinateSystem.getRect(),h=n.isHorizontal(),c=0,v=n.getTicksCoords({tickModel:a}),d=[],p=[],g=o.getLineStyle(),y=0;y<v.length;y++){var m=n.toGlobalCoord(v[y].coord);if(!(y===0&&!l||y===v.length-1&&!u)){var _=v[y].tickValue;h?(d[0]=m,d[1]=f.y,p[0]=m,p[1]=f.y+f.height):(d[0]=f.x,d[1]=m,p[0]=f.x+f.width,p[1]=m);var S=c++%s.length,x=new ui({anid:_!=null?"line_"+_:null,autoBatch:!0,shape:{x1:d[0],y1:d[1],x2:p[0],y2:p[1]},style:rt({stroke:s[S]},g),silent:!0});ga(x.shape,g.lineWidth),t.add(x)}}}},minorSplitLine:function(r,t,e,i){var n=e.axis,a=e.getModel("minorSplitLine"),o=a.getModel("lineStyle"),s=i.coordinateSystem.getRect(),l=n.isHorizontal(),u=n.getMinorTicksCoords();if(!!u.length)for(var f=[],h=[],c=o.getLineStyle(),v=0;v<u.length;v++)for(var d=0;d<u[v].length;d++){var p=n.toGlobalCoord(u[v][d].coord);l?(f[0]=p,f[1]=s.y,h[0]=p,h[1]=s.y+s.height):(f[0]=s.x,f[1]=p,h[0]=s.x+s.width,h[1]=p);var g=new ui({anid:"minor_line_"+u[v][d].tickValue,autoBatch:!0,shape:{x1:f[0],y1:f[1],x2:h[0],y2:h[1]},style:c,silent:!0});ga(g.shape,c.lineWidth),t.add(g)}},splitArea:function(r,t,e,i){JL(r,t,e,i)}},p_=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="xAxis",t}(d_),iI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=p_.type,e}return t.type="yAxis",t}(d_),nI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="grid",e}return t.prototype.render=function(e,i){this.group.removeAll(),e.get("show")&&this.group.add(new _t({shape:e.coordinateSystem.getRect(),style:rt({fill:e.get("backgroundColor")},e.getItemStyle()),silent:!0,z2:-1}))},t.type="grid",t}(Ce),yp={offset:0};function aI(r){r.registerComponentView(nI),r.registerComponentModel(ML),r.registerCoordinateSystem("cartesian2d",zL),op(r,"x",Cf,yp),op(r,"y",Cf,yp),r.registerComponentView(p_),r.registerComponentView(iI),r.registerPreprocessor(function(t){t.xAxis&&t.yAxis&&!t.grid&&(t.grid={})})}function oI(r){r.eachSeriesByType("radar",function(t){var e=t.getData(),i=[],n=t.coordinateSystem;if(!!n){var a=n.getIndicatorAxes();A(a,function(o,s){e.each(e.mapDimension(a[s].dim),function(l,u){i[u]=i[u]||[];var f=n.dataToPoint(l,s);i[u][s]=mp(f)?f:_p(n)})}),e.each(function(o){var s=f1(i[o],function(l){return mp(l)})||_p(n);i[o].push(s.slice()),e.setItemLayout(o,i[o])})}})}function mp(r){return!isNaN(r[0])&&!isNaN(r[1])}function _p(r){return[r.cx,r.cy]}function sI(r){var t=r.polar;if(t){V(t)||(t=[t]);var e=[];A(t,function(i,n){i.indicator?(i.type&&!i.shape&&(i.shape=i.type),r.radar=r.radar||[],V(r.radar)||(r.radar=[r.radar]),r.radar.push(i)):e.push(i)}),r.polar=e}A(r.series,function(i){i&&i.type==="radar"&&i.polarIndex&&(i.radarIndex=i.polarIndex)})}var lI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,i,n){var a=e.coordinateSystem,o=this.group,s=e.getData(),l=this._data;function u(c,v){var d=c.getItemVisual(v,"symbol")||"circle";if(d!=="none"){var p=Hm(c.getItemVisual(v,"symbolSize")),g=ir(d,-1,-1,2,2),y=c.getItemVisual(v,"symbolRotate")||0;return g.attr({style:{strokeNoScale:!0},z2:100,scaleX:p[0]/2,scaleY:p[1]/2,rotation:y*Math.PI/180||0}),g}}function f(c,v,d,p,g,y){d.removeAll();for(var m=0;m<v.length-1;m++){var _=u(p,g);_&&(_.__dimIdx=m,c[m]?(_.setPosition(c[m]),Gy[y?"initProps":"updateProps"](_,{x:v[m][0],y:v[m][1]},e,g)):_.setPosition(v[m]),d.add(_))}}function h(c){return G(c,function(v){return[a.cx,a.cy]})}s.diff(l).add(function(c){var v=s.getItemLayout(c);if(!!v){var d=new La,p=new _i,g={shape:{points:v}};d.shape.points=h(v),p.shape.points=h(v),Jt(d,g,e,c),Jt(p,g,e,c);var y=new xt,m=new xt;y.add(p),y.add(d),y.add(m),f(p.shape.points,v,m,s,c,!0),s.setItemGraphicEl(c,y)}}).update(function(c,v){var d=l.getItemGraphicEl(v),p=d.childAt(0),g=d.childAt(1),y=d.childAt(2),m={shape:{points:s.getItemLayout(c)}};!m.shape.points||(f(p.shape.points,m.shape.points,y,s,c,!1),pa(g),pa(p),Lt(p,m,e),Lt(g,m,e),s.setItemGraphicEl(c,d))}).remove(function(c){o.remove(l.getItemGraphicEl(c))}).execute(),s.eachItemGraphicEl(function(c,v){var d=s.getItemModel(v),p=c.childAt(0),g=c.childAt(1),y=c.childAt(2),m=s.getItemVisual(v,"style"),_=m.fill;o.add(c),p.useStyle(rt(d.getModel("lineStyle").getLineStyle(),{fill:"none",stroke:_})),nn(p,d,"lineStyle"),nn(g,d,"areaStyle");var S=d.getModel("areaStyle"),x=S.isEmpty()&&S.parentModel.isEmpty();g.ignore=x,A(["emphasis","select","blur"],function(T){var M=d.getModel([T,"areaStyle"]),D=M.isEmpty()&&M.parentModel.isEmpty();g.ensureState(T).ignore=D&&x}),g.useStyle(rt(S.getAreaStyle(),{fill:_,opacity:.7,decal:m.decal}));var w=d.getModel("emphasis"),b=w.getModel("itemStyle").getItemStyle();y.eachChild(function(T){if(T instanceof nr){var M=T.style;T.useStyle(O({image:M.image,x:M.x,y:M.y,width:M.width,height:M.height},m))}else T.useStyle(m),T.setColor(_),T.style.strokeNoScale=!0;var D=T.ensureState("emphasis");D.style=et(b);var C=s.getStore().get(s.getDimensionIndex(T.__dimIdx),v);(C==null||isNaN(C))&&(C=""),un(T,fn(d),{labelFetcher:s.hostModel,labelDataIndex:v,labelDimIndex:T.__dimIdx,defaultText:C,inheritColor:_,defaultOpacity:m.opacity})}),rn(c,w.get("focus"),w.get("blurScope"),w.get("disabled"))}),this._data=s},t.prototype.remove=function(){this.group.removeAll(),this._data=null},t.type="radar",t}(Te);const uI=lI;var fI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.hasSymbolVisual=!0,e}return t.prototype.init=function(e){r.prototype.init.apply(this,arguments),this.legendVisualProvider=new l_($(this.getData,this),$(this.getRawData,this))},t.prototype.getInitialData=function(e,i){return s_(this,{generateCoord:"indicator_",generateCoordCount:1/0})},t.prototype.formatTooltip=function(e,i,n){var a=this.getData(),o=this.coordinateSystem,s=o.getIndicatorAxes(),l=this.getData().getName(e),u=l===""?this.name:l,f=Pm(this,e);return di("section",{header:u,sortBlocks:!0,blocks:G(s,function(h){var c=a.get(a.mapDimension(h.dim),e);return di("nameValue",{markerType:"subItem",markerColor:f,name:h.name,value:c,sortParam:c})})})},t.prototype.getTooltipPosition=function(e){if(e!=null){for(var i=this.getData(),n=this.coordinateSystem,a=i.getValues(G(n.dimensions,function(u){return i.mapDimension(u)}),e),o=0,s=a.length;o<s;o++)if(!isNaN(a[o])){var l=n.getIndicatorAxes();return n.coordToPoint(l[o].dataToCoord(a[o]),o)}}},t.type="series.radar",t.dependencies=["radar"],t.defaultOption={z:2,colorBy:"data",coordinateSystem:"radar",legendHoverLink:!0,radarIndex:0,lineStyle:{width:2,type:"solid",join:"round"},label:{position:"top"},symbolSize:8},t}(rr);const hI=fI;var kn=f_.value;function xo(r,t){return rt({show:t},r)}var vI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.optionUpdated=function(){var e=this.get("boundaryGap"),i=this.get("splitNumber"),n=this.get("scale"),a=this.get("axisLine"),o=this.get("axisTick"),s=this.get("axisLabel"),l=this.get("axisName"),u=this.get(["axisName","show"]),f=this.get(["axisName","formatter"]),h=this.get("axisNameGap"),c=this.get("triggerEvent"),v=G(this.get("indicator")||[],function(d){d.max!=null&&d.max>0&&!d.min?d.min=0:d.min!=null&&d.min<0&&!d.max&&(d.max=0);var p=l;d.color!=null&&(p=rt({color:d.color},l));var g=nt(et(d),{boundaryGap:e,splitNumber:i,scale:n,axisLine:a,axisTick:o,axisLabel:s,name:d.text,showName:u,nameLocation:"end",nameGap:h,nameTextStyle:p,triggerEvent:c},!1);if(W(f)){var y=g.name;g.name=f.replace("{value}",y!=null?y:"")}else K(f)&&(g.name=f(g.name,g));var m=new kt(g,null,this.ecModel);return Me(m,O0.prototype),m.mainType="radar",m.componentIndex=this.componentIndex,m},this);this._indicatorModels=v},t.prototype.getIndicatorModels=function(){return this._indicatorModels},t.type="radar",t.defaultOption={z:0,center:["50%","50%"],radius:"75%",startAngle:90,axisName:{show:!0},boundaryGap:[0,0],splitNumber:5,axisNameGap:15,scale:!1,shape:"polygon",axisLine:nt({lineStyle:{color:"#bbb"}},kn.axisLine),axisLabel:xo(kn.axisLabel,!1),axisTick:xo(kn.axisTick,!1),splitLine:xo(kn.splitLine,!0),splitArea:xo(kn.splitArea,!0),indicator:[]},t}(pt);const cI=vI;var dI=["axisLine","axisTickLabel","axisName"],pI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,i,n){var a=this.group;a.removeAll(),this._buildAxes(e),this._buildSplitLineAndArea(e)},t.prototype._buildAxes=function(e){var i=e.coordinateSystem,n=i.getIndicatorAxes(),a=G(n,function(o){var s=o.model.get("showName")?o.name:"",l=new Uh(o.model,{axisName:s,position:[i.cx,i.cy],rotation:o.angle,labelDirection:-1,tickDirection:-1,nameDirection:1});return l});A(a,function(o){A(dI,o.add,o),this.group.add(o.getGroup())},this)},t.prototype._buildSplitLineAndArea=function(e){var i=e.coordinateSystem,n=i.getIndicatorAxes();if(!n.length)return;var a=e.get("shape"),o=e.getModel("splitLine"),s=e.getModel("splitArea"),l=o.getModel("lineStyle"),u=s.getModel("areaStyle"),f=o.get("show"),h=s.get("show"),c=l.get("color"),v=u.get("color"),d=V(c)?c:[c],p=V(v)?v:[v],g=[],y=[];function m(R,E,z){var k=z%E.length;return R[k]=R[k]||[],k}if(a==="circle")for(var _=n[0].getTicksCoords(),S=i.cx,x=i.cy,w=0;w<_.length;w++){if(f){var b=m(g,d,w);g[b].push(new Ps({shape:{cx:S,cy:x,r:_[w].coord}}))}if(h&&w<_.length-1){var b=m(y,p,w);y[b].push(new sh({shape:{cx:S,cy:x,r0:_[w].coord,r:_[w+1].coord}}))}}else for(var T,M=G(n,function(R,E){var z=R.getTicksCoords();return T=T==null?z.length-1:Math.min(z.length-1,T),G(z,function(k){return i.coordToPoint(k.coord,E)})}),D=[],w=0;w<=T;w++){for(var C=[],L=0;L<n.length;L++)C.push(M[L][w]);if(C[0]&&C.push(C[0].slice()),f){var b=m(g,d,w);g[b].push(new _i({shape:{points:C}}))}if(h&&D){var b=m(y,p,w-1);y[b].push(new La({shape:{points:C.concat(D)}}))}D=C.slice().reverse()}var I=l.getLineStyle(),P=u.getAreaStyle();A(y,function(R,E){this.group.add(lf(R,{style:rt({stroke:"none",fill:p[E%p.length]},P),silent:!0}))},this),A(g,function(R,E){this.group.add(lf(R,{style:rt({fill:"none",stroke:d[E%d.length]},I),silent:!0}))},this)},t.type="radar",t}(Ce);const gI=pI;var yI=function(r){N(t,r);function t(e,i,n){var a=r.call(this,e,i,n)||this;return a.type="value",a.angle=0,a.name="",a}return t}(W0);const mI=yI;var _I=function(){function r(t,e,i){this.dimensions=[],this._model=t,this._indicatorAxes=G(t.getIndicatorModels(),function(n,a){var o="indicator_"+a,s=new mI(o,new pi);return s.name=n.get("name"),s.model=n,n.axis=s,this.dimensions.push(o),s},this),this.resize(t,i)}return r.prototype.getIndicatorAxes=function(){return this._indicatorAxes},r.prototype.dataToPoint=function(t,e){var i=this._indicatorAxes[e];return this.coordToPoint(i.dataToCoord(t),e)},r.prototype.coordToPoint=function(t,e){var i=this._indicatorAxes[e],n=i.angle,a=this.cx+t*Math.cos(n),o=this.cy-t*Math.sin(n);return[a,o]},r.prototype.pointToData=function(t){var e=t[0]-this.cx,i=t[1]-this.cy,n=Math.sqrt(e*e+i*i);e/=n,i/=n;for(var a=Math.atan2(-i,e),o=1/0,s,l=-1,u=0;u<this._indicatorAxes.length;u++){var f=this._indicatorAxes[u],h=Math.abs(a-f.angle);h<o&&(s=f,l=u,o=h)}return[l,+(s&&s.coordToData(n))]},r.prototype.resize=function(t,e){var i=t.get("center"),n=e.getWidth(),a=e.getHeight(),o=Math.min(n,a)/2;this.cx=st(i[0],n),this.cy=st(i[1],a),this.startAngle=t.get("startAngle")*Math.PI/180;var s=t.get("radius");(W(s)||dt(s))&&(s=[0,s]),this.r0=st(s[0],o),this.r=st(s[1],o),A(this._indicatorAxes,function(l,u){l.setExtent(this.r0,this.r);var f=this.startAngle+u*Math.PI*2/this._indicatorAxes.length;f=Math.atan2(Math.sin(f),Math.cos(f)),l.angle=f},this)},r.prototype.update=function(t,e){var i=this._indicatorAxes,n=this._model;A(i,function(s){s.scale.setExtent(1/0,-1/0)}),t.eachSeriesByType("radar",function(s,l){if(!(s.get("coordinateSystem")!=="radar"||t.getComponent("radar",s.get("radarIndex"))!==n)){var u=s.getData();A(i,function(f){f.scale.unionExtentFromData(u,u.mapDimension(f.dim))})}},this);var a=n.get("splitNumber"),o=new pi;o.setExtent(0,a),o.setInterval(1),A(i,function(s,l){h_(s.scale,s.model,o)})},r.prototype.convertToPixel=function(t,e,i){return console.warn("Not implemented."),null},r.prototype.convertFromPixel=function(t,e,i){return console.warn("Not implemented."),null},r.prototype.containPoint=function(t){return console.warn("Not implemented."),!1},r.create=function(t,e){var i=[];return t.eachComponent("radar",function(n){var a=new r(n,t,e);i.push(a),n.coordinateSystem=a}),t.eachSeriesByType("radar",function(n){n.get("coordinateSystem")==="radar"&&(n.coordinateSystem=i[n.get("radarIndex")||0])}),i},r.dimensions=[],r}();const SI=_I;function wI(r){r.registerCoordinateSystem("radar",SI),r.registerComponentModel(cI),r.registerComponentView(gI),r.registerVisual({seriesType:"radar",reset:function(t){var e=t.getData();e.each(function(i){e.setItemVisual(i,"legendIcon","roundRect")}),e.setVisual("legendIcon","roundRect")}})}function sR(r){Ge(wI),r.registerChartView(uI),r.registerSeriesModel(hI),r.registerLayout(oI),r.registerProcessor(a_("radar")),r.registerPreprocessor(sI)}var Sp="\0_ec_interaction_mutex";function wp(r,t){return!!xI(r)[t]}function xI(r){return r[Sp]||(r[Sp]={})}wi({type:"takeGlobalCursor",event:"globalCursorTaken",update:"update"},Gt);var bI=function(r){N(t,r);function t(e){var i=r.call(this)||this;i._zr=e;var n=$(i._mousedownHandler,i),a=$(i._mousemoveHandler,i),o=$(i._mouseupHandler,i),s=$(i._mousewheelHandler,i),l=$(i._pinchHandler,i);return i.enable=function(u,f){this.disable(),this._opt=rt(et(f)||{},{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),u==null&&(u=!0),(u===!0||u==="move"||u==="pan")&&(e.on("mousedown",n),e.on("mousemove",a),e.on("mouseup",o)),(u===!0||u==="scale"||u==="zoom")&&(e.on("mousewheel",s),e.on("pinch",l))},i.disable=function(){e.off("mousedown",n),e.off("mousemove",a),e.off("mouseup",o),e.off("mousewheel",s),e.off("pinch",l)},i}return t.prototype.isDragging=function(){return this._dragging},t.prototype.isPinching=function(){return this._pinching},t.prototype.setPointerChecker=function(e){this.pointerChecker=e},t.prototype.dispose=function(){this.disable()},t.prototype._mousedownHandler=function(e){if(!ov(e)){for(var i=e.target;i;){if(i.draggable)return;i=i.__hostTarget||i.parent}var n=e.offsetX,a=e.offsetY;this.pointerChecker&&this.pointerChecker(e,n,a)&&(this._x=n,this._y=a,this._dragging=!0)}},t.prototype._mousemoveHandler=function(e){if(!(!this._dragging||!Fo("moveOnMouseMove",e,this._opt)||e.gestureEvent==="pinch"||wp(this._zr,"globalPan"))){var i=e.offsetX,n=e.offsetY,a=this._x,o=this._y,s=i-a,l=n-o;this._x=i,this._y=n,this._opt.preventDefaultMouseMove&&en(e.event),g_(this,"pan","moveOnMouseMove",e,{dx:s,dy:l,oldX:a,oldY:o,newX:i,newY:n,isAvailableBehavior:null})}},t.prototype._mouseupHandler=function(e){ov(e)||(this._dragging=!1)},t.prototype._mousewheelHandler=function(e){var i=Fo("zoomOnMouseWheel",e,this._opt),n=Fo("moveOnMouseWheel",e,this._opt),a=e.wheelDelta,o=Math.abs(a),s=e.offsetX,l=e.offsetY;if(!(a===0||!i&&!n)){if(i){var u=o>3?1.4:o>1?1.2:1.1,f=a>0?u:1/u;yu(this,"zoom","zoomOnMouseWheel",e,{scale:f,originX:s,originY:l,isAvailableBehavior:null})}if(n){var h=Math.abs(a),c=(a>0?1:-1)*(h>3?.4:h>1?.15:.05);yu(this,"scrollMove","moveOnMouseWheel",e,{scrollDelta:c,originX:s,originY:l,isAvailableBehavior:null})}}},t.prototype._pinchHandler=function(e){if(!wp(this._zr,"globalPan")){var i=e.pinchScale>1?1.1:1/1.1;yu(this,"zoom",null,e,{scale:i,originX:e.pinchX,originY:e.pinchY,isAvailableBehavior:null})}},t}(Ae);function yu(r,t,e,i,n){r.pointerChecker&&r.pointerChecker(i,n.originX,n.originY)&&(en(i.event),g_(r,t,e,i,n))}function g_(r,t,e,i,n){n.isAvailableBehavior=$(Fo,null,e,i),r.trigger(t,n)}function Fo(r,t,e){var i=e[r];return!r||i&&(!W(i)||t.event[i+"Key"])}const TI=bI;function Js(r,t,e,i,n,a){r=r||0;var o=e[1]-e[0];if(n!=null&&(n=Fi(n,[0,o])),a!=null&&(a=Math.max(a,n!=null?n:0)),i==="all"){var s=Math.abs(t[1]-t[0]);s=Fi(s,[0,o]),n=a=Fi(s,[n,a]),i=0}t[0]=Fi(t[0],e),t[1]=Fi(t[1],e);var l=mu(t,i);t[i]+=r;var u=n||0,f=e.slice();l.sign<0?f[0]+=u:f[1]-=u,t[i]=Fi(t[i],f);var h;return h=mu(t,i),n!=null&&(h.sign!==l.sign||h.span<n)&&(t[1-i]=t[i]+l.sign*n),h=mu(t,i),a!=null&&h.span>a&&(t[1-i]=t[i]+h.sign*a),t}function mu(r,t){var e=r[t]-r[1-t];return{span:Math.abs(e),sign:e>0?-1:e<0?1:t?-1:1}}function Fi(r,t){return Math.min(t[1]!=null?t[1]:1/0,Math.max(t[0]!=null?t[0]:-1/0,r))}function CI(r,t,e,i){return r&&(r.legacy||r.legacy!==!1&&!e&&!i&&t!=="tspan"&&(t==="text"||Q(r,"text")))}function MI(r,t,e){var i=r,n,a,o;if(t==="text")o=i;else{o={},Q(i,"text")&&(o.text=i.text),Q(i,"rich")&&(o.rich=i.rich),Q(i,"textFill")&&(o.fill=i.textFill),Q(i,"textStroke")&&(o.stroke=i.textStroke),Q(i,"fontFamily")&&(o.fontFamily=i.fontFamily),Q(i,"fontSize")&&(o.fontSize=i.fontSize),Q(i,"fontStyle")&&(o.fontStyle=i.fontStyle),Q(i,"fontWeight")&&(o.fontWeight=i.fontWeight),a={type:"text",style:o,silent:!0},n={};var s=Q(i,"textPosition");e?n.position=s?i.textPosition:"inside":s&&(n.position=i.textPosition),Q(i,"textPosition")&&(n.position=i.textPosition),Q(i,"textOffset")&&(n.offset=i.textOffset),Q(i,"textRotation")&&(n.rotation=i.textRotation),Q(i,"textDistance")&&(n.distance=i.textDistance)}return xp(o,r),A(o.rich,function(l){xp(l,l)}),{textConfig:n,textContent:a}}function xp(r,t){!t||(t.font=t.textFont||t.font,Q(t,"textStrokeWidth")&&(r.lineWidth=t.textStrokeWidth),Q(t,"textAlign")&&(r.align=t.textAlign),Q(t,"textVerticalAlign")&&(r.verticalAlign=t.textVerticalAlign),Q(t,"textLineHeight")&&(r.lineHeight=t.textLineHeight),Q(t,"textWidth")&&(r.width=t.textWidth),Q(t,"textHeight")&&(r.height=t.textHeight),Q(t,"textBackgroundColor")&&(r.backgroundColor=t.textBackgroundColor),Q(t,"textPadding")&&(r.padding=t.textPadding),Q(t,"textBorderColor")&&(r.borderColor=t.textBorderColor),Q(t,"textBorderWidth")&&(r.borderWidth=t.textBorderWidth),Q(t,"textBorderRadius")&&(r.borderRadius=t.textBorderRadius),Q(t,"textBoxShadowColor")&&(r.shadowColor=t.textBoxShadowColor),Q(t,"textBoxShadowBlur")&&(r.shadowBlur=t.textBoxShadowBlur),Q(t,"textBoxShadowOffsetX")&&(r.shadowOffsetX=t.textBoxShadowOffsetX),Q(t,"textBoxShadowOffsetY")&&(r.shadowOffsetY=t.textBoxShadowOffsetY))}var y_={position:["x","y"],scale:["scaleX","scaleY"],origin:["originX","originY"]},bp=vt(y_);je(He,function(r,t){return r[t]=1,r},{});He.join(", ");var ms=["","style","shape","extra"],sn=gt();function $h(r,t,e,i,n){var a=r+"Animation",o=uh(r,i,n)||{},s=sn(t).userDuring;return o.duration>0&&(o.during=s?$(RI,{el:t,userDuring:s}):null,o.setToFinal=!0,o.scope=r),O(o,e[a]),o}function _u(r,t,e,i){i=i||{};var n=i.dataIndex,a=i.isInit,o=i.clearStyle,s=e.isAnimationEnabled(),l=sn(r),u=t.style;l.userDuring=t.during;var f={},h={};if(kI(r,t,h),Cp("shape",t,h),Cp("extra",t,h),!a&&s&&(EI(r,t,f),Tp("shape",r,t,f),Tp("extra",r,t,f),OI(r,t,u,f)),h.style=u,DI(r,h,o),II(r,t),s)if(a){var c={};A(ms,function(d){var p=d?t[d]:t;p&&p.enterFrom&&(d&&(c[d]=c[d]||{}),O(d?c[d]:c,p.enterFrom))});var v=$h("enter",r,t,e,n);v.duration>0&&r.animateFrom(c,v)}else LI(r,t,n||0,e,f);m_(r,t),u?r.dirty():r.markRedraw()}function m_(r,t){for(var e=sn(r).leaveToProps,i=0;i<ms.length;i++){var n=ms[i],a=n?t[n]:t;a&&a.leaveTo&&(e||(e=sn(r).leaveToProps={}),n&&(e[n]=e[n]||{}),O(n?e[n]:e,a.leaveTo))}}function AI(r,t,e,i){if(r){var n=r.parent,a=sn(r).leaveToProps;if(a){var o=$h("update",r,t,e,0);o.done=function(){n.remove(r),i&&i()},r.animateTo(a,o)}else n.remove(r),i&&i()}}function oi(r){return r==="all"}function DI(r,t,e){var i=t.style;if(!r.isGroup&&i){if(e){r.useStyle({});for(var n=r.animators,a=0;a<n.length;a++){var o=n[a];o.targetName==="style"&&o.changeTarget(r.style)}}r.setStyle(i)}t&&(t.style=null,t&&r.attr(t),t.style=i)}function LI(r,t,e,i,n){if(n){var a=$h("update",r,t,i,e);a.duration>0&&r.animateFrom(n,a)}}function II(r,t){Q(t,"silent")&&(r.silent=t.silent),Q(t,"ignore")&&(r.ignore=t.ignore),r instanceof yi&&Q(t,"invisible")&&(r.invisible=t.invisible),r instanceof ct&&Q(t,"autoBatch")&&(r.autoBatch=t.autoBatch)}var Oe={},PI={setTransform:function(r,t){return Oe.el[r]=t,this},getTransform:function(r){return Oe.el[r]},setShape:function(r,t){var e=Oe.el,i=e.shape||(e.shape={});return i[r]=t,e.dirtyShape&&e.dirtyShape(),this},getShape:function(r){var t=Oe.el.shape;if(t)return t[r]},setStyle:function(r,t){var e=Oe.el,i=e.style;return i&&(i[r]=t,e.dirtyStyle&&e.dirtyStyle()),this},getStyle:function(r){var t=Oe.el.style;if(t)return t[r]},setExtra:function(r,t){var e=Oe.el.extra||(Oe.el.extra={});return e[r]=t,this},getExtra:function(r){var t=Oe.el.extra;if(t)return t[r]}};function RI(){var r=this,t=r.el;if(!!t){var e=sn(t).userDuring,i=r.userDuring;if(e!==i){r.el=r.userDuring=null;return}Oe.el=t,i(PI)}}function Tp(r,t,e,i){var n=e[r];if(!!n){var a=t[r],o;if(a){var s=e.transition,l=n.transition;if(l)if(!o&&(o=i[r]={}),oi(l))O(o,a);else for(var u=At(l),f=0;f<u.length;f++){var h=u[f],c=a[h];o[h]=c}else if(oi(s)||at(s,r)>=0){!o&&(o=i[r]={});for(var v=vt(a),f=0;f<v.length;f++){var h=v[f],c=a[h];BI(n[h],c)&&(o[h]=c)}}}}}function Cp(r,t,e){var i=t[r];if(!!i)for(var n=e[r]={},a=vt(i),o=0;o<a.length;o++){var s=a[o];n[s]=jn(i[s])}}function EI(r,t,e){for(var i=t.transition,n=oi(i)?He:At(i||[]),a=0;a<n.length;a++){var o=n[a];if(!(o==="style"||o==="shape"||o==="extra")){var s=r[o];e[o]=s}}}function kI(r,t,e){for(var i=0;i<bp.length;i++){var n=bp[i],a=y_[n],o=t[n];o&&(e[a[0]]=o[0],e[a[1]]=o[1])}for(var i=0;i<He.length;i++){var s=He[i];t[s]!=null&&(e[s]=t[s])}}function OI(r,t,e,i){if(!!e){var n=r.style,a;if(n){var o=e.transition,s=t.transition;if(o&&!oi(o)){var l=At(o);!a&&(a=i.style={});for(var u=0;u<l.length;u++){var f=l[u],h=n[f];a[f]=h}}else if(r.getAnimationStyleProps&&(oi(s)||oi(o)||at(s,"style")>=0)){var c=r.getAnimationStyleProps(),v=c?c.style:null;if(v){!a&&(a=i.style={});for(var d=vt(e),u=0;u<d.length;u++){var f=d[u];if(v[f]){var h=n[f];a[f]=h}}}}}}}function BI(r,t){return Wt(r)?r!==t:r!=null&&isFinite(r)}var __=gt(),NI=["percent","easing","shape","style","extra"];function zI(r){r.stopAnimation("keyframe"),r.attr(__(r))}function If(r,t,e){if(!(!e.isAnimationEnabled()||!t)){if(V(t)){A(t,function(s){If(r,s,e)});return}var i=t.keyframes,n=t.duration;if(e&&n==null){var a=uh("enter",e,0);n=a&&a.duration}if(!(!i||!n)){var o=__(r);A(ms,function(s){if(!(s&&!r[s])){var l;i.sort(function(u,f){return u.percent-f.percent}),A(i,function(u){var f=r.animators,h=s?u[s]:u;if(!!h){var c=vt(h);if(s||(c=Ct(c,function(p){return at(NI,p)<0})),!!c.length){l||(l=r.animate(s,t.loop,!0),l.scope="keyframe");for(var v=0;v<f.length;v++)f[v]!==l&&f[v].targetName===l.targetName&&f[v].stopTracks(c);s&&(o[s]=o[s]||{});var d=s?o[s]:o;A(c,function(p){d[p]=((s?r[s]:r)||{})[p]}),l.whenWithKeys(n*u.percent,h,c,u.easing)}}}),l&&l.delay(t.delay||0).duration(n).start(t.easing)}})}}}var Jr=gt(),Mp=et,Su=$,FI=function(){function r(){this._dragging=!1,this.animationThreshold=15}return r.prototype.render=function(t,e,i,n){var a=e.get("value"),o=e.get("status");if(this._axisModel=t,this._axisPointerModel=e,this._api=i,!(!n&&this._lastValue===a&&this._lastStatus===o)){this._lastValue=a,this._lastStatus=o;var s=this._group,l=this._handle;if(!o||o==="hide"){s&&s.hide(),l&&l.hide();return}s&&s.show(),l&&l.show();var u={};this.makeElOption(u,a,t,e,i);var f=u.graphicKey;f!==this._lastGraphicKey&&this.clear(i),this._lastGraphicKey=f;var h=this._moveAnimation=this.determineAnimation(t,e);if(!s)s=this._group=new xt,this.createPointerEl(s,u,t,e),this.createLabelEl(s,u,t,e),i.getZr().add(s);else{var c=yt(Ap,e,h);this.updatePointerEl(s,u,c),this.updateLabelEl(s,u,c,e)}Lp(s,e,!0),this._renderHandle(a)}},r.prototype.remove=function(t){this.clear(t)},r.prototype.dispose=function(t){this.clear(t)},r.prototype.determineAnimation=function(t,e){var i=e.get("animation"),n=t.axis,a=n.type==="category",o=e.get("snap");if(!o&&!a)return!1;if(i==="auto"||i==null){var s=this.animationThreshold;if(a&&n.getBandWidth()>s)return!0;if(o){var l=Yh(t).seriesDataCount,u=n.getExtent();return Math.abs(u[0]-u[1])/l>s}return!1}return i===!0},r.prototype.makeElOption=function(t,e,i,n,a){},r.prototype.createPointerEl=function(t,e,i,n){var a=e.pointer;if(a){var o=Jr(t).pointerEl=new Gy[a.type](Mp(e.pointer));t.add(o)}},r.prototype.createLabelEl=function(t,e,i,n){if(e.label){var a=Jr(t).labelEl=new Dt(Mp(e.label));t.add(a),Dp(a,n)}},r.prototype.updatePointerEl=function(t,e,i){var n=Jr(t).pointerEl;n&&e.pointer&&(n.setStyle(e.pointer.style),i(n,{shape:e.pointer.shape}))},r.prototype.updateLabelEl=function(t,e,i,n){var a=Jr(t).labelEl;a&&(a.setStyle(e.label.style),i(a,{x:e.label.x,y:e.label.y}),Dp(a,n))},r.prototype._renderHandle=function(t){if(!(this._dragging||!this.updateHandleTransform)){var e=this._axisPointerModel,i=this._api.getZr(),n=this._handle,a=e.getModel("handle"),o=e.get("status");if(!a.get("show")||!o||o==="hide"){n&&i.remove(n),this._handle=null;return}var s;this._handle||(s=!0,n=this._handle=vh(a.get("icon"),{cursor:"move",draggable:!0,onmousemove:function(u){en(u.event)},onmousedown:Su(this._onHandleDragMove,this,0,0),drift:Su(this._onHandleDragMove,this),ondragend:Su(this._onHandleDragEnd,this)}),i.add(n)),Lp(n,e,!1),n.setStyle(a.getItemStyle(null,["color","borderColor","borderWidth","opacity","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"]));var l=a.get("size");V(l)||(l=[l,l]),n.scaleX=l[0]/2,n.scaleY=l[1]/2,Zs(this,"_doDispatchAxisPointer",a.get("throttle")||0,"fixRate"),this._moveHandleToValue(t,s)}},r.prototype._moveHandleToValue=function(t,e){Ap(this._axisPointerModel,!e&&this._moveAnimation,this._handle,wu(this.getHandleTransform(t,this._axisModel,this._axisPointerModel)))},r.prototype._onHandleDragMove=function(t,e){var i=this._handle;if(!!i){this._dragging=!0;var n=this.updateHandleTransform(wu(i),[t,e],this._axisModel,this._axisPointerModel);this._payloadInfo=n,i.stopAnimation(),i.attr(wu(n)),Jr(i).lastProp=null,this._doDispatchAxisPointer()}},r.prototype._doDispatchAxisPointer=function(){var t=this._handle;if(!!t){var e=this._payloadInfo,i=this._axisModel;this._api.dispatchAction({type:"updateAxisPointer",x:e.cursorPoint[0],y:e.cursorPoint[1],tooltipOption:e.tooltipOption,axesInfo:[{axisDim:i.axis.dim,axisIndex:i.componentIndex}]})}},r.prototype._onHandleDragEnd=function(){this._dragging=!1;var t=this._handle;if(!!t){var e=this._axisPointerModel.get("value");this._moveHandleToValue(e),this._api.dispatchAction({type:"hideTip"})}},r.prototype.clear=function(t){this._lastValue=null,this._lastStatus=null;var e=t.getZr(),i=this._group,n=this._handle;e&&i&&(this._lastGraphicKey=null,i&&e.remove(i),n&&e.remove(n),this._group=null,this._handle=null,this._payloadInfo=null),fs(this,"_doDispatchAxisPointer")},r.prototype.doClear=function(){},r.prototype.buildLabel=function(t,e,i){return i=i||0,{x:t[i],y:t[1-i],width:e[i],height:e[1-i]}},r}();function Ap(r,t,e,i){S_(Jr(e).lastProp,i)||(Jr(e).lastProp=i,t?Lt(e,i,r):(e.stopAnimation(),e.attr(i)))}function S_(r,t){if(Y(r)&&Y(t)){var e=!0;return A(t,function(i,n){e=e&&S_(r[n],i)}),!!e}else return r===t}function Dp(r,t){r[t.get(["label","show"])?"show":"hide"]()}function wu(r){return{x:r.x||0,y:r.y||0,rotation:r.rotation||0}}function Lp(r,t,e){var i=t.get("z"),n=t.get("zlevel");r&&r.traverse(function(a){a.type!=="group"&&(i!=null&&(a.z=i),n!=null&&(a.zlevel=n),a.silent=e)})}const VI=FI;function HI(r){var t=r.get("type"),e=r.getModel(t+"Style"),i;return t==="line"?(i=e.getLineStyle(),i.fill=null):t==="shadow"&&(i=e.getAreaStyle(),i.stroke=null),i}function GI(r,t,e,i,n){var a=e.get("value"),o=w_(a,t.axis,t.ecModel,e.get("seriesDataIndices"),{precision:e.get(["label","precision"]),formatter:e.get(["label","formatter"])}),s=e.getModel("label"),l=Gs(s.get("padding")||0),u=s.getFont(),f=Kf(o,u),h=n.position,c=f.width+l[1]+l[3],v=f.height+l[0]+l[2],d=n.align;d==="right"&&(h[0]-=c),d==="center"&&(h[0]-=c/2);var p=n.verticalAlign;p==="bottom"&&(h[1]-=v),p==="middle"&&(h[1]-=v/2),WI(h,c,v,i);var g=s.get("backgroundColor");(!g||g==="auto")&&(g=t.get(["axisLine","lineStyle","color"])),r.label={x:h[0],y:h[1],style:fi(s,{text:o,font:u,fill:s.getTextColor(),padding:l,backgroundColor:g}),z2:10}}function WI(r,t,e,i){var n=i.getWidth(),a=i.getHeight();r[0]=Math.min(r[0]+t,n)-t,r[1]=Math.min(r[1]+e,a)-e,r[0]=Math.max(r[0],0),r[1]=Math.max(r[1],0)}function w_(r,t,e,i,n){r=t.scale.parse(r);var a=t.scale.getLabel({value:r},{precision:n.precision}),o=n.formatter;if(o){var s={value:zh(t,{value:r}),axisDimension:t.dim,axisIndex:t.index,seriesData:[]};A(i,function(l){var u=e.getSeriesByIndex(l.seriesIndex),f=l.dataIndexInside,h=u&&u.getDataParams(f);h&&s.seriesData.push(h)}),W(o)?a=o.replace("{value}",a):K(o)&&(a=o(s))}return a}function x_(r,t,e){var i=qi();return $f(i,i,e.rotation),zu(i,i,e.position),ya([r.dataToCoord(t),(e.labelOffset||0)+(e.labelDirection||1)*(e.labelMargin||0)],i)}function UI(r,t,e,i,n,a){var o=Uh.innerTextLayout(e.rotation,0,e.labelDirection);e.labelMargin=n.get(["label","margin"]),GI(t,i,n,a,{position:x_(i.axis,r,e),align:o.textAlign,verticalAlign:o.textVerticalAlign})}function YI(r,t,e){return e=e||0,{x1:r[e],y1:r[1-e],x2:t[e],y2:t[1-e]}}function $I(r,t,e){return e=e||0,{x:r[e],y:r[1-e],width:t[e],height:t[1-e]}}var ZI=function(r){N(t,r);function t(){return r!==null&&r.apply(this,arguments)||this}return t.prototype.makeElOption=function(e,i,n,a,o){var s=n.axis,l=s.grid,u=a.get("type"),f=Ip(l,s).getOtherAxis(s).getGlobalExtent(),h=s.toGlobalCoord(s.dataToCoord(i,!0));if(u&&u!=="none"){var c=HI(a),v=XI[u](s,h,f);v.style=c,e.graphicKey=v.type,e.pointer=v}var d=Af(l.model,n);UI(i,e,d,n,a,o)},t.prototype.getHandleTransform=function(e,i,n){var a=Af(i.axis.grid.model,i,{labelInside:!1});a.labelMargin=n.get(["handle","margin"]);var o=x_(i.axis,e,a);return{x:o[0],y:o[1],rotation:a.rotation+(a.labelDirection<0?Math.PI:0)}},t.prototype.updateHandleTransform=function(e,i,n,a){var o=n.axis,s=o.grid,l=o.getGlobalExtent(!0),u=Ip(s,o).getOtherAxis(o).getGlobalExtent(),f=o.dim==="x"?0:1,h=[e.x,e.y];h[f]+=i[f],h[f]=Math.min(l[1],h[f]),h[f]=Math.max(l[0],h[f]);var c=(u[1]+u[0])/2,v=[c,c];v[f]=h[f];var d=[{verticalAlign:"middle"},{align:"center"}];return{x:h[0],y:h[1],rotation:e.rotation,cursorPoint:v,tooltipOption:d[f]}},t}(VI);function Ip(r,t){var e={};return e[t.dim+"AxisIndex"]=t.index,r.getCartesian(e)}var XI={line:function(r,t,e){var i=YI([t,e[0]],[t,e[1]],Pp(r));return{type:"Line",subPixelOptimize:!0,shape:i}},shadow:function(r,t,e){var i=Math.max(1,r.getBandWidth()),n=e[1]-e[0];return{type:"Rect",shape:$I([t-i/2,e[0]],[i,n],Pp(r))}}};function Pp(r){return r.dim==="x"?0:1}const qI=ZI;var KI=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="axisPointer",t.defaultOption={show:"auto",z:50,type:"line",snap:!1,triggerTooltip:!0,triggerEmphasis:!0,value:null,status:null,link:[],animation:null,animationDurationUpdate:200,lineStyle:{color:"#B9BEC9",width:1,type:"dashed"},shadowStyle:{color:"rgba(210,219,238,0.2)"},label:{show:!0,formatter:null,precision:"auto",margin:3,color:"#fff",padding:[5,7,5,7],backgroundColor:"auto",borderColor:null,borderWidth:0,borderRadius:3},handle:{show:!1,icon:"M10.7,11.9v-1.3H9.3v1.3c-4.9,0.3-8.8,4.4-8.8,9.4c0,5,3.9,9.1,8.8,9.4h1.3c4.9-0.3,8.8-4.4,8.8-9.4C19.5,16.3,15.6,12.2,10.7,11.9z M13.3,24.4H6.7v-1.2h6.6z M13.3,22H6.7v-1.2h6.6z M13.3,19.6H6.7v-1.2h6.6z",size:45,margin:50,color:"#333",shadowBlur:3,shadowColor:"#aaa",shadowOffsetX:0,shadowOffsetY:2,throttle:40}},t}(pt);const QI=KI;var Ke=gt(),JI=A;function b_(r,t,e){if(!tt.node){var i=t.getZr();Ke(i).records||(Ke(i).records={}),jI(i,t);var n=Ke(i).records[r]||(Ke(i).records[r]={});n.handler=e}}function jI(r,t){if(Ke(r).initialized)return;Ke(r).initialized=!0,e("click",yt(Rp,"click")),e("mousemove",yt(Rp,"mousemove")),e("globalout",e2);function e(i,n){r.on(i,function(a){var o=r2(t);JI(Ke(r).records,function(s){s&&n(s,a,o.dispatchAction)}),t2(o.pendings,t)})}}function t2(r,t){var e=r.showTip.length,i=r.hideTip.length,n;e?n=r.showTip[e-1]:i&&(n=r.hideTip[i-1]),n&&(n.dispatchAction=null,t.dispatchAction(n))}function e2(r,t,e){r.handler("leave",null,e)}function Rp(r,t,e,i){t.handler(r,e,i)}function r2(r){var t={showTip:[],hideTip:[]},e=function(i){var n=t[i.type];n?n.push(i):(i.dispatchAction=e,r.dispatchAction(i))};return{dispatchAction:e,pendings:t}}function Pf(r,t){if(!tt.node){var e=t.getZr(),i=(Ke(e).records||{})[r];i&&(Ke(e).records[r]=null)}}var i2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,i,n){var a=i.getComponent("tooltip"),o=e.get("triggerOn")||a&&a.get("triggerOn")||"mousemove|click";b_("axisPointer",n,function(s,l,u){o!=="none"&&(s==="leave"||o.indexOf(s)>=0)&&u({type:"updateAxisPointer",currTrigger:s,x:l&&l.offsetX,y:l&&l.offsetY})})},t.prototype.remove=function(e,i){Pf("axisPointer",i)},t.prototype.dispose=function(e,i){Pf("axisPointer",i)},t.type="axisPointer",t}(Ce);const n2=i2;function T_(r,t){var e=[],i=r.seriesIndex,n;if(i==null||!(n=t.getSeriesByIndex(i)))return{point:[]};var a=n.getData(),o=li(a,r);if(o==null||o<0||V(o))return{point:[]};var s=a.getItemGraphicEl(o),l=n.coordinateSystem;if(n.getTooltipPosition)e=n.getTooltipPosition(o)||[];else if(l&&l.dataToPoint)if(r.isStacked){var u=l.getBaseAxis(),f=l.getOtherAxis(u),h=f.dim,c=u.dim,v=h==="x"||h==="radius"?1:0,d=a.mapDimension(c),p=[];p[v]=a.get(d,o),p[1-v]=a.get(a.getCalculationInfo("stackResultDimension"),o),e=l.dataToPoint(p)||[]}else e=l.dataToPoint(a.getValues(G(l.dimensions,function(y){return a.mapDimension(y)}),o))||[];else if(s){var g=s.getBoundingRect().clone();g.applyTransform(s.transform),e=[g.x+g.width/2,g.y+g.height/2]}return{point:e,el:s}}var Ep=gt();function a2(r,t,e){var i=r.currTrigger,n=[r.x,r.y],a=r,o=r.dispatchAction||$(e.dispatchAction,e),s=t.getComponent("axisPointer").coordSysAxesInfo;if(!!s){Vo(n)&&(n=T_({seriesIndex:a.seriesIndex,dataIndex:a.dataIndex},t).point);var l=Vo(n),u=a.axesInfo,f=s.axesInfo,h=i==="leave"||Vo(n),c={},v={},d={list:[],map:{}},p={showPointer:yt(s2,v),showTooltip:yt(l2,d)};A(s.coordSysMap,function(y,m){var _=l||y.containPoint(n);A(s.coordSysAxesInfo[m],function(S,x){var w=S.axis,b=v2(u,S);if(!h&&_&&(!u||b)){var T=b&&b.value;T==null&&!l&&(T=w.pointToData(n)),T!=null&&kp(S,T,p,!1,c)}})});var g={};return A(f,function(y,m){var _=y.linkGroup;_&&!v[m]&&A(_.axesInfo,function(S,x){var w=v[x];if(S!==y&&w){var b=w.value;_.mapper&&(b=y.axis.scale.parse(_.mapper(b,Op(S),Op(y)))),g[y.key]=b}})}),A(g,function(y,m){kp(f[m],y,p,!0,c)}),u2(v,f,c),f2(d,n,r,o),h2(f,o,e),c}}function kp(r,t,e,i,n){var a=r.axis;if(!(a.scale.isBlank()||!a.containData(t))){if(!r.involveSeries){e.showPointer(r,t);return}var o=o2(t,r),s=o.payloadBatch,l=o.snapToValue;s[0]&&n.seriesIndex==null&&O(n,s[0]),!i&&r.snap&&a.containData(l)&&l!=null&&(t=l),e.showPointer(r,t,s),e.showTooltip(r,o,l)}}function o2(r,t){var e=t.axis,i=e.dim,n=r,a=[],o=Number.MAX_VALUE,s=-1;return A(t.seriesModels,function(l,u){var f=l.getData().mapDimensionsAll(i),h,c;if(l.getAxisTooltipData){var v=l.getAxisTooltipData(f,r,e);c=v.dataIndices,h=v.nestestValue}else{if(c=l.getData().indicesOfNearest(f[0],r,e.type==="category"?.5:null),!c.length)return;h=l.getData().get(f[0],c[0])}if(!(h==null||!isFinite(h))){var d=r-h,p=Math.abs(d);p<=o&&((p<o||d>=0&&s<0)&&(o=p,s=d,n=h,a.length=0),A(c,function(g){a.push({seriesIndex:l.seriesIndex,dataIndexInside:g,dataIndex:l.getData().getRawIndex(g)})}))}}),{payloadBatch:a,snapToValue:n}}function s2(r,t,e,i){r[t.key]={value:e,payloadBatch:i}}function l2(r,t,e,i){var n=e.payloadBatch,a=t.axis,o=a.model,s=t.axisPointerModel;if(!(!t.triggerTooltip||!n.length)){var l=t.coordSys.model,u=Ta(l),f=r.map[u];f||(f=r.map[u]={coordSysId:l.id,coordSysIndex:l.componentIndex,coordSysType:l.type,coordSysMainType:l.mainType,dataByAxis:[]},r.list.push(f)),f.dataByAxis.push({axisDim:a.dim,axisIndex:o.componentIndex,axisType:o.type,axisId:o.id,value:i,valueLabelOpt:{precision:s.get(["label","precision"]),formatter:s.get(["label","formatter"])},seriesDataIndices:n.slice()})}}function u2(r,t,e){var i=e.axesInfo=[];A(t,function(n,a){var o=n.axisPointerModel.option,s=r[a];s?(!n.useHandle&&(o.status="show"),o.value=s.value,o.seriesDataIndices=(s.payloadBatch||[]).slice()):!n.useHandle&&(o.status="hide"),o.status==="show"&&i.push({axisDim:n.axis.dim,axisIndex:n.axis.model.componentIndex,value:o.value})})}function f2(r,t,e,i){if(Vo(t)||!r.list.length){i({type:"hideTip"});return}var n=((r.list[0].dataByAxis[0]||{}).seriesDataIndices||[])[0]||{};i({type:"showTip",escapeConnect:!0,x:t[0],y:t[1],tooltipOption:e.tooltipOption,position:e.position,dataIndexInside:n.dataIndexInside,dataIndex:n.dataIndex,seriesIndex:n.seriesIndex,dataByCoordSys:r.list})}function h2(r,t,e){var i=e.getZr(),n="axisPointerLastHighlights",a=Ep(i)[n]||{},o=Ep(i)[n]={};A(r,function(u,f){var h=u.axisPointerModel.option;h.status==="show"&&u.triggerEmphasis&&A(h.seriesDataIndices,function(c){var v=c.seriesIndex+" | "+c.dataIndex;o[v]=c})});var s=[],l=[];A(a,function(u,f){!o[f]&&l.push(u)}),A(o,function(u,f){!a[f]&&s.push(u)}),l.length&&e.dispatchAction({type:"downplay",escapeConnect:!0,notBlur:!0,batch:l}),s.length&&e.dispatchAction({type:"highlight",escapeConnect:!0,notBlur:!0,batch:s})}function v2(r,t){for(var e=0;e<(r||[]).length;e++){var i=r[e];if(t.axis.dim===i.axisDim&&t.axis.model.componentIndex===i.axisIndex)return i}}function Op(r){var t=r.axis.model,e={},i=e.axisDim=r.axis.dim;return e.axisIndex=e[i+"AxisIndex"]=t.componentIndex,e.axisName=e[i+"AxisName"]=t.name,e.axisId=e[i+"AxisId"]=t.id,e}function Vo(r){return!r||r[0]==null||isNaN(r[0])||r[1]==null||isNaN(r[1])}function C_(r){c_.registerAxisPointerClass("CartesianAxisPointer",qI),r.registerComponentModel(QI),r.registerComponentView(n2),r.registerPreprocessor(function(t){if(t){(!t.axisPointer||t.axisPointer.length===0)&&(t.axisPointer={});var e=t.axisPointer.link;e&&!V(e)&&(t.axisPointer.link=[e])}}),r.registerProcessor(r.PRIORITY.PROCESSOR.STATISTIC,function(t,e){t.getComponent("axisPointer").coordSysAxesInfo=UL(t,e)}),r.registerAction({type:"updateAxisPointer",event:"updateAxisPointer",update:":updateAxisPointer"},a2)}function lR(r){Ge(aI),Ge(C_)}function c2(r,t){var e=r.existing;if(t.id=r.keyInfo.id,!t.type&&e&&(t.type=e.type),t.parentId==null){var i=t.parentOption;i?t.parentId=i.id:e&&(t.parentId=e.parentId)}t.parentOption=null}function Bp(r,t){var e;return A(t,function(i){r[i]!=null&&r[i]!=="auto"&&(e=!0)}),e}function d2(r,t,e){var i=O({},e),n=r[t],a=e.$action||"merge";a==="merge"?n?(nt(n,i,!0),ci(n,i,{ignoreSize:!0}),am(e,n),bo(e,n),bo(e,n,"shape"),bo(e,n,"style"),bo(e,n,"extra"),e.clipPath=n.clipPath):r[t]=i:a==="replace"?r[t]=i:a==="remove"&&n&&(r[t]=null)}var M_=["transition","enterFrom","leaveTo"],p2=M_.concat(["enterAnimation","updateAnimation","leaveAnimation"]);function bo(r,t,e){if(e&&(!r[e]&&t[e]&&(r[e]={}),r=r[e],t=t[e]),!(!r||!t))for(var i=e?M_:p2,n=0;n<i.length;n++){var a=i[n];r[a]==null&&t[a]!=null&&(r[a]=t[a])}}function g2(r,t){if(!!r&&(r.hv=t.hv=[Bp(t,["left","right"]),Bp(t,["top","bottom"])],r.type==="group")){var e=r,i=t;e.width==null&&(e.width=i.width=0),e.height==null&&(e.height=i.height=0)}}var y2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.preventAutoZ=!0,e}return t.prototype.mergeOption=function(e,i){var n=this.option.elements;this.option.elements=null,r.prototype.mergeOption.call(this,e,i),this.option.elements=n},t.prototype.optionUpdated=function(e,i){var n=this.option,a=(i?n:e).elements,o=n.elements=i?[]:n.elements,s=[];this._flatten(a,s,null);var l=Gg(o,s,"normalMerge"),u=this._elOptionsToUpdate=[];A(l,function(f,h){var c=f.newOption;!c||(u.push(c),c2(f,c),d2(o,h,c),g2(o[h],c))},this),n.elements=Ct(o,function(f){return f&&delete f.$action,f!=null})},t.prototype._flatten=function(e,i,n){A(e,function(a){if(!!a){n&&(a.parentOption=n),i.push(a);var o=a.children;o&&o.length&&this._flatten(o,i,a),delete a.children}},this)},t.prototype.useElOptionsToUpdate=function(){var e=this._elOptionsToUpdate;return this._elOptionsToUpdate=null,e},t.type="graphic",t.defaultOption={elements:[]},t}(pt),Np={path:null,compoundPath:null,group:xt,image:nr,text:Dt},he=gt(),m2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(){this._elMap=Z()},t.prototype.render=function(e,i,n){e!==this._lastGraphicModel&&this._clear(),this._lastGraphicModel=e,this._updateElements(e),this._relocate(e,n)},t.prototype._updateElements=function(e){var i=e.useElOptionsToUpdate();if(!!i){var n=this._elMap,a=this.group,o=e.get("z"),s=e.get("zlevel");A(i,function(l){var u=Kt(l.id,null),f=u!=null?n.get(u):null,h=Kt(l.parentId,null),c=h!=null?n.get(h):a,v=l.type,d=l.style;v==="text"&&d&&l.hv&&l.hv[1]&&(d.textVerticalAlign=d.textBaseline=d.verticalAlign=d.align=null);var p=l.textContent,g=l.textConfig;if(d&&CI(d,v,!!g,!!p)){var y=MI(d,v,!0);!g&&y.textConfig&&(g=l.textConfig=y.textConfig),!p&&y.textContent&&(p=y.textContent)}var m=_2(l),_=l.$action||"merge",S=_==="merge",x=_==="replace";if(S){var w=!f,b=f;w?b=zp(u,c,l.type,n):(b&&(he(b).isNew=!1),zI(b)),b&&(_u(b,m,e,{isInit:w}),Fp(b,l,o,s))}else if(x){Ho(f,l,n,e);var T=zp(u,c,l.type,n);T&&(_u(T,m,e,{isInit:!0}),Fp(T,l,o,s))}else _==="remove"&&(m_(f,l),Ho(f,l,n,e));var M=n.get(u);if(M&&p)if(S){var D=M.getTextContent();D?D.attr(p):M.setTextContent(new Dt(p))}else x&&M.setTextContent(new Dt(p));if(M){var C=l.clipPath;if(C){var L=C.type,I=void 0,w=!1;if(S){var P=M.getClipPath();w=!P||he(P).type!==L,I=w?Rf(L):P}else x&&(w=!0,I=Rf(L));M.setClipPath(I),_u(I,C,e,{isInit:w}),If(I,C.keyframeAnimation,e)}var R=he(M);M.setTextConfig(g),R.option=l,S2(M,e,l),Ia({el:M,componentModel:e,itemName:M.name,itemTooltipOption:l.tooltip}),If(M,l.keyframeAnimation,e)}})}},t.prototype._relocate=function(e,i){for(var n=e.option.elements,a=this.group,o=this._elMap,s=i.getWidth(),l=i.getHeight(),u=["x","y"],f=0;f<n.length;f++){var h=n[f],c=Kt(h.id,null),v=c!=null?o.get(c):null;if(!(!v||!v.isGroup)){var d=v.parent,p=d===a,g=he(v),y=he(d);g.width=st(g.option.width,p?s:y.width)||0,g.height=st(g.option.height,p?l:y.height)||0}}for(var f=n.length-1;f>=0;f--){var h=n[f],c=Kt(h.id,null),v=c!=null?o.get(c):null;if(!!v){var d=v.parent,y=he(d),m=d===a?{width:s,height:l}:{width:y.width,height:y.height},_={},S=Zb(v,h,m,null,{hv:h.hv,boundingMode:h.bounding},_);if(!he(v).isNew&&S){for(var x=h.transition,w={},b=0;b<u.length;b++){var T=u[b],M=_[T];x&&(oi(x)||at(x,T)>=0)?w[T]=M:v[T]=M}Lt(v,w,e,0)}else v.attr(_)}}},t.prototype._clear=function(){var e=this,i=this._elMap;i.each(function(n){Ho(n,he(n).option,i,e._lastGraphicModel)}),this._elMap=Z()},t.prototype.dispose=function(){this._clear()},t.type="graphic",t}(Ce);function Rf(r){var t=Q(Np,r)?Np[r]:ky(r),e=new t({});return he(e).type=r,e}function zp(r,t,e,i){var n=Rf(e);return t.add(n),i.set(r,n),he(n).id=r,he(n).isNew=!0,n}function Ho(r,t,e,i){var n=r&&r.parent;n&&(r.type==="group"&&r.traverse(function(a){Ho(a,t,e,i)}),AI(r,t,i),e.removeKey(he(r).id))}function Fp(r,t,e,i){r.isGroup||A([["cursor",yi.prototype.cursor],["zlevel",i||0],["z",e||0],["z2",0]],function(n){var a=n[0];Q(t,a)?r[a]=j(t[a],n[1]):r[a]==null&&(r[a]=n[1])}),A(vt(t),function(n){if(n.indexOf("on")===0){var a=t[n];r[n]=K(a)?a:null}}),Q(t,"draggable")&&(r.draggable=t.draggable),t.name!=null&&(r.name=t.name),t.id!=null&&(r.id=t.id)}function _2(r){return r=O({},r),A(["id","parentId","$action","hv","bounding","textContent","clipPath"].concat(nm),function(t){delete r[t]}),r}function S2(r,t,e){var i=lt(r).eventData;!r.silent&&!r.ignore&&!i&&(i=lt(r).eventData={componentType:"graphic",componentIndex:t.componentIndex,name:r.name}),i&&(i.info=e.info)}function uR(r){r.registerComponentModel(y2),r.registerComponentView(m2),r.registerPreprocessor(function(t){var e=t.graphic;V(e)?!e[0]||!e[0].elements?t.graphic=[{elements:e}]:t.graphic=[t.graphic[0]]:e&&!e.elements&&(t.graphic=[{elements:[e]}])})}var Vp=["x","y","radius","angle","single"],w2=["cartesian2d","polar","singleAxis"];function x2(r){var t=r.get("coordinateSystem");return at(w2,t)>=0}function Tr(r){return r+"Axis"}function b2(r,t){var e=Z(),i=[],n=Z();r.eachComponent({mainType:"dataZoom",query:t},function(f){n.get(f.uid)||s(f)});var a;do a=!1,r.eachComponent("dataZoom",o);while(a);function o(f){!n.get(f.uid)&&l(f)&&(s(f),a=!0)}function s(f){n.set(f.uid,!0),i.push(f),u(f)}function l(f){var h=!1;return f.eachTargetAxis(function(c,v){var d=e.get(c);d&&d[v]&&(h=!0)}),h}function u(f){f.eachTargetAxis(function(h,c){(e.get(h)||e.set(h,[]))[c]=!0})}return i}function A_(r){var t=r.ecModel,e={infoList:[],infoMap:Z()};return r.eachTargetAxis(function(i,n){var a=t.getComponent(Tr(i),n);if(!!a){var o=a.getCoordSysModel();if(!!o){var s=o.uid,l=e.infoMap.get(s);l||(l={model:o,axisModels:[]},e.infoList.push(l),e.infoMap.set(s,l)),l.axisModels.push(a)}}}),e}var xu=function(){function r(){this.indexList=[],this.indexMap=[]}return r.prototype.add=function(t){this.indexMap[t]||(this.indexList.push(t),this.indexMap[t]=!0)},r}(),T2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._autoThrottle=!0,e._noTarget=!0,e._rangePropMode=["percent","percent"],e}return t.prototype.init=function(e,i,n){var a=Hp(e);this.settledOption=a,this.mergeDefaultAndTheme(e,n),this._doInit(a)},t.prototype.mergeOption=function(e){var i=Hp(e);nt(this.option,e,!0),nt(this.settledOption,i,!0),this._doInit(i)},t.prototype._doInit=function(e){var i=this.option;this._setDefaultThrottle(e),this._updateRangeUse(e);var n=this.settledOption;A([["start","startValue"],["end","endValue"]],function(a,o){this._rangePropMode[o]==="value"&&(i[a[0]]=n[a[0]]=null)},this),this._resetTarget()},t.prototype._resetTarget=function(){var e=this.get("orient",!0),i=this._targetAxisInfoMap=Z(),n=this._fillSpecifiedTargetAxis(i);n?this._orient=e||this._makeAutoOrientByTargetAxis():(this._orient=e||"horizontal",this._fillAutoTargetAxisByOrient(i,this._orient)),this._noTarget=!0,i.each(function(a){a.indexList.length&&(this._noTarget=!1)},this)},t.prototype._fillSpecifiedTargetAxis=function(e){var i=!1;return A(Vp,function(n){var a=this.getReferringComponents(Tr(n),aw);if(!!a.specified){i=!0;var o=new xu;A(a.models,function(s){o.add(s.componentIndex)}),e.set(n,o)}},this),i},t.prototype._fillAutoTargetAxisByOrient=function(e,i){var n=this.ecModel,a=!0;if(a){var o=i==="vertical"?"y":"x",s=n.findComponents({mainType:o+"Axis"});l(s,o)}if(a){var s=n.findComponents({mainType:"singleAxis",filter:function(f){return f.get("orient",!0)===i}});l(s,"single")}function l(u,f){var h=u[0];if(!!h){var c=new xu;if(c.add(h.componentIndex),e.set(f,c),a=!1,f==="x"||f==="y"){var v=h.getReferringComponents("grid",Qt).models[0];v&&A(u,function(d){h.componentIndex!==d.componentIndex&&v===d.getReferringComponents("grid",Qt).models[0]&&c.add(d.componentIndex)})}}}a&&A(Vp,function(u){if(!!a){var f=n.findComponents({mainType:Tr(u),filter:function(c){return c.get("type",!0)==="category"}});if(f[0]){var h=new xu;h.add(f[0].componentIndex),e.set(u,h),a=!1}}},this)},t.prototype._makeAutoOrientByTargetAxis=function(){var e;return this.eachTargetAxis(function(i){!e&&(e=i)},this),e==="y"?"vertical":"horizontal"},t.prototype._setDefaultThrottle=function(e){if(e.hasOwnProperty("throttle")&&(this._autoThrottle=!1),this._autoThrottle){var i=this.ecModel.option;this.option.throttle=i.animation&&i.animationDurationUpdate>0?100:20}},t.prototype._updateRangeUse=function(e){var i=this._rangePropMode,n=this.get("rangeMode");A([["start","startValue"],["end","endValue"]],function(a,o){var s=e[a[0]]!=null,l=e[a[1]]!=null;s&&!l?i[o]="percent":!s&&l?i[o]="value":n?i[o]=n[o]:s&&(i[o]="percent")})},t.prototype.noTarget=function(){return this._noTarget},t.prototype.getFirstTargetAxisModel=function(){var e;return this.eachTargetAxis(function(i,n){e==null&&(e=this.ecModel.getComponent(Tr(i),n))},this),e},t.prototype.eachTargetAxis=function(e,i){this._targetAxisInfoMap.each(function(n,a){A(n.indexList,function(o){e.call(i,a,o)})})},t.prototype.getAxisProxy=function(e,i){var n=this.getAxisModel(e,i);if(n)return n.__dzAxisProxy},t.prototype.getAxisModel=function(e,i){var n=this._targetAxisInfoMap.get(e);if(n&&n.indexMap[i])return this.ecModel.getComponent(Tr(e),i)},t.prototype.setRawRange=function(e){var i=this.option,n=this.settledOption;A([["start","startValue"],["end","endValue"]],function(a){(e[a[0]]!=null||e[a[1]]!=null)&&(i[a[0]]=n[a[0]]=e[a[0]],i[a[1]]=n[a[1]]=e[a[1]])},this),this._updateRangeUse(e)},t.prototype.setCalculatedRange=function(e){var i=this.option;A(["start","startValue","end","endValue"],function(n){i[n]=e[n]})},t.prototype.getPercentRange=function(){var e=this.findRepresentativeAxisProxy();if(e)return e.getDataPercentWindow()},t.prototype.getValueRange=function(e,i){if(e==null&&i==null){var n=this.findRepresentativeAxisProxy();if(n)return n.getDataValueWindow()}else return this.getAxisProxy(e,i).getDataValueWindow()},t.prototype.findRepresentativeAxisProxy=function(e){if(e)return e.__dzAxisProxy;for(var i,n=this._targetAxisInfoMap.keys(),a=0;a<n.length;a++)for(var o=n[a],s=this._targetAxisInfoMap.get(o),l=0;l<s.indexList.length;l++){var u=this.getAxisProxy(o,s.indexList[l]);if(u.hostedBy(this))return u;i||(i=u)}return i},t.prototype.getRangePropMode=function(){return this._rangePropMode.slice()},t.prototype.getOrient=function(){return this._orient},t.type="dataZoom",t.dependencies=["xAxis","yAxis","radiusAxis","angleAxis","singleAxis","series","toolbox"],t.defaultOption={z:4,filterMode:"filter",start:0,end:100},t}(pt);function Hp(r){var t={};return A(["start","end","startValue","endValue","throttle"],function(e){r.hasOwnProperty(e)&&(t[e]=r[e])}),t}const _s=T2;var C2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.render=function(e,i,n,a){this.dataZoomModel=e,this.ecModel=i,this.api=n},t.type="dataZoom",t}(Ce);const D_=C2;var Wi=A,Gp=Un,M2=function(){function r(t,e,i,n){this._dimName=t,this._axisIndex=e,this.ecModel=n,this._dataZoomModel=i}return r.prototype.hostedBy=function(t){return this._dataZoomModel===t},r.prototype.getDataValueWindow=function(){return this._valueWindow.slice()},r.prototype.getDataPercentWindow=function(){return this._percentWindow.slice()},r.prototype.getTargetSeriesModels=function(){var t=[];return this.ecModel.eachSeries(function(e){if(x2(e)){var i=Tr(this._dimName),n=e.getReferringComponents(i,Qt).models[0];n&&this._axisIndex===n.componentIndex&&t.push(e)}},this),t},r.prototype.getAxisModel=function(){return this.ecModel.getComponent(this._dimName+"Axis",this._axisIndex)},r.prototype.getMinMaxSpan=function(){return et(this._minMaxSpan)},r.prototype.calculateDataWindow=function(t){var e=this._dataExtent,i=this.getAxisModel(),n=i.axis.scale,a=this._dataZoomModel.getRangePropMode(),o=[0,100],s=[],l=[],u;Wi(["start","end"],function(c,v){var d=t[c],p=t[c+"Value"];a[v]==="percent"?(d==null&&(d=o[v]),p=n.parse(Rt(d,o,e))):(u=!0,p=p==null?e[v]:n.parse(p),d=Rt(p,e,o)),l[v]=p==null||isNaN(p)?e[v]:p,s[v]=d==null||isNaN(d)?o[v]:d}),Gp(l),Gp(s);var f=this._minMaxSpan;u?h(l,s,e,o,!1):h(s,l,o,e,!0);function h(c,v,d,p,g){var y=g?"Span":"ValueSpan";Js(0,c,d,"all",f["min"+y],f["max"+y]);for(var m=0;m<2;m++)v[m]=Rt(c[m],d,p,!0),g&&(v[m]=n.parse(v[m]))}return{valueWindow:l,percentWindow:s}},r.prototype.reset=function(t){if(t===this._dataZoomModel){var e=this.getTargetSeriesModels();this._dataExtent=A2(this,this._dimName,e),this._updateMinMaxSpan();var i=this.calculateDataWindow(t.settledOption);this._valueWindow=i.valueWindow,this._percentWindow=i.percentWindow,this._setAxisModel()}},r.prototype.filterData=function(t,e){if(t!==this._dataZoomModel)return;var i=this._dimName,n=this.getTargetSeriesModels(),a=t.get("filterMode"),o=this._valueWindow;if(a==="none")return;Wi(n,function(l){var u=l.getData(),f=u.mapDimensionsAll(i);if(!!f.length){if(a==="weakFilter"){var h=u.getStore(),c=G(f,function(v){return u.getDimensionIndex(v)},u);u.filterSelf(function(v){for(var d,p,g,y=0;y<f.length;y++){var m=h.get(c[y],v),_=!isNaN(m),S=m<o[0],x=m>o[1];if(_&&!S&&!x)return!0;_&&(g=!0),S&&(d=!0),x&&(p=!0)}return g&&d&&p})}else Wi(f,function(v){if(a==="empty")l.setData(u=u.map(v,function(p){return s(p)?p:NaN}));else{var d={};d[v]=o,u.selectRange(d)}});Wi(f,function(v){u.setApproximateExtent(o,v)})}});function s(l){return l>=o[0]&&l<=o[1]}},r.prototype._updateMinMaxSpan=function(){var t=this._minMaxSpan={},e=this._dataZoomModel,i=this._dataExtent;Wi(["min","max"],function(n){var a=e.get(n+"Span"),o=e.get(n+"ValueSpan");o!=null&&(o=this.getAxisModel().axis.scale.parse(o)),o!=null?a=Rt(i[0]+o,i,[0,100],!0):a!=null&&(o=Rt(a,[0,100],i,!0)-i[0]),t[n+"Span"]=a,t[n+"ValueSpan"]=o},this)},r.prototype._setAxisModel=function(){var t=this.getAxisModel(),e=this._percentWindow,i=this._valueWindow;if(!!e){var n=Bg(i,[0,500]);n=Math.min(n,20);var a=t.axis.scale.rawExtentInfo;e[0]!==0&&a.setDeterminedMinMax("min",+i[0].toFixed(n)),e[1]!==100&&a.setDeterminedMinMax("max",+i[1].toFixed(n)),a.freeze()}},r}();function A2(r,t,e){var i=[1/0,-1/0];Wi(e,function(o){KA(i,o.getData(),t)});var n=r.getAxisModel(),a=P0(n.axis.scale,n,i).calculate();return[a.min,a.max]}const D2=M2;var L2={getTargetSeries:function(r){function t(n){r.eachComponent("dataZoom",function(a){a.eachTargetAxis(function(o,s){var l=r.getComponent(Tr(o),s);n(o,s,l,a)})})}t(function(n,a,o,s){o.__dzAxisProxy=null});var e=[];t(function(n,a,o,s){o.__dzAxisProxy||(o.__dzAxisProxy=new D2(n,a,s,r),e.push(o.__dzAxisProxy))});var i=Z();return A(e,function(n){A(n.getTargetSeriesModels(),function(a){i.set(a.uid,a)})}),i},overallReset:function(r,t){r.eachComponent("dataZoom",function(e){e.eachTargetAxis(function(i,n){e.getAxisProxy(i,n).reset(e)}),e.eachTargetAxis(function(i,n){e.getAxisProxy(i,n).filterData(e,t)})}),r.eachComponent("dataZoom",function(e){var i=e.findRepresentativeAxisProxy();if(i){var n=i.getDataPercentWindow(),a=i.getDataValueWindow();e.setCalculatedRange({start:n[0],end:n[1],startValue:a[0],endValue:a[1]})}})}};const I2=L2;function P2(r){r.registerAction("dataZoom",function(t,e){var i=b2(e,t);A(i,function(n){n.setRawRange({start:t.start,end:t.end,startValue:t.startValue,endValue:t.endValue})})})}var Wp=!1;function L_(r){Wp||(Wp=!0,r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,I2),P2(r),r.registerSubTypeDefaulter("dataZoom",function(){return"slider"}))}function R2(r,t){var e=Gs(t.get("padding")),i=t.getItemStyle(["color","opacity"]);return i.fill=t.get("backgroundColor"),r=new _t({shape:{x:r.x-e[3],y:r.y-e[0],width:r.width+e[1]+e[3],height:r.height+e[0]+e[2],r:t.get("borderRadius")},style:i,silent:!0,z2:-1}),r}var E2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="tooltip",t.dependencies=["axisPointer"],t.defaultOption={z:60,show:!0,showContent:!0,trigger:"item",triggerOn:"mousemove|click",alwaysShowContent:!1,displayMode:"single",renderMode:"auto",confine:null,showDelay:0,hideDelay:100,transitionDuration:.4,enterable:!1,backgroundColor:"#fff",shadowBlur:10,shadowColor:"rgba(0, 0, 0, .2)",shadowOffsetX:1,shadowOffsetY:2,borderRadius:4,borderWidth:1,padding:null,extraCssText:"",axisPointer:{type:"line",axis:"auto",animation:"auto",animationDurationUpdate:200,animationEasingUpdate:"exponentialOut",crossStyle:{color:"#999",width:1,type:"dashed",textStyle:{}}},textStyle:{color:"#666",fontSize:14}},t}(pt);const k2=E2;function I_(r){var t=r.get("confine");return t!=null?!!t:r.get("renderMode")==="richText"}function P_(r){if(!!tt.domSupported){for(var t=document.documentElement.style,e=0,i=r.length;e<i;e++)if(r[e]in t)return r[e]}}var R_=P_(["transform","webkitTransform","OTransform","MozTransform","msTransform"]),O2=P_(["webkitTransition","transition","OTransition","MozTransition","msTransition"]);function E_(r,t){if(!r)return t;t=rm(t,!0);var e=r.indexOf(t);return r=e===-1?t:"-"+r.slice(0,e)+"-"+t,r.toLowerCase()}function B2(r,t){var e=r.currentStyle||document.defaultView&&document.defaultView.getComputedStyle(r);return e?t?e[t]:e:null}var N2=E_(O2,"transition"),Zh=E_(R_,"transform"),z2="position:absolute;display:block;border-style:solid;white-space:nowrap;z-index:9999999;"+(tt.transform3dSupported?"will-change:transform;":"");function F2(r){return r=r==="left"?"right":r==="right"?"left":r==="top"?"bottom":"top",r}function V2(r,t,e){if(!W(e)||e==="inside")return"";var i=r.get("backgroundColor"),n=r.get("borderWidth");t=hi(t);var a=F2(e),o=Math.max(Math.round(n)*1.5,6),s="",l=Zh+":",u;at(["left","right"],a)>-1?(s+="top:50%",l+="translateY(-50%) rotate("+(u=a==="left"?-225:-45)+"deg)"):(s+="left:50%",l+="translateX(-50%) rotate("+(u=a==="top"?225:45)+"deg)");var f=u*Math.PI/180,h=o+n,c=h*Math.abs(Math.cos(f))+h*Math.abs(Math.sin(f)),v=Math.round(((c-Math.SQRT2*n)/2+Math.SQRT2*n-(c-h)/2)*100)/100;s+=";"+a+":-"+v+"px";var d=t+" solid "+n+"px;",p=["position:absolute;width:"+o+"px;height:"+o+"px;z-index:-1;",s+";"+l+";","border-bottom:"+d,"border-right:"+d,"background-color:"+i+";"];return'<div style="'+p.join("")+'"></div>'}function H2(r,t){var e="cubic-bezier(0.23,1,0.32,1)",i=" "+r/2+"s "+e,n="opacity"+i+",visibility"+i;return t||(i=" "+r+"s "+e,n+=tt.transformSupported?","+Zh+i:",left"+i+",top"+i),N2+":"+n}function Up(r,t,e){var i=r.toFixed(0)+"px",n=t.toFixed(0)+"px";if(!tt.transformSupported)return e?"top:"+n+";left:"+i+";":[["top",n],["left",i]];var a=tt.transform3dSupported,o="translate"+(a?"3d":"")+"("+i+","+n+(a?",0":"")+")";return e?"top:0;left:0;"+Zh+":"+o+";":[["top",0],["left",0],[R_,o]]}function G2(r){var t=[],e=r.get("fontSize"),i=r.getTextColor();i&&t.push("color:"+i),t.push("font:"+r.getFont());var n=j(r.get("lineHeight"),Math.round(e*3/2));e&&t.push("line-height:"+n+"px");var a=r.get("textShadowColor"),o=r.get("textShadowBlur")||0,s=r.get("textShadowOffsetX")||0,l=r.get("textShadowOffsetY")||0;return a&&o&&t.push("text-shadow:"+s+"px "+l+"px "+o+"px "+a),A(["decoration","align"],function(u){var f=r.get(u);f&&t.push("text-"+u+":"+f)}),t.join(";")}function W2(r,t,e){var i=[],n=r.get("transitionDuration"),a=r.get("backgroundColor"),o=r.get("shadowBlur"),s=r.get("shadowColor"),l=r.get("shadowOffsetX"),u=r.get("shadowOffsetY"),f=r.getModel("textStyle"),h=Rm(r,"html"),c=l+"px "+u+"px "+o+"px "+s;return i.push("box-shadow:"+c),t&&n&&i.push(H2(n,e)),a&&i.push("background-color:"+a),A(["width","color","radius"],function(v){var d="border-"+v,p=rm(d),g=r.get(p);g!=null&&i.push(d+":"+g+(v==="color"?"":"px"))}),i.push(G2(f)),h!=null&&i.push("padding:"+Gs(h).join("px ")+"px"),i.join(";")+";"}function Yp(r,t,e,i,n){var a=t&&t.painter;if(e){var o=a&&a.getViewportRoot();o&&D1(r,o,e,i,n)}else{r[0]=i,r[1]=n;var s=a&&a.getViewportRootOffset();s&&(r[0]+=s.offsetLeft,r[1]+=s.offsetTop)}r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}var U2=function(){function r(t,e){if(this._show=!1,this._styleCoord=[0,0,0,0],this._enterable=!0,this._alwaysShowContent=!1,this._firstShow=!0,this._longHide=!0,tt.wxa)return null;var i=document.createElement("div");i.domBelongToZr=!0,this.el=i;var n=this._zr=t.getZr(),a=e.appendTo,o=a&&(W(a)?document.querySelector(a):ha(a)?a:K(a)&&a(t.getDom()));Yp(this._styleCoord,n,o,t.getWidth()/2,t.getHeight()/2),(o||t.getDom()).appendChild(i),this._api=t,this._container=o;var s=this;i.onmouseenter=function(){s._enterable&&(clearTimeout(s._hideTimeout),s._show=!0),s._inContent=!0},i.onmousemove=function(l){if(l=l||window.event,!s._enterable){var u=n.handler,f=n.painter.getViewportRoot();le(f,l,!0),u.dispatch("mousemove",l)}},i.onmouseleave=function(){s._inContent=!1,s._enterable&&s._show&&s.hideLater(s._hideDelay)}}return r.prototype.update=function(t){if(!this._container){var e=this._api.getDom(),i=B2(e,"position"),n=e.style;n.position!=="absolute"&&i!=="absolute"&&(n.position="relative")}var a=t.get("alwaysShowContent");a&&this._moveIfResized(),this._alwaysShowContent=a,this.el.className=t.get("className")||""},r.prototype.show=function(t,e){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var i=this.el,n=i.style,a=this._styleCoord;i.innerHTML?n.cssText=z2+W2(t,!this._firstShow,this._longHide)+Up(a[0],a[1],!0)+("border-color:"+hi(e)+";")+(t.get("extraCssText")||"")+(";pointer-events:"+(this._enterable?"auto":"none")):n.display="none",this._show=!0,this._firstShow=!1,this._longHide=!1},r.prototype.setContent=function(t,e,i,n,a){var o=this.el;if(t==null){o.innerHTML="";return}var s="";if(W(a)&&i.get("trigger")==="item"&&!I_(i)&&(s=V2(i,n,a)),W(t))o.innerHTML=t+s;else if(t){o.innerHTML="",V(t)||(t=[t]);for(var l=0;l<t.length;l++)ha(t[l])&&t[l].parentNode!==o&&o.appendChild(t[l]);if(s&&o.childNodes.length){var u=document.createElement("div");u.innerHTML=s,o.appendChild(u)}}},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el;return t?[t.offsetWidth,t.offsetHeight]:[0,0]},r.prototype.moveTo=function(t,e){if(!!this.el){var i=this._styleCoord;if(Yp(i,this._zr,this._container,t,e),i[0]!=null&&i[1]!=null){var n=this.el.style,a=Up(i[0],i[1]);A(a,function(o){n[o[0]]=o[1]})}}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){var t=this,e=this.el.style;e.visibility="hidden",e.opacity="0",tt.transform3dSupported&&(e.willChange=""),this._show=!1,this._longHideTimeout=setTimeout(function(){return t._longHide=!0},500)},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout($(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){clearTimeout(this._hideTimeout),clearTimeout(this._longHideTimeout);var t=this.el.parentNode;t&&t.removeChild(this.el),this.el=this._container=null},r}();const Y2=U2;var $2=function(){function r(t){this._show=!1,this._styleCoord=[0,0,0,0],this._alwaysShowContent=!1,this._enterable=!0,this._zr=t.getZr(),Zp(this._styleCoord,this._zr,t.getWidth()/2,t.getHeight()/2)}return r.prototype.update=function(t){var e=t.get("alwaysShowContent");e&&this._moveIfResized(),this._alwaysShowContent=e},r.prototype.show=function(){this._hideTimeout&&clearTimeout(this._hideTimeout),this.el.show(),this._show=!0},r.prototype.setContent=function(t,e,i,n,a){var o=this;Y(t)&&Xt(""),this.el&&this._zr.remove(this.el);var s=i.getModel("textStyle");this.el=new Dt({style:{rich:e.richTextStyles,text:t,lineHeight:22,borderWidth:1,borderColor:n,textShadowColor:s.get("textShadowColor"),fill:i.get(["textStyle","color"]),padding:Rm(i,"richText"),verticalAlign:"top",align:"left"},z:i.get("z")}),A(["backgroundColor","borderRadius","shadowColor","shadowBlur","shadowOffsetX","shadowOffsetY"],function(u){o.el.style[u]=i.get(u)}),A(["textShadowBlur","textShadowOffsetX","textShadowOffsetY"],function(u){o.el.style[u]=s.get(u)||0}),this._zr.add(this.el);var l=this;this.el.on("mouseover",function(){l._enterable&&(clearTimeout(l._hideTimeout),l._show=!0),l._inContent=!0}),this.el.on("mouseout",function(){l._enterable&&l._show&&l.hideLater(l._hideDelay),l._inContent=!1})},r.prototype.setEnterable=function(t){this._enterable=t},r.prototype.getSize=function(){var t=this.el,e=this.el.getBoundingRect(),i=$p(t.style);return[e.width+i.left+i.right,e.height+i.top+i.bottom]},r.prototype.moveTo=function(t,e){var i=this.el;if(i){var n=this._styleCoord;Zp(n,this._zr,t,e),t=n[0],e=n[1];var a=i.style,o=_r(a.borderWidth||0),s=$p(a);i.x=t+o+s.left,i.y=e+o+s.top,i.markRedraw()}},r.prototype._moveIfResized=function(){var t=this._styleCoord[2],e=this._styleCoord[3];this.moveTo(t*this._zr.getWidth(),e*this._zr.getHeight())},r.prototype.hide=function(){this.el&&this.el.hide(),this._show=!1},r.prototype.hideLater=function(t){this._show&&!(this._inContent&&this._enterable)&&!this._alwaysShowContent&&(t?(this._hideDelay=t,this._show=!1,this._hideTimeout=setTimeout($(this.hide,this),t)):this.hide())},r.prototype.isShow=function(){return this._show},r.prototype.dispose=function(){this._zr.remove(this.el)},r}();function _r(r){return Math.max(0,r)}function $p(r){var t=_r(r.shadowBlur||0),e=_r(r.shadowOffsetX||0),i=_r(r.shadowOffsetY||0);return{left:_r(t-e),right:_r(t+e),top:_r(t-i),bottom:_r(t+i)}}function Zp(r,t,e,i){r[0]=e,r[1]=i,r[2]=r[0]/t.getWidth(),r[3]=r[1]/t.getHeight()}const Z2=$2;var X2=new _t({shape:{x:-1,y:-1,width:2,height:2}}),q2=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.init=function(e,i){if(!(tt.node||!i.getDom())){var n=e.getComponent("tooltip"),a=this._renderMode=sw(n.get("renderMode"));this._tooltipContent=a==="richText"?new Z2(i):new Y2(i,{appendTo:n.get("appendToBody",!0)?"body":n.get("appendTo",!0)})}},t.prototype.render=function(e,i,n){if(!(tt.node||!n.getDom())){this.group.removeAll(),this._tooltipModel=e,this._ecModel=i,this._api=n;var a=this._tooltipContent;a.update(e),a.setEnterable(e.get("enterable")),this._initGlobalListener(),this._keepShow(),this._renderMode!=="richText"&&e.get("transitionDuration")?Zs(this,"_updatePosition",50,"fixRate"):fs(this,"_updatePosition")}},t.prototype._initGlobalListener=function(){var e=this._tooltipModel,i=e.get("triggerOn");b_("itemTooltip",this._api,$(function(n,a,o){i!=="none"&&(i.indexOf(n)>=0?this._tryShow(a,o):n==="leave"&&this._hide(o))},this))},t.prototype._keepShow=function(){var e=this._tooltipModel,i=this._ecModel,n=this._api,a=e.get("triggerOn");if(this._lastX!=null&&this._lastY!=null&&a!=="none"&&a!=="click"){var o=this;clearTimeout(this._refreshUpdateTimeout),this._refreshUpdateTimeout=setTimeout(function(){!n.isDisposed()&&o.manuallyShowTip(e,i,n,{x:o._lastX,y:o._lastY,dataByCoordSys:o._lastDataByCoordSys})})}},t.prototype.manuallyShowTip=function(e,i,n,a){if(!(a.from===this.uid||tt.node||!n.getDom())){var o=Xp(a,n);this._ticket="";var s=a.dataByCoordSys,l=j2(a,i,n);if(l){var u=l.el.getBoundingRect().clone();u.applyTransform(l.el.transform),this._tryShow({offsetX:u.x+u.width/2,offsetY:u.y+u.height/2,target:l.el,position:a.position,positionDefault:"bottom"},o)}else if(a.tooltip&&a.x!=null&&a.y!=null){var f=X2;f.x=a.x,f.y=a.y,f.update(),lt(f).tooltipConfig={name:null,option:a.tooltip},this._tryShow({offsetX:a.x,offsetY:a.y,target:f},o)}else if(s)this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,dataByCoordSys:s,tooltipOption:a.tooltipOption},o);else if(a.seriesIndex!=null){if(this._manuallyAxisShowTip(e,i,n,a))return;var h=T_(a,i),c=h.point[0],v=h.point[1];c!=null&&v!=null&&this._tryShow({offsetX:c,offsetY:v,target:h.el,position:a.position,positionDefault:"bottom"},o)}else a.x!=null&&a.y!=null&&(n.dispatchAction({type:"updateAxisPointer",x:a.x,y:a.y}),this._tryShow({offsetX:a.x,offsetY:a.y,position:a.position,target:n.getZr().findHover(a.x,a.y).target},o))}},t.prototype.manuallyHideTip=function(e,i,n,a){var o=this._tooltipContent;this._tooltipModel&&o.hideLater(this._tooltipModel.get("hideDelay")),this._lastX=this._lastY=this._lastDataByCoordSys=null,a.from!==this.uid&&this._hide(Xp(a,n))},t.prototype._manuallyAxisShowTip=function(e,i,n,a){var o=a.seriesIndex,s=a.dataIndex,l=i.getComponent("axisPointer").coordSysAxesInfo;if(!(o==null||s==null||l==null)){var u=i.getSeriesByIndex(o);if(!!u){var f=u.getData(),h=On([f.getItemModel(s),u,(u.coordinateSystem||{}).model],this._tooltipModel);if(h.get("trigger")==="axis")return n.dispatchAction({type:"updateAxisPointer",seriesIndex:o,dataIndex:s,position:a.position}),!0}}},t.prototype._tryShow=function(e,i){var n=e.target,a=this._tooltipModel;if(!!a){this._lastX=e.offsetX,this._lastY=e.offsetY;var o=e.dataByCoordSys;if(o&&o.length)this._showAxisTooltip(o,e);else if(n){var s=lt(n);if(s.ssrType==="legend")return;this._lastDataByCoordSys=null;var l,u;Xn(n,function(f){if(lt(f).dataIndex!=null)return l=f,!0;if(lt(f).tooltipConfig!=null)return u=f,!0},!0),l?this._showSeriesItemTooltip(e,l,i):u?this._showComponentItemTooltip(e,u,i):this._hide(i)}else this._lastDataByCoordSys=null,this._hide(i)}},t.prototype._showOrMove=function(e,i){var n=e.get("showDelay");i=$(i,this),clearTimeout(this._showTimout),n>0?this._showTimout=setTimeout(i,n):i()},t.prototype._showAxisTooltip=function(e,i){var n=this._ecModel,a=this._tooltipModel,o=[i.offsetX,i.offsetY],s=On([i.tooltipOption],a),l=this._renderMode,u=[],f=di("section",{blocks:[],noHeader:!0}),h=[],c=new Xl;A(e,function(m){A(m.dataByAxis,function(_){var S=n.getComponent(_.axisDim+"Axis",_.axisIndex),x=_.value;if(!(!S||x==null)){var w=w_(x,S.axis,n,_.seriesDataIndices,_.valueLabelOpt),b=di("section",{header:w,noHeader:!Fe(w),sortBlocks:!0,blocks:[]});f.blocks.push(b),A(_.seriesDataIndices,function(T){var M=n.getSeriesByIndex(T.seriesIndex),D=T.dataIndexInside,C=M.getDataParams(D);if(!(C.dataIndex<0)){C.axisDim=_.axisDim,C.axisIndex=_.axisIndex,C.axisType=_.axisType,C.axisId=_.axisId,C.axisValue=zh(S.axis,{value:x}),C.axisValueLabel=w,C.marker=c.makeTooltipMarker("item",hi(C.color),l);var L=Wc(M.formatTooltip(D,!0,null)),I=L.frag;if(I){var P=On([M],a).get("valueFormatter");b.blocks.push(P?O({valueFormatter:P},I):I)}L.text&&h.push(L.text),u.push(C)}})}})}),f.blocks.reverse(),h.reverse();var v=i.position,d=s.get("order"),p=Xc(f,c,l,d,n.get("useUTC"),s.get("textStyle"));p&&h.unshift(p);var g=l==="richText"?`

`:"<br/>",y=h.join(g);this._showOrMove(s,function(){this._updateContentNotChangedOnAxis(e,u)?this._updatePosition(s,v,o[0],o[1],this._tooltipContent,u):this._showTooltipContent(s,y,u,Math.random()+"",o[0],o[1],v,null,c)})},t.prototype._showSeriesItemTooltip=function(e,i,n){var a=this._ecModel,o=lt(i),s=o.seriesIndex,l=a.getSeriesByIndex(s),u=o.dataModel||l,f=o.dataIndex,h=o.dataType,c=u.getData(h),v=this._renderMode,d=e.positionDefault,p=On([c.getItemModel(f),u,l&&(l.coordinateSystem||{}).model],this._tooltipModel,d?{position:d}:null),g=p.get("trigger");if(!(g!=null&&g!=="item")){var y=u.getDataParams(f,h),m=new Xl;y.marker=m.makeTooltipMarker("item",hi(y.color),v);var _=Wc(u.formatTooltip(f,!1,h)),S=p.get("order"),x=p.get("valueFormatter"),w=_.frag,b=w?Xc(x?O({valueFormatter:x},w):w,m,v,S,a.get("useUTC"),p.get("textStyle")):_.text,T="item_"+u.name+"_"+f;this._showOrMove(p,function(){this._showTooltipContent(p,b,y,T,e.offsetX,e.offsetY,e.position,e.target,m)}),n({type:"showTip",dataIndexInside:f,dataIndex:c.getRawIndex(f),seriesIndex:s,from:this.uid})}},t.prototype._showComponentItemTooltip=function(e,i,n){var a=this._renderMode==="html",o=lt(i),s=o.tooltipConfig,l=s.option||{},u=l.encodeHTMLContent;if(W(l)){var f=l;l={content:f,formatter:f},u=!0}u&&a&&l.content&&(l=et(l),l.content=Zt(l.content));var h=[l],c=this._ecModel.getComponent(o.componentMainType,o.componentIndex);c&&h.push(c),h.push({formatter:l.content});var v=e.positionDefault,d=On(h,this._tooltipModel,v?{position:v}:null),p=d.get("content"),g=Math.random()+"",y=new Xl;this._showOrMove(d,function(){var m=et(d.get("formatterParams")||{});this._showTooltipContent(d,p,m,g,e.offsetX,e.offsetY,e.position,i,y)}),n({type:"showTip",from:this.uid})},t.prototype._showTooltipContent=function(e,i,n,a,o,s,l,u,f){if(this._ticket="",!(!e.get("showContent")||!e.get("show"))){var h=this._tooltipContent;h.setEnterable(e.get("enterable"));var c=e.get("formatter");l=l||e.get("position");var v=i,d=this._getNearestPoint([o,s],n,e.get("trigger"),e.get("borderColor")),p=d.color;if(c)if(W(c)){var g=e.ecModel.get("useUTC"),y=V(n)?n[0]:n,m=y&&y.axisType&&y.axisType.indexOf("time")>=0;v=c,m&&(v=Ns(y.axisValue,v,g)),v=im(v,n,!0)}else if(K(c)){var _=$(function(S,x){S===this._ticket&&(h.setContent(x,f,e,p,l),this._updatePosition(e,l,o,s,h,n,u))},this);this._ticket=a,v=c(n,a,_)}else v=c;h.setContent(v,f,e,p,l),h.show(e,p),this._updatePosition(e,l,o,s,h,n,u)}},t.prototype._getNearestPoint=function(e,i,n,a){if(n==="axis"||V(i))return{color:a||(this._renderMode==="html"?"#fff":"none")};if(!V(i))return{color:a||i.color||i.borderColor}},t.prototype._updatePosition=function(e,i,n,a,o,s,l){var u=this._api.getWidth(),f=this._api.getHeight();i=i||e.get("position");var h=o.getSize(),c=e.get("align"),v=e.get("verticalAlign"),d=l&&l.getBoundingRect().clone();if(l&&d.applyTransform(l.transform),K(i)&&(i=i([n,a],s,o.el,d,{viewSize:[u,f],contentSize:h.slice()})),V(i))n=st(i[0],u),a=st(i[1],f);else if(Y(i)){var p=i;p.width=h[0],p.height=h[1];var g=vi(p,{width:u,height:f});n=g.x,a=g.y,c=null,v=null}else if(W(i)&&l){var y=J2(i,d,h,e.get("borderWidth"));n=y[0],a=y[1]}else{var y=K2(n,a,o,u,f,c?null:20,v?null:20);n=y[0],a=y[1]}if(c&&(n-=qp(c)?h[0]/2:c==="right"?h[0]:0),v&&(a-=qp(v)?h[1]/2:v==="bottom"?h[1]:0),I_(e)){var y=Q2(n,a,o,u,f);n=y[0],a=y[1]}o.moveTo(n,a)},t.prototype._updateContentNotChangedOnAxis=function(e,i){var n=this._lastDataByCoordSys,a=this._cbParamsList,o=!!n&&n.length===e.length;return o&&A(n,function(s,l){var u=s.dataByAxis||[],f=e[l]||{},h=f.dataByAxis||[];o=o&&u.length===h.length,o&&A(u,function(c,v){var d=h[v]||{},p=c.seriesDataIndices||[],g=d.seriesDataIndices||[];o=o&&c.value===d.value&&c.axisType===d.axisType&&c.axisId===d.axisId&&p.length===g.length,o&&A(p,function(y,m){var _=g[m];o=o&&y.seriesIndex===_.seriesIndex&&y.dataIndex===_.dataIndex}),a&&A(c.seriesDataIndices,function(y){var m=y.seriesIndex,_=i[m],S=a[m];_&&S&&S.data!==_.data&&(o=!1)})})}),this._lastDataByCoordSys=e,this._cbParamsList=i,!!o},t.prototype._hide=function(e){this._lastDataByCoordSys=null,e({type:"hideTip",from:this.uid})},t.prototype.dispose=function(e,i){tt.node||!i.getDom()||(fs(this,"_updatePosition"),this._tooltipContent.dispose(),Pf("itemTooltip",i))},t.type="tooltip",t}(Ce);function On(r,t,e){var i=t.ecModel,n;e?(n=new kt(e,i,i),n=new kt(t.option,n,i)):n=t;for(var a=r.length-1;a>=0;a--){var o=r[a];o&&(o instanceof kt&&(o=o.get("tooltip",!0)),W(o)&&(o={formatter:o}),o&&(n=new kt(o,n,i)))}return n}function Xp(r,t){return r.dispatchAction||$(t.dispatchAction,t)}function K2(r,t,e,i,n,a,o){var s=e.getSize(),l=s[0],u=s[1];return a!=null&&(r+l+a+2>i?r-=l+a:r+=a),o!=null&&(t+u+o>n?t-=u+o:t+=o),[r,t]}function Q2(r,t,e,i,n){var a=e.getSize(),o=a[0],s=a[1];return r=Math.min(r+o,i)-o,t=Math.min(t+s,n)-s,r=Math.max(r,0),t=Math.max(t,0),[r,t]}function J2(r,t,e,i){var n=e[0],a=e[1],o=Math.ceil(Math.SQRT2*i)+8,s=0,l=0,u=t.width,f=t.height;switch(r){case"inside":s=t.x+u/2-n/2,l=t.y+f/2-a/2;break;case"top":s=t.x+u/2-n/2,l=t.y-a-o;break;case"bottom":s=t.x+u/2-n/2,l=t.y+f+o;break;case"left":s=t.x-n-o,l=t.y+f/2-a/2;break;case"right":s=t.x+u+o,l=t.y+f/2-a/2}return[s,l]}function qp(r){return r==="center"||r==="middle"}function j2(r,t,e){var i=eh(r).queryOptionMap,n=i.keys()[0];if(!(!n||n==="series")){var a=Da(t,n,i.get(n),{useDefault:!1,enableAll:!1,enableNone:!1}),o=a.models[0];if(!!o){var s=e.getViewOfComponentModel(o),l;if(s.group.traverse(function(u){var f=lt(u).tooltipConfig;if(f&&f.name===r.name)return l=u,!0}),l)return{componentMainType:n,componentIndex:o.componentIndex,el:l}}}}const tP=q2;function fR(r){Ge(C_),r.registerComponentModel(k2),r.registerComponentView(tP),r.registerAction({type:"showTip",event:"showTip",update:"tooltip:manuallyShowTip"},Gt),r.registerAction({type:"hideTip",event:"hideTip",update:"tooltip:manuallyHideTip"},Gt)}var eP=function(r,t){if(t==="all")return{type:"all",title:r.getLocaleModel().get(["legend","selector","all"])};if(t==="inverse")return{type:"inverse",title:r.getLocaleModel().get(["legend","selector","inverse"])}},rP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.layoutMode={type:"box",ignoreSize:!0},e}return t.prototype.init=function(e,i,n){this.mergeDefaultAndTheme(e,n),e.selected=e.selected||{},this._updateSelector(e)},t.prototype.mergeOption=function(e,i){r.prototype.mergeOption.call(this,e,i),this._updateSelector(e)},t.prototype._updateSelector=function(e){var i=e.selector,n=this.ecModel;i===!0&&(i=e.selector=["all","inverse"]),V(i)&&A(i,function(a,o){W(a)&&(a={type:a}),i[o]=nt(a,eP(n,a.type))})},t.prototype.optionUpdated=function(){this._updateData(this.ecModel);var e=this._data;if(e[0]&&this.get("selectedMode")==="single"){for(var i=!1,n=0;n<e.length;n++){var a=e[n].get("name");if(this.isSelected(a)){this.select(a),i=!0;break}}!i&&this.select(e[0].get("name"))}},t.prototype._updateData=function(e){var i=[],n=[];e.eachRawSeries(function(l){var u=l.name;n.push(u);var f;if(l.legendVisualProvider){var h=l.legendVisualProvider,c=h.getAllNames();e.isSeriesFiltered(l)||(n=n.concat(c)),c.length?i=i.concat(c):f=!0}else f=!0;f&&th(l)&&i.push(l.name)}),this._availableNames=n;var a=this.get("data")||i,o=Z(),s=G(a,function(l){return(W(l)||dt(l))&&(l={name:l}),o.get(l.name)?null:(o.set(l.name,!0),new kt(l,this,this.ecModel))},this);this._data=Ct(s,function(l){return!!l})},t.prototype.getData=function(){return this._data},t.prototype.select=function(e){var i=this.option.selected,n=this.get("selectedMode");if(n==="single"){var a=this._data;A(a,function(o){i[o.get("name")]=!1})}i[e]=!0},t.prototype.unSelect=function(e){this.get("selectedMode")!=="single"&&(this.option.selected[e]=!1)},t.prototype.toggleSelected=function(e){var i=this.option.selected;i.hasOwnProperty(e)||(i[e]=!0),this[i[e]?"unSelect":"select"](e)},t.prototype.allSelect=function(){var e=this._data,i=this.option.selected;A(e,function(n){i[n.get("name",!0)]=!0})},t.prototype.inverseSelect=function(){var e=this._data,i=this.option.selected;A(e,function(n){var a=n.get("name",!0);i.hasOwnProperty(a)||(i[a]=!0),i[a]=!i[a]})},t.prototype.isSelected=function(e){var i=this.option.selected;return!(i.hasOwnProperty(e)&&!i[e])&&at(this._availableNames,e)>=0},t.prototype.getOrient=function(){return this.get("orient")==="vertical"?{index:1,name:"vertical"}:{index:0,name:"horizontal"}},t.type="legend.plain",t.dependencies=["series"],t.defaultOption={z:4,show:!0,orient:"horizontal",left:"center",top:0,align:"auto",backgroundColor:"rgba(0,0,0,0)",borderColor:"#ccc",borderRadius:0,borderWidth:0,padding:5,itemGap:10,itemWidth:25,itemHeight:14,symbolRotate:"inherit",symbolKeepAspect:!0,inactiveColor:"#ccc",inactiveBorderColor:"#ccc",inactiveBorderWidth:"auto",itemStyle:{color:"inherit",opacity:"inherit",borderColor:"inherit",borderWidth:"auto",borderCap:"inherit",borderJoin:"inherit",borderDashOffset:"inherit",borderMiterLimit:"inherit"},lineStyle:{width:"auto",color:"inherit",inactiveColor:"#ccc",inactiveWidth:2,opacity:"inherit",type:"inherit",cap:"inherit",join:"inherit",dashOffset:"inherit",miterLimit:"inherit"},textStyle:{color:"#333"},selectedMode:!0,selector:!1,selectorLabel:{show:!0,borderRadius:10,padding:[3,5,3,5],fontSize:12,fontFamily:"sans-serif",color:"#666",borderWidth:1,borderColor:"#666"},emphasis:{selectorLabel:{show:!0,color:"#eee",backgroundColor:"#666"}},selectorPosition:"auto",selectorItemGap:7,selectorButtonGap:10,tooltip:{show:!1}},t}(pt);const Ef=rP;var Vi=yt,kf=A,To=xt,iP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.newlineDisabled=!1,e}return t.prototype.init=function(){this.group.add(this._contentGroup=new To),this.group.add(this._selectorGroup=new To),this._isFirstRender=!0},t.prototype.getContentGroup=function(){return this._contentGroup},t.prototype.getSelectorGroup=function(){return this._selectorGroup},t.prototype.render=function(e,i,n){var a=this._isFirstRender;if(this._isFirstRender=!1,this.resetInner(),!!e.get("show",!0)){var o=e.get("align"),s=e.get("orient");(!o||o==="auto")&&(o=e.get("left")==="right"&&s==="vertical"?"right":"left");var l=e.get("selector",!0),u=e.get("selectorPosition",!0);l&&(!u||u==="auto")&&(u=s==="horizontal"?"end":"start"),this.renderInner(o,e,i,n,l,s,u);var f=e.getBoxLayoutParams(),h={width:n.getWidth(),height:n.getHeight()},c=e.get("padding"),v=vi(f,h,c),d=this.layoutInner(e,o,v,a,l,u),p=vi(rt({width:d.width,height:d.height},f),h,c);this.group.x=p.x-d.x,this.group.y=p.y-d.y,this.group.markRedraw(),this.group.add(this._backgroundEl=R2(d,e))}},t.prototype.resetInner=function(){this.getContentGroup().removeAll(),this._backgroundEl&&this.group.remove(this._backgroundEl),this.getSelectorGroup().removeAll()},t.prototype.renderInner=function(e,i,n,a,o,s,l){var u=this.getContentGroup(),f=Z(),h=i.get("selectedMode"),c=[];n.eachRawSeries(function(v){!v.get("legendHoverLink")&&c.push(v.id)}),kf(i.getData(),function(v,d){var p=v.get("name");if(!this.newlineDisabled&&(p===""||p===`
`)){var g=new To;g.newline=!0,u.add(g);return}var y=n.getSeriesByName(p)[0];if(!f.get(p))if(y){var m=y.getData(),_=m.getVisual("legendLineStyle")||{},S=m.getVisual("legendIcon"),x=m.getVisual("style"),w=this._createItem(y,p,d,v,i,e,_,x,S,h,a);w.on("click",Vi(Kp,p,null,a,c)).on("mouseover",Vi(Of,y.name,null,a,c)).on("mouseout",Vi(Bf,y.name,null,a,c)),n.ssr&&w.eachChild(function(b){var T=lt(b);T.seriesIndex=y.seriesIndex,T.dataIndex=d,T.ssrType="legend"}),f.set(p,!0)}else n.eachRawSeries(function(b){if(!f.get(p)&&b.legendVisualProvider){var T=b.legendVisualProvider;if(!T.containName(p))return;var M=T.indexOfName(p),D=T.getItemVisual(M,"style"),C=T.getItemVisual(M,"legendIcon"),L=Qe(D.fill);L&&L[3]===0&&(L[3]=.2,D=O(O({},D),{fill:Ts(L,"rgba")}));var I=this._createItem(b,p,d,v,i,e,{},D,C,h,a);I.on("click",Vi(Kp,null,p,a,c)).on("mouseover",Vi(Of,null,p,a,c)).on("mouseout",Vi(Bf,null,p,a,c)),n.ssr&&I.eachChild(function(P){var R=lt(P);R.seriesIndex=b.seriesIndex,R.dataIndex=d,R.ssrType="legend"}),f.set(p,!0)}},this)},this),o&&this._createSelector(o,i,a,s,l)},t.prototype._createSelector=function(e,i,n,a,o){var s=this.getSelectorGroup();kf(e,function(u){var f=u.type,h=new Dt({style:{x:0,y:0,align:"center",verticalAlign:"middle"},onclick:function(){n.dispatchAction({type:f==="all"?"legendAllSelect":"legendInverseSelect",legendId:i.id})}});s.add(h);var c=i.getModel("selectorLabel"),v=i.getModel(["emphasis","selectorLabel"]);un(h,{normal:c,emphasis:v},{defaultText:u.title}),rs(h)})},t.prototype._createItem=function(e,i,n,a,o,s,l,u,f,h,c){var v=e.visualDrawType,d=o.get("itemWidth"),p=o.get("itemHeight"),g=o.isSelected(i),y=a.get("symbolRotate"),m=a.get("symbolKeepAspect"),_=a.get("icon");f=_||f||"roundRect";var S=nP(f,a,l,u,v,g,c),x=new To,w=a.getModel("textStyle");if(K(e.getLegendIcon)&&(!_||_==="inherit"))x.add(e.getLegendIcon({itemWidth:d,itemHeight:p,icon:f,iconRotate:y,itemStyle:S.itemStyle,lineStyle:S.lineStyle,symbolKeepAspect:m}));else{var b=_==="inherit"&&e.getData().getVisual("symbol")?y==="inherit"?e.getData().getVisual("symbolRotate"):y:0;x.add(aP({itemWidth:d,itemHeight:p,icon:f,iconRotate:b,itemStyle:S.itemStyle,lineStyle:S.lineStyle,symbolKeepAspect:m}))}var T=s==="left"?d+5:-5,M=s,D=o.get("formatter"),C=i;W(D)&&D?C=D.replace("{name}",i!=null?i:""):K(D)&&(C=D(i));var L=g?w.getTextColor():a.get("inactiveColor");x.add(new Dt({style:fi(w,{text:C,x:T,y:p/2,fill:L,align:M,verticalAlign:"middle"},{inheritColor:L})}));var I=new _t({shape:x.getBoundingRect(),style:{fill:"transparent"}}),P=a.getModel("tooltip");return P.get("show")&&Ia({el:I,componentModel:o,itemName:i,itemTooltipOption:P.option}),x.add(I),x.eachChild(function(R){R.silent=!0}),I.silent=!h,this.getContentGroup().add(x),rs(x),x.__legendDataIndex=n,x},t.prototype.layoutInner=function(e,i,n,a,o,s){var l=this.getContentGroup(),u=this.getSelectorGroup();oa(e.get("orient"),l,e.get("itemGap"),n.width,n.height);var f=l.getBoundingRect(),h=[-f.x,-f.y];if(u.markRedraw(),l.markRedraw(),o){oa("horizontal",u,e.get("selectorItemGap",!0));var c=u.getBoundingRect(),v=[-c.x,-c.y],d=e.get("selectorButtonGap",!0),p=e.getOrient().index,g=p===0?"width":"height",y=p===0?"height":"width",m=p===0?"y":"x";s==="end"?v[p]+=f[g]+d:h[p]+=c[g]+d,v[1-p]+=f[y]/2-c[y]/2,u.x=v[0],u.y=v[1],l.x=h[0],l.y=h[1];var _={x:0,y:0};return _[g]=f[g]+d+c[g],_[y]=Math.max(f[y],c[y]),_[m]=Math.min(0,c[m]+v[1-p]),_}else return l.x=h[0],l.y=h[1],this.group.getBoundingRect()},t.prototype.remove=function(){this.getContentGroup().removeAll(),this._isFirstRender=!0},t.type="legend.plain",t}(Ce);function nP(r,t,e,i,n,a,o){function s(g,y){g.lineWidth==="auto"&&(g.lineWidth=y.lineWidth>0?2:0),kf(g,function(m,_){g[_]==="inherit"&&(g[_]=y[_])})}var l=t.getModel("itemStyle"),u=l.getItemStyle(),f=r.lastIndexOf("empty",0)===0?"fill":"stroke",h=l.getShallow("decal");u.decal=!h||h==="inherit"?i.decal:mf(h,o),u.fill==="inherit"&&(u.fill=i[n]),u.stroke==="inherit"&&(u.stroke=i[f]),u.opacity==="inherit"&&(u.opacity=(n==="fill"?i:e).opacity),s(u,i);var c=t.getModel("lineStyle"),v=c.getLineStyle();if(s(v,e),u.fill==="auto"&&(u.fill=i.fill),u.stroke==="auto"&&(u.stroke=i.fill),v.stroke==="auto"&&(v.stroke=i.fill),!a){var d=t.get("inactiveBorderWidth"),p=u[f];u.lineWidth=d==="auto"?i.lineWidth>0&&p?2:0:u.lineWidth,u.fill=t.get("inactiveColor"),u.stroke=t.get("inactiveBorderColor"),v.stroke=c.get("inactiveColor"),v.lineWidth=c.get("inactiveWidth")}return{itemStyle:u,lineStyle:v}}function aP(r){var t=r.icon||"roundRect",e=ir(t,0,0,r.itemWidth,r.itemHeight,r.itemStyle.fill,r.symbolKeepAspect);return e.setStyle(r.itemStyle),e.rotation=(r.iconRotate||0)*Math.PI/180,e.setOrigin([r.itemWidth/2,r.itemHeight/2]),t.indexOf("empty")>-1&&(e.style.stroke=e.style.fill,e.style.fill="#fff",e.style.lineWidth=2),e}function Kp(r,t,e,i){Bf(r,t,e,i),e.dispatchAction({type:"legendToggleSelect",name:r!=null?r:t}),Of(r,t,e,i)}function k_(r){for(var t=r.getZr().storage.getDisplayList(),e,i=0,n=t.length;i<n&&!(e=t[i].states.emphasis);)i++;return e&&e.hoverLayer}function Of(r,t,e,i){k_(e)||e.dispatchAction({type:"highlight",seriesName:r,name:t,excludeSeriesId:i})}function Bf(r,t,e,i){k_(e)||e.dispatchAction({type:"downplay",seriesName:r,name:t,excludeSeriesId:i})}const O_=iP;function oP(r){var t=r.findComponents({mainType:"legend"});t&&t.length&&r.filterSeries(function(e){for(var i=0;i<t.length;i++)if(!t[i].isSelected(e.name))return!1;return!0})}function Bn(r,t,e){var i=r==="allSelect"||r==="inverseSelect",n={},a=[];e.eachComponent({mainType:"legend",query:t},function(s){i?s[r]():s[r](t.name),Qp(s,n),a.push(s.componentIndex)});var o={};return e.eachComponent("legend",function(s){A(n,function(l,u){s[l?"select":"unSelect"](u)}),Qp(s,o)}),i?{selected:o,legendIndex:a}:{name:t.name,selected:o}}function Qp(r,t){var e=t||{};return A(r.getData(),function(i){var n=i.get("name");if(!(n===`
`||n==="")){var a=r.isSelected(n);Q(e,n)?e[n]=e[n]&&a:e[n]=a}}),e}function sP(r){r.registerAction("legendToggleSelect","legendselectchanged",yt(Bn,"toggleSelected")),r.registerAction("legendAllSelect","legendselectall",yt(Bn,"allSelect")),r.registerAction("legendInverseSelect","legendinverseselect",yt(Bn,"inverseSelect")),r.registerAction("legendSelect","legendselected",yt(Bn,"select")),r.registerAction("legendUnSelect","legendunselected",yt(Bn,"unSelect"))}function B_(r){r.registerComponentModel(Ef),r.registerComponentView(O_),r.registerProcessor(r.PRIORITY.PROCESSOR.SERIES_FILTER,oP),r.registerSubTypeDefaulter("legend",function(){return"plain"}),sP(r)}var lP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.prototype.setScrollDataIndex=function(e){this.option.scrollDataIndex=e},t.prototype.init=function(e,i,n){var a=Pa(e);r.prototype.init.call(this,e,i,n),Jp(this,e,a)},t.prototype.mergeOption=function(e,i){r.prototype.mergeOption.call(this,e,i),Jp(this,this.option,e)},t.type="legend.scroll",t.defaultOption=Bs(Ef.defaultOption,{scrollDataIndex:0,pageButtonItemGap:5,pageButtonGap:null,pageButtonPosition:"end",pageFormatter:"{current}/{total}",pageIcons:{horizontal:["M0,0L12,-10L12,10z","M0,0L-12,-10L-12,10z"],vertical:["M0,0L20,0L10,-20z","M0,0L20,0L10,20z"]},pageIconColor:"#2f4554",pageIconInactiveColor:"#aaa",pageIconSize:15,pageTextStyle:{color:"#333"},animationDurationUpdate:800}),t}(Ef);function Jp(r,t,e){var i=r.getOrient(),n=[1,1];n[i.index]=0,ci(t,e,{type:"box",ignoreSize:!!n})}const uP=lP;var jp=xt,bu=["width","height"],Tu=["x","y"],fP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e.newlineDisabled=!0,e._currentIndex=0,e}return t.prototype.init=function(){r.prototype.init.call(this),this.group.add(this._containerGroup=new jp),this._containerGroup.add(this.getContentGroup()),this.group.add(this._controllerGroup=new jp)},t.prototype.resetInner=function(){r.prototype.resetInner.call(this),this._controllerGroup.removeAll(),this._containerGroup.removeClipPath(),this._containerGroup.__rectSize=null},t.prototype.renderInner=function(e,i,n,a,o,s,l){var u=this;r.prototype.renderInner.call(this,e,i,n,a,o,s,l);var f=this._controllerGroup,h=i.get("pageIconSize",!0),c=V(h)?h:[h,h];d("pagePrev",0);var v=i.getModel("pageTextStyle");f.add(new Dt({name:"pageText",style:{text:"xx/xx",fill:v.getTextColor(),font:v.getFont(),verticalAlign:"middle",align:"center"},silent:!0})),d("pageNext",1);function d(p,g){var y=p+"DataIndex",m=vh(i.get("pageIcons",!0)[i.getOrient().name][g],{onclick:$(u._pageGo,u,y,i,a)},{x:-c[0]/2,y:-c[1]/2,width:c[0],height:c[1]});m.name=p,f.add(m)}},t.prototype.layoutInner=function(e,i,n,a,o,s){var l=this.getSelectorGroup(),u=e.getOrient().index,f=bu[u],h=Tu[u],c=bu[1-u],v=Tu[1-u];o&&oa("horizontal",l,e.get("selectorItemGap",!0));var d=e.get("selectorButtonGap",!0),p=l.getBoundingRect(),g=[-p.x,-p.y],y=et(n);o&&(y[f]=n[f]-p[f]-d);var m=this._layoutContentAndController(e,a,y,u,f,c,v,h);if(o){if(s==="end")g[u]+=m[f]+d;else{var _=p[f]+d;g[u]-=_,m[h]-=_}m[f]+=p[f]+d,g[1-u]+=m[v]+m[c]/2-p[c]/2,m[c]=Math.max(m[c],p[c]),m[v]=Math.min(m[v],p[v]+g[1-u]),l.x=g[0],l.y=g[1],l.markRedraw()}return m},t.prototype._layoutContentAndController=function(e,i,n,a,o,s,l,u){var f=this.getContentGroup(),h=this._containerGroup,c=this._controllerGroup;oa(e.get("orient"),f,e.get("itemGap"),a?n.width:null,a?null:n.height),oa("horizontal",c,e.get("pageButtonItemGap",!0));var v=f.getBoundingRect(),d=c.getBoundingRect(),p=this._showController=v[o]>n[o],g=[-v.x,-v.y];i||(g[a]=f[u]);var y=[0,0],m=[-d.x,-d.y],_=j(e.get("pageButtonGap",!0),e.get("itemGap",!0));if(p){var S=e.get("pageButtonPosition",!0);S==="end"?m[a]+=n[o]-d[o]:y[a]+=d[o]+_}m[1-a]+=v[s]/2-d[s]/2,f.setPosition(g),h.setPosition(y),c.setPosition(m);var x={x:0,y:0};if(x[o]=p?n[o]:v[o],x[s]=Math.max(v[s],d[s]),x[l]=Math.min(0,d[l]+m[1-a]),h.__rectSize=n[o],p){var w={x:0,y:0};w[o]=Math.max(n[o]-d[o]-_,0),w[s]=x[s],h.setClipPath(new _t({shape:w})),h.__rectSize=w[o]}else c.eachChild(function(T){T.attr({invisible:!0,silent:!0})});var b=this._getPageInfo(e);return b.pageIndex!=null&&Lt(f,{x:b.contentPosition[0],y:b.contentPosition[1]},p?e:null),this._updatePageInfoView(e,b),x},t.prototype._pageGo=function(e,i,n){var a=this._getPageInfo(i)[e];a!=null&&n.dispatchAction({type:"legendScroll",scrollDataIndex:a,legendId:i.id})},t.prototype._updatePageInfoView=function(e,i){var n=this._controllerGroup;A(["pagePrev","pageNext"],function(f){var h=f+"DataIndex",c=i[h]!=null,v=n.childOfName(f);v&&(v.setStyle("fill",c?e.get("pageIconColor",!0):e.get("pageIconInactiveColor",!0)),v.cursor=c?"pointer":"default")});var a=n.childOfName("pageText"),o=e.get("pageFormatter"),s=i.pageIndex,l=s!=null?s+1:0,u=i.pageCount;a&&o&&a.setStyle("text",W(o)?o.replace("{current}",l==null?"":l+"").replace("{total}",u==null?"":u+""):o({current:l,total:u}))},t.prototype._getPageInfo=function(e){var i=e.get("scrollDataIndex",!0),n=this.getContentGroup(),a=this._containerGroup.__rectSize,o=e.getOrient().index,s=bu[o],l=Tu[o],u=this._findTargetItemIndex(i),f=n.children(),h=f[u],c=f.length,v=c?1:0,d={contentPosition:[n.x,n.y],pageCount:v,pageIndex:v-1,pagePrevDataIndex:null,pageNextDataIndex:null};if(!h)return d;var p=S(h);d.contentPosition[o]=-p.s;for(var g=u+1,y=p,m=p,_=null;g<=c;++g)_=S(f[g]),(!_&&m.e>y.s+a||_&&!x(_,y.s))&&(m.i>y.i?y=m:y=_,y&&(d.pageNextDataIndex==null&&(d.pageNextDataIndex=y.i),++d.pageCount)),m=_;for(var g=u-1,y=p,m=p,_=null;g>=-1;--g)_=S(f[g]),(!_||!x(m,_.s))&&y.i<m.i&&(m=y,d.pagePrevDataIndex==null&&(d.pagePrevDataIndex=y.i),++d.pageCount,++d.pageIndex),y=_;return d;function S(w){if(w){var b=w.getBoundingRect(),T=b[l]+w[l];return{s:T,e:T+b[s],i:w.__legendDataIndex}}}function x(w,b){return w.e>=b&&w.s<=b+a}},t.prototype._findTargetItemIndex=function(e){if(!this._showController)return 0;var i,n=this.getContentGroup(),a;return n.eachChild(function(o,s){var l=o.__legendDataIndex;a==null&&l!=null&&(a=s),l===e&&(i=s)}),i!=null?i:a},t.type="legend.scroll",t}(O_);const hP=fP;function vP(r){r.registerAction("legendScroll","legendscroll",function(t,e){var i=t.scrollDataIndex;i!=null&&e.eachComponent({mainType:"legend",subType:"scroll",query:t},function(n){n.setScrollDataIndex(i)})})}function cP(r){Ge(B_),r.registerComponentModel(uP),r.registerComponentView(hP),vP(r)}function hR(r){Ge(B_),Ge(cP)}var dP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.inside",t.defaultOption=Bs(_s.defaultOption,{disabled:!1,zoomLock:!1,zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!1,preventDefaultMouseMove:!0}),t}(_s);const pP=dP;var Xh=gt();function gP(r,t,e){Xh(r).coordSysRecordMap.each(function(i){var n=i.dataZoomInfoMap.get(t.uid);n&&(n.getRange=e)})}function yP(r,t){for(var e=Xh(r).coordSysRecordMap,i=e.keys(),n=0;n<i.length;n++){var a=i[n],o=e.get(a),s=o.dataZoomInfoMap;if(s){var l=t.uid,u=s.get(l);u&&(s.removeKey(l),s.keys().length||N_(e,o))}}}function N_(r,t){if(t){r.removeKey(t.model.uid);var e=t.controller;e&&e.dispose()}}function mP(r,t){var e={model:t,containsPoint:yt(SP,t),dispatchAction:yt(_P,r),dataZoomInfoMap:null,controller:null},i=e.controller=new TI(r.getZr());return A(["pan","zoom","scrollMove"],function(n){i.on(n,function(a){var o=[];e.dataZoomInfoMap.each(function(s){if(!!a.isAvailableBehavior(s.model.option)){var l=(s.getRange||{})[n],u=l&&l(s.dzReferCoordSysInfo,e.model.mainType,e.controller,a);!s.model.get("disabled",!0)&&u&&o.push({dataZoomId:s.model.id,start:u[0],end:u[1]})}}),o.length&&e.dispatchAction(o)})}),e}function _P(r,t){r.isDisposed()||r.dispatchAction({type:"dataZoom",animation:{easing:"cubicOut",duration:100},batch:t})}function SP(r,t,e,i){return r.coordinateSystem.containPoint([e,i])}function wP(r){var t,e="type_",i={type_true:2,type_move:1,type_false:0,type_undefined:-1},n=!0;return r.each(function(a){var o=a.model,s=o.get("disabled",!0)?!1:o.get("zoomLock",!0)?"move":!0;i[e+s]>i[e+t]&&(t=s),n=n&&o.get("preventDefaultMouseMove",!0)}),{controlType:t,opt:{zoomOnMouseWheel:!0,moveOnMouseMove:!0,moveOnMouseWheel:!0,preventDefaultMouseMove:!!n}}}function xP(r){r.registerProcessor(r.PRIORITY.PROCESSOR.FILTER,function(t,e){var i=Xh(e),n=i.coordSysRecordMap||(i.coordSysRecordMap=Z());n.each(function(a){a.dataZoomInfoMap=null}),t.eachComponent({mainType:"dataZoom",subType:"inside"},function(a){var o=A_(a);A(o.infoList,function(s){var l=s.model.uid,u=n.get(l)||n.set(l,mP(e,s.model)),f=u.dataZoomInfoMap||(u.dataZoomInfoMap=Z());f.set(a.uid,{dzReferCoordSysInfo:s,model:a,getRange:null})})}),n.each(function(a){var o=a.controller,s,l=a.dataZoomInfoMap;if(l){var u=l.keys()[0];u!=null&&(s=l.get(u))}if(!s){N_(n,a);return}var f=wP(l);o.enable(f.controlType,f.opt),o.setPointerChecker(a.containsPoint),Zs(a,"dispatchAction",s.model.get("throttle",!0),"fixRate")})})}var bP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type="dataZoom.inside",e}return t.prototype.render=function(e,i,n){if(r.prototype.render.apply(this,arguments),e.noTarget()){this._clear();return}this.range=e.getPercentRange(),gP(n,e,{pan:$(Cu.pan,this),zoom:$(Cu.zoom,this),scrollMove:$(Cu.scrollMove,this)})},t.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){yP(this.api,this.dataZoomModel),this.range=null},t.type="dataZoom.inside",t}(D_),Cu={zoom:function(r,t,e,i){var n=this.range,a=n.slice(),o=r.axisModels[0];if(!!o){var s=Mu[t](null,[i.originX,i.originY],o,e,r),l=(s.signal>0?s.pixelStart+s.pixelLength-s.pixel:s.pixel-s.pixelStart)/s.pixelLength*(a[1]-a[0])+a[0],u=Math.max(1/i.scale,0);a[0]=(a[0]-l)*u+l,a[1]=(a[1]-l)*u+l;var f=this.dataZoomModel.findRepresentativeAxisProxy().getMinMaxSpan();if(Js(0,a,[0,100],0,f.minSpan,f.maxSpan),this.range=a,n[0]!==a[0]||n[1]!==a[1])return a}},pan:tg(function(r,t,e,i,n,a){var o=Mu[i]([a.oldX,a.oldY],[a.newX,a.newY],t,n,e);return o.signal*(r[1]-r[0])*o.pixel/o.pixelLength}),scrollMove:tg(function(r,t,e,i,n,a){var o=Mu[i]([0,0],[a.scrollDelta,a.scrollDelta],t,n,e);return o.signal*(r[1]-r[0])*a.scrollDelta})};function tg(r){return function(t,e,i,n){var a=this.range,o=a.slice(),s=t.axisModels[0];if(!!s){var l=r(o,s,t,e,i,n);if(Js(l,o,[0,100],"all"),this.range=o,a[0]!==o[0]||a[1]!==o[1])return o}}}var Mu={grid:function(r,t,e,i,n){var a=e.axis,o={},s=n.model.coordinateSystem.getRect();return r=r||[0,0],a.dim==="x"?(o.pixel=t[0]-r[0],o.pixelLength=s.width,o.pixelStart=s.x,o.signal=a.inverse?1:-1):(o.pixel=t[1]-r[1],o.pixelLength=s.height,o.pixelStart=s.y,o.signal=a.inverse?-1:1),o},polar:function(r,t,e,i,n){var a=e.axis,o={},s=n.model.coordinateSystem,l=s.getRadiusAxis().getExtent(),u=s.getAngleAxis().getExtent();return r=r?s.pointToCoord(r):[0,0],t=s.pointToCoord(t),e.mainType==="radiusAxis"?(o.pixel=t[0]-r[0],o.pixelLength=l[1]-l[0],o.pixelStart=l[0],o.signal=a.inverse?1:-1):(o.pixel=t[1]-r[1],o.pixelLength=u[1]-u[0],o.pixelStart=u[0],o.signal=a.inverse?-1:1),o},singleAxis:function(r,t,e,i,n){var a=e.axis,o=n.model.coordinateSystem.getRect(),s={};return r=r||[0,0],a.orient==="horizontal"?(s.pixel=t[0]-r[0],s.pixelLength=o.width,s.pixelStart=o.x,s.signal=a.inverse?1:-1):(s.pixel=t[1]-r[1],s.pixelLength=o.height,s.pixelStart=o.y,s.signal=a.inverse?-1:1),s}};const TP=bP;function CP(r){L_(r),r.registerComponentModel(pP),r.registerComponentView(TP),xP(r)}var MP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e}return t.type="dataZoom.slider",t.layoutMode="box",t.defaultOption=Bs(_s.defaultOption,{show:!0,right:"ph",top:"ph",width:"ph",height:"ph",left:null,bottom:null,borderColor:"#d2dbee",borderRadius:3,backgroundColor:"rgba(47,69,84,0)",dataBackground:{lineStyle:{color:"#d2dbee",width:.5},areaStyle:{color:"#d2dbee",opacity:.2}},selectedDataBackground:{lineStyle:{color:"#8fb0f7",width:.5},areaStyle:{color:"#8fb0f7",opacity:.2}},fillerColor:"rgba(135,175,274,0.2)",handleIcon:"path://M-9.35,34.56V42m0-40V9.5m-2,0h4a2,2,0,0,1,2,2v21a2,2,0,0,1-2,2h-4a2,2,0,0,1-2-2v-21A2,2,0,0,1-11.35,9.5Z",handleSize:"100%",handleStyle:{color:"#fff",borderColor:"#ACB8D1"},moveHandleSize:7,moveHandleIcon:"path://M-320.9-50L-320.9-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-348-41-339-50-320.9-50z M-212.3-50L-212.3-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-239.4-41-230.4-50-212.3-50z M-103.7-50L-103.7-50c18.1,0,27.1,9,27.1,27.1V85.7c0,18.1-9,27.1-27.1,27.1l0,0c-18.1,0-27.1-9-27.1-27.1V-22.9C-130.9-41-121.8-50-103.7-50z",moveHandleStyle:{color:"#D2DBEE",opacity:.7},showDetail:!0,showDataShadow:"auto",realtime:!0,zoomLock:!1,textStyle:{color:"#6E7079"},brushSelect:!0,brushStyle:{color:"rgba(135,175,274,0.15)"},emphasis:{handleLabel:{show:!0},handleStyle:{borderColor:"#8FB0F7"},moveHandleStyle:{color:"#8FB0F7"}}}),t}(_s);const AP=MP;var Nn=_t,eg=7,DP=1,Au=30,LP=7,zn="horizontal",rg="vertical",IP=5,PP=["line","bar","candlestick","scatter"],RP={easing:"cubicOut",duration:100,delay:0},EP=function(r){N(t,r);function t(){var e=r!==null&&r.apply(this,arguments)||this;return e.type=t.type,e._displayables={},e}return t.prototype.init=function(e,i){this.api=i,this._onBrush=$(this._onBrush,this),this._onBrushEnd=$(this._onBrushEnd,this)},t.prototype.render=function(e,i,n,a){if(r.prototype.render.apply(this,arguments),Zs(this,"_dispatchZoomAction",e.get("throttle"),"fixRate"),this._orient=e.getOrient(),e.get("show")===!1){this.group.removeAll();return}if(e.noTarget()){this._clear(),this.group.removeAll();return}(!a||a.type!=="dataZoom"||a.from!==this.uid)&&this._buildView(),this._updateView()},t.prototype.dispose=function(){this._clear(),r.prototype.dispose.apply(this,arguments)},t.prototype._clear=function(){fs(this,"_dispatchZoomAction");var e=this.api.getZr();e.off("mousemove",this._onBrush),e.off("mouseup",this._onBrushEnd)},t.prototype._buildView=function(){var e=this.group;e.removeAll(),this._brushing=!1,this._displayables.brushRect=null,this._resetLocation(),this._resetInterval();var i=this._displayables.sliderGroup=new xt;this._renderBackground(),this._renderHandle(),this._renderDataShadow(),e.add(i),this._positionGroup()},t.prototype._resetLocation=function(){var e=this.dataZoomModel,i=this.api,n=e.get("brushSelect"),a=n?LP:0,o=this._findCoordRect(),s={width:i.getWidth(),height:i.getHeight()},l=this._orient===zn?{right:s.width-o.x-o.width,top:s.height-Au-eg-a,width:o.width,height:Au}:{right:eg,top:o.y,width:Au,height:o.height},u=Pa(e.option);A(["right","top","width","height"],function(h){u[h]==="ph"&&(u[h]=l[h])});var f=vi(u,s);this._location={x:f.x,y:f.y},this._size=[f.width,f.height],this._orient===rg&&this._size.reverse()},t.prototype._positionGroup=function(){var e=this.group,i=this._location,n=this._orient,a=this.dataZoomModel.getFirstTargetAxisModel(),o=a&&a.get("inverse"),s=this._displayables.sliderGroup,l=(this._dataShadowInfo||{}).otherAxisInverse;s.attr(n===zn&&!o?{scaleY:l?1:-1,scaleX:1}:n===zn&&o?{scaleY:l?1:-1,scaleX:-1}:n===rg&&!o?{scaleY:l?-1:1,scaleX:1,rotation:Math.PI/2}:{scaleY:l?-1:1,scaleX:-1,rotation:Math.PI/2});var u=e.getBoundingRect([s]);e.x=i.x-u.x,e.y=i.y-u.y,e.markRedraw()},t.prototype._getViewExtent=function(){return[0,this._size[0]]},t.prototype._renderBackground=function(){var e=this.dataZoomModel,i=this._size,n=this._displayables.sliderGroup,a=e.get("brushSelect");n.add(new Nn({silent:!0,shape:{x:0,y:0,width:i[0],height:i[1]},style:{fill:e.get("backgroundColor")},z2:-40}));var o=new Nn({shape:{x:0,y:0,width:i[0],height:i[1]},style:{fill:"transparent"},z2:0,onclick:$(this._onClickPanel,this)}),s=this.api.getZr();a?(o.on("mousedown",this._onBrushStart,this),o.cursor="crosshair",s.on("mousemove",this._onBrush),s.on("mouseup",this._onBrushEnd)):(s.off("mousemove",this._onBrush),s.off("mouseup",this._onBrushEnd)),n.add(o)},t.prototype._renderDataShadow=function(){var e=this._dataShadowInfo=this._prepareDataShadowInfo();if(this._displayables.dataShadowSegs=[],!e)return;var i=this._size,n=this._shadowSize||[],a=e.series,o=a.getRawData(),s=a.getShadowDim&&a.getShadowDim(),l=s&&o.getDimensionInfo(s)?a.getShadowDim():e.otherDim;if(l==null)return;var u=this._shadowPolygonPts,f=this._shadowPolylinePts;if(o!==this._shadowData||l!==this._shadowDim||i[0]!==n[0]||i[1]!==n[1]){var h=o.getDataExtent(l),c=(h[1]-h[0])*.3;h=[h[0]-c,h[1]+c];var v=[0,i[1]],d=[0,i[0]],p=[[i[0],0],[0,0]],g=[],y=d[1]/(o.count()-1),m=0,_=Math.round(o.count()/i[0]),S;o.each([l],function(M,D){if(_>0&&D%_){m+=y;return}var C=M==null||isNaN(M)||M==="",L=C?0:Rt(M,h,v,!0);C&&!S&&D?(p.push([p[p.length-1][0],0]),g.push([g[g.length-1][0],0])):!C&&S&&(p.push([m,0]),g.push([m,0])),p.push([m,L]),g.push([m,L]),m+=y,S=C}),u=this._shadowPolygonPts=p,f=this._shadowPolylinePts=g}this._shadowData=o,this._shadowDim=l,this._shadowSize=[i[0],i[1]];var x=this.dataZoomModel;function w(M){var D=x.getModel(M?"selectedDataBackground":"dataBackground"),C=new xt,L=new La({shape:{points:u},segmentIgnoreThreshold:1,style:D.getModel("areaStyle").getAreaStyle(),silent:!0,z2:-20}),I=new _i({shape:{points:f},segmentIgnoreThreshold:1,style:D.getModel("lineStyle").getLineStyle(),silent:!0,z2:-19});return C.add(L),C.add(I),C}for(var b=0;b<3;b++){var T=w(b===1);this._displayables.sliderGroup.add(T),this._displayables.dataShadowSegs.push(T)}},t.prototype._prepareDataShadowInfo=function(){var e=this.dataZoomModel,i=e.get("showDataShadow");if(i!==!1){var n,a=this.ecModel;return e.eachTargetAxis(function(o,s){var l=e.getAxisProxy(o,s).getTargetSeriesModels();A(l,function(u){if(!n&&!(i!==!0&&at(PP,u.get("type"))<0)){var f=a.getComponent(Tr(o),s).axis,h=kP(o),c,v=u.coordinateSystem;h!=null&&v.getOtherAxis&&(c=v.getOtherAxis(f).inverse),h=u.getData().mapDimension(h),n={thisAxis:f,series:u,thisDim:o,otherDim:h,otherAxisInverse:c}}},this)},this),n}},t.prototype._renderHandle=function(){var e=this.group,i=this._displayables,n=i.handles=[null,null],a=i.handleLabels=[null,null],o=this._displayables.sliderGroup,s=this._size,l=this.dataZoomModel,u=this.api,f=l.get("borderRadius")||0,h=l.get("brushSelect"),c=i.filler=new Nn({silent:h,style:{fill:l.get("fillerColor")},textConfig:{position:"inside"}});o.add(c),o.add(new Nn({silent:!0,subPixelOptimize:!0,shape:{x:0,y:0,width:s[0],height:s[1],r:f},style:{stroke:l.get("dataBackgroundColor")||l.get("borderColor"),lineWidth:DP,fill:"rgba(0,0,0,0)"}})),A([0,1],function(_){var S=l.get("handleIcon");!vs[S]&&S.indexOf("path://")<0&&S.indexOf("image://")<0&&(S="path://"+S);var x=ir(S,-1,0,2,2,null,!0);x.attr({cursor:ig(this._orient),draggable:!0,drift:$(this._onDragMove,this,_),ondragend:$(this._onDragEnd,this),onmouseover:$(this._showDataInfo,this,!0),onmouseout:$(this._showDataInfo,this,!1),z2:5});var w=x.getBoundingRect(),b=l.get("handleSize");this._handleHeight=st(b,this._size[1]),this._handleWidth=w.width/w.height*this._handleHeight,x.setStyle(l.getModel("handleStyle").getItemStyle()),x.style.strokeNoScale=!0,x.rectHover=!0,x.ensureState("emphasis").style=l.getModel(["emphasis","handleStyle"]).getItemStyle(),rs(x);var T=l.get("handleColor");T!=null&&(x.style.fill=T),o.add(n[_]=x);var M=l.getModel("textStyle"),D=l.get("handleLabel")||{},C=D.show||!1;e.add(a[_]=new Dt({silent:!0,invisible:!C,style:fi(M,{x:0,y:0,text:"",verticalAlign:"middle",align:"center",fill:M.getTextColor(),font:M.getFont()}),z2:10}))},this);var v=c;if(h){var d=st(l.get("moveHandleSize"),s[1]),p=i.moveHandle=new _t({style:l.getModel("moveHandleStyle").getItemStyle(),silent:!0,shape:{r:[0,0,2,2],y:s[1]-.5,height:d}}),g=d*.8,y=i.moveHandleIcon=ir(l.get("moveHandleIcon"),-g/2,-g/2,g,g,"#fff",!0);y.silent=!0,y.y=s[1]+d/2-.5,p.ensureState("emphasis").style=l.getModel(["emphasis","moveHandleStyle"]).getItemStyle();var m=Math.min(s[1]/2,Math.max(d,10));v=i.moveZone=new _t({invisible:!0,shape:{y:s[1]-m,height:d+m}}),v.on("mouseover",function(){u.enterEmphasis(p)}).on("mouseout",function(){u.leaveEmphasis(p)}),o.add(p),o.add(y),o.add(v)}v.attr({draggable:!0,cursor:ig(this._orient),drift:$(this._onDragMove,this,"all"),ondragstart:$(this._showDataInfo,this,!0),ondragend:$(this._onDragEnd,this),onmouseover:$(this._showDataInfo,this,!0),onmouseout:$(this._showDataInfo,this,!1)})},t.prototype._resetInterval=function(){var e=this._range=this.dataZoomModel.getPercentRange(),i=this._getViewExtent();this._handleEnds=[Rt(e[0],[0,100],i,!0),Rt(e[1],[0,100],i,!0)]},t.prototype._updateInterval=function(e,i){var n=this.dataZoomModel,a=this._handleEnds,o=this._getViewExtent(),s=n.findRepresentativeAxisProxy().getMinMaxSpan(),l=[0,100];Js(i,a,o,n.get("zoomLock")?"all":e,s.minSpan!=null?Rt(s.minSpan,l,o,!0):null,s.maxSpan!=null?Rt(s.maxSpan,l,o,!0):null);var u=this._range,f=this._range=Un([Rt(a[0],o,l,!0),Rt(a[1],o,l,!0)]);return!u||u[0]!==f[0]||u[1]!==f[1]},t.prototype._updateView=function(e){var i=this._displayables,n=this._handleEnds,a=Un(n.slice()),o=this._size;A([0,1],function(v){var d=i.handles[v],p=this._handleHeight;d.attr({scaleX:p/2,scaleY:p/2,x:n[v]+(v?-1:1),y:o[1]/2-p/2})},this),i.filler.setShape({x:a[0],y:0,width:a[1]-a[0],height:o[1]});var s={x:a[0],width:a[1]-a[0]};i.moveHandle&&(i.moveHandle.setShape(s),i.moveZone.setShape(s),i.moveZone.getBoundingRect(),i.moveHandleIcon&&i.moveHandleIcon.attr("x",s.x+s.width/2));for(var l=i.dataShadowSegs,u=[0,a[0],a[1],o[0]],f=0;f<l.length;f++){var h=l[f],c=h.getClipPath();c||(c=new _t,h.setClipPath(c)),c.setShape({x:u[f],y:0,width:u[f+1]-u[f],height:o[1]})}this._updateDataInfo(e)},t.prototype._updateDataInfo=function(e){var i=this.dataZoomModel,n=this._displayables,a=n.handleLabels,o=this._orient,s=["",""];if(i.get("showDetail")){var l=i.findRepresentativeAxisProxy();if(l){var u=l.getAxisModel().axis,f=this._range,h=e?l.calculateDataWindow({start:f[0],end:f[1]}).valueWindow:l.getDataValueWindow();s=[this._formatLabel(h[0],u),this._formatLabel(h[1],u)]}}var c=Un(this._handleEnds.slice());v.call(this,0),v.call(this,1);function v(d){var p=zy(n.handles[d].parent,this.group),g=Fy(d===0?"right":"left",p),y=this._handleWidth/2+IP,m=ya([c[d]+(d===0?-y:y),this._size[1]/2],p);a[d].setStyle({x:m[0],y:m[1],verticalAlign:o===zn?"middle":g,align:o===zn?g:"center",text:s[d]})}},t.prototype._formatLabel=function(e,i){var n=this.dataZoomModel,a=n.get("labelFormatter"),o=n.get("labelPrecision");(o==null||o==="auto")&&(o=i.getPixelPrecision());var s=e==null||isNaN(e)?"":i.type==="category"||i.type==="time"?i.scale.getLabel({value:Math.round(e)}):e.toFixed(Math.min(o,20));return K(a)?a(e,s):W(a)?a.replace("{value}",s):s},t.prototype._showDataInfo=function(e){var i=this.dataZoomModel.get("handleLabel")||{},n=i.show||!1,a=this.dataZoomModel.getModel(["emphasis","handleLabel"]),o=a.get("show")||!1,s=e||this._dragging?o:n,l=this._displayables,u=l.handleLabels;u[0].attr("invisible",!s),u[1].attr("invisible",!s),l.moveHandle&&this.api[s?"enterEmphasis":"leaveEmphasis"](l.moveHandle,1)},t.prototype._onDragMove=function(e,i,n,a){this._dragging=!0,en(a.event);var o=this._displayables.sliderGroup.getLocalTransform(),s=ya([i,n],o,!0),l=this._updateInterval(e,s[0]),u=this.dataZoomModel.get("realtime");this._updateView(!u),l&&u&&this._dispatchZoomAction(!0)},t.prototype._onDragEnd=function(){this._dragging=!1,this._showDataInfo(!1);var e=this.dataZoomModel.get("realtime");!e&&this._dispatchZoomAction(!1)},t.prototype._onClickPanel=function(e){var i=this._size,n=this._displayables.sliderGroup.transformCoordToLocal(e.offsetX,e.offsetY);if(!(n[0]<0||n[0]>i[0]||n[1]<0||n[1]>i[1])){var a=this._handleEnds,o=(a[0]+a[1])/2,s=this._updateInterval("all",n[0]-o);this._updateView(),s&&this._dispatchZoomAction(!1)}},t.prototype._onBrushStart=function(e){var i=e.offsetX,n=e.offsetY;this._brushStart=new q(i,n),this._brushing=!0,this._brushStartTime=+new Date},t.prototype._onBrushEnd=function(e){if(!!this._brushing){var i=this._displayables.brushRect;if(this._brushing=!1,!!i){i.attr("ignore",!0);var n=i.shape,a=+new Date;if(!(a-this._brushStartTime<200&&Math.abs(n.width)<5)){var o=this._getViewExtent(),s=[0,100];this._range=Un([Rt(n.x,o,s,!0),Rt(n.x+n.width,o,s,!0)]),this._handleEnds=[n.x,n.x+n.width],this._updateView(),this._dispatchZoomAction(!1)}}}},t.prototype._onBrush=function(e){this._brushing&&(en(e.event),this._updateBrushRect(e.offsetX,e.offsetY))},t.prototype._updateBrushRect=function(e,i){var n=this._displayables,a=this.dataZoomModel,o=n.brushRect;o||(o=n.brushRect=new Nn({silent:!0,style:a.getModel("brushStyle").getItemStyle()}),n.sliderGroup.add(o)),o.attr("ignore",!1);var s=this._brushStart,l=this._displayables.sliderGroup,u=l.transformCoordToLocal(e,i),f=l.transformCoordToLocal(s.x,s.y),h=this._size;u[0]=Math.max(Math.min(h[0],u[0]),0),o.setShape({x:f[0],y:0,width:u[0]-f[0],height:h[1]})},t.prototype._dispatchZoomAction=function(e){var i=this._range;this.api.dispatchAction({type:"dataZoom",from:this.uid,dataZoomId:this.dataZoomModel.id,animation:e?RP:null,start:i[0],end:i[1]})},t.prototype._findCoordRect=function(){var e,i=A_(this.dataZoomModel).infoList;if(!e&&i.length){var n=i[0].model.coordinateSystem;e=n.getRect&&n.getRect()}if(!e){var a=this.api.getWidth(),o=this.api.getHeight();e={x:a*.2,y:o*.2,width:a*.6,height:o*.6}}return e},t.type="dataZoom.slider",t}(D_);function kP(r){var t={x:"y",y:"x",radius:"angle",angle:"radius"};return t[r]}function ig(r){return r==="vertical"?"ns-resize":"ew-resize"}const OP=EP;function BP(r){r.registerComponentModel(AP),r.registerComponentView(OP),L_(r)}function vR(r){Ge(CP),Ge(BP)}var Du=null;function NP(r){return Du||(Du=(window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||function(t){return setTimeout(t,16)}).bind(window)),Du(r)}var Lu=null;function zP(r){Lu||(Lu=(window.cancelAnimationFrame||window.webkitCancelAnimationFrame||window.mozCancelAnimationFrame||function(t){clearTimeout(t)}).bind(window)),Lu(r)}function FP(r){var t=document.createElement("style");return t.styleSheet?t.styleSheet.cssText=r:t.appendChild(document.createTextNode(r)),(document.querySelector("head")||document.body).appendChild(t),t}function Co(r,t){t===void 0&&(t={});var e=document.createElement(r);return Object.keys(t).forEach(function(i){e[i]=t[i]}),e}function z_(r,t,e){var i=window.getComputedStyle(r,e||null)||{display:"none"};return i[t]}function Nf(r){if(!document.documentElement.contains(r))return{detached:!0,rendered:!1};for(var t=r;t!==document;){if(z_(t,"display")==="none")return{detached:!1,rendered:!1};t=t.parentNode}return{detached:!1,rendered:!0}}var VP='.resize-triggers{visibility:hidden;opacity:0;pointer-events:none}.resize-contract-trigger,.resize-contract-trigger:before,.resize-expand-trigger,.resize-triggers{content:"";position:absolute;top:0;left:0;height:100%;width:100%;overflow:hidden}.resize-contract-trigger,.resize-expand-trigger{background:#eee;overflow:auto}.resize-contract-trigger:before{width:200%;height:200%}',zf=0,Go=null;function HP(r,t){r.__resize_mutation_handler__||(r.__resize_mutation_handler__=UP.bind(r));var e=r.__resize_listeners__;if(!e){if(r.__resize_listeners__=[],window.ResizeObserver){var i=r.offsetWidth,n=r.offsetHeight,a=new ResizeObserver(function(){!r.__resize_observer_triggered__&&(r.__resize_observer_triggered__=!0,r.offsetWidth===i&&r.offsetHeight===n)||Ss(r)}),o=Nf(r),s=o.detached,l=o.rendered;r.__resize_observer_triggered__=s===!1&&l===!1,r.__resize_observer__=a,a.observe(r)}else if(r.attachEvent&&r.addEventListener)r.__resize_legacy_resize_handler__=function(){Ss(r)},r.attachEvent("onresize",r.__resize_legacy_resize_handler__),document.addEventListener("DOMSubtreeModified",r.__resize_mutation_handler__);else if(zf||(Go=FP(VP)),YP(r),r.__resize_rendered__=Nf(r).rendered,window.MutationObserver){var u=new MutationObserver(r.__resize_mutation_handler__);u.observe(document,{attributes:!0,childList:!0,characterData:!0,subtree:!0}),r.__resize_mutation_observer__=u}}r.__resize_listeners__.push(t),zf++}function GP(r,t){var e=r.__resize_listeners__;if(!!e){if(t&&e.splice(e.indexOf(t),1),!e.length||!t){if(r.detachEvent&&r.removeEventListener){r.detachEvent("onresize",r.__resize_legacy_resize_handler__),document.removeEventListener("DOMSubtreeModified",r.__resize_mutation_handler__);return}r.__resize_observer__?(r.__resize_observer__.unobserve(r),r.__resize_observer__.disconnect(),r.__resize_observer__=null):(r.__resize_mutation_observer__&&(r.__resize_mutation_observer__.disconnect(),r.__resize_mutation_observer__=null),r.removeEventListener("scroll",qh),r.removeChild(r.__resize_triggers__.triggers),r.__resize_triggers__=null),r.__resize_listeners__=null}!--zf&&Go&&Go.parentNode.removeChild(Go)}}function WP(r){var t=r.__resize_last__,e=t.width,i=t.height,n=r.offsetWidth,a=r.offsetHeight;return n!==e||a!==i?{width:n,height:a}:null}function UP(){var r=Nf(this),t=r.rendered,e=r.detached;t!==this.__resize_rendered__&&(!e&&this.__resize_triggers__&&(Kh(this),this.addEventListener("scroll",qh,!0)),this.__resize_rendered__=t,Ss(this))}function qh(){var r=this;Kh(this),this.__resize_raf__&&zP(this.__resize_raf__),this.__resize_raf__=NP(function(){var t=WP(r);t&&(r.__resize_last__=t,Ss(r))})}function Ss(r){!r||!r.__resize_listeners__||r.__resize_listeners__.forEach(function(t){t.call(r,r)})}function YP(r){var t=z_(r,"position");(!t||t==="static")&&(r.style.position="relative"),r.__resize_old_position__=t,r.__resize_last__={};var e=Co("div",{className:"resize-triggers"}),i=Co("div",{className:"resize-expand-trigger"}),n=Co("div"),a=Co("div",{className:"resize-contract-trigger"});i.appendChild(n),e.appendChild(i),e.appendChild(a),r.appendChild(e),r.__resize_triggers__={triggers:e,expand:i,expandChild:n,contract:a},Kh(r),r.addEventListener("scroll",qh,!0),r.__resize_last__={width:r.offsetWidth,height:r.offsetHeight}}function Kh(r){var t=r.__resize_triggers__,e=t.expand,i=t.expandChild,n=t.contract,a=n.scrollWidth,o=n.scrollHeight,s=e.offsetWidth,l=e.offsetHeight,u=e.scrollWidth,f=e.scrollHeight;n.scrollLeft=a,n.scrollTop=o,i.style.width=s+1+"px",i.style.height=l+1+"px",e.scrollLeft=u,e.scrollTop=f}var Be=function(){return Be=Object.assign||function(r){for(var t,e=1,i=arguments.length;e<i;e++)for(var n in t=arguments[e])Object.prototype.hasOwnProperty.call(t,n)&&(r[n]=t[n]);return r},Be.apply(this,arguments)};var $P=["getWidth","getHeight","getDom","getOption","resize","dispatchAction","convertToPixel","convertFromPixel","containPixel","getDataURL","getConnectedDataURL","appendData","clear","isDisposed","dispose"];function ZP(r){return t=Object.create(null),$P.forEach(function(e){t[e]=function(i){return function(){for(var n=[],a=0;a<arguments.length;a++)n[a]=arguments[a];if(!r.value)throw new Error("ECharts is not initialized yet.");return r.value[i].apply(r.value,n)}}(e)}),t;var t}var XP={autoresize:[Boolean,Object]},qP=/^on[^a-z]/,ng=function(r){return qP.test(r)};function Mo(r,t){var e=X_(r)?q_(r):r;return e&&typeof e=="object"&&"value"in e?e.value||t:e||t}var KP="ecLoadingOptions",QP={loading:Boolean,loadingOptions:Object},Fn=null,F_="x-vue-echarts",ag=[],Vn=[];(function(r,t){if(r&&typeof document<"u"){var e,i=t.prepend===!0?"prepend":"append",n=t.singleTag===!0,a=typeof t.container=="string"?document.querySelector(t.container):document.getElementsByTagName("head")[0];if(n){var o=ag.indexOf(a);o===-1&&(o=ag.push(a)-1,Vn[o]={}),e=Vn[o]&&Vn[o][i]?Vn[o][i]:Vn[o][i]=s()}else e=s();r.charCodeAt(0)===65279&&(r=r.substring(1)),e.styleSheet?e.styleSheet.cssText+=r:e.appendChild(document.createTextNode(r))}function s(){var l=document.createElement("style");if(l.setAttribute("type","text/css"),t.attributes)for(var u=Object.keys(t.attributes),f=0;f<u.length;f++)l.setAttribute(u[f],t.attributes[u[f]]);var h=i==="prepend"?"afterbegin":"beforeend";return a.insertAdjacentElement(h,l),l}})(`x-vue-echarts{display:flex;flex-direction:column;width:100%;height:100%;min-width:0}
.vue-echarts-inner{flex-grow:1;min-width:0;width:auto!important;height:auto!important}
`,{});var JP=function(){if(Fn!=null)return Fn;if(typeof HTMLElement>"u"||typeof customElements>"u")return Fn=!1;try{new Function("tag",`class EChartsElement extends HTMLElement {
  __dispose = null;

  disconnectedCallback() {
    if (this.__dispose) {
      this.__dispose();
      this.__dispose = null;
    }
  }
}

if (customElements.get(tag) == null) {
  customElements.define(tag, EChartsElement);
}
`)(F_)}catch{return Fn=!1}return Fn=!0}(),jP="ecTheme",tR="ecInitOptions",eR="ecUpdateOptions",og=/(^&?~?!?)native:/,cR=G_({name:"echarts",props:Be(Be({option:Object,theme:{type:[Object,String]},initOptions:Object,updateOptions:Object,group:String,manualUpdate:Boolean},XP),QP),emits:{},inheritAttrs:!1,setup:function(r,t){var e=t.attrs,i=Ra(),n=Ra(),a=Ra(),o=Ra(),s=Ea(jP,null),l=Ea(tR,null),u=Ea(eR,null),f=W_(r),h=f.autoresize,c=f.manualUpdate,v=f.loading,d=f.loadingOptions,p=Ti(function(){return o.value||r.option||null}),g=Ti(function(){return r.theme||Mo(s,{})}),y=Ti(function(){return r.initOptions||Mo(l,{})}),m=Ti(function(){return r.updateOptions||Mo(u,{})}),_=Ti(function(){return function(C){var L={};for(var I in C)ng(I)||(L[I]=C[I]);return L}(e)}),S={},x=U_().proxy.$listeners,w={};function b(C){if(n.value){var L=a.value=OM(n.value,g.value,y.value);r.group&&(L.group=r.group),Object.keys(w).forEach(function(P){var R=w[P];if(R){var E=P.toLowerCase();E.charAt(0)==="~"&&(E=E.substring(1),R.__once__=!0);var z=L;if(E.indexOf("zr:")===0&&(z=L.getZr(),E=E.substring(3)),R.__once__){delete R.__once__;var k=R;R=function(){for(var B=[],F=0;F<arguments.length;F++)B[F]=arguments[F];k.apply(void 0,B),z.off(E,R)}}z.on(E,R)}}),h.value?Z_(function(){L&&!L.isDisposed()&&L.resize(),I()}):I()}function I(){var P=C||p.value;P&&L.setOption(P,m.value)}}function T(){a.value&&(a.value.dispose(),a.value=void 0)}x?Object.keys(x).forEach(function(C){og.test(C)?S[C.replace(og,"$1")]=x[C]:w[C]=x[C]}):Object.keys(e).filter(function(C){return ng(C)}).forEach(function(C){var L=C.charAt(2).toLowerCase()+C.slice(3);if(L.indexOf("native:")!==0)L.substring(L.length-4)==="Once"&&(L="~".concat(L.substring(0,L.length-4))),w[L]=e[C];else{var I="on".concat(L.charAt(7).toUpperCase()).concat(L.slice(8));S[I]=e[C]}});var M=null;ka(c,function(C){typeof M=="function"&&(M(),M=null),C||(M=ka(function(){return r.option},function(L,I){L&&(a.value?a.value.setOption(L,Be({notMerge:L!==I},m.value)):b())},{deep:!0}))},{immediate:!0}),ka([g,y],function(){T(),b()},{deep:!0}),Jh(function(){r.group&&a.value&&(a.value.group=r.group)});var D=ZP(a);return function(C,L,I){var P=Ea(KP,{}),R=Ti(function(){return Be(Be({},Mo(P,{})),I==null?void 0:I.value)});Jh(function(){var E=C.value;E&&(L.value?E.showLoading(R.value):E.hideLoading())})}(a,v,d),function(C,L,I){var P=null;ka([I,C,L],function(R,E,z){var k=R[0],B=R[1],F=R[2];if(k&&B&&F){var H=F===!0?{}:F,U=H.throttle,J=U===void 0?100:U,ot=H.onResize,ft=function(){B.resize(),ot==null||ot()};P=J?$s(ft,J):ft,HP(k,P)}z(function(){k&&P&&GP(k,P)})})}(a,h,n),Y_(function(){b()}),$_(function(){JP&&i.value?i.value.__dispose=T:T()}),Be({chart:a,root:i,inner:n,setOption:function(C,L){r.manualUpdate&&(o.value=C),a.value?a.value.setOption(C,L||{}):b(C)},nonEventAttrs:_,nativeListeners:S},D)},render:function(){var r=Be(Be({},this.nonEventAttrs),this.nativeListeners);return r.ref="root",r.class=r.class?["echarts"].concat(r.class):"echarts",jh(F_,r,[jh("div",{ref:"inner",class:"vue-echarts-inner"})])}});export{cR as H,aR as a,nR as b,oR as c,sR as d,lR as e,fR as f,hR as g,vR as h,iR as i,uR as j,Ge as u};
